@@ -34,7 +34,7 @@ if sys.version[0:3] == '2.2':
 try:
    import rlcompleter, readline
 
-   class FileNameCompleter( rlcompleter.Completer ):
+   class RootNameCompleter( rlcompleter.Completer ):
       def file_matches( self, text ):
          matches = []
          path, name = os.path.split( text )
@@ -69,11 +69,14 @@ try:
          matches = rlcompleter.Completer.attr_matches( self, text )
          if not matches: matches = []
          b = text.find('.')
-         if 0 <= b and self.namespace[text[:b]].__name__ == 'ROOT':
-            matches += self.root_global_matches( text[b+1:], text[:b+1] )
+         try:
+            if 0 <= b and self.namespace[text[:b]].__name__ == 'ROOT':
+               matches += self.root_global_matches( text[b+1:], text[:b+1] )
+         except AttributeError:    # not all objects have a __name__
+            pass
          return matches
 
-   readline.set_completer( FileNameCompleter().complete )
+   readline.set_completer( RootNameCompleter().complete )
    readline.set_completer_delims(
       readline.get_completer_delims().replace( os.sep , '' ) )
 
@@ -222,8 +225,6 @@ class std( object ):
    for name in stlclasses:
       locals()[ name ] = Template( "std::%s" % name )
 
-   string = _root.MakeRootClass( 'string' )
-
 _root.std = std
 sys.modules['ROOT.std'] = std
 
@@ -245,6 +246,12 @@ class _ExpandMacroFunction( object ):
          return 1
       return 0
 
+   def __repr__( self ):
+      return repr( self.func() )
+
+   def __str__( self ):
+      return str( self.func() )
+
 _root.gPad         = _ExpandMacroFunction( "TVirtualPad",  "Pad" )
 _root.gVirtualX    = _ExpandMacroFunction( "TVirtualX",    "Instance" )
 _root.gDirectory   = _ExpandMacroFunction( "TDirectory",   "CurrentDirectory" )
@@ -503,6 +510,9 @@ class ModuleFacade( types.ModuleType ):
       if hasargv and PyConfig.IgnoreCommandLineOptions:
          sys.argv = argv
 
+    # now add 'string' to std so as to not confuse with module string
+      std.string = _root.MakeRootClass( 'string' )
+
     # must be called after gApplication creation:
       if '__IPYTHON__' in __builtins__:
        # IPython's FakeModule hack otherwise prevents usage of python from CINT
@@ -549,16 +559,13 @@ class ModuleFacade( types.ModuleType ):
             self.__dict__[ 'PyGUIThread' ] = \
                threading.Thread( None, _processRootEvents, None, ( self, ) )
 
-            def _finishSchedule( ROOT = self ):
-               import threading
-               if threading.currentThread() != self.PyGUIThread:
-                  while self.PyConfig.GUIThreadScheduleOnce:
-                     self.PyGUIThread.join( 0.1 )
-
-            self.PyGUIThread.finishSchedule = _finishSchedule
             self.PyGUIThread.setDaemon( 1 )
             self.PyGUIThread.start()
 
+            if threading.currentThread() != self.PyGUIThread:
+               while self.PyConfig.GUIThreadScheduleOnce:
+                  self.PyGUIThread.join( 0.1 )
+
     # store already available ROOT objects to prevent spurious lookups
       for name in self.module.__pseudo__all__ + _memPolicyAPI + _sigPolicyAPI:
          self.__dict__[ name ] = getattr( _root, name )
