@@ -1,4 +1,4 @@
-// @(#)root/pyroot:$Id: RootModule.cxx 43677 2012-04-10 15:50:45Z pcanal $
+// @(#)root/pyroot:$Id$
 // Author: Wim Lavrijsen, Apr 2004
 
 // Bindings
@@ -30,15 +30,49 @@
 #include <string>
 
 
+//- from Python's dictobject.c -------------------------------------------------
+#if PY_VERSION_HEX >= 0x03030000
+   typedef struct PyDictKeyEntry {
+      /* Cached hash code of me_key. */
+      Py_hash_t me_hash;
+      PyObject *me_key;
+      PyObject *me_value; /* This field is only meaningful for combined tables */
+   } PyDictEntry;
+
+   typedef struct _dictkeysobject {
+      Py_ssize_t dk_refcnt;
+      Py_ssize_t dk_size;
+      dict_lookup_func dk_lookup;
+      Py_ssize_t dk_usable;
+      PyDictKeyEntry dk_entries[1];
+   } PyDictKeysObject;
+
+#define PYROOT_GET_DICT_LOOKUP( mp )\
+   ((dict_lookup_func&)mp->ma_keys->dk_lookup)
+
+#else
+
+#define PYROOT_GET_DICT_LOOKUP( mp )\
+   ((dict_lookup_func&)mp->ma_lookup)
+
+#endif
+
 //- data -----------------------------------------------------------------------
 PyObject* gRootModule = 0;
 
-
 //- private helpers ------------------------------------------------------------
 namespace {
 
    using namespace PyROOT;
 
+//____________________________________________________________________________
+   PyObject* RootModuleResetCallback( PyObject*, PyObject* )
+   {
+      gRootModule = 0;   // reference was borrowed
+      Py_INCREF( Py_None );
+      return Py_None;
+   }
+
 //____________________________________________________________________________
    PyObject* LookupRootEntity( PyObject* pyname, PyObject* args )
    {
@@ -49,6 +83,12 @@ namespace {
       else if ( ! ( args && PyArg_ParseTuple( args, const_cast< char* >( "s" ), &cname ) ) )
          return 0;
 
+   // we may have been destroyed if this code is called during shutdown
+      if ( !gRootModule ) {
+         PyErr_Format( PyExc_AttributeError, "%s", cname );
+         return 0;
+      }
+
       std::string name = cname;
 
    // block search for privates
@@ -83,10 +123,32 @@ namespace {
    }
 
 //____________________________________________________________________________
+#if PY_VERSION_HEX >= 0x03030000
+   inline PyDictKeyEntry* OrgDictLookup(
+         PyDictObject* mp, PyObject* key, Py_hash_t hash, PyObject*** value_addr )
+   {
+      return (*gDictLookupOrg)( mp, key, hash, value_addr );
+   }
+
+#define PYROOT_ORGDICT_LOOKUP( mp, key, hash, value_addr )\
+   OrgDictLookup( mp, key, hash, value_addr )
+
+   PyDictKeyEntry* RootLookDictString(
+         PyDictObject* mp, PyObject* key, Py_hash_t hash, PyObject*** value_addr )
+#else
+   inline PyDictEntry* OrgDictLookup( PyDictObject* mp, PyObject* key, Long_t hash )
+   {
+       return (*gDictLookupOrg)( mp, key, hash );
+   }
+
+#define PYROOT_ORGDICT_LOOKUP( mp, key, hash, value_addr )\
+   OrgDictLookup( mp, key, hash )
+
    PyDictEntry* RootLookDictString( PyDictObject* mp, PyObject* key, Long_t hash )
+#endif
    {
    // first search dictionary itself
-      PyDictEntry* ep = (*gDictLookupOrg)( mp, key, hash );
+      PyDictEntry* ep = PYROOT_ORGDICT_LOOKUP( mp, key, hash, value_addr );
       if ( ! ep || ep->me_value != 0 || gDictLookupActive )
          return ep;
 
@@ -111,14 +173,14 @@ namespace {
             ep->me_value = Py_TYPE(val)->tp_descr_get( val, NULL, NULL );
          } else {
          // add reference to ROOT entity in the given dictionary
-            ((DictLookup_t&)mp->ma_lookup) = gDictLookupOrg;     // prevent recursion
+            PYROOT_GET_DICT_LOOKUP( mp ) = gDictLookupOrg;     // prevent recursion
             if ( PyDict_SetItem( (PyObject*)mp, key, val ) == 0 ) {
-               ep = (*gDictLookupOrg)( mp, key, hash );
+               ep = PYROOT_ORGDICT_LOOKUP( mp, key, hash, value_addr );
             } else {
                ep->me_key   = 0;
                ep->me_value = 0;
             }
-            ((DictLookup_t&)mp->ma_lookup) = RootLookDictString; // restore
+            PYROOT_GET_DICT_LOOKUP( mp ) = RootLookDictString; // restore
          }
 
       // done with val
@@ -142,7 +204,7 @@ namespace {
       if ( ! PyArg_ParseTuple( args, const_cast< char* >( "O!" ), &PyDict_Type, &dict ) )
          return 0;
 
-      ((DictLookup_t&)dict->ma_lookup) = RootLookDictString;
+      PYROOT_GET_DICT_LOOKUP( dict ) = RootLookDictString;
 
       Py_INCREF( Py_None );
       return Py_None;
@@ -330,6 +392,14 @@ namespace {
 
       const char* clname = PyBytes_AS_STRING(pyname);
 
+   // make sure that ROOT.py is loaded and fully initialized by accessing on it
+      PyObject* mod = PyImport_ImportModule( (char*)"ROOT" );
+      if ( mod ) {
+         PyObject* dummy = PyObject_GetAttrString( mod, (char*)"kRed" );
+         Py_XDECREF( dummy );
+         Py_DECREF( mod );
+      }
+
    // TBuffer and its derived classes can't write themselves, but can be created
    // directly from the buffer, so handle them in a special case
       void* newObj = 0;
@@ -425,6 +495,8 @@ static PyMethodDef gPyROOTMethods[] = {
      METH_VARARGS, (char*) "PyROOT internal function" },
    { (char*) "_DestroyPyStrings", (PyCFunction)PyROOT::DestroyPyStrings,
      METH_NOARGS, (char*) "PyROOT internal function" },
+   { (char*) "_ResetRootModule", (PyCFunction)RootModuleResetCallback,
+     METH_NOARGS, (char*) "PyROOT internal function" },
    { (char*) "AddressOf", (PyCFunction)AddressOf,
      METH_VARARGS, (char*) "Retrieve address of held object in a buffer" },
    { (char*) "AsCObject", (PyCFunction)AsCObject,
@@ -441,6 +513,10 @@ static PyMethodDef gPyROOTMethods[] = {
      METH_VARARGS, (char*) "Trap signals in safe mode to prevent interpreter abort" },
    { (char*) "SetOwnership", (PyCFunction)SetOwnership,
      METH_VARARGS, (char*) "Modify held C++ object ownership" },
+   { (char*) "InstallGUIEventInputHook", (PyCFunction)PyROOT::Utility::InstallGUIEventInputHook,
+     METH_NOARGS, (char*) "Install input hook to sent GUI events" },
+   { (char*) "RemoveGUIEventInputHook", (PyCFunction)PyROOT::Utility::RemoveGUIEventInputHook,
+     METH_NOARGS, (char*) "Remove input hook to sent GUI events" },
 #ifdef PYROOT_USE_REFLEX
    { (char*) "EnableReflex", (PyCFunction)PyROOT::TRflxCallback::Enable,
      METH_NOARGS, (char*) "Enable PyReflex notification of new types from Reflex" },
@@ -500,7 +576,11 @@ extern "C" void initlibPyROOT()
 
 // prepare for lazyness
    PyObject* dict = PyDict_New();
-   gDictLookupOrg = (DictLookup_t)((PyDictObject*)dict)->ma_lookup;
+#if PY_VERSION_HEX >= 0x03030000
+   gDictLookupOrg = (dict_lookup_func)((PyDictObject*)dict)->ma_keys->dk_lookup;
+#else
+   gDictLookupOrg = (dict_lookup_func)((PyDictObject*)dict)->ma_lookup;
+#endif
    Py_DECREF( dict );
 
 // setup PyROOT
