@@ -1,4 +1,4 @@
-// @(#)root/pyroot:$Id: RootWrapper.cxx 44044 2012-04-30 23:02:08Z wlav $
+// @(#)root/pyroot:$Id$
 // Author: Wim Lavrijsen, Apr 2004
 
 // Bindings
@@ -645,6 +645,22 @@ PyObject* PyROOT::MakeRootClassFromString( const std::string& fullname, PyObject
    if ( pyclass )                      // store a ref from ROOT TClass to new python class
       gPyClasses[ klass.Id() ] = PyWeakref_NewRef( pyclass, NULL );
 
+   if ( klass.IsNamespace() && klass.Name() != "ROOT" ) {
+   // add to sys.modules to allow importing from this module
+      std::string pyfullname = lookup;
+      std::string::size_type pos = pyfullname.find( "::" );
+      while ( pos != std::string::npos ) {
+         pyfullname = pyfullname.replace( pos, 2, "." );
+         pos = pyfullname.find( "::", pos );
+      }
+      PyObject* modules = PySys_GetObject( const_cast<char*>("modules") );
+      if ( modules && PyDict_Check( modules) ) {
+         
+         PyDict_SetItemString( modules,
+            const_cast<char*>(("ROOT."+pyfullname).c_str()), pyclass );
+      }
+   }
+
 // all done
    return pyclass;
 }
@@ -778,6 +794,9 @@ PyObject* PyROOT::BindRootObject( void* address, TClass* klass, Bool_t isRef )
       return 0;
    }
 
+// get actual class for recycling checking and/or downcasting
+   TClass* clActual = isRef ? 0 : klass->GetActualClass( address );
+
 // obtain pointer to TObject base class (if possible) for memory mgmt; this is
 // done before downcasting, as upcasting from the current class may be easier and
 // downcasting is unnecessary if the python side object gets recycled by the
@@ -787,18 +806,15 @@ PyObject* PyROOT::BindRootObject( void* address, TClass* klass, Bool_t isRef )
       object = (TObject*)((Long_t)address - GetObjectOffset( klass, TObject::Class(), address, false ) );
 
    // use the old reference if the object already exists
-      PyObject* oldPyObject = TMemoryRegulator::RetrieveObject( object );
+      PyObject* oldPyObject = TMemoryRegulator::RetrieveObject( object, clActual ? clActual : klass );
       if ( oldPyObject )
          return oldPyObject;
    }
                        
 // upgrade to real class for object returns
-   if ( ! isRef ) {
-      TClass* clActual = klass->GetActualClass( address );
-      if ( clActual ) {
-         address = (void*)((Long_t)address - GetObjectOffset( klass, clActual, address ) );
-         klass = clActual;
-      }
+   if ( clActual ) {
+      address = (void*)((Long_t)address - GetObjectOffset( klass, clActual, address ) );
+      klass = clActual;
    }
 
 // actual binding
