@@ -1,4 +1,4 @@
-// @(#)root/pyroot:$Id: Utility.cxx 41693 2011-11-01 18:23:36Z wlav $
+// @(#)root/pyroot:$Id$
 // Author: Wim Lavrijsen, Apr 2004
 
 // Bindings
@@ -15,6 +15,7 @@
 
 // ROOT
 #include "TROOT.h"
+#include "TSystem.h"
 #include "TObject.h"
 #include "TClassEdit.h"
 #include "TClassRef.h"
@@ -36,7 +37,7 @@
 
 
 //- data _____________________________________________________________________
-PyROOT::DictLookup_t PyROOT::gDictLookupOrg = 0;
+dict_lookup_func PyROOT::gDictLookupOrg = 0;
 Bool_t PyROOT::gDictLookupActive = kFALSE;
 
 PyROOT::Utility::EMemoryPolicy PyROOT::Utility::gMemoryPolicy = PyROOT::Utility::kHeuristics;
@@ -886,3 +887,46 @@ PyObject* PyROOT::Utility::PyErr_Occurred_WithGIL()
 
    return e;
 }
+
+//____________________________________________________________________________
+namespace {
+
+   static int (*sOldInputHook)() = NULL;
+   static PyThreadState* sInputHookEventThreadState = NULL;
+
+   static int EventInputHook()
+   {
+   // This method is supposed to be called from CPython's command line and
+   // drives the GUI.
+      PyEval_RestoreThread( sInputHookEventThreadState );
+      gSystem->ProcessEvents();
+      PyEval_SaveThread();
+
+      if ( sOldInputHook ) return sOldInputHook();
+         return 0;
+   }
+
+} // unnamed namespace
+
+PyObject* PyROOT::Utility::InstallGUIEventInputHook()
+{
+// Install the method hook for sending events to the GUI
+   if ( PyOS_InputHook && PyOS_InputHook != &EventInputHook )
+      sOldInputHook = PyOS_InputHook;
+
+   sInputHookEventThreadState = PyThreadState_Get();
+
+   PyOS_InputHook = (int (*)())&EventInputHook;
+   Py_INCREF( Py_None );
+   return Py_None;
+}
+
+PyObject* PyROOT::Utility::RemoveGUIEventInputHook()
+{
+// Remove event hook, if it was installed
+   PyOS_InputHook = sOldInputHook;
+   sInputHookEventThreadState = NULL;
+
+   Py_INCREF( Py_None );
+   return Py_None;
+}
