@@ -12,7 +12,13 @@
 #ifndef __GNU_CXX_HASH_H
 #define __GNU_CXX_HASH_H
 
-#if defined(__GNUC__)
+#if defined(_LIBCPP_ABI_VERSION)
+// using libc++
+# include <unordered_map>
+# define hash_map unordered_map
+# define hash_multimap unordered_multimap
+# define __gnu_cxx std
+#elif defined(__GNUC__)
 # if defined(__INTEL_COMPILER) && (__INTEL_COMPILER <= 800)
 #  define __gnu_cxx std
 # endif
@@ -124,10 +130,10 @@ public:
  */
 } // namespace __gnu_cxx
 
-#endif // __ICC, __ECC, _WIN32
+#endif // _WIN32
 
 
-#if defined(__GNUC__)
+#if defined(__GNUC__) && !defined(_LIBCPP_ABI_VERSION)
 namespace __gnu_cxx {
 template <> struct hash<const char**> {
    size_t
@@ -140,7 +146,6 @@ template <> struct hash<const char**> {
    }
 };
 
-
 template <> struct hash<const std::string*> {
    size_t
    operator ()(const std::string* __s) const {
@@ -150,8 +155,6 @@ template <> struct hash<const std::string*> {
       return __stl_hash_string(__s->c_str());
 # endif
    }
-
-
 };
 }
 
@@ -163,8 +166,6 @@ template <> struct equal_to<const char*> :
                const char* const& _Right) const {
       return strcmp(_Left, _Right) == 0;
    }
-
-
 };
 
 template <> struct equal_to<const char**> :
@@ -174,8 +175,6 @@ template <> struct equal_to<const char**> :
                const char** const& _Right) const {
       return strcmp(*_Left, *_Right) == 0;
    }
-
-
 };
 
 template <> struct equal_to<const std::string*> :
@@ -185,14 +184,60 @@ template <> struct equal_to<const std::string*> :
                const std::string* const& _Right) const {
       return * _Left == * _Right;
    }
-
-
 };
 
 } // namespace std
 
 #endif // __GNUC__
 
+
+#if defined(_LIBCPP_ABI_VERSION)
+#include <stdio.h>
+namespace std {
+
+template <> struct hash<const char**> {
+   size_t
+   operator ()(const char** const& __s) const {
+      return __do_string_hash<const char*>(*__s, *__s + strlen(*__s));
+   }
+};
+
+template <> struct hash<const std::string*> {
+   size_t
+   operator ()(const std::string* const& __s) const {
+      return __do_string_hash<const char*>(__s->c_str(), __s->c_str() + strlen(__s->c_str()));
+   }
+};
+
+template <> struct equal_to<const char*> {
+   bool
+   operator ()(const char* const& _Left,
+               const char* const& _Right) const {
+      return strcmp(_Left, _Right) == 0;
+   }
+};
+
+template <> struct equal_to<const char**> {
+   bool
+   operator ()(const char** const& _Left,
+               const char** const& _Right) const {
+      return strcmp(*_Left, *_Right) == 0;
+   }
+};
+
+template <> struct equal_to<const std::string*> {
+   bool
+   operator ()(const std::string* const& _Left,
+               const std::string* const& _Right) const {
+      return * _Left == * _Right;
+   }
+};
+
+} // namespace std
+
+#endif  // _LIBCPP_ABI_VERSION
+
+
 #if defined(__INTEL_COMPILER) && (__INTEL_COMPILER <= 800)
 
 namespace __gnu_cxx {
