@@ -76,7 +76,7 @@ public:
    virtual void  PrintFast(Int_t nch, const char *string="");
    virtual void  PrintStr(const char *string="");
    virtual void  WriteInteger(Int_t i, Bool_t space=kTRUE);
-   virtual void  WriteReal(Float_t r);
+   virtual void  WriteReal(Float_t r, Bool_t space=kTRUE);
    virtual void  PrintRaw(Int_t len, const char *str);
    virtual void *GetStream() const {  return (void*)fStream; }
    virtual void  SetStream(std::ofstream *os) {  fStream = os; }
