@@ -45,6 +45,8 @@
 #include "TBrowser.h"
 #include "TUrl.h"
 
+#include <stdlib.h>
+
 #if defined(R__MACOSX) && (TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR)
 #include "TGIOS.h"
 #endif
@@ -74,6 +76,13 @@ Bool_t TIdleTimer::Notify()
 
 ClassImp(TApplication)
 
+static void CallEndOfProcessCleanups()
+{
+  // Insure that the files, canvases and sockets are closed.
+
+  gROOT->EndOfProcessCleanups();
+}
+
 //______________________________________________________________________________
 TApplication::TApplication() :
    fArgc(0), fArgv(0), fAppImp(0), fIsRunning(kFALSE), fReturnFromRun(kFALSE),
@@ -126,6 +135,10 @@ TApplication::TApplication(const char *appClassName, Int_t *argc, char **argv,
    if (!gSystem)
       ::Fatal("TApplication::TApplication", "gSystem not initialized");
 
+   if (!gApplication) {
+      // If we are the first TApplication register the atexit)
+      atexit(CallEndOfProcessCleanups);
+   }
    gApplication = this;
    gROOT->SetApplication(this);
    gROOT->SetName(appClassName);
@@ -197,7 +210,7 @@ TApplication::~TApplication()
    for (int i = 0; i < fArgc; i++)
       if (fArgv[i]) delete [] fArgv[i];
    delete [] fArgv;
-   SafeDelete(fAppImp);
+
    if (fgApplications)
       fgApplications->Remove(this);
 
@@ -206,6 +219,21 @@ TApplication::~TApplication()
       ProcessLine("TMemStat::Close()");
       fUseMemstat = kFALSE;
    }
+
+   // Reduce the risk of the files or sockets being closed after the
+   // end of 'main' (or more exactly before the library start being
+   // unloaded).
+   if (fgApplications == 0 || fgApplications->FirstLink() == 0 ) {
+      if (gROOT) {
+         gROOT->EndOfProcessCleanups();
+      } else if (gInterpreter) {
+         gInterpreter->ResetGlobals();
+      }
+   }
+
+   // Now that all the canvases and files have been closed we can
+   // delete the implementation.
+   SafeDelete(fAppImp);
 }
 
 //______________________________________________________________________________
@@ -945,7 +973,7 @@ Long_t TApplication::ExecuteFile(const char *file, Int_t *error, Bool_t keep)
    Long_t retval = 0;
 
    while (1) {
-      bool res = macro.getline(currentline, kBufSize);
+      bool res = (bool)macro.getline(currentline, kBufSize);
       if (macro.eof()) break;
       if (!res) {
          // Probably only read kBufSize, let's ignore the remainder of
