@@ -1,4 +1,4 @@
-// @(#)root/base:$Id: TPRegexp.cxx 41014 2011-09-27 07:15:38Z pcanal $
+// @(#)root/base:$Id$
 // Author: Eddy Offermann   24/06/05
 
 /*************************************************************************
@@ -32,6 +32,7 @@
 #include <pcre.h>
 
 #include <vector>
+#include <stdexcept>
 
 struct PCREPriv_t {
    pcre       *fPCRE;
@@ -43,6 +44,8 @@ struct PCREPriv_t {
 
 ClassImp(TPRegexp)
 
+Bool_t TPRegexp::fgThrowAtCompileError = kFALSE;
+
 //______________________________________________________________________________
 TPRegexp::TPRegexp()
 {
@@ -207,8 +210,15 @@ void TPRegexp::Compile()
                                &errstr, &patIndex, 0);
 
    if (!fPriv->fPCRE) {
-      Error("Compile", "compilation of TPRegexp(%s) failed at: %d because %s",
-            fPattern.Data(), patIndex, errstr);
+      if (fgThrowAtCompileError) {
+         throw std::runtime_error
+            (TString::Format("TPRegexp::Compile() compilation of TPRegexp(%s) failed at: %d because %s",
+                             fPattern.Data(), patIndex, errstr).Data());
+      } else {
+         Error("Compile", "compilation of TPRegexp(%s) failed at: %d because %s",
+               fPattern.Data(), patIndex, errstr);
+         return;
+      }
    }
 
    if (fPriv->fPCREExtra || (fPCREOpts & kPCRE_OPTIMIZE))
@@ -346,8 +356,8 @@ TObjArray *TPRegexp::MatchS(const TString &s, const TString &mods,
                             Int_t start, Int_t nMaxMatch)
 {
    // Returns a TObjArray of matched substrings as TObjString's.
-   // The TObjArray is owner of the objects. The first entry is the full
-   // matched pattern, followed by the subpatterns.
+   // The TObjArray is owner of the objects and must be deleted by the user.
+   // The first entry is the full matched pattern, followed by the subpatterns.
    // If a pattern was not matched, it will return an empty substring:
    //
    // TObjArray *subStrL = TPRegexp("(a|(z))(bc)").MatchS("abc");
@@ -472,6 +482,33 @@ Int_t TPRegexp::Substitute(TString &s, const TString &replacePattern,
 }
 
 
+//______________________________________________________________________________
+Bool_t TPRegexp::IsValid() const
+{
+   // Returns true if underlying PCRE structure has been successfully
+   // generated via regexp compilation.
+
+   return fPriv->fPCRE != 0;
+}
+
+//______________________________________________________________________________
+Bool_t TPRegexp::GetThrowAtCompileError()
+{
+   // Get value of static flag controlling whether exception should be thrown upon an
+   // error during regular expression compilation by the PCRE engine.
+
+   return fgThrowAtCompileError;
+}
+
+//______________________________________________________________________________
+void TPRegexp::SetThrowAtCompileError(Bool_t throwp)
+{
+   // Set static flag controlling whether exception should be thrown upon an
+   // error during regular expression compilation by the PCRE engine.
+
+   fgThrowAtCompileError = throwp;
+}
+
 //////////////////////////////////////////////////////////////////////////
 //                                                                      //
 // TString member functions, put here so the linker will include        //
