@@ -696,19 +696,6 @@ void TStyle::Reset(Option_t *opt)
 }
 
 
-//______________________________________________________________________________
-Int_t TStyle::AxisChoice( Option_t *axis) const
-{
-   // Return axis number.
-
-   char achoice = toupper(axis[0]);
-   if (achoice == 'X') return 1;
-   if (achoice == 'Y') return 2;
-   if (achoice == 'Z') return 3;
-   return 0;
-}
-
-
 //______________________________________________________________________________
 Int_t TStyle::GetNdivisions( Option_t *axis) const
 {
@@ -1263,6 +1250,7 @@ void TStyle::SetOptStat(Int_t mode)
    //    s = 1;  skewness printed
    //    s = 2;  skewness and skewness error printed
    //    i = 1;  integral of bins printed
+   //    i = 2;  integral of bins with option "width" printed
    //    o = 1;  number of overflows printed
    //    u = 1;  number of underflows printed
    //    r = 1;  rms printed
@@ -1305,6 +1293,7 @@ void TStyle::SetOptStat(Option_t *stat)
    //    s :  skewness printed
    //    S :  skewness and skewness error printed
    //    i :  integral of bins printed
+   //    I :  integral of bins with option "width" printed
    //    o :  number of overflows printed
    //    u :  number of underflows printed
    //    r :  rms printed
@@ -1331,6 +1320,7 @@ void TStyle::SetOptStat(Option_t *stat)
    if (opt.Contains("u")) mode+=10000;
    if (opt.Contains("o")) mode+=100000;
    if (opt.Contains("i")) mode+=1000000;
+   if (opt.Contains("I")) mode+=2000000;
    if (opt.Contains("s")) mode+=10000000;
    if (opt.Contains("S")) mode+=20000000;
    if (opt.Contains("k")) mode+=100000000;
