@@ -1,4 +1,4 @@
-// @(#)root/base:$Id: TTimeStamp.cxx 43972 2012-04-26 14:53:18Z rdm $
+// @(#)root/base:$Id$
 // Author: R. Hatcher   30/9/2001
 
 /*************************************************************************
@@ -411,7 +411,18 @@ Int_t TTimeStamp::GetZoneOffset()
 #if defined(R__WINGCC)
    return _timezone;
 #else
+#if !defined(R__FBSD) && !defined(R__OBSD)
    return  timezone;   // unix has extern long int
+#else	 
+   time_t tp = 0;	 
+   time(&tp);	 
+#ifdef _REENTRANT	 
+   struct tm buf;	 
+   return -localtime_r(&tp, &buf)->tm_gmtoff;	 
+#else	 
+   return -localtime(&tp)->tm_gmtoff;	 
+#endif	 
+#endif  
 #endif
 #else
    _tzset();
