@@ -1,4 +1,4 @@
-// @(#)root/base:$Id: TVirtualX.cxx 43914 2012-04-23 22:08:24Z rdm $
+// @(#)root/base:$Id$
 // Author: Fons Rademakers   3/12/95
 
 /*************************************************************************
@@ -188,6 +188,14 @@ void TVirtualX::CopyPixmap(Int_t /*wid*/, Int_t /*xpos*/, Int_t /*ypos*/)
    // Copies the pixmap "wid" at the position [xpos,ypos] in the current window.
 }
 
+//______________________________________________________________________________
+Double_t TVirtualX::GetOpenGLScalingFactor()
+{
+   //On a HiDPI resolution it can be > 1., this means glViewport should use
+   //scaled width and height.
+   return 1.;
+}
+
 //______________________________________________________________________________
 void TVirtualX::CreateOpenGLContext(Int_t /*wid*/)
 {
@@ -200,6 +208,40 @@ void TVirtualX::DeleteOpenGLContext(Int_t /*wid*/)
    // Deletes OpenGL context for window "wid"
 }
 
+//______________________________________________________________________________
+Window_t TVirtualX::CreateOpenGLWindow(Window_t /*parentID*/, UInt_t /*width*/, UInt_t /*height*/, const std::vector<std::pair<UInt_t, Int_t> > &/*format*/)
+{
+   //Create window with special pixel format. Noop everywhere except Cocoa.
+   return Window_t();
+}
+
+//______________________________________________________________________________
+Handle_t TVirtualX::CreateOpenGLContext(Window_t /*windowID*/, Handle_t /*shareWith*/)
+{
+   // Creates OpenGL context for window "windowID".
+   return Handle_t();
+}
+
+//______________________________________________________________________________
+Bool_t TVirtualX::MakeOpenGLContextCurrent(Handle_t /*ctx*/, Window_t /*windowID*/)
+{
+   // Makes context ctx current OpenGL context.
+   return kFALSE;
+}
+
+//______________________________________________________________________________
+Handle_t TVirtualX::GetCurrentOpenGLContext()
+{
+   // Asks OpenGL subsystem about the current OpenGL context.
+   return Handle_t();
+}
+
+//______________________________________________________________________________
+void TVirtualX::FlushOpenGLBuffer(Handle_t /*ctx*/)
+{
+   // Flushes OpenGL buffer.
+}
+
 //______________________________________________________________________________
 void TVirtualX::DrawBox(Int_t /*x1*/, Int_t /*y1*/, Int_t /*x2*/, Int_t /*y2*/,
                         EBoxMode /*mode*/)
@@ -281,6 +323,23 @@ void TVirtualX::DrawText(Int_t /*x*/, Int_t /*y*/, Float_t /*angle*/,
 
 }
 
+//______________________________________________________________________________
+void TVirtualX::DrawText(Int_t /*x*/, Int_t /*y*/, Float_t /*angle*/,
+                         Float_t /*mgn*/, const wchar_t * /*text*/,
+                         ETextMode /*mode*/)
+{
+   // Draws a text string using current font.
+   //
+   // x,y   - text position
+   // angle - text angle
+   // mgn   - magnification factor
+   // text  - text string
+   // mode  - drawing mode:
+   //         mode = 0 the background is not drawn (kClear)
+   //         mode = 1 the background is drawn (kOpaque)
+
+}
+
 //______________________________________________________________________________
 UInt_t TVirtualX::ExecCommand(TGWin32Command * /*code*/)
 {
@@ -372,6 +431,17 @@ void TVirtualX::GetTextExtent(UInt_t &w, UInt_t &h, char * /*mess*/)
    w = h = 0;
 }
 //______________________________________________________________________________
+void TVirtualX::GetTextExtent(UInt_t &w, UInt_t &h, wchar_t * /*mess*/)
+{
+   // Returns the size of the specified character string "mess".
+   //
+   // w    - the text width
+   // h    - the text height
+   // mess - the string
+
+   w = h = 0;
+}
+//______________________________________________________________________________
 Int_t   TVirtualX::GetFontAscent() const
 {
    // Returns the ascent of the current font (in pixels).
@@ -1589,7 +1659,7 @@ void TVirtualX::DrawString(Drawable_t /*id*/, GContext_t /*gc*/, Int_t /*x*/,
 Int_t TVirtualX::TextWidth(FontStruct_t /*font*/, const char * /*s*/,
                              Int_t /*len*/)
 {
-   // Return lenght of the string "s" in pixels. Size depends on font.
+   // Return length of the string "s" in pixels. Size depends on font.
 
    return 5;
 }
