@@ -1,4 +1,4 @@
-// @(#)root/cont:$Id: TList.cxx 43515 2012-03-27 21:15:53Z pcanal $
+// @(#)root/cont:$Id$
 // Author: Fons Rademakers   10/08/95
 
 /*************************************************************************
@@ -68,6 +68,7 @@
 
 #include "TList.h"
 #include "TClass.h"
+#include "TROOT.h"
 
 #include <string>
 namespace std {} using namespace std;
@@ -351,6 +352,16 @@ void TList::Clear(Option_t *option)
       return;
    }
 
+   // In some case, for example TParallelCoord, a list (the pad's list of 
+   // primitives) will contain both the container and the containees
+   // (the TParallelCoorVar) but if the Clear is being called from
+   // the destructor of the container of this list, one of the first
+   // thing done will be the remove the container (the pad) for the
+   // list (of Primitives of the canvas) that was connecting it 
+   // (indirectly) to the list of cleanups.
+   // So let's temporarily add the current list and remove it later.
+   bool needRegister = fFirst && TROOT::Initialized() && !gROOT->GetListOfCleanups()->FindObject(this);
+   if (needRegister) gROOT->GetListOfCleanups()->Add(this);
    while (fFirst) {
       TObjLink *tlk = fFirst;
       fFirst = fFirst->Next();
@@ -365,6 +376,7 @@ void TList::Clear(Option_t *option)
       }
       delete tlk;
    }
+   if (needRegister) ROOT::GetROOT()->GetListOfCleanups()->Remove(this);
    fFirst = fLast = fCache = 0;
    fSize  = 0;
    Changed();
@@ -385,6 +397,16 @@ void TList::Delete(Option_t *option)
 
    if (slow) {
 
+      // In some case, for example TParallelCoord, a list (the pad's list of 
+      // primitives) will contain both the container and the containees
+      // (the TParallelCoorVar) but if the Clear is being called from
+      // the destructor of the container of this list, one of the first
+      // thing done will be the remove the container (the pad) for the
+      // list (of Primitives of the canvas) that was connecting it 
+      // (indirectly) to the list of cleanups.
+      // So let's temporarily add the current list and remove it later.
+      bool needRegister = fFirst && TROOT::Initialized() && !gROOT->GetListOfCleanups()->FindObject(this);
+      if (needRegister) gROOT->GetListOfCleanups()->Add(this);
       while (fFirst) {
          TObjLink *tlk = fFirst;
          fFirst = fFirst->Next();
@@ -397,6 +419,7 @@ void TList::Delete(Option_t *option)
 
          delete tlk;
       }
+      if (needRegister) ROOT::GetROOT()->GetListOfCleanups()->Remove(this);
       fFirst = fLast = fCache = 0;
       fSize  = 0;
 
