@@ -157,9 +157,13 @@ private:
 
 class AutoreleasePool {
 public:
-   AutoreleasePool();
+   AutoreleasePool(bool delayCreation = false);
    ~AutoreleasePool();
    
+   //Drains the previous pool (if any)
+   //and activates a new one.
+   void Reset();
+   
 private:
    NSAutoreleasePool *fPool;
 
