@@ -1,4 +1,4 @@
-// @(#)root/meta:$Id$
+// @(#)root/meta:$Id: e0eac11e63ad37390c9467c97c5c6849c4ab7d39 $
 // Author: Rene Brun   12/10/2000
 
 /*************************************************************************
@@ -25,6 +25,10 @@
 #include "TNamed.h"
 #endif
 
+#ifndef ROOT_ESTLType
+#include "ESTLType.h"
+#endif
+
 class TMethodCall;
 class TClass;
 class TStreamerBasicType;
@@ -54,12 +58,17 @@ protected:
 
 public:
 
-   enum ESTLtype { kSTL       = 300 /* TVirtualStreamerInfo::kSTL */, 
-                   kSTLstring = 365 /* TVirtualStreamerInfo::kSTLstring */,   
-                   kSTLvector =  1,
-                   kSTLlist   =  2,  kSTLdeque   =  3,   kSTLmap      = 4,
-                   kSTLset    =  5,  kSTLmultimap=  6,   kSTLmultiset = 7, 
-                   kSTLbitset =  8
+   enum ESTLtype {
+      kSTL         = ROOT::kSTLany,
+      kSTLstring   = ROOT::kSTLstring,
+      kSTLvector   = ROOT::kSTLvector,
+      kSTLlist     = ROOT::kSTLlist,
+      kSTLdeque    = ROOT::kSTLdeque,
+      kSTLmap      = ROOT::kSTLmap,
+      kSTLmultimap = ROOT::kSTLmultimap,
+      kSTLset      = ROOT::kSTLset,
+      kSTLmultiset = ROOT::kSTLmultiset,
+      kSTLbitset   = ROOT::kSTLbitset
    };
    // TStreamerElement status bits
    enum {
@@ -68,7 +77,8 @@ public:
       kRepeat       = BIT(10),
       kRead         = BIT(11),
       kWrite        = BIT(12),
-      kDoNotDelete  = BIT(13)
+      kDoNotDelete  = BIT(13),
+      kWholeObject  = BIT(14)
    };
 
    TStreamerElement();
@@ -90,6 +100,7 @@ public:
    TClass*          GetNewClass() const { return fNewClass; }
    Int_t            GetType() const {return fType;}
    Int_t            GetOffset() const {return fOffset;}
+   void             GetSequenceType(TString &type) const;
    Int_t            GetTObjectOffset() const { return fTObjectOffset; }
    const char      *GetTypeName() const {return fTypeName.Data();}
    const char      *GetTypeNameBasic() const;
@@ -362,6 +373,8 @@ public:
    TStreamerSTL();
    TStreamerSTL(const char *name, const char *title, Int_t offset, 
                 const char *typeName, const char *trueType, Bool_t dmPointer);
+   TStreamerSTL(const char *name, const char *title, Int_t offset, 
+                const char *typeName, const TVirtualCollectionProxy &proxy , Bool_t dmPointer);
    virtual       ~TStreamerSTL();
    Bool_t         CannotSplit() const;
    Bool_t         IsaPointer() const;
