@@ -1,4 +1,4 @@
-// @(#)root/base:$Id: TClassEdit.cxx 43294 2012-03-08 14:59:41Z pcanal $
+// @(#)root/base:$Id$
 // Author: Victor Perev   04/10/2003
 //         Philippe Canal 05/2004
 
@@ -278,7 +278,8 @@ int   TClassEdit::STLArgs(int kind)
 //      Return number of arguments for STL container before allocator
 
    static const char  stln[] =// min number of container arguments
-   {    1,       1,     1,      1,    3,         3,    2,        2 };
+      //     vector, list, deque, map, multimap, set, multiset, bitset 
+      {    1,     1,    1,     1,   3,        3,   2,        2,      1 };
 
    return stln[kind];
 }
