@@ -1,4 +1,4 @@
-// @(#)root/rint:$Id: TRint.cxx 43494 2012-03-27 09:50:39Z axel $
+// @(#)root/rint:$Id$
 // Author: Rene Brun   17/02/95
 
 /*************************************************************************
@@ -426,10 +426,6 @@ void TRint::Run(Bool_t retrn)
          }
       } ENDTRY;
 
-      // Allow end-of-file on the terminal to be noticed
-      // after we finish processing the command line input files.
-      fInputHandler->Activate();
-
       if (QuitOpt()) {
          if (retrn) return;
          if (error) {
@@ -441,6 +437,10 @@ void TRint::Run(Bool_t retrn)
          Terminate(retval);
       }
 
+      // Allow end-of-file on the terminal to be noticed
+      // after we finish processing the command line input files.
+      fInputHandler->Activate();
+      
       ClearInputFiles();
 
       if (needGetlinemInit) Getlinem(kInit, GetPrompt());
@@ -486,8 +486,8 @@ void TRint::PrintLogo(Bool_t lite)
       Printf("  *******************************************\n");
    }
 
-   Printf("ROOT %s (%s@%d, %s on %s)", root_version, gROOT->GetSvnBranch(),
-          gROOT->GetSvnRevision(), gROOT->GetSvnDate(),
+   Printf("ROOT %s (%s@%s, %s on %s)", root_version, gROOT->GetGitBranch(),
+          gROOT->GetGitCommit(), gROOT->GetGitDate(),
           gSystem->GetBuildArch());
 
    if (!lite)
