@@ -44,6 +44,7 @@ TGeoBranchArray::TGeoBranchArray(Int_t level)
 // Constructor. Alocates the array with a size given by level.
    fMaxLevel = (fLevel+1 > 10) ? fLevel+1:10;
    fArray = new TGeoNode*[fMaxLevel];
+   fMatrix = new TGeoHMatrix();
 }
 
 //______________________________________________________________________________
@@ -92,7 +93,7 @@ TGeoBranchArray& TGeoBranchArray::operator=(const TGeoBranchArray& other)
    fLevel = other.fLevel;
    if (fLevel+1) memcpy(fArray, other.fArray, (fLevel+1)*sizeof(TGeoNode*));
    if (other.fMatrix) {
-      fMatrix = new TGeoHMatrix();
+      if (!fMatrix) fMatrix = new TGeoHMatrix();
       fMatrix->CopyFrom(other.fMatrix);
    }
    fClient = other.fClient;
@@ -104,7 +105,7 @@ TGeoBranchArray& TGeoBranchArray::operator=(const TGeoBranchArray& other)
 void TGeoBranchArray::AddLevel(Int_t dindex)
 {
 // Add and extra daughter to the current path array. No validity check performed !
-   if (!fLevel) {
+   if (fLevel<=0) {
       Error("AddLevel", "You must initialize from navigator or copy from another branch array first.");
       return;
    }
@@ -244,7 +245,6 @@ void TGeoBranchArray::InitFromNavigator(TGeoNavigator *nav)
    Int_t level = cache->GetLevel();
    if (!fMatrix) fMatrix = new TGeoHMatrix();
    fMatrix->CopyFrom(cache->GetCurrentMatrix());
-//   TThread::Lock();
    if (!fArray || level+1>fMaxLevel) {
       delete [] fArray; 
       fMaxLevel = level+1;
@@ -252,7 +252,7 @@ void TGeoBranchArray::InitFromNavigator(TGeoNavigator *nav)
    }
    fLevel = level;
    memcpy(fArray, branch, (fLevel+1)*sizeof(TGeoNode*));
-//   TThread::UnLock();
+   if (nav->IsOutside()) fLevel = -1;
 }
 
 //______________________________________________________________________________
@@ -292,5 +292,6 @@ void TGeoBranchArray::UpdateNavigator(TGeoNavigator *nav) const
 {
 // Update the navigator to reflect the branch.
    nav->CdTop();
+   if (fLevel<0) {nav->SetOutside(kTRUE); return;}
    for (Int_t i=1; i<fLevel+1; i++) nav->CdDown(fArray[i]);
 }
