@@ -263,14 +263,14 @@ void TGeoCompositeShape::ComputeBBox()
 }
 
 //_____________________________________________________________________________
-void TGeoCompositeShape::ComputeNormal(Double_t *point, Double_t *dir, Double_t *norm)
+void TGeoCompositeShape::ComputeNormal(const Double_t *point, const Double_t *dir, Double_t *norm)
 {
 // Computes normal vector in POINT to the composite shape.
    if (fNode) fNode->ComputeNormal(point,dir,norm);
 }
 
 //_____________________________________________________________________________
-Bool_t TGeoCompositeShape::Contains(Double_t *point) const
+Bool_t TGeoCompositeShape::Contains(const Double_t *point) const
 {
 // Tests if point is inside the shape.
    if (fNode) return fNode->Contains(point);
@@ -286,7 +286,7 @@ Int_t TGeoCompositeShape::DistancetoPrimitive(Int_t px, Int_t py)
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCompositeShape::DistFromOutside(Double_t *point, Double_t *dir, Int_t iact,
+Double_t TGeoCompositeShape::DistFromOutside(const Double_t *point, const Double_t *dir, Int_t iact,
                                       Double_t step, Double_t *safe) const
 {
 // Compute distance from outside point to this composite shape.
@@ -298,7 +298,7 @@ Double_t TGeoCompositeShape::DistFromOutside(Double_t *point, Double_t *dir, Int
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCompositeShape::DistFromInside(Double_t *point, Double_t *dir, Int_t iact,
+Double_t TGeoCompositeShape::DistFromInside(const Double_t *point, const Double_t *dir, Int_t iact,
                                       Double_t step, Double_t *safe) const
 {
 // Compute distance from inside point to outside of this composite shape.
@@ -453,7 +453,7 @@ void TGeoCompositeShape::RegisterYourself()
 }
 
 //_____________________________________________________________________________
-Double_t TGeoCompositeShape::Safety(Double_t *point, Bool_t in) const
+Double_t TGeoCompositeShape::Safety(const Double_t *point, Bool_t in) const
 {
 // computes the closest distance from given point to this shape, according
 // to option. The matching point on the shape is stored in spoint.
@@ -501,3 +501,44 @@ Int_t TGeoCompositeShape::GetNmeshVertices() const
    if (!fNode) return 0;
    return fNode->GetNpoints();
 }
+
+//_____________________________________________________________________________
+void TGeoCompositeShape::Contains_v(const Double_t *points, Bool_t *inside, Int_t vecsize) const
+{
+// Check the inside status for each of the points in the array.
+// Input: Array of point coordinates + vector size
+// Output: Array of Booleans for the inside of each point
+   for (Int_t i=0; i<vecsize; i++) inside[i] = Contains(&points[3*i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCompositeShape::ComputeNormal_v(const Double_t *points, const Double_t *dirs, Double_t *norms, Int_t vecsize)
+{
+// Compute the normal for an array o points so that norm.dot.dir is positive
+// Input: Arrays of point coordinates and directions + vector size
+// Output: Array of normal directions
+   for (Int_t i=0; i<vecsize; i++) ComputeNormal(&points[3*i], &dirs[3*i], &norms[3*i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCompositeShape::DistFromInside_v(const Double_t *points, const Double_t *dirs, Double_t *dists, Int_t vecsize, Double_t* step) const
+{
+// Compute distance from array of input points having directions specisied by dirs. Store output in dists
+   for (Int_t i=0; i<vecsize; i++) dists[i] = DistFromInside(&points[3*i], &dirs[3*i], 3, step[i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCompositeShape::DistFromOutside_v(const Double_t *points, const Double_t *dirs, Double_t *dists, Int_t vecsize, Double_t* step) const
+{
+// Compute distance from array of input points having directions specisied by dirs. Store output in dists
+   for (Int_t i=0; i<vecsize; i++) dists[i] = DistFromOutside(&points[3*i], &dirs[3*i], 3, step[i]);
+}
+
+//_____________________________________________________________________________
+void TGeoCompositeShape::Safety_v(const Double_t *points, const Bool_t *inside, Double_t *safe, Int_t vecsize) const
+{
+// Compute safe distance from each of the points in the input array.
+// Input: Array of point coordinates, array of statuses for these points, size of the arrays
+// Output: Safety values
+   for (Int_t i=0; i<vecsize; i++) safe[i] = Safety(&points[3*i], inside[i]);
+}
