@@ -122,7 +122,7 @@ TGeoMaterial::TGeoMaterial(const char *name, Double_t a, Double_t z,
    }
    if (fZ - Int_t(fZ) > 1E-3)
       Warning("ctor", "Material %s defined with fractional Z=%f", GetName(), fZ);
-   GetElement()->SetUsed();
+   if (GetElement()) GetElement()->SetUsed();
    gGeoManager->AddMaterial(this);
 }
 
@@ -155,7 +155,7 @@ TGeoMaterial::TGeoMaterial(const char *name, Double_t a, Double_t z, Double_t rh
    }
    if (fZ - Int_t(fZ) > 1E-3)
       Warning("ctor", "Material %s defined with fractional Z=%f", GetName(), fZ);
-   GetElement()->SetUsed();
+   if (GetElement()) GetElement()->SetUsed();
    gGeoManager->AddMaterial(this);
 }
 
@@ -192,7 +192,7 @@ TGeoMaterial::TGeoMaterial(const char *name, TGeoElement *elem, Double_t rho)
    }
    if (fZ - Int_t(fZ) > 1E-3)
       Warning("ctor", "Material %s defined with fractional Z=%f", GetName(), fZ);
-   GetElement()->SetUsed();
+   if (GetElement()) GetElement()->SetUsed();
    gGeoManager->AddMaterial(this);
 }
 
@@ -344,6 +344,10 @@ void TGeoMaterial::SetRadLen(Double_t radlen, Double_t intlen)
       const Double_t lambda0 = 35.*g/(cm*cm);  // [g/cm^2]
       Double_t nilinv = 0.0;
       TGeoElement *elem = GetElement();
+      if (!elem) {
+         Fatal("SetRadLen", "Element not found for material %s", GetName());
+         return;
+      }   
       Double_t nbAtomsPerVolume = TMath::Na()*fDensity/elem->A();
       nilinv += nbAtomsPerVolume*TMath::Power(elem->Neff(), 0.6666667);
       nilinv *= amu/lambda0;
@@ -521,6 +525,10 @@ void TGeoMaterial::FillMaterialEvolution(TObjArray *population, Double_t precisi
    TIter next(table->GetElementsRN());
    while ((elemrn=(TGeoElementRN*)next())) elemrn->ResetRatio();
    elem = GetElement();
+   if (!elem) {
+      Fatal("FillMaterialEvolution", "Element not found for material %s", GetName());
+      return;
+   }   
    if (!elem->IsRadioNuclide()) {
       population->Add(elem);
       return;
