@@ -78,7 +78,7 @@
 // Note that global queries related to a geometry are handled by the manager class.
 // However, shape-related queries might be sometimes usefull.
 //
-// A) Bool_t TGeoShape::Contains(Double_t *point[3])
+// A) Bool_t TGeoShape::Contains(const Double_t *point[3])
 //   - this method returns true if POINT is actually inside the shape. The point
 // has to be defined in the local shape reference. For instance, for a box having
 // DX, DY and DZ half-lengths a point will be considered inside if :
@@ -108,7 +108,7 @@
 //   - computes the distance to entering a shape from a given point OUTSIDE. Acts
 // in the same way as B).
 //
-// D) Double_t Safety(Double_t *point[3], Bool_t inside)
+// D) Double_t Safety(const Double_t *point[3], Bool_t inside)
 //
 //   - compute maximum shift of a point in any direction that does not change its
 // INSIDE/OUTSIDE state (does not cross shape boundaries). The state of the point
@@ -191,7 +191,7 @@ TGeoShape::TGeoShape(const char *name)
 TGeoShape::~TGeoShape()
 {
 // Destructor
-   if (gGeoManager) gGeoManager->GetListOfShapes()->Remove(this);
+   if (gGeoManager && !gGeoManager->IsCleaning()) gGeoManager->GetListOfShapes()->Remove(this);
 }
 
 //_____________________________________________________________________________
@@ -240,7 +240,7 @@ Double_t TGeoShape::EpsMch()
 const char *TGeoShape::GetName() const
 {
 // Get the shape name.
-   if (!strlen(fName)) {
+   if (!fName[0]) {
       return ((TObject *)this)->ClassName();
    }
    return TNamed::GetName();
@@ -256,7 +256,7 @@ Int_t TGeoShape::ShapeDistancetoPrimitive(Int_t numpoints, Int_t px, Int_t py) c
 }
 
 //_____________________________________________________________________________
-Bool_t TGeoShape::IsCloseToPhi(Double_t epsil, Double_t *point, Double_t c1, Double_t s1, Double_t c2, Double_t s2)
+Bool_t TGeoShape::IsCloseToPhi(Double_t epsil, const Double_t *point, Double_t c1, Double_t s1, Double_t c2, Double_t s2)
 {
 // True if point is closer than epsil to one of the phi planes defined by c1,s1 or c2,s2
    Double_t saf1 = TGeoShape::Big();
@@ -269,7 +269,7 @@ Bool_t TGeoShape::IsCloseToPhi(Double_t epsil, Double_t *point, Double_t c1, Dou
 }   
 
 //_____________________________________________________________________________
-Bool_t TGeoShape::IsInPhiRange(Double_t *point, Double_t phi1, Double_t phi2)
+Bool_t TGeoShape::IsInPhiRange(const Double_t *point, Double_t phi1, Double_t phi2)
 {
 // Static method to check if a point is in the phi range (phi1, phi2) [degrees]
    Double_t phi = TMath::ATan2(point[1], point[0]) * TMath::RadToDeg();
@@ -280,7 +280,7 @@ Bool_t TGeoShape::IsInPhiRange(Double_t *point, Double_t phi1, Double_t phi2)
 }   
 
 //_____________________________________________________________________________  
-Bool_t TGeoShape::IsCrossingSemiplane(Double_t *point, Double_t *dir, Double_t cphi, Double_t sphi, Double_t &snext, Double_t &rxy)
+Bool_t TGeoShape::IsCrossingSemiplane(const Double_t *point, const Double_t *dir, Double_t cphi, Double_t sphi, Double_t &snext, Double_t &rxy)
 {
 // Compute distance from POINT to semiplane defined by PHI angle along DIR. Computes
 // also radius at crossing point. This might be negative in case the crossing is
@@ -387,7 +387,7 @@ Bool_t TGeoShape::IsSegCrossing(Double_t x1, Double_t y1, Double_t x2, Double_t
 }         
 
 //_____________________________________________________________________________
-Double_t TGeoShape::DistToPhiMin(Double_t *point, Double_t *dir, Double_t s1, Double_t c1,
+Double_t TGeoShape::DistToPhiMin(const Double_t *point, const Double_t *dir, Double_t s1, Double_t c1,
                                  Double_t s2, Double_t c2, Double_t sm, Double_t cm, Bool_t in)
 {
 // compute distance from point (inside phi) to both phi planes. Return minimum.
@@ -418,7 +418,7 @@ Double_t TGeoShape::DistToPhiMin(Double_t *point, Double_t *dir, Double_t s1, Do
 }
 
 //_____________________________________________________________________________
-void TGeoShape::NormalPhi(Double_t *point, Double_t *dir, Double_t *norm, Double_t c1, Double_t s1, Double_t c2, Double_t s2)
+void TGeoShape::NormalPhi(const Double_t *point, const Double_t *dir, Double_t *norm, Double_t c1, Double_t s1, Double_t c2, Double_t s2)
 {
 // Static method to compute normal to phi planes.
    Double_t saf1 = TGeoShape::Big();
@@ -443,7 +443,7 @@ void TGeoShape::NormalPhi(Double_t *point, Double_t *dir, Double_t *norm, Double
 }           
  
 //_____________________________________________________________________________
-Double_t TGeoShape::SafetyPhi(Double_t *point, Bool_t in, Double_t phi1, Double_t phi2)
+Double_t TGeoShape::SafetyPhi(const Double_t *point, Bool_t in, Double_t phi1, Double_t phi2)
 {
 // Static method to compute safety w.r.t a phi corner defined by cosines/sines
 // of the angles phi1, phi2.
@@ -480,7 +480,7 @@ Double_t TGeoShape::SafetySeg(Double_t r, Double_t z, Double_t r1, Double_t z1,
    crossp *= (outer) ? 1. : -1.;
    // Positive crossp means point on the requested side of the (1,2) segment
    if (crossp < 0) {
-      if (((z-z1)*(z2-z)) > 0) return 0;
+      if (((z-z1)*(z2-z)) > -1.E-10) return 0;
       return TGeoShape::Big();
    }   
    // Compute (1,P) dot (1,2)
@@ -694,7 +694,7 @@ void TGeoShape::Draw(Option_t *option)
 {
 // Draw this shape.
    TVirtualGeoPainter *painter = gGeoManager->GetGeomPainter();
-   if (option && strlen(option) > 0) {
+   if (option && option[0]) {
       painter->DrawShape(this, option); 
    } else {
       painter->DrawShape(this, gEnv->GetValue("Viewer3D.DefaultDrawOption",""));
@@ -706,7 +706,7 @@ void TGeoShape::Paint(Option_t *option)
 {
 // Paint this shape.
    TVirtualGeoPainter *painter = gGeoManager->GetGeomPainter();
-   if (option && strlen(option) > 0) {
+   if (option && option[0]) {
       painter->PaintShape(this, option); 
    } else {
       painter->PaintShape(this, gEnv->GetValue("Viewer3D.DefaultDrawOption",""));
