@@ -1,4 +1,4 @@
-// @(#)root/asimage:$Id: TASPaletteEditor.cxx 37058 2010-11-29 09:12:52Z couet $
+// @(#)root/asimage:$Id$
 // Author: Reiner Rohlfs   24/03/2002
 
 /*************************************************************************
@@ -32,6 +32,11 @@
 #include "TROOT.h"
 #include "TClass.h"
 #include "TMath.h"
+#include "RConfigure.h"
+
+#ifdef R__HAS_COCOA
+#   define X_DISPLAY_MISSING 1
+#endif
 
 #ifdef WIN32
 #include "Windows4root.h"
