@@ -13,11 +13,17 @@
 #ifndef ROOT_QuartzPixmap
 #define ROOT_QuartzPixmap
 
-#import <Cocoa/Cocoa.h>
+#include <Cocoa/Cocoa.h>
 
-#import "CocoaGuiTypes.h"
-#import "X11Drawable.h"
-#import "GuiTypes.h"
+#ifndef ROOT_CocoaGuiTypes
+#include "CocoaGuiTypes.h"
+#endif
+#ifndef ROOT_X11Drawable
+#include "X11Drawable.h"
+#endif
+#ifndef ROOT_GuiTypes
+#include "GuiTypes.h"
+#endif
 
 ///////////////////////////////////////////////////////
 //                                                   //
