@@ -12,11 +12,17 @@
 #ifndef ROOT_QuartzWindow
 #define ROOT_QuartzWindow
 
-#import <Cocoa/Cocoa.h>
+#include <Cocoa/Cocoa.h>
 
-#import "CocoaGuiTypes.h"
-#import "X11Drawable.h"
-#import "GuiTypes.h"
+#ifndef ROOT_CocoaGuiTypes
+#include "CocoaGuiTypes.h"
+#endif
+#ifndef ROOT_X11Drawable
+#include "X11Drawable.h"
+#endif
+#ifndef ROOT_GuiTypes
+#include "GuiTypes.h"
+#endif
 
 ////////////////////////////////////////////////
 //                                            //
@@ -277,7 +283,9 @@ void GetWindowAttributes(NSObject<X11Window> *window, WindowAttributes_t *dst);
 NSPoint ConvertPointFromBaseToScreen(NSWindow *window, NSPoint windowPoint);
 NSPoint ConvertPointFromScreenToBase(NSPoint screenPoint, NSWindow *window);
 
+int GlobalXCocoaToROOT(CGFloat xCocoa);
 int GlobalYCocoaToROOT(CGFloat yCocoa);
+int GlobalXROOTToCocoa(CGFloat xROOT);
 int GlobalYROOTToCocoa(CGFloat yROOT);
 
 int LocalYCocoaToROOT(NSView<X11Window> *parentView, CGFloat yCocoa);
