@@ -1,4 +1,4 @@
-// @(#)root/gpad:$Id: TPad.h 43408 2012-03-20 13:02:53Z couet $
+// @(#)root/gpad:$Id$
 // Author: Rene Brun   12/12/94
 
 /*************************************************************************
@@ -127,7 +127,7 @@ protected:
    void          PaintBorder(Color_t color, Bool_t tops);
    virtual void  PaintBorderPS(Double_t xl,Double_t yl,Double_t xt,Double_t yt,Int_t bmode,Int_t bsize,Int_t dark,Int_t light);
    void          PaintDate();
-   virtual void  SavePrimitive(ostream &out, Option_t *option = "");
+   virtual void  SavePrimitive(std::ostream &out, Option_t *option = "");
    virtual void  SetBatch(Bool_t batch=kTRUE);
 
 private:
@@ -284,7 +284,9 @@ public:
    void              PaintPolyMarker(Int_t n, Double_t *x, Double_t *y, Option_t *option="");
    virtual void      PaintModified();
    void              PaintText(Double_t x, Double_t y, const char *text);
+   void              PaintText(Double_t x, Double_t y, const wchar_t *text);
    void              PaintTextNDC(Double_t u, Double_t v, const char *text);
+   void              PaintTextNDC(Double_t u, Double_t v, const wchar_t *text);
    virtual TPad     *Pick(Int_t px, Int_t py, TObjLink *&pickobj);
    Double_t          PixeltoX(Int_t px);
    Double_t          PixeltoY(Int_t py);
