@@ -1,4 +1,4 @@
-// @(#)root/graf:$Id: TPie.cxx 41891 2011-11-10 22:46:31Z pcanal $
+// @(#)root/graf:$Id$
 // Author: Guido Volpi, Olivier Couet 03/11/2006
 
 /*************************************************************************
@@ -810,6 +810,7 @@ void TPie::Paint(Option_t *option)
    // "R"   Print the labels along the central "R"adius of slices.
    // "T"   Print the label in a direction "T"angent to circle that describes
    //       the TPie.
+   // "SC"  Paint the the labels with the "S"ame "C"olor as the slices.
    // "3D"  Draw the pie-chart with a pseudo 3D effect.
    // "NOL" No OutLine: Don't draw the slices' outlines, any property over the
    //       slices' line is ignored.
@@ -830,6 +831,9 @@ void TPie::Paint(Option_t *option)
 
    // if true the lines around the slices are drawn, if false not
    Bool_t optionLine(kTRUE);
+   
+   // if true the labels' colors are the same as the slices' colors
+   Bool_t optionSameColor(kFALSE);
 
    // For the label orientation there are 3 possibilities:
    //   0: horizontal
@@ -849,6 +853,11 @@ void TPie::Paint(Option_t *option)
       optionLine = kFALSE;
       soption.Remove(idx,3);
    }
+   
+   if ( (idx=soption.Index("sc"))>=0 ) {
+      optionSameColor = kTRUE;
+      soption.Remove(idx,2);
+   }
 
    // check if is active the pseudo-3d
    if ( (idx=soption.Index("3d"))>=0 ) {
@@ -1049,7 +1058,8 @@ void TPie::Paint(Option_t *option)
       Float_t rphi = TMath::ATan2((ly-fY)*radXY,lx-fX);
       if (rphi < 0 && fIs3D && label_off>=0.)
          ly -= fHeight;
-
+      
+      if (optionSameColor) textlabel->SetTextColor((fPieSlices[i]->GetFillColor()));
       textlabel->PaintLatex(lx,ly,
                             lblang*180/TMath::Pi()+GetTextAngle(),
                             GetTextSize(), tmptxt.Data());
@@ -1131,57 +1141,57 @@ void TPie::Paint(Option_t *option)
 
 
 //______________________________________________________________________________
-void TPie::SavePrimitive(ostream &out, Option_t *option)
+void TPie::SavePrimitive(std::ostream &out, Option_t *option)
 {
    // Save primitive as a C++ statement(s) on output stream out
 
-   out << "   " << endl;
+   out << "   " << std::endl;
    if (gROOT->ClassSaved(TPie::Class())) {
       out << "   ";
    } else {
       out << "   TPie *";
    }
    out << GetName() << " = new TPie(\"" << GetName() << "\", \"" << GetTitle()
-       << "\", " << fNvals << ");" << endl;
+       << "\", " << fNvals << ");" << std::endl;
    out << "   " << GetName() << "->SetCircle(" << fX << ", " << fY << ", "
-       << fRadius << ");" << endl;
+       << fRadius << ");" << std::endl;
    out << "   " << GetName() << "->SetValueFormat(\"" << GetValueFormat()
-       << "\");" << endl;
+       << "\");" << std::endl;
    out << "   " << GetName() << "->SetLabelFormat(\"" << GetLabelFormat()
-       << "\");" << endl;
+       << "\");" << std::endl;
    out << "   " << GetName() << "->SetPercentFormat(\"" << GetPercentFormat()
-       << "\");" << endl;
+       << "\");" << std::endl;
    out << "   " << GetName() << "->SetLabelsOffset(" << GetLabelsOffset()
-       << ");" << endl;
+       << ");" << std::endl;
    out << "   " << GetName() << "->SetAngularOffset(" << GetAngularOffset()
-       << ");" << endl;
-   out << "   " << GetName() << "->SetTextAngle(" << GetTextAngle() << ");" << endl;
-   out << "   " << GetName() << "->SetTextColor(" << GetTextColor() << ");" << endl;
-   out << "   " << GetName() << "->SetTextFont(" << GetTextFont() << ");" << endl;
-   out << "   " << GetName() << "->SetTextSize(" << GetTextSize() << ");" << endl;
+       << ");" << std::endl;
+   out << "   " << GetName() << "->SetTextAngle(" << GetTextAngle() << ");" << std::endl;
+   out << "   " << GetName() << "->SetTextColor(" << GetTextColor() << ");" << std::endl;
+   out << "   " << GetName() << "->SetTextFont(" << GetTextFont() << ");" << std::endl;
+   out << "   " << GetName() << "->SetTextSize(" << GetTextSize() << ");" << std::endl;
 
 
    // Save the values for the slices
    for (Int_t i=0;i<fNvals;++i) {
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetTitle(\""
-          << fPieSlices[i]->GetTitle() << "\");" << endl;
+          << fPieSlices[i]->GetTitle() << "\");" << std::endl;
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetValue("
-          << fPieSlices[i]->GetValue() << ");" << endl;
+          << fPieSlices[i]->GetValue() << ");" << std::endl;
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetRadiusOffset("
-          << fPieSlices[i]->GetRadiusOffset() << ");" << endl;
+          << fPieSlices[i]->GetRadiusOffset() << ");" << std::endl;
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetFillColor("
-          << fPieSlices[i]->GetFillColor() << ");" << endl;
+          << fPieSlices[i]->GetFillColor() << ");" << std::endl;
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetFillStyle("
-          << fPieSlices[i]->GetFillStyle() << ");" << endl;
+          << fPieSlices[i]->GetFillStyle() << ");" << std::endl;
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetLineColor("
-          << fPieSlices[i]->GetLineColor() << ");" << endl;
+          << fPieSlices[i]->GetLineColor() << ");" << std::endl;
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetLineStyle("
-          << fPieSlices[i]->GetLineStyle() << ");" << endl;
+          << fPieSlices[i]->GetLineStyle() << ");" << std::endl;
       out << "   " << GetName() << "->GetSlice(" << i << ")->SetLineWidth("
-          << fPieSlices[i]->GetLineWidth() << ");" << endl;
+          << fPieSlices[i]->GetLineWidth() << ");" << std::endl;
    }
 
-   out << "   " << GetName() << "->Draw(\"" << option << "\");" << endl;
+   out << "   " << GetName() << "->Draw(\"" << option << "\");" << std::endl;
 }
 
 
