@@ -1,4 +1,4 @@
-// @(#)root/base:$Id: TVirtualX.interface.h 33707 2010-06-02 06:27:34Z brun $
+// @(#)root/base:$Id$
 // Author: Valeri Fine   28/07/2004
 
 //
@@ -21,6 +21,14 @@ public:
    virtual void      ClosePixmap();
    virtual void      CloseWindow();
    virtual void      CopyPixmap(Int_t wid, Int_t xpos, Int_t ypos);
+
+   //TVirtualX has two versions of CreateOpenGLContext
+   using TVirtualX::CreateOpenGLContext;
+
+   //TVirtualX has these two methods with wchar_t
+   using TVirtualX::DrawText;
+   using TVirtualX::GetTextExtent;;
+   
    virtual void      CreateOpenGLContext(Int_t wid=0);
    virtual void      DeleteOpenGLContext(Int_t wid=0);
    virtual void      DrawBox(Int_t x1, Int_t y1, Int_t x2, Int_t y2, EBoxMode mode);
