@@ -1,4 +1,4 @@
-// @(#)root/x11ttf:$Id: TGX11TTF.cxx 42714 2012-01-19 09:10:08Z couet $
+// @(#)root/x11ttf:$Id$
 // Author: Valeriy Onuchin (Xft support)  02/10/07
 // Author: Olivier Couet     01/10/02
 // Author: Fons Rademakers   21/11/98
@@ -350,6 +350,25 @@ void TGX11TTF::DrawText(Int_t x, Int_t y, Float_t angle, Float_t mgn,
    }
 }
 
+//______________________________________________________________________________
+void TGX11TTF::DrawText(Int_t x, Int_t y, Float_t angle, Float_t mgn,
+                        const wchar_t *text, ETextMode mode)
+{
+   // Draw text using TrueType fonts. If TrueType fonts are not available the
+   // text is drawn with TGX11::DrawText.
+
+   if (!fHasTTFonts) {
+      TGX11::DrawText(x, y, angle, mgn, text, mode);
+   } else {
+      if (!TTF::fgInit) TTF::Init();
+      TTF::SetRotationMatrix(angle);
+      TTF::PrepareString(text);
+      TTF::LayoutGlyphs();
+      Align();
+      RenderString(x, y, mode);
+   }
+}
+
 //______________________________________________________________________________
 XImage *TGX11TTF::GetBackground(Int_t x, Int_t y, UInt_t w, UInt_t h)
 {
@@ -591,7 +610,7 @@ void TGX11TTF::DeleteFont(FontStruct_t fs)
 //______________________________________________________________________________
 Int_t TGX11TTF::TextWidth(FontStruct_t font, const char *s, Int_t len)
 {
-   // Return lenght of string in pixels. Size depends on font
+   // Return length of string in pixels. Size depends on font
 
    if (!fXftFontHash) {
       return TGX11::TextWidth(font, s, len);
