@@ -1,4 +1,4 @@
-// @(#)root/gl:$Id: TGLUtil.h 42953 2012-02-09 22:40:19Z matevz $
+// @(#)root/gl:$Id$
 // Author:  Richard Maunder  25/05/2005
 
 /*************************************************************************
@@ -19,6 +19,10 @@
 #include "TError.h"
 #endif
 
+#include <vector>
+#include <cmath>
+#include <cassert>
+
 class TString;
 class TGLBoundingBox;
 class TGLCamera;
@@ -28,48 +32,26 @@ class TAttLine;
 
 class GLUtesselator;
 
-#include <vector>
-#include <cmath>
-#include <cassert>
-
-// TODO:Find a better place for these enums - TGLEnum.h?
-// Whole GL viewer should be moved into own namespace
-// probably
-enum EPosition
+namespace Rgl
 {
-   kInFront = 0,
-   kBehind
-};
+   enum EOverlap
+   {
+      kInside = 0,
+      kPartial,
+      kOutside
+   };
+}
 
-enum EOverlap
+enum EGLCoordType
 {
-   kInside = 0,
-   kPartial,
-   kOutside
-};
-
-enum EClipType
-{
-   kClipNone = 0,
-   kClipPlane,
-   kClipBox
-};
-
-enum EManipType
-{
-   kManipTrans = 0,
-   kManipScale,
-   kManipRotate
-};
-
-enum EGLCoordType {
    kGLCartesian,
    kGLPolar,
    kGLCylindrical,
    kGLSpherical
 };
 
-enum EGLPlotType {
+enum EGLPlotType
+{
    kGLLegoPlot,
    kGLSurfacePlot,
    kGLBoxPlot,
@@ -149,7 +131,7 @@ public:
 
    void Dump() const;
 
-   ClassDef(TGLVertex3,0); // GL 3 component vertex helper/wrapper class
+   ClassDef(TGLVertex3,1); // GL 3 component vertex helper/wrapper class
 };
 
 //______________________________________________________________________________
@@ -283,7 +265,7 @@ public:
    Double_t Mag() const;
    void     Normalise();
 
-   ClassDef(TGLVector3,0); // GL 3 component vector helper/wrapper class
+   ClassDef(TGLVector3,1); // GL 3 component vector helper/wrapper class
 };
 
 // Inline for TGLVertex3 requiring full TGLVector definition
@@ -485,7 +467,7 @@ public:
    Int_t Longest() const;
 
    Double_t Aspect() const;
-   EOverlap Overlap(const TGLRect & other) const;
+   Rgl::EOverlap Overlap(const TGLRect & other) const;
 
    ClassDef(TGLRect,0); // GL rect helper/wrapper class
 };
@@ -666,6 +648,7 @@ public:
    // Accesors
    TGLVector3  GetTranslation() const;
    TGLVector3  GetScale() const;
+   Bool_t      IsScalingForRender() const;
 
    void SetBaseVec(Int_t b, Double_t x, Double_t y, Double_t z);
    void SetBaseVec(Int_t b, const TGLVector3& v);
@@ -686,7 +669,7 @@ public:
 
    void Dump() const;
 
-   ClassDef(TGLMatrix,0); // GL matrix helper/wrapper class
+   ClassDef(TGLMatrix,1); // GL matrix helper/wrapper class
 };
 
 //______________________________________________________________________________
@@ -943,11 +926,16 @@ private:
    static Float_t fgPointSizeScale;
    static Float_t fgLineWidthScale;
 
+   static Float_t fgScreenScalingFactor;
+   static Float_t fgPointLineScalingFactor;
+   static Int_t   fgPickingRadius;
+
    TGLUtil(const TGLUtil&);            // Not implemented.
    TGLUtil& operator=(const TGLUtil&); // Not implemented.
 
 public:
    virtual ~TGLUtil() {}
+   static void InitializeIfNeeded();
 
    // Error checking
    static Int_t  CheckError(const char * loc);
@@ -986,6 +974,13 @@ public:
    static void Color3fv(const Float_t* rgb);
    static void Color4fv(const Float_t* rgba);
 
+   // Coordinate conversion and extra scaling (needed for osx retina)
+   static void    PointToViewport(Int_t& x, Int_t& y);
+   static void    PointToViewport(Int_t& x, Int_t& y, Int_t& w, Int_t& h);
+   static Float_t GetScreenScalingFactor();
+   static Float_t GetPointLineScalingFactor();
+   static Int_t   GetPickingRadius();
+
    static Float_t GetPointSizeScale();
    static void    SetPointSizeScale(Float_t scale);
    static Float_t GetLineWidthScale();
