@@ -1,4 +1,4 @@
-// @(#)root/gl:$Id: TGLWidget.cxx 38716 2011-04-04 10:33:53Z matevz $
+// @(#)root/gl:$Id$
 // Author:  Timur Pocheptsov, Jun 2007
 
 /*************************************************************************
@@ -12,6 +12,7 @@
 #include <stdexcept>
 #include <vector>
 
+
 #include "TVirtualX.h"
 #include "TGClient.h"
 #include "TError.h"
@@ -21,8 +22,8 @@
 #include "TGLIncludes.h"
 #include "TGLWSIncludes.h"
 #include "TGLUtil.h"
-
 #include "TGLEventHandler.h"
+#include "RConfigure.h"
 
 /******************************************************************************/
 // TGLWidget
@@ -74,7 +75,7 @@ TGLWidget* TGLWidget::CreateDummy()
 {
    // Static constructor for creating widget with default pixel format.
 
-   TGLFormat format(TGLFormat::kNone);
+   TGLFormat format(Rgl::kNone);
 
    return Create(format, gClient->GetDefaultRoot(), kFALSE, kFALSE, 0, 1, 1);
 }
@@ -100,6 +101,9 @@ TGLWidget* TGLWidget::Create(const TGLFormat &format,
 {
    // Static constructor for creating widget with given pixel format.
 
+   // Make sure window-system dependent part of GL-util is initialized.
+   TGLUtil::InitializeIfNeeded();
+
    std::pair<void *, void *> innerData;
 
    Window_t wid = CreateWindow(parent, format, width, height, innerData);
@@ -108,6 +112,8 @@ TGLWidget* TGLWidget::Create(const TGLFormat &format,
 
 #ifdef WIN32
    glw->fWindowIndex = (Int_t) innerData.second;
+#elif defined(R__HAS_COCOA)
+   glw->fWindowIndex = wid;
 #else
    glw->fWindowIndex = gVirtualX->AddWindow(wid, width, height);
    glw->fInnerData   = innerData;
@@ -136,7 +142,7 @@ TGLWidget::TGLWidget(Window_t glw, const TGWindow* p, Bool_t selectInput)
    : TGFrame(gClient, glw, p),
      fGLContext(0),
      fWindowIndex(-1),
-     fGLFormat(TGLFormat::kNone),
+     fGLFormat(Rgl::kNone),
      fFromInit(kTRUE),
      fEventHandler(0)
 {
@@ -159,7 +165,9 @@ TGLWidget::~TGLWidget()
    //Destructor. Deletes window ???? and XVisualInfo
 
 #ifndef WIN32
+#ifndef R__HAS_COCOA
    XFree(fInnerData.second);//free XVisualInfo
+#endif
 #endif
    if (fValidContexts.size() > 1u) {
       Warning("~TGLWidget", "There are some gl-contexts connected to this gl device"
@@ -250,6 +258,7 @@ void TGLWidget::RemoveContext(TGLContext *ctx)
 void TGLWidget::ExtractViewport(Int_t *vp)const
 {
    //For camera.
+
    vp[0] = 0;
    vp[1] = 0;
    vp[2] = GetWidth();
@@ -377,9 +386,47 @@ void TGLWidget::SetFormat()
       throw std::runtime_error("ChoosePixelFormat failed");
    }
 }
+//==============================================================================
+#elif defined(R__HAS_COCOA) //MacOSX with Cocoa enabled.
+//==============================================================================
+
+//______________________________________________________________________________
+Window_t TGLWidget::CreateWindow(const TGWindow* parent, const TGLFormat &format,
+                                 UInt_t width, UInt_t height,
+                                 std::pair<void *, void *>& /*internalData*/)
+{
+   // CreateWidget - MacOSX/Cocoa version.
+   // Static function called prior to construction.
+
+   typedef std::pair<UInt_t, Int_t> component_type;
+   
+   std::vector<component_type>formatComponents;
+
+   if (format.HasDepth())
+      formatComponents.push_back(component_type(Rgl::kDepth, format.GetDepthSize()));
+   if (format.HasStencil())
+      formatComponents.push_back(component_type(Rgl::kStencil, format.GetStencilSize()));
+   if (format.HasAccumBuffer())
+      formatComponents.push_back(component_type(Rgl::kAccum, format.GetAccumSize()));
+   if (format.IsDoubleBuffered())
+      formatComponents.push_back(component_type(Rgl::kDoubleBuffer, 0));
+   if (format.IsStereo())
+      formatComponents.push_back(component_type(Rgl::kStereo, 0));
+   if (format.HasMultiSampling())
+      formatComponents.push_back(component_type(Rgl::kMultiSample, format.GetSamples()));
+
+   return gVirtualX->CreateOpenGLWindow(parent->GetId(), width, height, formatComponents);
+}
+
+//______________________________________________________________________________
+void TGLWidget::SetFormat()
+{
+   // Set pixel format.
+   // Empty version for X11.
+}
 
 //==============================================================================
-#else // Non WIN32
+#else // X11
 //==============================================================================
 
 namespace
