@@ -1,4 +1,4 @@
-// @(#)root/gui:$Id: TGTextEditor.cxx 43733 2012-04-13 13:43:16Z bellenot $
+// @(#)root/gui:$Id$
 // Author: Bertrand Bellenot   20/06/06
 
 /*************************************************************************
@@ -439,7 +439,7 @@ void TGTextEditor::Build()
    fStatusBar->SetParts(parts, 2);
    AddFrame(fStatusBar, new TGLayoutHints(kLHintsBottom | kLHintsExpandX, 0, 0, 3, 0));
 
-   SetClassHints("TGTextEditor", "TGTextEditor");
+   SetClassHints("ROOT", "TGTextEditor");
    SetWindowName("Untitled - TGTextEditor");
 
    fMacro = 0;
@@ -476,7 +476,7 @@ void TGTextEditor::Build()
 //______________________________________________________________________________
 void TGTextEditor::DataDropped(char *fname)
 {
-   // Update file informations when receiving the signal
+   // Update file information when receiving the signal
    // DataDropped from TGTextEdit widget.
 
    TString tmp;
