@@ -1,4 +1,4 @@
-// @(#)root/gui:$Id: TRootBrowser.cxx 43360 2012-03-15 10:55:25Z bellenot $
+// @(#)root/gui:$Id: 4ed8aea02c288ef2cae232094ae0b155c9a799df $
 // Author: Bertrand Bellenot   26/09/2007
 
 /*************************************************************************
@@ -70,12 +70,13 @@
 #include "TEnv.h"
 #include <KeySymbols.h>
 
+#include "RConfigure.h"
+
 #include "TRootBrowser.h"
 #include "TGFileBrowser.h"
 #include "TGInputDialog.h"
 #include "TRootHelpDialog.h"
 #include "HelpText.h"
-
 #include "Getline.h"
 
 #ifdef WIN32
@@ -94,28 +95,6 @@ static const char *gPluginFileTypes[] = {
    0,              0
 };
 
-enum ENewBrowserMessages {
-   kBrowse = 11011,
-   kOpenFile,
-   kClone,
-   kHelpAbout,
-   kHelpOnBrowser,
-   kHelpOnCanvas,
-   kHelpOnMenus,
-   kHelpOnGraphicsEd,
-   kHelpOnObjects,
-   kHelpOnPS,
-   kHelpOnRemote,
-   kNewEditor,
-   kNewCanvas,
-   kNewHtml,
-   kExecPluginMacro,
-   kExecPluginCmd,
-   kCloseTab,
-   kCloseWindow,
-   kQuitRoot
-};
-
 //_____________________________________________________________________________
 //
 // TRootBrowser
@@ -134,6 +113,7 @@ TRootBrowser::TRootBrowser(TBrowser *b, const char *name, UInt_t width,
 
    fShowCloseTab = kTRUE;
    fActBrowser = 0;
+   fIconPic = 0;
    CreateBrowser(name);
    Resize(width, height);
    if (initshow) {
@@ -153,6 +133,7 @@ TRootBrowser::TRootBrowser(TBrowser *b, const char *name, Int_t x, Int_t y,
 
    fShowCloseTab = kTRUE;
    fActBrowser = 0;
+   fIconPic = 0;
    CreateBrowser(name);
    MoveResize(x, y, width, height);
    SetWMPosition(x, y);
@@ -238,7 +219,11 @@ void TRootBrowser::CreateBrowser(const char *name)
 
    fHf = new TGHorizontalFrame(fVf, 100, 100);
    // Tabs & co...
+#if defined(R__HAS_COCOA)
+   fV1 = new TGVerticalFrame(fHf, 252, 100, kFixedWidth);
+#else
    fV1 = new TGVerticalFrame(fHf, 250, 100, kFixedWidth);
+#endif
    fV2 = new TGVerticalFrame(fHf, 600, 100);
    fH1 = new TGHorizontalFrame(fV2, 100, 100);
    fH2 = new TGHorizontalFrame(fV2, 100, 100, kFixedHeight);
@@ -296,7 +281,8 @@ void TRootBrowser::CreateBrowser(const char *name)
    // Set a name to the main frame
    SetWindowName(name);
    SetIconName(name);
-   SetClassHints("Browser", "Browser");
+   fIconPic = SetIconPixmap("rootdb_s.xpm");
+   SetClassHints("ROOT", "Browser");
 
    if (!strcmp(gROOT->GetDefCanvasName(), "c1"))
       gROOT->SetDefCanvasName("Canvas_1");
@@ -314,6 +300,7 @@ TRootBrowser::~TRootBrowser()
 {
    // Clean up all widgets, frames and layouthints that were used
 
+   if (fIconPic) gClient->FreePicture(fIconPic);
    delete fLH0;
    delete fLH1;
    delete fLH2;
@@ -780,7 +767,7 @@ void TRootBrowser::HandleMenu(Int_t id)
          }
          break;
       case kCloseTab:
-         RemoveTab(kRight, fTabRight->GetCurrent());
+         CloseTab(fTabRight->GetCurrent());
          break;
       case kCloseWindow:
          CloseWindow();
