@@ -48,6 +48,7 @@
 #include "TClassMenuItem.h"
 #include "TObjectSpy.h"
 #include "KeySymbols.h"
+#include "RConfigure.h"
 
 enum EContextMenu {
    kToggleStart       = 1000, // first id of toggle menu items
@@ -116,6 +117,23 @@ void TRootContextMenu::DisplayPopup(Int_t x, Int_t y)
 
    xx = topx + x + 1;
    yy = topy + y + 1;
+   
+#ifdef R__HAS_COCOA
+   //Context menu must be transient for a canvas, otherwise it's possible
+   //to break the z-order (for example, using alt-tab to switch between
+   //different aplications). This hint works ONLY for canvas though
+   //(otherwise selected canvas is null).
+   TGWindow *parent = 0;
+   if (TVirtualPad *pad = fContextMenu->GetSelectedCanvas())
+      parent = dynamic_cast<TGWindow *>(pad->GetCanvasImp());
+   else if ((pad = fContextMenu->GetSelectedPad()) && pad->GetCanvasImp())
+      parent = dynamic_cast<TGWindow *>(pad->GetCanvasImp());
+   else if (TBrowser * const browser = fContextMenu->GetBrowser())
+      parent = dynamic_cast<TGWindow *>(browser->GetBrowserImp());
+   
+   if (parent)
+      gVirtualX->SetWMTransientHint(GetId(), parent->GetId());
+#endif
 
    PlaceMenu(xx, yy, kTRUE, kTRUE);
    // add some space for the right-side '?' (help)
@@ -350,6 +368,7 @@ void TRootContextMenu::CreateMenu(TObject *object)
             break;
          case TClassMenuItem::kPopupUserFunction:
             {
+               const char* menuItemTitle = menuItem->GetTitle();
                if (menuItem->IsToggle()) {
                   TMethod* method =
                         object->IsA()->GetMethodWithPrototype(menuItem->GetFunctionName(),menuItem->GetArgs());
@@ -359,11 +378,11 @@ void TRootContextMenu::CreateMenu(TObject *object)
                      t->SetOnValue(1);
                      fTrash->Add(t);
 
-                     AddEntry(method->GetName(), toggle++, t);
+                     if (strlen(menuItemTitle)==0) menuItemTitle = method->GetName();
+                     AddEntry(menuItemTitle, toggle++, t);
                      if (t->GetState()) CheckEntry(toggle-1);
                   }
                } else {
-                  const char* menuItemTitle = menuItem->GetTitle();
                   if (strlen(menuItemTitle)==0) menuItemTitle = menuItem->GetFunctionName();
                   AddEntry(menuItemTitle,userfunction++,menuItem);
                }
