@@ -623,7 +623,9 @@ void TAxis::SaveAttributes(std::ostream &out, const char *name, const char *subn
 
    char quote = '"';
    if (strlen(GetTitle())) {
-      out<<"   "<<name<<subname<<"->SetTitle("<<quote<<GetTitle()<<quote<<");"<<std::endl;
+      TString t(GetTitle());
+      t.ReplaceAll("\\","\\\\");
+      out<<"   "<<name<<subname<<"->SetTitle("<<quote<<t.Data()<<quote<<");"<<std::endl;
    }
    if (fTimeDisplay) {
       out<<"   "<<name<<subname<<"->SetTimeDisplay(1);"<<std::endl;
@@ -788,6 +790,8 @@ void TAxis::SetBinLabel(Int_t bin, const char *label)
       if ( obj->GetUniqueID()==(UInt_t)bin ) {
          // It does. Overwrite it.
          obj->SetString(label);
+         // LM need to rehash the labels list (see ROOT-5025)
+         fLabels->Rehash(fLabels->GetSize() );
          return;
       }
    }
@@ -1076,7 +1080,7 @@ void TAxis::UnZoom()
 {
    // Reset first & last bin to the full range
 
-
+   if (!gPad) return;
    gPad->SetView();
 
    //unzoom object owning this axis
@@ -1096,8 +1100,13 @@ void TAxis::UnZoom()
          hobj1->SetMinimum(fXmin);
          hobj1->SetMaximum(fXmax);
       } else {
-         hobj1->SetMinimum();
-         hobj1->SetMaximum();
+         if (fXmin==hobj1->GetMinimum() && fXmax==hobj1->GetMaximum()) {
+            hobj1->SetMinimum(fXmin);
+            hobj1->SetMaximum(fXmax);
+         } else {
+            hobj1->SetMinimum();
+            hobj1->SetMaximum();
+         }
          hobj1->ResetBit(TH1::kIsZoomed);
       }
    }
