@@ -589,7 +589,7 @@ void TGraph::Browse(TBrowser *b)
 
 
 //______________________________________________________________________________
-Double_t TGraph::Chisquare(const TF1 *f1) const
+Double_t TGraph::Chisquare(const TF1 *f1, Option_t * option) const
 {
    // Return the chisquare of this graph with respect to f1.
    // The chisquare is computed as the sum of the quantity below at each point:
@@ -602,45 +602,60 @@ Double_t TGraph::Chisquare(const TF1 *f1) const
    // In case of a pure TGraph, the denominator is 1.
    // In case of a TGraphErrors or TGraphAsymmErrors the errors are taken
    // into account.
+   // By default the range of the graph is used whatever function range.
+   //  Use option "R" to use the function range
 
-   if (!f1) return 0;
-   Double_t cu, eu, exh, exl, ey, eux, fu, fsum;
-   Double_t x[1];
-   Double_t chi2 = 0;
-   TF1 *func = (TF1*)f1; //EvalPar is not const !
-   for (Int_t i = 0; i < fNpoints; i++) {
-      func->InitArgs(x, 0); //must be inside the loop because of TF1::Derivative calling InitArgs
-      x[0] = fX[i];
-      if (!func->IsInside(x)) continue;
-      cu   = fY[i];
-      TF1::RejectPoint(kFALSE);
-      fu   = func->EvalPar(x);
-      if (TF1::RejectedPoint()) continue;
-      fsum = (cu - fu);
-      //npfits++;
-      exh = GetErrorXhigh(i);
-      exl = GetErrorXlow(i);
-      if (fsum < 0)
-         ey = GetErrorYhigh(i);
-      else
-         ey = GetErrorYlow(i);
-      if (exl < 0) exl = 0;
-      if (exh < 0) exh = 0;
-      if (ey < 0)  ey  = 0;
-      if (exh > 0 || exl > 0) {
-         //"Effective Variance" method introduced by Anna Kreshuk
-         //a copy of the algorithm in GraphFitChisquare from TFitter
-         eux = 0.5 * (exl + exh) * func->Derivative(x[0]);
-      } else
-         eux = 0.;
-      eu = ey * ey + eux * eux;
-      if (eu <= 0) eu = 1;
-      chi2 += fsum * fsum / eu;
+   // need to cast away the const - since it requires evaluating the function which is not const
+   TF1 * func = const_cast<TF1*>(f1);
+   if (!func) { 
+      Error("Chisquare","Function pointer is Null - return -1");
+      return -1;
    }
-   return chi2;
+
+   TString opt(option); opt.ToUpper(); 
+   bool useRange = opt.Contains("R");
+   
+   return ROOT::Fit::Chisquare(*this, *func,useRange);
 }
 
 
+//    Double_t cu, eu, exh, exl, ey, eux, fu, fsum;
+//    Double_t x[1];
+//    Double_t chi2 = 0;
+//    TF1 *func = (TF1*)f1; //EvalPar is not const !
+//    for (Int_t i = 0; i < fNpoints; i++) {
+//       func->InitArgs(x, 0); //must be inside the loop because of TF1::Derivative calling InitArgs
+//       x[0] = fX[i];
+//       if (!func->IsInside(x)) continue;
+//       cu   = fY[i];
+//       TF1::RejectPoint(kFALSE);
+//       fu   = func->EvalPar(x);
+//       if (TF1::RejectedPoint()) continue;
+//       fsum = (cu - fu);
+//       //npfits++;
+//       exh = GetErrorXhigh(i);
+//       exl = GetErrorXlow(i);
+//       if (fsum < 0)
+//          ey = GetErrorYhigh(i);
+//       else
+//          ey = GetErrorYlow(i);
+//       if (exl < 0) exl = 0;
+//       if (exh < 0) exh = 0;
+//       if (ey < 0)  ey  = 0;
+//       if (exh > 0 || exl > 0) {
+//          //"Effective Variance" method introduced by Anna Kreshuk
+//          //a copy of the algorithm in GraphFitChisquare from TFitter
+//          eux = 0.5 * (exl + exh) * func->Derivative(x[0]);
+//       } else
+//          eux = 0.;
+//       eu = ey * ey + eux * eux;
+//       if (eu <= 0) eu = 1;
+//       chi2 += fsum * fsum / eu;
+//    }
+//    return chi2;
+// }
+
+
 //______________________________________________________________________________
 Bool_t TGraph::CompareArg(const TGraph* gr, Int_t left, Int_t right)
 {
@@ -804,6 +819,15 @@ void TGraph::Draw(Option_t *option)
       if (!gPad->IsEditable()) gROOT->MakeDefCanvas();
       if (opt.Contains("a")) gPad->Clear();
    }
+   // If no option is specified, it is defined as "alp" in case there
+   // no current pad or if the current pad as no axis defined.
+   if (!strlen(option)) {
+      if (gPad) {
+         if (!gPad->GetListOfPrimitives()->FindObject("TFrame")) opt = "alp";
+      } else {
+         opt = "alp";
+      }
+   }
    AppendPad(opt);
 }
 
@@ -1259,7 +1283,7 @@ TFitResultPtr TGraph::Fit(TF1 *f1, Option_t *option, Option_t *goption, Axis_t r
    //  TMatrixDSym cov = r->GetCovarianceMatrix();  //  to access the covariance matrix
    //  Double_t chi2   = r->Chi2(); // to retrieve the fit chi2
    //  Double_t par0   = r->Value(0); // retrieve the value for the parameter 0
-   //  Double_t err0   = r->Error(0); // retrieve the error for the parameter 0
+   //  Double_t err0   = r->ParError(0); // retrieve the error for the parameter 0
    //  r->Print("V");     // print full information of fit including covariance matrix
    //  r->Write();        // store the result in a file
    //
@@ -1278,7 +1302,7 @@ TFitResultPtr TGraph::Fit(TF1 *f1, Option_t *option, Option_t *goption, Axis_t r
    //  =====================
    //  The status of the fit can be obtained converting the TFitResultPtr to an integer
    //  indipendently if the fit option "S" is used or not:
-   //  TFitResultPtr r = h=>Fit(myFunc,opt);
+   //  TFitResultPtr r = h->Fit(myFunc,opt);
    //  Int_t fitStatus = r;
    //
    //  The fitStatus is 0 if the fit is OK (i.e. no error occurred).
