@@ -190,7 +190,7 @@ Begin_Macro(source)
          z = sin(sqrt(x*x+y*y))+1;
          dt->SetPoint(k,x,y,z);
          k++;
-         y = y+dx;
+         y = y+dy;
       }
       x = x+dx;
       y = -P;
@@ -614,7 +614,7 @@ void TGraph2D::Clear(Option_t * /*option = "" */)
    delete [] fZ;
    fZ = 0;
    fSize = fNpoints = 0;
-   if (fHistogram) {
+   if (fHistogram && !fUserHisto) {
       delete fHistogram;
       fHistogram = 0;
    }
