@@ -143,10 +143,8 @@ void TProfile3D::BuildOptions(Double_t tmin, Double_t tmax, Option_t *option)
 
    SetErrorOption(option);
 
-   fBinEntries.Set(fNcells);  //*-* create number of entries per cell array
-
-   TH1::Sumw2();                   //*-* create sum of squares of weights array times y 
-   if (fgDefaultSumw2) Sumw2();    // optionally create sum of squares of weights
+   // create extra profile data structire (bin entries/ y^2 and sum of weight square)
+   TProfileHelper::BuildArray(this);
 
    fTmin = tmin;
    fTmax = tmax;
@@ -1268,6 +1266,16 @@ void TProfile3D::SetBins(Int_t nx, const Double_t *xBins, Int_t ny, const Double
    fBinEntries.Set(fNcells);
    if (fBinSumw2.fN) fBinSumw2.Set(fNcells);
 }
+
+//______________________________________________________________________________
+void TProfile3D::SetBinsLength(Int_t n)
+{
+   // Set total number of bins including under/overflow
+   // Reallocate bin contents array
+   TH3D::SetBinsLength(n);
+   TProfileHelper::BuildArray(this);   
+}
+
 //______________________________________________________________________________
 void TProfile3D::SetBuffer(Int_t buffersize, Option_t *)
 {
