@@ -33,6 +33,9 @@ public:
    template <typename T>
    static Bool_t Add(T* p, const TH1 *h1,  const TH1 *h2, Double_t c1, Double_t c2=1);
 
+   template <typename T>
+   static void BuildArray(T* p);
+
    template <typename T>
    static Double_t GetBinEffectiveEntries(T* p, Int_t bin);
 
@@ -120,6 +123,19 @@ Bool_t TProfileHelper::Add(T* p, const TH1 *h1,  const TH1 *h2, Double_t c1, Dou
    return kTRUE;
 }
 
+template <typename T>
+void TProfileHelper::BuildArray(T* p) { 
+   // Build the extra profile data structure in addition to the histograms
+   // this are:    array of bin entries:  fBinEntries 
+   //              array of sum of profiled observable value - squared
+   //              stored in TH1::fSumw2 
+   //              array of some of weight squared (optional) in TProfile::fBinSumw2
+   p->fBinEntries.Set(p->fNcells);
+   p->fSumw2.Set(p->fNcells);  
+   if (TH1::GetDefaultSumw2() || p->fBinSumw2.fN > 0 ) p->fBinSumw2.Set(p->fNcells);
+}
+
+
 template <typename T>
 Double_t TProfileHelper::GetBinEffectiveEntries(T* p, Int_t bin) 
 {
