@@ -1,4 +1,4 @@
-// @(#)root/html:$Id: TClassDocOutput.cxx 43326 2012-03-12 13:32:53Z axel $
+// @(#)root/html:$Id$
 // Author: Axel Naumann 2007-01-09
 
 /*************************************************************************
@@ -1046,7 +1046,7 @@ Bool_t TClassDocOutput::CreateDotClassChartLib(const char* filename) {
       }
       outdot << "}" << endl; // dependencies
    } else
-      outdot << "\"No rlibmap information avaliable.\"" << endl;
+      outdot << "\"No rlibmap information available.\"" << endl;
 
    outdot << "}" << endl; // digraph
 
