@@ -1,4 +1,4 @@
-// @(#)root/html:$Id: THtml.cxx 44070 2012-05-02 14:46:38Z axel $
+// @(#)root/html:$Id$
 // Author: Nenad Buncic (18/10/95), Axel Naumann (09/28/01)
 
 /*************************************************************************
@@ -310,11 +310,13 @@ TString THtml::TFileDefinition::MatchFileSysName(TString& filename, TFileSysEntr
          if (!filename.EndsWith(fsentry->GetName()))
             continue;
          fsentry->GetFullName(filesysname, kTRUE); // get the short version
+         filename = filesysname;
          if (!filename.EndsWith(filesysname)) {
-            filesysname = "";
+            // It's something - let's see whether we find something better
+            // else leave it as plan B. This helps finding Reflex sources.
+            //filesysname = "";
             continue;
          }
-         filename = filesysname;
          fsentry->GetFullName(filesysname, kFALSE); // get the long version
          if (fse) *fse = fsentry;
          break;
@@ -785,7 +787,7 @@ These are typical things people do with THtml:
 or to run on just a few classes:
 <pre>
     root[] <a href="http://root.cern.ch/root/html/THtml.html">THtml</a> html;                // create a <a href="http://root.cern.ch/root/html/THtml.html">THtml</a> object
-    root[] html.MakeIndex();           // create auxilliary files (style sheet etc) and indices
+    root[] html.MakeIndex();           // create auxiliary files (style sheet etc) and indices
     root[] html.MakeClass("TMyClass"); // create documentation for TMyClass only
 </pre>
 To "beautify" (i.e. create links to documentation for class names etc) some text
@@ -2396,7 +2398,7 @@ void THtml::MakeTree(const char *className, Bool_t force)
 
 //______________________________________________________________________________
 void THtml::SetFoundDot(Bool_t found) {
-   // Set whether "dot" (a GraphViz utility) is avaliable
+   // Set whether "dot" (a GraphViz utility) is available
    if (found) fPathInfo.fFoundDot = PathInfo_t::kDotFound;
    else fPathInfo.fFoundDot = PathInfo_t::kDotNotFound;
 }
