@@ -593,7 +593,7 @@ void TDirectoryFile::Delete(const char *namecycle)
    TDirectory::TContext ctxt(gDirectory, this);
    Short_t  cycle;
    char     name[kMaxLen];
-   DecodeNameCycle(namecycle, name, cycle);
+   DecodeNameCycle(namecycle, name, cycle, kMaxLen);
 
    Int_t deleteall    = 0;
    Int_t deletetree   = 0;
@@ -718,7 +718,7 @@ TKey *TDirectoryFile::FindKey(const char *keyname) const
    Short_t  cycle;
    char     name[kMaxLen];
 
-   DecodeNameCycle(keyname, name, cycle);
+   DecodeNameCycle(keyname, name, cycle, kMaxLen);
    return GetKey(name,cycle);
 }
 
@@ -734,7 +734,7 @@ TKey *TDirectoryFile::FindKeyAny(const char *keyname) const
    Short_t  cycle;
    char     name[kMaxLen];
 
-   DecodeNameCycle(keyname, name, cycle);
+   DecodeNameCycle(keyname, name, cycle, kMaxLen);
 
    TIter next(GetListOfKeys());
    TKey *key;
@@ -777,7 +777,7 @@ TObject *TDirectoryFile::FindObjectAny(const char *aname) const
    Short_t  cycle;
    char     name[kMaxLen];
 
-   DecodeNameCycle(aname, name, cycle);
+   DecodeNameCycle(aname, name, cycle, kMaxLen);
 
    TIter next(GetListOfKeys());
    TKey *key;
@@ -849,7 +849,7 @@ TObject *TDirectoryFile::Get(const char *namecycle)
    Short_t  cycle;
    char     name[kMaxLen];
 
-   DecodeNameCycle(namecycle, name, cycle);
+   DecodeNameCycle(namecycle, name, cycle, kMaxLen);
    Int_t nch = strlen(name);
    for (Int_t i = nch-1; i > 0; i--) {
       if (name[i] == '/') {
@@ -949,7 +949,7 @@ void *TDirectoryFile::GetObjectChecked(const char *namecycle, const TClass* expe
    Short_t  cycle;
    char     name[kMaxLen];
 
-   DecodeNameCycle(namecycle, name, cycle);
+   DecodeNameCycle(namecycle, name, cycle, kMaxLen);
    Int_t nch = strlen(name);
    for (Int_t i = nch-1; i > 0; i--) {
       if (name[i] == '/') {
@@ -1026,13 +1026,18 @@ TKey *TDirectoryFile::GetKey(const char *name, Short_t cycle) const
 //*-*                  =====================================
 //  if cycle = 9999 returns highest cycle
 //
+
+   // TIter::TIter() already checks for null pointers
+   TIter next( ((THashList *)(GetListOfKeys()))->GetListForObject(name) );
+
    TKey *key;
-   TIter next(GetListOfKeys());
-   while ((key = (TKey *) next()))
+   while (( key = (TKey *)next() )) {
       if (!strcmp(name, key->GetName())) {
-         if (cycle == 9999)             return key;
-         if (cycle >= key->GetCycle())  return key;
+         if ((cycle == 9999) || (cycle >= key->GetCycle()))
+            return key;
       }
+   }
+
    return 0;
 }
 
@@ -1788,7 +1793,7 @@ Int_t TDirectoryFile::WriteTObject(const TObject *obj, const char *name, Option_
    // Remove trailing blanks in object name
    Int_t nch = strlen(oname);
    char *newName = 0;
-   if (oname[nch-1] == ' ') {
+   if (nch && oname[nch-1] == ' ') {
       newName = new char[nch+1];
       strlcpy(newName,oname,nch+1);
       for (Int_t i=0;i<nch;i++) {
@@ -1912,7 +1917,7 @@ Int_t TDirectoryFile::WriteObjectAny(const void *obj, const TClass *cl, const ch
    // Remove trailing blanks in object name
    Int_t nch = strlen(oname);
    char *newName = 0;
-   if (oname[nch-1] == ' ') {
+   if (nch && oname[nch-1] == ' ') {
       newName = new char[nch+1];
       strlcpy(newName,oname,nch+1);
       for (Int_t i=0;i<nch;i++) {
