@@ -1,4 +1,4 @@
-// @(#)root/io:$Id: TFileMerger.cxx 44534 2012-06-04 16:52:20Z pcanal $
+// @(#)root/io:$Id$
 // Author: Andreas Peters + Fons Rademakers + Rene Brun  26/5/2005
 
 /*************************************************************************
@@ -87,7 +87,7 @@ static Int_t R__GetSystemMaxOpenedFiles()
 TFileMerger::TFileMerger(Bool_t isLocal, Bool_t histoOneGo)
             : fOutputFile(0), fFastMethod(kTRUE), fNoTrees(kFALSE), fExplicitCompLevel(kFALSE), fCompressionChange(kFALSE),
               fPrintLevel(0), fMsgPrefix("TFileMerger"), fMaxOpenedFiles( R__GetSystemMaxOpenedFiles() ),
-              fLocal(isLocal), fHistoOneGo(histoOneGo)
+              fLocal(isLocal), fHistoOneGo(histoOneGo), fObjectNames()
 {
    // Create file merger object.
 
@@ -122,6 +122,7 @@ void TFileMerger::Reset()
    fFileList->Clear();
    fMergeList->Clear();
    fExcessFiles->Clear();
+   fObjectNames.Clear();
 }
 
 //______________________________________________________________________________
@@ -350,8 +351,11 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
    //   kAll          : merge all type of objects (default)
    //   kResetable    : merge only the objects with a MergeAfterReset member function.
    //   kNonResetable : merge only the objects without a MergeAfterReset member function.
+   //   kOnlyListed   : merge only objects listed in fObjectNames
+   //   kSkipListed   : skip merging of objects listed in fObjectNames
 
    Bool_t status = kTRUE;
+   Bool_t onlyListed = kFALSE;
    if (fPrintLevel > 0) {
       Printf("%s Target path: %s",fMsgPrefix.Data(),target->GetPath());
    }
@@ -364,6 +368,14 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
    Int_t nguess = sourcelist->GetSize()+1000;
    THashList allNames(nguess);
    allNames.SetOwner(kTRUE);
+   // If the mode is set to skipping list objects, add names to the allNames list
+   if (type & kSkipListed) {
+      TObjArray *arr = fObjectNames.Tokenize(" ");
+      arr->SetOwner(kFALSE);
+      for (Int_t iname=0; iname<arr->GetEntriesFast(); iname++)
+         allNames.Add(arr->At(iname));
+      delete arr;   
+   }
    ((THashList*)target->GetList())->Rehash(nguess);
    ((THashList*)target->GetListOfKeys())->Rehash(nguess);
    
@@ -393,13 +405,15 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
          TString oldkeyname;
          
          while ( (key = (TKey*)nextkey())) {
-            
-            // Keep only the highest cycle number for each key.  They are stored in the (hash) list
-            // consecutively and in decreasing order of cycles, so we can continue until the name
-            // changes.
-            if (oldkeyname == key->GetName()) continue;
+
+            // Keep only the highest cycle number for each key for mergeable objects. They are stored
+            // in the (hash) list onsecutively and in decreasing order of cycles, so we can continue
+            // until the name changes. We flag the case here and we act consequently later.
+            Bool_t alreadyseen = (oldkeyname == key->GetName()) ? kTRUE : kFALSE;
+
             // Read in but do not copy directly the processIds.
             if (strcmp(key->GetClassName(),"TProcessID") == 0) { key->ReadObj(); continue;}
+
             // If we have already seen this object [name], we already processed
             // the whole list of files for this objects and we can just skip it
             // and any related cycles.
@@ -407,14 +421,29 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
                oldkeyname = key->GetName();
                continue;
             }
-            
+
             TClass *cl = TClass::GetClass(key->GetClassName());
             if (!cl || !cl->InheritsFrom(TObject::Class())) {
                Info("MergeRecursive", "cannot merge object type, name: %s title: %s",
                     key->GetName(), key->GetTitle());
                continue;
             }
-            allNames.Add(new TObjString(key->GetName()));
+            // Check if only the listed objects are to be merged
+            if (type & kOnlyListed) {
+               onlyListed = kFALSE;
+               oldkeyname = key->GetName();
+               oldkeyname += " ";
+               onlyListed = fObjectNames.Contains(oldkeyname);
+               oldkeyname = key->GetName();
+               if ((!onlyListed) && (!cl->InheritsFrom(TDirectory::Class()))) continue;
+            }               
+            // For mergeable objects we add the names in a local hashlist handling them
+            // again (see above)
+            if (cl->GetMerge() || cl->InheritsFrom(TDirectory::Class()) ||
+               (cl->InheritsFrom(TObject::Class()) &&
+               (cl->GetMethodWithPrototype("Merge", "TCollection*,TFileMergeInfo*") ||
+                cl->GetMethodWithPrototype("Merge", "TCollection*"))))
+               allNames.Add(new TObjString(key->GetName()));
             
             if (fNoTrees && cl->InheritsFrom(R__TTree_Class)) {
                // Skip the TTree objects and any related cycles.
@@ -462,7 +491,9 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
                
                target->cd();
                TDirectory *newdir;
-               if (type & kIncremental) {
+
+               // For incremental or already seen we may have already a directory created
+               if (type & kIncremental || alreadyseen) {
                   newdir = target->GetDirectory(obj->GetName());
                   if (!newdir) {
                      newdir = target->mkdir( obj->GetName(), obj->GetTitle() );
@@ -470,14 +501,22 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
                } else {
                   newdir = target->mkdir( obj->GetName(), obj->GetTitle() );
                }
-               
+
                // newdir is now the starting point of another round of merging
                // newdir still knows its depth within the target file via
                // GetPath(), so we can still figure out where we are in the recursion
+
+
+               // If this folder is a onlyListed object, merge everything inside.
+               if (onlyListed) type &= ~kOnlyListed;
                status = MergeRecursive(newdir, sourcelist, type);
+               if (onlyListed) type |= kOnlyListed;
                if (!status) return status;
             } else if (obj->IsA()->GetMerge()) {
                
+               // Check if already treated
+               if (alreadyseen) continue;
+               
                TList inputs;
                Bool_t oneGo = fHistoOneGo && obj->IsA()->InheritsFrom(R__TH1_Class);
                
@@ -535,6 +574,9 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
                        obj->IsA()->GetMethodWithPrototype("Merge", "TCollection*,TFileMergeInfo*") ) {
                // Object implements Merge(TCollection*,TFileMergeInfo*) and has a reflex dictionary ... 
                
+               // Check if already treated
+               if (alreadyseen) continue;
+               
                TList listH;
                TString listHargs;
                listHargs.Form("(TCollection*)0x%lx,(TFileMergeInfo*)0x%lx", (ULong_t)&listH,(ULong_t)&info);
@@ -595,6 +637,9 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
                        obj->IsA()->GetMethodWithPrototype("Merge", "TCollection*") ) {
                // Object implements Merge(TCollection*) and has a reflex dictionary ...
                
+               // Check if already treated
+               if (alreadyseen) continue;
+               
                TList listH;
                TString listHargs;
                listHargs.Form("((TCollection*)0x%lx)", (ULong_t)&listH);
@@ -652,42 +697,7 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
                }
             } else {
                // Object is of no type that we can merge
-               Bool_t warned = kFALSE;
                canBeMerged = kFALSE;
-
-               // Loop over all source files and write similar objects directly to the output file
-               TFile *nextsource = current_file ? (TFile*)sourcelist->After( current_file ) : (TFile*)sourcelist->First();
-               while (nextsource) {
-                  // make sure we are at the correct directory level by cd'ing to path
-                  TDirectory *ndir = nextsource->GetDirectory(path);
-                  if (ndir) {
-                     ndir->cd();
-                     TKey *key2 = (TKey*)ndir->GetListOfKeys()->FindObject(key->GetName());
-                     if (key2) {
-                        if (!warned) {
-                           Warning("MergeRecursive", "cannot merge object type (n:'%s', t:'%s') - "
-                                   "Merge(TCollection *) not implemented",
-                                   obj->GetName(), obj->GetTitle());
-                           warned = kTRUE;
-                        }
-                        TObject *nobj = key2->ReadObj();
-                        if (!nobj) {
-                           Info("MergeRecursive", "could not read object for key {%s, %s}; skipping file %s",
-                                key->GetName(), key->GetTitle(), nextsource->GetName());
-                           nextsource = (TFile*)sourcelist->After(nextsource);
-                           continue;
-                        }
-                        nobj->ResetBit(kMustCleanup);
-                        if (target->WriteTObject(nobj, key2->GetName(), "SingleKey") <= 0) {
-                           Warning("MergeRecursive", "problems copying object (n:'%s', t:'%s') to output file ",
-                                   obj->GetName(), obj->GetTitle());
-                           status = kFALSE;
-                        }
-                        delete nobj;
-                     }
-                  }
-                  nextsource = (TFile*)sourcelist->After( nextsource );
-               }
             }
             
             // now write the merged histogram (which is "in" obj) to the target file
@@ -716,10 +726,11 @@ Bool_t TFileMerger::MergeRecursive(TDirectory *target, TList *sourcelist, Int_t
                delete obj;
             } else {
                // Don't overwrite, if the object were not merged.
+               // NOTE: this is probably wrong for emulated objects.
                if ( obj->Write( oldkeyname, canBeMerged ? TObject::kOverwrite : 0) <= 0) {
                   status = kFALSE;
                }
-               delete obj;
+               cl->Destructor(obj); // just in case the class is not loaded.
             }
             info.Reset();
          } // while ( ( TKey *key = (TKey*)nextkey() ) )
@@ -905,7 +916,7 @@ void TFileMerger::RecursiveRemove(TObject *obj)
    // Intercept the case where the output TFile is deleted!
    
    if (obj == fOutputFile) {
-      Fatal("RecursiveRemove","Output file of the TFile Merger (targetting %s) has been deleted (likely due to a TTree larger than 100Gb)", fOutputFilename.Data());
+      Fatal("RecursiveRemove","Output file of the TFile Merger (targeting %s) has been deleted (likely due to a TTree larger than 100Gb)", fOutputFilename.Data());
    }
    
 }
