@@ -39,13 +39,17 @@ TFilePrefetch::TFilePrefetch(TFile* file) :
 
    fPendingBlocks    = new TList();
    fReadBlocks       = new TList();
+
+   fPendingBlocks->SetOwner();
+   fReadBlocks->SetOwner();
+   
    fMutexReadList    = new TMutex();
    fMutexPendingList = new TMutex();
    fNewBlockAdded    = new TCondition(0);
    fReadBlockAdded   = new TCondition(0);
-   fCondNextFile     = new TCondition(0);
    fSemMasterWorker  = new TSemaphore(0);
    fSemWorkerMaster  = new TSemaphore(0);
+   fSemChangeFile    = new TSemaphore(0);
 }
 
 //____________________________________________________________________________________________
@@ -64,9 +68,9 @@ TFilePrefetch::~TFilePrefetch()
    SafeDelete(fMutexPendingList);
    SafeDelete(fNewBlockAdded);
    SafeDelete(fReadBlockAdded);
-   SafeDelete(fCondNextFile);
    SafeDelete(fSemMasterWorker);
    SafeDelete(fSemWorkerMaster);
+   SafeDelete(fSemChangeFile);
 }
 
 
@@ -306,8 +310,26 @@ TThread* TFilePrefetch::GetThread() const
 void TFilePrefetch::SetFile(TFile *file) 
 {
    // Change the file
+   // When prefetching is enabled we also need to:
+   // - make sure the async thread is not doing any work 
+   // - clear all blocks from prefetching and read list
+   // - reset the file pointer
   
+   fSemChangeFile->Wait();
+
+   if (fFile) {
+     // Remove all pending and read blocks
+     fMutexPendingList->Lock();
+     fPendingBlocks->Clear();
+     fMutexPendingList->UnLock();
+
+     fMutexReadList->Lock();
+     fReadBlocks->Clear();
+     fMutexReadList->UnLock();
+   }
+      
    fFile = file;
+   fSemChangeFile->Post();
 }
 
 
@@ -331,28 +353,26 @@ TThread::VoidRtnFunc_t TFilePrefetch::ThreadProc(void* arg)
    // Execution loop of the consumer thread.
 
    TFilePrefetch* pClass = (TFilePrefetch*) arg;
-   TMutex *mutex = pClass->fCondNextFile->GetMutex();
-
+   TSemaphore* semChangeFile = pClass->fSemChangeFile;
+   semChangeFile->Post();
    pClass->fNewBlockAdded->Wait();
+   semChangeFile->Wait();
    
    while( pClass->fSemMasterWorker->TryWait() != 0 ) {
- 
       pClass->ReadListOfBlocks();
    
-      //need to signal TChain that we finished work
-      //in the previous file, before we move on
-      mutex->Lock();
-      pClass->fCondNextFile->Signal();
-      mutex->UnLock();
-
+      // Use the semaphore to deal with the case when the file pointer
+      // is changed on the fly by TChain
+      semChangeFile->Post();
       pClass->fNewBlockAdded->Wait();
+      semChangeFile->Wait();
    }
 
    pClass->fSemWorkerMaster->Post();       
    return (TThread::VoidRtnFunc_t) 1;
 }
 
-//########################################### CACHING PART ###############################################################
+//########################################### CACHING PART ####################################
 
 //____________________________________________________________________________________________
 Int_t TFilePrefetch::SumHex(const char *hex)
@@ -381,7 +401,7 @@ Bool_t TFilePrefetch::CheckBlockInCache(char*& path, TFPBlock* block)
 
    Int_t value = 0;
 
-   if (gSystem->OpenDirectory(fullPath) == 0)
+   if (!gSystem->OpenDirectory(fullPath))
       gSystem->mkdir(fullPath);
 
    //dir is SHA1 value modulo 16; filename is the value of the SHA1(offset+len)
@@ -474,7 +494,7 @@ void TFilePrefetch::SaveBlockInCache(TFPBlock* block)
    dirName.Form("%i", value);
    fullPath += ("/" + dirName);
 
-   if (gSystem->OpenDirectory(fullPath) == false)
+   if (!gSystem->OpenDirectory(fullPath))
       gSystem->mkdir(fullPath);
 
    TFile* file = 0;
@@ -514,7 +534,8 @@ Bool_t TFilePrefetch::CheckCachePath(const char* locationCache)
       TString directory(dir);
 
       for(Int_t i=0; i < directory.Sizeof()-1; i++)
-        if (!isdigit(directory[i]) && !isalpha(directory[i]) && directory[i] !='/' && directory[i] != ':'){
+        if (!isdigit(directory[i]) && !isalpha(directory[i]) && directory[i] !='/'
+            && directory[i] != ':' && directory[i] != '_'){
            found = false;
            break;
         }
@@ -533,7 +554,7 @@ Bool_t TFilePrefetch::SetCache(const char* path)
       fPathCache = path;
 
       if (!gSystem->OpenDirectory(path)){
-        gSystem->mkdir(path);
+         gSystem->mkdir(path);
       }
    } else
       return false;
