@@ -1,4 +1,4 @@
-// @(#)root/io:$Id: TGenCollectionStreamer.cxx 41102 2011-10-03 21:42:02Z pcanal $
+// @(#)root/io:$Id$
 // Author: Markus Frank 28/10/04
 
 /*************************************************************************
@@ -62,15 +62,166 @@ TVirtualCollectionProxy* TGenCollectionStreamer::Generate() const
    return new TGenCollectionStreamer(*this);
 }
 
+template <typename T>
+static T* getaddress(TGenCollectionProxy::StreamHelper &itm);
 
-void TGenCollectionStreamer::ReadPrimitives(int nElements, TBuffer &b)
+template <>
+bool* getaddress<bool>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.boolean;
+}
+
+template <>
+Char_t* getaddress<Char_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.s_char;
+}
+
+template <>
+Short_t* getaddress<Short_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.s_short;
+}
+
+template <>
+Int_t* getaddress<Int_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.s_int;
+}
+
+template <>
+Long_t* getaddress<Long_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.s_long;
+}
+
+template <>
+Long64_t* getaddress<Long64_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.s_longlong;
+}
+
+template <>
+Float_t* getaddress<Float_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.flt;
+}
+
+template <>
+Double_t* getaddress<Double_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.dbl;
+}
+
+template <>
+UChar_t* getaddress<UChar_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.u_char;
+}
+
+template <>
+UShort_t* getaddress<UShort_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.u_short;
+}
+
+template <>
+UInt_t* getaddress<UInt_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.u_int;
+}
+
+template <>
+ULong_t* getaddress<ULong_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.u_long;
+}
+
+template <>
+ULong64_t* getaddress<ULong64_t>(TGenCollectionProxy::StreamHelper &itm)
+{
+   return &itm.u_longlong;
+}
+
+template <typename From, typename To>
+void ConvertArray(TGenCollectionProxy::StreamHelper *read, TGenCollectionProxy::StreamHelper *write, int nElements)
+{
+   From *r = getaddress<From>( *read );
+   To *w = getaddress<To>( *write );
+   for(int i = 0; i < nElements; ++i) {
+      // getvalue<To>( write[i] ) = (To) getvalue<From>( read[i] );
+      w[i] = (To)r[i];
+   }
+}
+
+template <typename From>
+void DispatchConvertArray(int writeType, TGenCollectionProxy::StreamHelper *read, TGenCollectionProxy::StreamHelper *write, int nElements)
+{
+   switch(writeType) {
+      case kBool_t:
+         ConvertArray<From,bool>(read,write,nElements);
+         break;
+      case kChar_t:
+         ConvertArray<From,Char_t>(read,write,nElements);
+         break;
+      case kShort_t:
+         ConvertArray<From,Short_t>(read,write,nElements);
+         break;
+      case kInt_t:
+         ConvertArray<From,Int_t>(read,write,nElements);
+         break;
+      case kLong_t:
+         ConvertArray<From,Long64_t>(read,write,nElements);
+         break;
+      case kLong64_t:
+         ConvertArray<From,Long64_t>(read,write,nElements);
+         break;
+      case kFloat_t:
+         ConvertArray<From,Float_t>(read,write,nElements);
+         break;
+      case kFloat16_t:
+         ConvertArray<From,Float16_t>(read,write,nElements);
+         break;
+      case kDouble_t:
+         ConvertArray<From,Double_t>(read,write,nElements);
+         break;
+      case TGenCollectionProxy::kBOOL_t:
+         ConvertArray<From,bool>(read,write,nElements);
+         break;
+      case kUChar_t:
+         ConvertArray<From,UChar_t>(read,write,nElements);
+         break;
+      case kUShort_t:
+         ConvertArray<From,UShort_t>(read,write,nElements);
+         break;
+      case kUInt_t:
+         ConvertArray<From,UInt_t>(read,write,nElements);
+         break;
+      case kULong_t:
+         ConvertArray<From,ULong_t>(read,write,nElements);
+         break;
+      case kULong64_t:
+         ConvertArray<From,ULong64_t>(read,write,nElements);
+         break;
+      case kDouble32_t:
+         ConvertArray<From,Double32_t>(read,write,nElements);
+         break;
+      case kchar:
+      case kNoType_t:
+      case kOther_t:
+         Error("TGenCollectionStreamer", "fType %d is not supported yet!\n", writeType);
+   }
+}
+
+void TGenCollectionStreamer::ReadPrimitives(int nElements, TBuffer &b, const TClass *onFileClass)
 {
    // Primitive input streamer.
    size_t len = fValDiff * nElements;
    char   buffer[8096];
    Bool_t   feed = false;
    void*  memory = 0;
-   StreamHelper* itm = 0;
+   StreamHelper* itmstore = 0;
+   StreamHelper* itmconv = 0;
    fEnv->fSize = nElements;
    switch (fSTL_type)  {
       case TClassEdit::kVector:
@@ -80,79 +231,147 @@ void TGenCollectionStreamer::ReadPrimitives(int nElements, TBuffer &b)
             
             TVirtualVectorIterators iterators(fFunctionCreateIterators);
             iterators.CreateIterators(fEnv->fObject);
-            itm = (StreamHelper*)iterators.fBegin;
-            fEnv->fStart = itm;
+            itmstore = (StreamHelper*)iterators.fBegin;
+            fEnv->fStart = itmstore;
             break;
          }
       default:
          feed = true;
-         itm = (StreamHelper*)(len < sizeof(buffer) ? buffer : memory =::operator new(len));
+         itmstore = (StreamHelper*)(len < sizeof(buffer) ? buffer : memory =::operator new(len));
          break;
    }
-   fEnv->fStart = itm;
-   switch (int(fVal->fKind))   {
+   fEnv->fStart = itmstore;
+
+   StreamHelper *itmread;
+   int readkind;
+   if (onFileClass) {
+      readkind = onFileClass->GetCollectionProxy()->GetType();
+      itmconv = (StreamHelper*) ::operator new( nElements * onFileClass->GetCollectionProxy()->GetIncrement() );
+      itmread = itmconv;
+   } else {
+      itmread = itmstore;
+      readkind = fVal->fKind;
+   }
+   switch (readkind)   {
       case kBool_t:
-         b.ReadFastArray(&itm->boolean   , nElements);
+         b.ReadFastArray(&itmread->boolean   , nElements);
          break;
       case kChar_t:
-         b.ReadFastArray(&itm->s_char    , nElements);
+         b.ReadFastArray(&itmread->s_char    , nElements);
          break;
       case kShort_t:
-         b.ReadFastArray(&itm->s_short   , nElements);
+         b.ReadFastArray(&itmread->s_short   , nElements);
          break;
       case kInt_t:
-         b.ReadFastArray(&itm->s_int     , nElements);
+         b.ReadFastArray(&itmread->s_int     , nElements);
          break;
       case kLong_t:
-         b.ReadFastArray(&itm->s_long    , nElements);
+         b.ReadFastArray(&itmread->s_long    , nElements);
          break;
       case kLong64_t:
-         b.ReadFastArray(&itm->s_longlong, nElements);
+         b.ReadFastArray(&itmread->s_longlong, nElements);
          break;
       case kFloat_t:
-         b.ReadFastArray(&itm->flt       , nElements);
+         b.ReadFastArray(&itmread->flt       , nElements);
          break;
       case kFloat16_t:
-         b.ReadFastArrayFloat16(&itm->flt, nElements);
+         b.ReadFastArrayFloat16(&itmread->flt, nElements);
          break;
       case kDouble_t:
-         b.ReadFastArray(&itm->dbl       , nElements);
+         b.ReadFastArray(&itmread->dbl       , nElements);
          break;
       case kBOOL_t:
-         b.ReadFastArray(&itm->boolean   , nElements);
+         b.ReadFastArray(&itmread->boolean   , nElements);
          break;
       case kUChar_t:
-         b.ReadFastArray(&itm->u_char    , nElements);
+         b.ReadFastArray(&itmread->u_char    , nElements);
          break;
       case kUShort_t:
-         b.ReadFastArray(&itm->u_short   , nElements);
+         b.ReadFastArray(&itmread->u_short   , nElements);
          break;
       case kUInt_t:
-         b.ReadFastArray(&itm->u_int     , nElements);
+         b.ReadFastArray(&itmread->u_int     , nElements);
          break;
       case kULong_t:
-         b.ReadFastArray(&itm->u_long    , nElements);
+         b.ReadFastArray(&itmread->u_long    , nElements);
          break;
       case kULong64_t:
-         b.ReadFastArray(&itm->u_longlong, nElements);
+         b.ReadFastArray(&itmread->u_longlong, nElements);
          break;
       case kDouble32_t:
-         b.ReadFastArrayDouble32(&itm->dbl, nElements);
+         b.ReadFastArrayDouble32(&itmread->dbl, nElements);
          break;
       case kchar:
       case kNoType_t:
       case kOther_t:
-         Error("TGenCollectionStreamer", "fType %d is not supported yet!\n", fVal->fKind);
+         Error("TGenCollectionStreamer", "fType %d is not supported yet!\n", readkind);
+   }
+   if (onFileClass) {
+      switch (readkind)   {
+         case kBool_t:
+            DispatchConvertArray<bool>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kChar_t:
+            DispatchConvertArray<Char_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kShort_t:
+            DispatchConvertArray<Short_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kInt_t:
+            DispatchConvertArray<Int_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kLong_t:
+            DispatchConvertArray<Long_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kLong64_t:
+            DispatchConvertArray<Long64_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kFloat_t:
+            DispatchConvertArray<Float_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kFloat16_t:
+            DispatchConvertArray<Float16_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kDouble_t:
+            DispatchConvertArray<Double_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kBOOL_t:
+            DispatchConvertArray<bool>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kUChar_t:
+            DispatchConvertArray<UChar_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kUShort_t:
+            DispatchConvertArray<UShort_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kUInt_t:
+            DispatchConvertArray<UInt_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kULong_t:
+            DispatchConvertArray<ULong_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kULong64_t:
+            DispatchConvertArray<ULong64_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kDouble32_t:
+            DispatchConvertArray<Double_t>(fVal->fKind, itmread, itmstore, nElements);
+            break;
+         case kchar:
+         case kNoType_t:
+         case kOther_t:
+            Error("TGenCollectionStreamer", "fType %d is not supported yet!\n", readkind);
+      }
+      ::operator delete((void*)itmconv);
    }
    if (feed)  {      // need to feed in data...
-      fEnv->fStart = fFeed(fEnv->fStart,fEnv->fObject,fEnv->fSize);
+      fEnv->fStart = fFeed(itmstore,fEnv->fObject,fEnv->fSize);
       if (memory)  {
          ::operator delete(memory);
       }
    }
 }
 
-void TGenCollectionStreamer::ReadObjects(int nElements, TBuffer &b)
+void TGenCollectionStreamer::ReadObjects(int nElements, TBuffer &b, const TClass *onFileClass)
 {
    // Object input streamer.
    Bool_t vsn3 = b.GetInfo() && b.GetInfo()->GetOldVersion() <= 3;
@@ -161,7 +380,7 @@ void TGenCollectionStreamer::ReadObjects(int nElements, TBuffer &b)
    char   buffer[8096];
    void*  memory = 0;
    
-   TClass* onFileValClass = (fOnFileClass ? fOnFileClass->GetCollectionProxy()->GetValueClass() : 0);
+   TClass* onFileValClass = (onFileClass ? onFileClass->GetCollectionProxy()->GetValueClass() : 0);
 
    fEnv->fSize = nElements;
    switch (fSTL_type)  {
@@ -435,7 +654,88 @@ void TGenCollectionStreamer::ReadMapHelper(StreamHelper *i, Value *v, Bool_t vsn
    }
 }
 
-void TGenCollectionStreamer::ReadMap(int nElements, TBuffer &b)
+template <typename To>
+To readOneValue(TBuffer &b, int readtype) {
+   TGenCollectionProxy::StreamHelper itm;
+   TGenCollectionProxy::StreamHelper *i = &itm;
+   switch (readtype)   {
+   case kBool_t:
+      b >> i->boolean;
+      return (To)i->boolean;
+      break;
+   case kChar_t:
+      b >> i->s_char;
+      return (To)i->s_char;
+      break;
+   case kShort_t:
+      b >> i->s_short;
+      return (To)i->s_short;
+      break;
+   case kInt_t:
+      b >> i->s_int;
+      return (To)i->s_int;
+      break;
+   case kLong_t:
+      b >> i->s_long;
+      return (To)i->s_long;
+      break;
+   case kLong64_t:
+      b >> i->s_longlong;
+      return (To)i->s_longlong;
+      break;
+   case kFloat_t:
+      b >> i->flt;
+      return (To)i->flt;
+      break;
+   case kFloat16_t:
+      b >> i->flt;
+      return (To)i->flt;
+      break;
+   case kDouble_t:
+      b >> i->dbl;
+      return (To)i->dbl;
+      break;
+   case TGenCollectionProxy::kBOOL_t:
+      b >> i->boolean;
+      return (To)i->boolean;
+      break;
+   case kUChar_t:
+      b >> i->u_char;
+      return (To)i->u_char;
+      break;
+   case kUShort_t:
+      b >> i->u_short;
+      return (To)i->u_short;
+      break;
+   case kUInt_t:
+      b >> i->u_int;
+      return (To)i->u_int;
+      break;
+   case kULong_t:
+      b >> i->u_long;
+      return (To)i->u_long;
+      break;
+   case kULong64_t:
+      b >> i->u_longlong;
+      return (To)i->u_longlong;
+      break;
+   case kDouble32_t: {
+      float f;
+      b >> f;
+      i->dbl = double(f);
+      return (To)i->dbl;
+      break;
+   }
+   case kchar:
+   case kNoType_t:
+   case kOther_t:
+      Error("TGenCollectionStreamer", "fType %d is not supported yet!\n", readtype);
+   }
+   return 0;
+}
+
+
+void TGenCollectionStreamer::ReadMap(int nElements, TBuffer &b, const TClass *onFileClass)
 {
    // Map input streamer.
    Bool_t vsn3 = b.GetInfo() && b.GetInfo()->GetOldVersion() <= 3;
@@ -449,6 +749,14 @@ void TGenCollectionStreamer::ReadMap(int nElements, TBuffer &b)
    fEnv->fStart = (len < sizeof(buffer) ? buffer : memory =::operator new(len));
    addr = temp = (char*)fEnv->fStart;
    fConstruct(addr,nElements);
+
+   int onFileValueKind[2];
+   if (onFileClass) {
+      TClass *onFileValueClass = onFileClass->GetCollectionProxy()->GetValueClass();
+      TVirtualStreamerInfo *sourceInfo = onFileValueClass->GetStreamerInfo();
+      onFileValueKind[0] = ((TStreamerElement*)sourceInfo->GetElements()->At(0))->GetType();
+      onFileValueKind[1] = ((TStreamerElement*)sourceInfo->GetElements()->At(1))->GetType();
+   }
    for (int loop, idx = 0; idx < nElements; ++idx)  {
       addr = temp + fValDiff * idx;
       v = fKey;
@@ -457,7 +765,64 @@ void TGenCollectionStreamer::ReadMap(int nElements, TBuffer &b)
          switch (v->fCase) {
             case G__BIT_ISFUNDAMENTAL:  // Only handle primitives this way
             case G__BIT_ISENUM:
-               switch (int(v->fKind))   {
+               if (onFileClass) {
+                  int readtype = (int)(onFileValueKind[loop]);
+                  switch (int(v->fKind))   {
+                  case kBool_t:
+                     i->boolean = readOneValue<bool>(b,readtype);
+                     break;
+                  case kChar_t:
+                     i->s_char = readOneValue<Char_t>(b,readtype);
+                     break;
+                  case kShort_t:
+                     i->s_short = readOneValue<Short_t>(b,readtype);
+                     break;
+                  case kInt_t:
+                     i->s_int = readOneValue<Int_t>(b,readtype);
+                     break;
+                  case kLong_t:
+                     i->s_long = readOneValue<Long_t>(b,readtype);
+                     break;
+                  case kLong64_t:
+                     i->s_longlong = readOneValue<Long64_t>(b,readtype);
+                     break;
+                  case kFloat_t:
+                     i->flt = readOneValue<Float_t>(b,readtype);
+                     break;
+                  case kFloat16_t:
+                     i->flt = readOneValue<Float16_t>(b,readtype);
+                     break;
+                  case kDouble_t:
+                     i->dbl = readOneValue<Double_t>(b,readtype);
+                     break;
+                  case kBOOL_t:
+                     i->boolean = readOneValue<bool>(b,readtype);
+                     break;
+                  case kUChar_t:
+                     i->u_char = readOneValue<UChar_t>(b,readtype);
+                     break;
+                  case kUShort_t:
+                     i->u_short = readOneValue<UShort_t>(b,readtype);
+                     break;
+                  case kUInt_t:
+                     i->u_int = readOneValue<UInt_t>(b,readtype);
+                     break;
+                  case kULong_t:
+                     i->u_long = readOneValue<ULong_t>(b,readtype);
+                     break;
+                  case kULong64_t:
+                     i->u_longlong = readOneValue<ULong64_t>(b,readtype);
+                     break;
+                  case kDouble32_t:
+                     i->dbl = readOneValue<Double32_t>(b,readtype);
+                     break;
+                  case kchar:
+                  case kNoType_t:
+                  case kOther_t:
+                     Error("TGenCollectionStreamer", "fType %d is not supported yet!\n", v->fKind);
+                  }
+               } else {
+                  switch (int(v->fKind))   {
                   case kBool_t:
                      b >> i->boolean;
                      break;
@@ -512,6 +877,7 @@ void TGenCollectionStreamer::ReadMap(int nElements, TBuffer &b)
                   case kNoType_t:
                   case kOther_t:
                      Error("TGenCollectionStreamer", "fType %d is not supported yet!\n", v->fKind);
+                  }
                }
                break;
             case G__BIT_ISCLASS:
@@ -556,7 +922,7 @@ void TGenCollectionStreamer::WritePrimitives(int nElements, TBuffer &b)
          }
       default:
          fEnv->fStart = itm = (StreamHelper*)(len < sizeof(buffer) ? buffer : memory =::operator new(len));
-         fCollect.invoke(fEnv);
+         fCollect(fEnv->fObject,itm);
          break;
    }
    switch (int(fVal->fKind))   {
@@ -764,38 +1130,109 @@ void TGenCollectionStreamer::WriteMap(int nElements, TBuffer &b)
    }
 }
 
+template <typename From, typename To>
+void TGenCollectionStreamer::ConvertBufferVectorPrimitives(TBuffer &b, void *obj, Int_t nElements)
+{
+   From *temp = new From[nElements];
+   b.ReadFastArray(temp, nElements);
+   std::vector<To> *const vec = (std::vector<To>*)(obj);      
+   for(Int_t ind = 0; ind < nElements; ++ind) {
+      (*vec)[ind] = (To)temp[ind];
+   }
+   delete [] temp;
+}
+
+template <typename To>
+void TGenCollectionStreamer::ConvertBufferVectorPrimitivesFloat16(TBuffer &b, void *obj, Int_t nElements)
+{
+   Float16_t *temp = new Float16_t[nElements];
+   b.ReadFastArrayFloat16(temp, nElements);
+   std::vector<To> *const vec = (std::vector<To>*)(obj);      
+   for(Int_t ind = 0; ind < nElements; ++ind) {
+      (*vec)[ind] = (To)temp[ind];
+   }
+   delete [] temp;
+}
+
+template <typename To>
+void TGenCollectionStreamer::ConvertBufferVectorPrimitivesDouble32(TBuffer &b, void *obj, Int_t nElements)
+{
+   Double32_t *temp = new Double32_t[nElements];
+   b.ReadFastArrayDouble32(temp, nElements);
+   std::vector<To> *const vec = (std::vector<To>*)(obj);      
+   for(Int_t ind = 0; ind < nElements; ++ind) {
+      (*vec)[ind] = (To)temp[ind];
+   }
+   delete [] temp;
+}
+
+template <typename To>
+void TGenCollectionStreamer::DispatchConvertBufferVectorPrimitives(TBuffer &b, void *obj, Int_t nElements, const TVirtualCollectionProxy *onFileProxy)
+{
+   switch (onFileProxy->GetType()) {
+      case TStreamerInfo::kBool:     ConvertBufferVectorPrimitives<Bool_t    ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kChar:     ConvertBufferVectorPrimitives<Char_t    ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kShort:    ConvertBufferVectorPrimitives<Short_t   ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kInt:      ConvertBufferVectorPrimitives<Int_t     ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kLong:     ConvertBufferVectorPrimitives<Long_t    ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kLong64:   ConvertBufferVectorPrimitives<Long64_t  ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kFloat:    ConvertBufferVectorPrimitives<Float_t   ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kFloat16:  ConvertBufferVectorPrimitives<Float16_t ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kDouble:   ConvertBufferVectorPrimitives<Double_t  ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kDouble32: ConvertBufferVectorPrimitives<Double32_t,To>(b,obj,nElements); break;
+      case TStreamerInfo::kUChar:    ConvertBufferVectorPrimitives<UChar_t   ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kUShort:   ConvertBufferVectorPrimitives<UShort_t  ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kUInt:     ConvertBufferVectorPrimitives<UInt_t    ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kULong:    ConvertBufferVectorPrimitives<ULong_t   ,To>(b,obj,nElements); break;
+      case TStreamerInfo::kULong64:  ConvertBufferVectorPrimitives<ULong64_t ,To>(b,obj,nElements); break;
+     default: break;
+   }
+}
+
 template <typename basictype>
-void TGenCollectionStreamer::ReadBufferVectorPrimitives(TBuffer &b, void *obj)
+void TGenCollectionStreamer::ReadBufferVectorPrimitives(TBuffer &b, void *obj, const TClass *onFileClass)
 {
    int nElements = 0;
    b >> nElements;
    fResize(obj,nElements);
    
-   TVirtualVectorIterators iterators(fFunctionCreateIterators);
-   iterators.CreateIterators(obj);
-   b.ReadFastArray((basictype*)iterators.fBegin, nElements);
+   if (onFileClass) {
+      DispatchConvertBufferVectorPrimitives<basictype>(b,obj,nElements,onFileClass->GetCollectionProxy());
+   } else {
+      TVirtualVectorIterators iterators(fFunctionCreateIterators);
+      iterators.CreateIterators(obj);
+      b.ReadFastArray((basictype*)iterators.fBegin, nElements);
+   }
 }
 
-void TGenCollectionStreamer::ReadBufferVectorPrimitivesFloat16(TBuffer &b, void *obj)
+void TGenCollectionStreamer::ReadBufferVectorPrimitivesFloat16(TBuffer &b, void *obj, const TClass *onFileClass)
 {
    int nElements = 0;
    b >> nElements;
    fResize(obj,nElements);
    
-   TVirtualVectorIterators iterators(fFunctionCreateIterators);
-   iterators.CreateIterators(obj);
-   b.ReadFastArrayFloat16((Float16_t*)iterators.fBegin, nElements);
+   if (onFileClass) {
+      DispatchConvertBufferVectorPrimitives<Float16_t>(b,obj,nElements,onFileClass->GetCollectionProxy());
+   } else {
+      TVirtualVectorIterators iterators(fFunctionCreateIterators);
+      iterators.CreateIterators(obj);
+      b.ReadFastArrayFloat16((Float16_t*)iterators.fBegin, nElements);
+   }
 }
 
-void TGenCollectionStreamer::ReadBufferVectorPrimitivesDouble32(TBuffer &b, void *obj)
+void TGenCollectionStreamer::ReadBufferVectorPrimitivesDouble32(TBuffer &b, void *obj, const TClass *onFileClass)
 {
    int nElements = 0;
    b >> nElements;
    fResize(obj,nElements);
    
-   TVirtualVectorIterators iterators(fFunctionCreateIterators);
-   iterators.CreateIterators(obj);
-   b.ReadFastArrayDouble32((Double32_t*)iterators.fBegin, nElements);
+   if (onFileClass) {
+      DispatchConvertBufferVectorPrimitives<Double32_t>(b,obj,nElements,onFileClass->GetCollectionProxy());
+   } else {
+      TVirtualVectorIterators iterators(fFunctionCreateIterators);
+      iterators.CreateIterators(obj);
+      b.ReadFastArrayDouble32((Double32_t*)iterators.fBegin, nElements);
+   }
 }
 
 
@@ -805,8 +1242,7 @@ void TGenCollectionStreamer::ReadBuffer(TBuffer &b, void *obj, const TClass *onF
    // Call the specialized function.  The first time this call ReadBufferDefault which
    // actually set to fReadBufferFunc to the 'right' specialized version.
    
-   SetOnFileClass((TClass*)onFileClass);
-   (this->*fReadBufferFunc)(b,obj);
+   (this->*fReadBufferFunc)(b,obj,onFileClass);
 }
 
 void TGenCollectionStreamer::ReadBuffer(TBuffer &b, void *obj)
@@ -814,14 +1250,16 @@ void TGenCollectionStreamer::ReadBuffer(TBuffer &b, void *obj)
    // Call the specialized function.  The first time this call ReadBufferDefault which
    // actually set to fReadBufferFunc to the 'right' specialized version.
    
-   (this->*fReadBufferFunc)(b,obj);
+   (this->*fReadBufferFunc)(b,obj,0);
 }
 
-void TGenCollectionStreamer::ReadBufferDefault(TBuffer &b, void *obj)
+void TGenCollectionStreamer::ReadBufferDefault(TBuffer &b, void *obj, const TClass *onFileClass)
 {
  
    fReadBufferFunc = &TGenCollectionStreamer::ReadBufferGeneric;
+
    // We will need this later, so let's make sure it is initialized.
+   if ( !fValue ) InitializeEx(kFALSE);
    if (!GetFunctionCreateIterators()) {
       Fatal("TGenCollectionStreamer::ReadBufferDefault","No CreateIterators function for %s",fName.c_str());
    }
@@ -884,10 +1322,10 @@ void TGenCollectionStreamer::ReadBufferDefault(TBuffer &b, void *obj)
             break;
       }
    }
-   (this->*fReadBufferFunc)(b,obj);
+   (this->*fReadBufferFunc)(b,obj,onFileClass);
 }
 
-void TGenCollectionStreamer::ReadBufferGeneric(TBuffer &b, void *obj)
+void TGenCollectionStreamer::ReadBufferGeneric(TBuffer &b, void *obj, const TClass *onFileClass)
 {
    TVirtualCollectionProxy::TPushPop env(this, obj);
 
@@ -908,7 +1346,7 @@ void TGenCollectionStreamer::ReadBufferGeneric(TBuffer &b, void *obj)
                   fClear.invoke(fEnv);
                }
             }
-            ReadPrimitives(nElements, b);
+            ReadPrimitives(nElements, b, onFileClass);
             return;
          case TClassEdit::kVector:
             if (obj) {
@@ -922,10 +1360,10 @@ void TGenCollectionStreamer::ReadBufferGeneric(TBuffer &b, void *obj)
             switch (fVal->fCase) {
                case G__BIT_ISFUNDAMENTAL:  // Only handle primitives this way
                case G__BIT_ISENUM:
-                  ReadPrimitives(nElements, b);
+                  ReadPrimitives(nElements, b, onFileClass);
                   return;
                default:
-                  ReadObjects(nElements, b);
+                  ReadObjects(nElements, b, onFileClass);
                   return;
             }
             break;
@@ -943,10 +1381,10 @@ void TGenCollectionStreamer::ReadBufferGeneric(TBuffer &b, void *obj)
             switch (fVal->fCase) {
                case G__BIT_ISFUNDAMENTAL:  // Only handle primitives this way
                case G__BIT_ISENUM:
-                  ReadPrimitives(nElements, b);
+                  ReadPrimitives(nElements, b, onFileClass);
                   return;
                default:
-                  ReadObjects(nElements, b);
+                  ReadObjects(nElements, b, onFileClass);
                   return;
             }
             break;
@@ -959,7 +1397,7 @@ void TGenCollectionStreamer::ReadBufferGeneric(TBuffer &b, void *obj)
                   fClear.invoke(fEnv);
                }
             }
-            ReadMap(nElements, b);
+            ReadMap(nElements, b, onFileClass);
             break;
       }
    }
@@ -977,7 +1415,7 @@ void TGenCollectionStreamer::Streamer(TBuffer &b)
       if (nElements > 0)  {
          switch (fSTL_type)  {
             case TClassEdit::kBitSet:
-               ReadPrimitives(nElements, b);
+               ReadPrimitives(nElements, b, fOnFileClass);
                return;
             case TClassEdit::kVector:
             case TClassEdit::kList:
@@ -987,16 +1425,16 @@ void TGenCollectionStreamer::Streamer(TBuffer &b)
                switch (fVal->fCase) {
                   case G__BIT_ISFUNDAMENTAL:  // Only handle primitives this way
                   case G__BIT_ISENUM:
-                     ReadPrimitives(nElements, b);
+                     ReadPrimitives(nElements, b, fOnFileClass);
                      return;
                   default:
-                     ReadObjects(nElements, b);
+                     ReadObjects(nElements, b, fOnFileClass);
                      return;
                }
                break;
             case TClassEdit::kMap:
             case TClassEdit::kMultiMap:
-               ReadMap(nElements, b);
+               ReadMap(nElements, b, fOnFileClass);
                break;
          }
       }
@@ -1045,7 +1483,7 @@ void TGenCollectionStreamer::StreamerAsMap(TBuffer &b)
          switch (fSTL_type)  {
             case TClassEdit::kMap:
             case TClassEdit::kMultiMap:
-               ReadMap(nElements, b);
+               ReadMap(nElements, b, fOnFileClass);
                break;
             case TClassEdit::kVector:
             case TClassEdit::kList:
