@@ -1,4 +1,4 @@
-// @(#)root/io:$Id: TMemFile.cxx 42754 2012-01-20 20:13:07Z pcanal $
+// @(#)root/io:$Id$
 // Author: Philippe Canal, May 2011
 
 /*************************************************************************
@@ -317,8 +317,6 @@ void TMemFile::ResetAfterMerge(TFileMergeInfo *info)
    fNProcessIDs  = 0;
    fOffset       = 0;
    fCacheRead    = 0;
-   delete fCacheReadMap;
-   fCacheReadMap = 0;
    fCacheWrite   = 0;
    fReadCalls    = 0;
    if (fFree) {
