@@ -1,4 +1,4 @@
-// @(#)root/rfio:$Id: TRFIOFile.cxx 38018 2011-02-09 15:16:52Z rdm $
+// @(#)root/rfio:$Id$
 // Author: Fons Rademakers 20/01/99 + Giulia Taurelli 29/06/2006 + Andreas Peters 07/12/2007
 
 /*************************************************************************
@@ -282,6 +282,7 @@ Bool_t TRFIOFile::ReadBuffers(char *buf, Long64_t *pos, Int_t *len, Int_t nbuf)
    }
 
    fBytesRead += k;
+   fReadCalls++;
 #ifdef WIN32
    SetFileBytesRead(GetFileBytesRead() + k);
    SetFileReadCalls(GetFileReadCalls() + 1);
@@ -543,7 +544,7 @@ Bool_t TRFIOSystem::AccessPathName(const char *path, EAccessMode mode)
 //______________________________________________________________________________
 Int_t TRFIOSystem::Unlink(const char *path)
 {
-   // Unlink, i.e. remove, a file or directory. Returns 0 when succesfull,
+   // Unlink, i.e. remove, a file or directory. Returns 0 when successful,
    // -1 in case of failure.
 
    TUrl url(path);
