@@ -1,4 +1,4 @@
-// @(#)root/xml:$Id: TBufferXML.h 40872 2011-09-13 21:33:33Z pcanal $
+// @(#)root/xml:$Id: d90d66e8fd2aa9daa4b05bcba9166aee1e2b2e7f $
 // Author: Sergey Linev  10.05.2004
 
 /*************************************************************************
@@ -49,8 +49,8 @@ public:
    TBufferXML(TBuffer::EMode mode, TXMLFile* file);
    virtual ~TBufferXML();
 
-   static TString   ConvertToXML(TObject* obj, Bool_t GenericLayout = kFALSE, Bool_t UseNamespaces = kFALSE);
-   static TString   ConvertToXML(void* obj, TClass* cl, Bool_t GenericLayout = kFALSE, Bool_t UseNamespaces = kFALSE);
+   static TString   ConvertToXML(const TObject* obj, Bool_t GenericLayout = kFALSE, Bool_t UseNamespaces = kFALSE);
+   static TString   ConvertToXML(const void* obj, const TClass* cl, Bool_t GenericLayout = kFALSE, Bool_t UseNamespaces = kFALSE);
    
    static TObject*  ConvertFromXML(const char* str, Bool_t GenericLayout = kFALSE, Bool_t UseNamespaces = kFALSE);   
    static void*     ConvertFromXMLAny(const char* str, TClass** cl = 0, Bool_t GenericLayout = kFALSE, Bool_t UseNamespaces = kFALSE);
@@ -139,6 +139,10 @@ public:
    virtual void     ReadFastArray(Double_t  *d, Int_t n);
    virtual void     ReadFastArrayFloat16(Float_t  *f, Int_t n, TStreamerElement *ele=0);
    virtual void     ReadFastArrayDouble32(Double_t  *d, Int_t n, TStreamerElement *ele=0);
+   virtual void     ReadFastArrayWithFactor(Float_t *ptr, Int_t n, Double_t factor, Double_t minvalue) ;
+   virtual void     ReadFastArrayWithNbits(Float_t *ptr, Int_t n, Int_t nbits);
+   virtual void     ReadFastArrayWithFactor(Double_t *ptr, Int_t n, Double_t factor, Double_t minvalue);
+   virtual void     ReadFastArrayWithNbits(Double_t *ptr, Int_t n, Int_t nbits) ;
 
    virtual void     WriteArray(const Bool_t    *b, Int_t n);
    virtual void     WriteArray(const Char_t    *c, Int_t n);
