@@ -1,4 +1,4 @@
-// @(#)root/mathcore:$Id: TRandom.cxx 43094 2012-02-22 15:24:51Z rdm $
+// @(#)root/mathcore:$Id$
 // Author: Rene Brun, Lorenzo Moneta   15/12/95
 
 /*************************************************************************
@@ -129,7 +129,7 @@
 #include "TSystem.h"
 #include "TDirectory.h"
 #include "Math/QuantFuncMathCore.h"
-#include <time.h>
+#include "TUUID.h"
 
 ClassImp(TRandom)
 
@@ -546,18 +546,17 @@ void TRandom::SetSeed(UInt_t seed)
    // Set the random generator seed. Note that default value is zero, which is
    // different than the default value used when constructing the class.  
    // If the seed is zero the seed is set to a random value 
-   // which in case of TRandom depends on the machine clock. 
-   // Note that the machine clock is returned with a precision of 1 second.
-   // If one calls SetSeed(0) within a loop and the loop time is less than 1s,
-   // all generated numbers will be identical!
+   // which in case of TRandom depends on the lowest 4 bytes of TUUID 
+   // The UUID will be identical if SetSeed(0) is called with time smaller than 100 ns
    // Instead if a different generator implementation is used (TRandom1, 2 or 3)
    // the seed is generated using a 128 bit UUID. This results in different seeds
    // and then random sequence for every SetSeed(0) call. 
 
    if( seed==0 ) {
-      time_t curtime;      // Set 'random' seed number  if seed=0
-      time(&curtime);      // Get current time in fSeed.
-      fSeed = (UInt_t)curtime;
+      TUUID u; 
+      UChar_t uuid[16];
+      u.GetUUID(uuid);
+      fSeed  =  int(uuid[3])*16777216 + int(uuid[2])*65536 + int(uuid[1])*256 + int(uuid[0]);
    } else {
       fSeed = seed;
    }
