@@ -293,6 +293,22 @@ namespace Math {
 
   }; 
 
+} // namespace Math
+} // namespace ROOT
+
+#ifndef ROOT_Math_GSLRndmEngines
+#include "Math/GSLRndmEngines.h"
+#endif
+
+namespace ROOT {
+namespace Math {
+
+
+   typedef   Random<ROOT::Math::GSLRngMT>     RandomMT;
+   typedef   Random<ROOT::Math::GSLRngTaus>   RandomTaus;
+   typedef   Random<ROOT::Math::GSLRngRanLux> RandomRanLux;
+   typedef   Random<ROOT::Math::GSLRngGFSR4>  RandomGFSR4;
+
 
 } // namespace Math
 } // namespace ROOT
