@@ -455,7 +455,7 @@ bool  Minuit2Minimizer::ExamineMinimum(const ROOT::Minuit2::FunctionMinimum & mi
    bool validMinimum = min.IsValid();
    if (validMinimum) { 
       // print a warning message in case something is not ok
-      if (fStatus != 0)  MN_INFO_MSG2("Minuit2Minimizer::Minimize",txt);
+      if (fStatus != 0 && debugLevel > 0)  MN_INFO_MSG2("Minuit2Minimizer::Minimize",txt);
    }
    else { 
       // minimum is not valid when state is not valid and edm is over max or has passed call limits
@@ -748,24 +748,34 @@ bool Minuit2Minimizer::GetMinosError(unsigned int i, double & errLow, double & e
       
    }
 
-   bool isValid = true; 
-   if (runLower && !me.LowerValid() ) isValid = false; 
-   if (runUpper && !me.UpperValid() ) isValid = false; 
-   if ( !isValid ) { 
+   bool lowerInvalid =  (runLower && !me.LowerValid() ); 
+   bool upperInvalid =  (runUpper && !me.UpperValid() );
+   int mstatus = 0; 
+   if (lowerInvalid || upperInvalid ) { 
+      // set status accroding to bit  
+      // bit 1:  lower invalid Minos errors 
+      // bit 2:  uper invalid Minos error
+      // bit 3:   invalid because max FCN
+      // bit 4 : invalid because a new minimum has been found
+      if (lowerInvalid) { 
+         mstatus |= 1;
+         if (me.AtLowerMaxFcn() ) mstatus |= 4; 
+         if (me.LowerNewMin() ) mstatus |= 8; 
+      }
+      if(upperInvalid) { 
+         mstatus |= 3;
+         if (me.AtUpperMaxFcn() ) mstatus |= 4; 
+         if (me.UpperNewMin() ) mstatus |= 8; 
+      }
       //std::cout << "Error running Minos for parameter " << i << std::endl; 
-      int mstatus = 5; 
-      if (me.AtLowerMaxFcn() ) mstatus = 1; 
-      if (me.AtUpperMaxFcn() ) mstatus = 2; 
-      if (me.LowerNewMin() ) mstatus = 3; 
-      if (me.UpperNewMin() ) mstatus = 4; 
       fStatus += 10*mstatus; 
-      return false; 
    }
          
    errLow = me.Lower();
    errUp = me.Upper();
-      
-   return true;
+
+   bool isValid = (runLower && me.LowerValid() ) || (runUpper && me.UpperValid() );    
+   return isValid;  
 } 
 
 bool Minuit2Minimizer::Scan(unsigned int ipar, unsigned int & nstep, double * x, double * y, double xmin, double xmax) { 
@@ -817,7 +827,7 @@ bool Minuit2Minimizer::Scan(unsigned int ipar, unsigned int & nstep, double * x,
    // what to do if a new minimum has been found ? 
    // use that as new minimum
    if (scan.Fval() < amin ) { 
-      MN_INFO_MSG2("Minuit2Minimizer::Scan","A new minimum has been found");
+      if (PrintLevel() > 0) MN_INFO_MSG2("Minuit2Minimizer::Scan","A new minimum has been found");
       fState.SetValue(ipar, scan.Parameters().Value(ipar) );
          
    }
