@@ -16,6 +16,12 @@
  *	factored code to provide a nice Cholesky decomposition class, along
  *	with separate methods for solving a single linear system and to
  *	obtain the inverse matrix from the decomposition
+ * @date July 15th 2013
+ * 	provide a version of that class which works if the dimension of the
+ * 	problem is only known at run time
+ * @date September 30th 2013
+ * 	provide routines to access the result of the decomposition L and its
+ * 	inverse
  */
 
 #include <cmath>
@@ -28,9 +34,13 @@ namespace ROOT {
 /// helpers for CholeskyDecomp
 namespace CholeskyDecompHelpers {
    // forward decls
+   template<class F, class M> struct _decomposerGenDim;
    template<class F, unsigned N, class M> struct _decomposer;
+   template<class F, class M> struct _inverterGenDim;
    template<class F, unsigned N, class M> struct _inverter;
+   template<class F, class V> struct _solverGenDim;
    template<class F, unsigned N, class V> struct _solver;
+   template<typename G> class PackedArrayAdapter;
 }
 
 /// class to compute the Cholesky decomposition of a matrix
@@ -72,21 +82,6 @@ private:
    F fL[N * (N + 1) / 2];
    /// flag indicating a successful decomposition
    bool fOk;
-   /// adapter for packed arrays (to SMatrix indexing conventions)
-   template<typename G> class PackedArrayAdapter
-   {
-   private:
-      G* fArr; ///< pointer to first array element
-   public:
-      /// constructor
-      PackedArrayAdapter(G* arr) : fArr(arr) {}
-      /// read access to elements (make sure that j <= i)
-      const G operator()(unsigned i, unsigned j) const
-      { return fArr[((i * (i + 1)) / 2) + j]; }
-      /// write access to elements (make sure that j <= i)
-      G& operator()(unsigned i, unsigned j)
-      { return fArr[((i * (i + 1)) / 2) + j]; }
-   };
 public:
    /// perform a Cholesky decomposition
    /** perfrom a Cholesky decomposition of a symmetric positive
@@ -118,6 +113,7 @@ public:
       fL(), fOk(false)
    {
       using CholeskyDecompHelpers::_decomposer;
+      using CholeskyDecompHelpers::PackedArrayAdapter;
       fOk = _decomposer<F, N, PackedArrayAdapter<G> >()(
          fL, PackedArrayAdapter<G>(m));
    }
@@ -129,8 +125,7 @@ public:
    /** @returns true if decomposition was successful */
    operator bool() const { return fOk; }
 
-   /// solves a linear system for the given right hand side
-   /** solves a linear system for the given right hand side
+   /** @brief solves a linear system for the given right hand side
     *
     * Note that you can use both SVector classes and plain arrays for
     * rhs. (Make sure that the sizes match!). It will work with any vector 
@@ -144,8 +139,7 @@ public:
       if (fOk) _solver<F,N,V>()(rhs, fL); return fOk;
    }
 
-   /// place the inverse into m
-   /** place the inverse into m
+   /** @brief place the inverse into m
     *
     * This is the method to use with an SMatrix.
     *
@@ -157,8 +151,7 @@ public:
       if (fOk) _inverter<F,N,M>()(m, fL); return fOk;
    }
 
-   /// place the inverse into m
-   /** place the inverse into m
+   /** @brief place the inverse into m
     *
     * This is the method to use with a plain array.
     *
@@ -171,22 +164,376 @@ public:
    template<typename G> bool Invert(G* m) const
    {
       using CholeskyDecompHelpers::_inverter;
+      using CholeskyDecompHelpers::PackedArrayAdapter;
       if (fOk) {
          PackedArrayAdapter<G> adapted(m);
          _inverter<F,N,PackedArrayAdapter<G> >()(adapted, fL);
       }
       return fOk;
    }
+
+   /** @brief obtain the decomposed matrix L
+    *
+    * This is the method to use with a plain array.
+    *
+    * @returns if the decomposition was successful
+    */
+   template<class M> bool getL(M& m) const
+   {
+       if (!fOk) return false;
+       for (unsigned i = 0; i < N; ++i) {
+	   // zero upper half of matrix
+	   for (unsigned j = i + 1; j < N; ++j)
+	       m(i, j) = F(0);
+	   // copy the rest
+	   for (unsigned j = 0; j <= i; ++j)
+	       m(i, j) = fL[i * (i + 1) / 2 + j];
+	   // adjust the diagonal - we save 1/L(i, i) in that position, so
+	   // convert to what caller expects
+	   m(i, i) = F(1) / m(i, i);
+       }
+       return true;
+   }
+
+   /** @brief obtain the decomposed matrix L
+    *
+    * @returns if the decomposition was successful
+    *
+    * NOTE: the matrix is given in packed representation, matrix
+    * element m(i,j) (j <= i) is supposed to be in array element
+    * (i * (i + 1)) / 2 + j
+    */
+   template<typename G> bool getL(G* m) const
+   {
+       if (!fOk) return false;
+       // copy L
+       for (unsigned i = 0; i < (N * (N + 1)) / 2; ++i)
+	   m[i] = fL[i];
+       // adjust diagonal - we save 1/L(i, i) in that position, so convert to
+       // what caller expects
+       for (unsigned i = 0; i < N; ++i)
+	   m[(i * (i + 1)) / 2 + i] = F(1) / fL[(i * (i + 1)) / 2 + i];
+       return true;
+   }
+
+   /** @brief obtain the inverse of the decomposed matrix L
+    *
+    * This is the method to use with a plain array.
+    *
+    * @returns if the decomposition was successful
+    */
+   template<class M> bool getLi(M& m) const
+   {
+       if (!fOk) return false;
+       for (unsigned i = 0; i < N; ++i) {
+	   // zero lower half of matrix
+	   for (unsigned j = i + 1; j < N; ++j)
+	       m(j, i) = F(0);
+	   // copy the rest
+	   for (unsigned j = 0; j <= i; ++j)
+	       m(j, i) = fL[i * (i + 1) / 2 + j];
+       }
+       // invert the off-diagonal part of what we just copied
+       for (unsigned i = 1; i < N; ++i) {
+	   for (unsigned j = 0; j < i; ++j) {
+	       typename M::value_type tmp = F(0);
+	       for (unsigned k = i; k-- > j;)
+		   tmp -= m(k, i) * m(j, k);
+	       m(j, i) = tmp * m(i, i);
+	   }
+       }
+       return true;
+   }
+
+   /** @brief obtain the inverse of the decomposed matrix L
+    *
+    * @returns if the decomposition was successful
+    *
+    * NOTE: the matrix is given in packed representation, matrix
+    * element m(j,i) (j <= i) is supposed to be in array element
+    * (i * (i + 1)) / 2 + j
+    */
+   template<typename G> bool getLi(G* m) const
+   {
+       if (!fOk) return false;
+       // copy L
+       for (unsigned i = 0; i < (N * (N + 1)) / 2; ++i)
+	   m[i] = fL[i];
+       // invert the off-diagonal part of what we just copied
+       G* base1 = &m[1];
+       for (unsigned i = 1; i < N; base1 += ++i) {
+	   for (unsigned j = 0; j < i; ++j) {
+	       G tmp = F(0);
+	       const G *base2 = &m[(i * (i - 1)) / 2];
+	       for (unsigned k = i; k-- > j; base2 -= k)
+		   tmp -= base1[k] * base2[j];
+	       base1[j] = tmp * base1[i];
+	   }
+       }
+       return true;
+   }
 };
 
+/// class to compute the Cholesky decomposition of a matrix
+/** class to compute the Cholesky decomposition of a symmetric
+ * positive definite matrix when the dimensionality of the problem is not known
+ * at compile time
+ *
+ * provides routines to check if the decomposition succeeded (i.e. if
+ * matrix is positive definite and non-singular), to solve a linear
+ * system for the given matrix and to obtain its inverse
+ *
+ * the actual functionality is implemented in templated helper
+ * classes which have specializations for dimensions N = 1 to 6
+ * to achieve a gain in speed for common matrix sizes
+ *
+ * usage example:
+ * @code
+ * // let m be a symmetric positive definite SMatrix (use type float
+ * // for internal computations, matrix size is 4x4)
+ * CholeskyDecompGenDim<float> decomp(4, m);
+ * // check if the decomposition succeeded
+ * if (!decomp) {
+ *   std::cerr << "decomposition failed!" << std::endl;
+ * } else {
+ *   // let rhs be a vector; we seek a vector x such that m * x = rhs
+ *   decomp.Solve(rhs);
+ *   // rhs now contains the solution we are looking for
+ *
+ *   // obtain the inverse of m, put it into m itself
+ *   decomp.Invert(m);
+ * }
+ * @endcode
+ */
+template<class F> class CholeskyDecompGenDim
+{
+private:
+   /** @brief dimensionality
+    * dimensionality of the problem */
+   unsigned fN; 
+   /// lower triangular matrix L
+   /** lower triangular matrix L, packed storage, with diagonal
+    * elements pre-inverted */
+   F *fL;
+   /// flag indicating a successful decomposition
+   bool fOk;
+public:
+   /// perform a Cholesky decomposition
+   /** perfrom a Cholesky decomposition of a symmetric positive
+    * definite matrix m
+    *
+    * this is the constructor to uses with an SMatrix (and objects
+    * that behave like an SMatrix in terms of using
+    * operator()(int i, int j) for access to elements)
+    */
+   template<class M> CholeskyDecompGenDim(unsigned N, const M& m) : 
+      fN(N), fL(new F[(fN * (fN + 1)) / 2]), fOk(false)
+   {
+      using CholeskyDecompHelpers::_decomposerGenDim;
+      fOk = _decomposerGenDim<F, M>()(fL, m, fN);
+   }
+
+   /// perform a Cholesky decomposition
+   /** perfrom a Cholesky decomposition of a symmetric positive
+    * definite matrix m
+    * 
+    * this is the constructor to use in special applications where
+    * plain arrays are used
+    *
+    * NOTE: the matrix is given in packed representation, matrix
+    * element m(i,j) (j <= i) is supposed to be in array element
+    * (i * (i + 1)) / 2 + j
+    */
+   template<typename G> CholeskyDecompGenDim(unsigned N, G* m) : 
+      fN(N), fL(new F[(fN * (fN + 1)) / 2]), fOk(false)
+   {
+      using CholeskyDecompHelpers::_decomposerGenDim;
+      using CholeskyDecompHelpers::PackedArrayAdapter;
+      fOk = _decomposerGenDim<F, PackedArrayAdapter<G> >()(
+         fL, PackedArrayAdapter<G>(m), fN);
+   }
+
+   /// destructor
+   ~CholeskyDecompGenDim() { delete[] fL; }
+
+   /// returns true if decomposition was successful
+   /** @returns true if decomposition was successful */
+   bool ok() const { return fOk; }
+   /// returns true if decomposition was successful
+   /** @returns true if decomposition was successful */
+   operator bool() const { return fOk; }
+
+   /** @brief solves a linear system for the given right hand side
+    *
+    * Note that you can use both SVector classes and plain arrays for
+    * rhs. (Make sure that the sizes match!). It will work with any vector 
+    * implementing the operator [i]
+    *
+    * @returns if the decomposition was successful
+    */
+   template<class V> bool Solve(V& rhs) const
+   {
+      using CholeskyDecompHelpers::_solverGenDim;
+      if (fOk) _solverGenDim<F,V>()(rhs, fL, fN); return fOk;
+   }
+
+   /** @brief place the inverse into m
+    *
+    * This is the method to use with an SMatrix.
+    *
+    * @returns if the decomposition was successful
+    */
+   template<class M> bool Invert(M& m) const
+   {
+      using CholeskyDecompHelpers::_inverterGenDim;
+      if (fOk) _inverterGenDim<F,M>()(m, fL, fN); return fOk;
+   }
+
+   /** @brief place the inverse into m
+    *
+    * This is the method to use with a plain array.
+    *
+    * @returns if the decomposition was successful
+    *
+    * NOTE: the matrix is given in packed representation, matrix
+    * element m(i,j) (j <= i) is supposed to be in array element
+    * (i * (i + 1)) / 2 + j
+    */
+   template<typename G> bool Invert(G* m) const
+   {
+      using CholeskyDecompHelpers::_inverterGenDim;
+      using CholeskyDecompHelpers::PackedArrayAdapter;
+      if (fOk) {
+         PackedArrayAdapter<G> adapted(m);
+         _inverterGenDim<F,PackedArrayAdapter<G> >()(adapted, fL, fN);
+      }
+      return fOk;
+   }   
+
+   /** @brief obtain the decomposed matrix L
+    *
+    * This is the method to use with a plain array.
+    *
+    * @returns if the decomposition was successful
+    */
+   template<class M> bool getL(M& m) const
+   {
+       if (!fOk) return false;
+       for (unsigned i = 0; i < fN; ++i) {
+	   // zero upper half of matrix
+	   for (unsigned j = i + 1; j < fN; ++j)
+	       m(i, j) = F(0);
+	   // copy the rest
+	   for (unsigned j = 0; j <= i; ++j)
+	       m(i, j) = fL[i * (i + 1) / 2 + j];
+	   // adjust the diagonal - we save 1/L(i, i) in that position, so
+	   // convert to what caller expects
+	   m(i, i) = F(1) / m(i, i);
+       }
+       return true;
+   }
+
+   /** @brief obtain the decomposed matrix L
+    *
+    * @returns if the decomposition was successful
+    *
+    * NOTE: the matrix is given in packed representation, matrix
+    * element m(i,j) (j <= i) is supposed to be in array element
+    * (i * (i + 1)) / 2 + j
+    */
+   template<typename G> bool getL(G* m) const
+   {
+       if (!fOk) return false;
+       // copy L
+       for (unsigned i = 0; i < (fN * (fN + 1)) / 2; ++i)
+	   m[i] = fL[i];
+       // adjust diagonal - we save 1/L(i, i) in that position, so convert to
+       // what caller expects
+       for (unsigned i = 0; i < fN; ++i)
+	   m[(i * (i + 1)) / 2 + i] = F(1) / fL[(i * (i + 1)) / 2 + i];
+       return true;
+   }
+
+   /** @brief obtain the inverse of the decomposed matrix L
+    *
+    * This is the method to use with a plain array.
+    *
+    * @returns if the decomposition was successful
+    */
+   template<class M> bool getLi(M& m) const
+   {
+       if (!fOk) return false;
+       for (unsigned i = 0; i < fN; ++i) {
+	   // zero lower half of matrix
+	   for (unsigned j = i + 1; j < fN; ++j)
+	       m(j, i) = F(0);
+	   // copy the rest
+	   for (unsigned j = 0; j <= i; ++j)
+	       m(j, i) = fL[i * (i + 1) / 2 + j];
+       }
+       // invert the off-diagonal part of what we just copied
+       for (unsigned i = 1; i < fN; ++i) {
+	   for (unsigned j = 0; j < i; ++j) {
+	       typename M::value_type tmp = F(0);
+	       for (unsigned k = i; k-- > j;)
+		   tmp -= m(k, i) * m(j, k);
+	       m(j, i) = tmp * m(i, i);
+	   }
+       }
+       return true;
+   }
+
+   /** @brief obtain the inverse of the decomposed matrix L
+    *
+    * @returns if the decomposition was successful
+    *
+    * NOTE: the matrix is given in packed representation, matrix
+    * element m(j,i) (j <= i) is supposed to be in array element
+    * (i * (i + 1)) / 2 + j
+    */
+   template<typename G> bool getLi(G* m) const
+   {
+       if (!fOk) return false;
+       // copy L
+       for (unsigned i = 0; i < (fN * (fN + 1)) / 2; ++i)
+	   m[i] = fL[i];
+       // invert the off-diagonal part of what we just copied
+       G* base1 = &m[1];
+       for (unsigned i = 1; i < fN; base1 += ++i) {
+	   for (unsigned j = 0; j < i; ++j) {
+	       G tmp = F(0);
+	       const G *base2 = &m[(i * (i - 1)) / 2];
+	       for (unsigned k = i; k-- > j; base2 -= k)
+		   tmp -= base1[k] * base2[j];
+	       base1[j] = tmp * base1[i];
+	   }
+       }
+       return true;
+   }
+};
 
 namespace CholeskyDecompHelpers {
-   /// struct to do a Cholesky decomposition
-   template<class F, unsigned N, class M> struct _decomposer
+   /// adapter for packed arrays (to SMatrix indexing conventions)
+   template<typename G> class PackedArrayAdapter
+   {
+   private:
+      G* fArr; ///< pointer to first array element
+   public:
+      /// constructor
+      PackedArrayAdapter(G* arr) : fArr(arr) {}
+      /// read access to elements (make sure that j <= i)
+      const G operator()(unsigned i, unsigned j) const
+      { return fArr[((i * (i + 1)) / 2) + j]; }
+      /// write access to elements (make sure that j <= i)
+      G& operator()(unsigned i, unsigned j)
+      { return fArr[((i * (i + 1)) / 2) + j]; }
+   };
+   /// struct to do a Cholesky decomposition (general dimensionality)
+   template<class F, class M> struct _decomposerGenDim
    {
       /// method to do the decomposition
       /** @returns if the decomposition was successful */
-      bool operator()(F* dst, const M& src) const
+      bool operator()(F* dst, const M& src, unsigned N) const
       {
          // perform Cholesky decomposition of matrix: M = L L^T
          // only thing that can go wrong: trying to take square
@@ -223,14 +570,23 @@ namespace CholeskyDecompHelpers {
       }
    };
 
-   /// struct to obtain the inverse from a Cholesky decomposition
-   template<class F, unsigned N, class M> struct _inverter
+   /// struct to do a Cholesky decomposition
+   template<class F, unsigned N, class M> struct _decomposer
+   {
+      /// method to do the decomposition
+      /** @returns if the decomposition was successful */
+      bool operator()(F* dst, const M& src) const
+      { return _decomposerGenDim<F, M>()(dst, src, N); }
+   };
+
+   /// struct to obtain the inverse from a Cholesky decomposition (general dimensionality)
+   template<class F, class M> struct _inverterGenDim
    {
       /// method to do the inversion
-      void operator()(M& dst, const F* src) const
+      void operator()(M& dst, const F* src, unsigned N) const
       {
          // make working copy
-         F l[N * (N + 1) / 2];
+         F * l = new F[N * (N + 1) / 2];
          std::copy(src, src + ((N * (N + 1)) / 2), l);
          // ok, next step: invert off-diagonal part of matrix
          F* base1 = &l[1];
@@ -254,14 +610,23 @@ namespace CholeskyDecompHelpers {
                dst(i, j) = tmp;
             }
          }
+         delete [] l;
       }
    };
 
-   /// struct to solve a linear system using its Cholesky decomposition
-   template<class F, unsigned N, class V> struct _solver
+   /// struct to obtain the inverse from a Cholesky decomposition
+   template<class F, unsigned N, class M> struct _inverter
+   {
+      /// method to do the inversion
+      void operator()(M& dst, const F* src) const
+      { return _inverterGenDim<F, M>()(dst, src, N); }
+   };
+
+   /// struct to solve a linear system using its Cholesky decomposition (generalised dimensionality)
+   template<class F, class V> struct _solverGenDim
    {
       /// method to solve the linear system
-      void operator()(V& rhs, const F* l) const
+      void operator()(V& rhs, const F* l, unsigned N) const
       {
          // solve Ly = rhs
          for (unsigned k = 0; k < N; ++k) {
@@ -283,6 +648,14 @@ namespace CholeskyDecompHelpers {
       }
    };
 
+   /// struct to solve a linear system using its Cholesky decomposition
+   template<class F, unsigned N, class V> struct _solver
+   {
+      /// method to solve the linear system
+      void operator()(V& rhs, const F* l) const
+      { _solverGenDim<F, V>()(rhs, l, N); }
+   };
+
    /// struct to do a Cholesky decomposition (specialized, N = 6)
    template<class F, class M> struct _decomposer<F, 6, M>
    {
