@@ -66,7 +66,7 @@
 */
 
 #include "TGenerator.h"
-#include "Pythia.h"
+#include "Pythia8/Pythia.h"
 
 
 class Pythia;
