@@ -1,4 +1,4 @@
-// @(#)root/alien:$Id: TAlienCollection.cxx 35952 2010-09-30 16:20:22Z brun $
+// @(#)root/alien:$Id$
 // Author: Andreas-Joachim Peters 9/5/2005
 
 /*************************************************************************
@@ -956,6 +956,22 @@ leaveloop:
    }
 }
 
+//______________________________________________________________________________
+void TAlienCollection::AddFast(TGridCollection * addcollection)
+{
+   // adds <addcollection> to this collection - NO check for identical elements
+
+   if ((!addcollection)) {
+      return;
+   }
+   addcollection->Reset();
+   TMap *addmap, *clonemap;
+   while ((addmap = addcollection->Next())) {
+      clonemap = (TMap *) addmap->Clone();
+      fFileGroupList->Add(clonemap);
+   }
+}
+
 //______________________________________________________________________________
 Bool_t TAlienCollection::LookupSUrls(Bool_t verbose)
 {
