@@ -1,4 +1,4 @@
-// @(#)root/krb5auth:$Id: Krb5Auth.cxx 39415 2011-05-26 14:04:11Z axel $
+// @(#)root/krb5auth:$Id$
 // Author: Johannes Muelmenstaedt  17/03/2002
 
 /*************************************************************************
@@ -485,7 +485,7 @@ Int_t Krb5Authenticate(TAuthenticate *auth, TString &user, TString &det,
 
    if (gDebug > 1)
      Info("Krb5Authenticate",
-          "Sending kerberos authentification to %s",
+          "Sending kerberos authentication to %s",
           serv_host.Data());
 
    retval = krb5_sendauth(context, &auth_context, (krb5_pointer)&sockd,
