@@ -1,4 +1,4 @@
-// @(#)root/netx:$Id: TXNetSystem.cxx 43295 2012-03-08 15:01:08Z ganis $
+// @(#)root/netx:$Id$
 // Author: Frank Winklmeier, Fabrizio Furano
 
 /*************************************************************************
@@ -564,7 +564,8 @@ Int_t TXNetSystem::Prepare(TCollection *paths,
          *buf += Form("%s\n", path.Data());
       }
 
-      Info("Prepare","buffer ready: issuing prepare ...");
+      Info("Prepare","buffer ready: issuing prepare (opt=%d, prio=%d) ...",
+         opt, prio);
       cg.ClientAdmin()->Prepare(buf->Data(), (kXR_char)opt, (kXR_char)prio);
       cg.ClientAdmin()->GoBackToRedirector();
       if (!bufout)
