@@ -1,4 +1,4 @@
-// @(#)root/proof:$Id: TProofServ.h 44010 2012-04-29 23:07:48Z ganis $
+// @(#)root/proof:$Id$
 // Author: Fons Rademakers   16/02/97
 
 /*************************************************************************
@@ -44,6 +44,7 @@
 #endif
 
 class TDataSetManager;
+class TDataSetManagerFile;
 class TDSet;
 class TDSetElement;
 class TFileCollection;
@@ -97,7 +98,9 @@ private:
    TString       fQueryDir;         //directory containing query results and status
    TString       fDataSetDir;       //directory containing info about known data sets
    TString       fDataDir;          //directory containing data files produced during queries
+   TString       fDataDirOpts;      //Url type options for fDataDir
    TString       fAdminPath;        //admin path for this session
+   TString       fOutputFile;       //path with the temporary results of the current or last query
    TProofLockPath *fPackageLock;    //package dir locker
    TProofLockPath *fCacheLock;      //cache dir locker
    TProofLockPath *fQueryLock;      //query dir locker
@@ -122,7 +125,8 @@ private:
    Float_t       fRealTime;         //real time spent executing commands
    Float_t       fCpuTime;          //CPU time spent executing commands
    TStopwatch    fLatency;          //measures latency of packet requests
-   TStopwatch    fCompute;          //measures time spend processing a packet
+   TStopwatch    fCompute;          //measures time spent processing a packet
+   TStopwatch    fSaveOutput;       //measures time spent saving the partial result
    Int_t         fQuerySeqNum;      //sequential number of the current or last query
 
    Int_t         fTotSessions;      //Total number of PROOF sessions on the cluster 
@@ -152,6 +156,7 @@ private:
    Int_t         fCompressMsg;     // Compression level for messages
 
    TDataSetManager* fDataSetManager; // dataset manager
+   TDataSetManagerFile *fDataSetStgRepo;  // repository for staging requests
 
    Bool_t        fSendLogToMaster; // On workers, controls logs sending to master
 
@@ -200,9 +205,6 @@ private:
    // Results handling
    Int_t         SendResults(TSocket *sock, TList *outlist = 0, TQueryResult *pq = 0);
    Bool_t        AcceptResults(Int_t connections, TVirtualProofPlayer *mergerPlayer);
-   
-   TMap         *GetDataSetNodeMap(const char *dsn, TString &emsg);
-   Int_t         RegisterDataSets(TList *in, TList *out);
 
    // Waiting queries handlers
    void          SetIdle(Bool_t st = kTRUE);
@@ -254,10 +256,12 @@ public:
    const char    *GetGroup()      const { return fGroup; }
    const char    *GetWorkDir()    const { return fWorkDir; }
    const char    *GetImage()      const { return fImage; }
-   const char    *GetSessionTag() const { return fTopSessionTag; }
+   const char    *GetSessionTag() const { return fSessionTag; }
+   const char    *GetTopSessionTag() const { return fTopSessionTag; }
    const char    *GetSessionDir() const { return fSessionDir; }
    const char    *GetPackageDir() const { return fPackageDir; }
    const char    *GetDataDir()    const { return fDataDir; }
+   const char    *GetDataDirOpts() const { return fDataDirOpts; }
    Int_t          GetProtocol()   const { return fProtocol; }
    const char    *GetOrdinal()    const { return fOrdinal; }
    Int_t          GetGroupId()    const { return fGroupId; }
@@ -343,6 +347,14 @@ public:
    static void    SetLastMsg(const char *lastmsg);
    static void    SetLastEntry(Long64_t lastentry);
 
+   // To handle local data server related paths
+   static void    FilterLocalroot(TString &path, const char *url = "root://dum/");
+   static void    GetLocalServer(TString &dsrv);
+
+   // To prepara ethe map of files to process
+   static TMap   *GetDataSetNodeMap(TFileCollection *fc, TString &emsg);
+   static Int_t   RegisterDataSets(TList *in, TList *out, TDataSetManager *dsm, TString &e);
+
    static Bool_t      IsActive();
    static TProofServ *This();
 
@@ -421,9 +433,10 @@ public:
 class TShutdownTimer : public TTimer {
 private:
    TProofServ    *fProofServ;
+   Int_t          fTimeout;
 
 public:
-   TShutdownTimer(TProofServ *p, Int_t delay) : TTimer(delay, kFALSE), fProofServ(p) { }
+   TShutdownTimer(TProofServ *p, Int_t delay);
 
    Bool_t Notify();
 };
