@@ -124,6 +124,7 @@ TDSetElement::TDSetElement(const char *file, const char *objname, const char *di
    fAssocObjList = 0;
    if (dir)
       fDirectory = dir;
+   fMaxProcTime = -1.;
 
    ResetBit(kWriteV3);
    ResetBit(kHasBeenLookedUp);
@@ -149,6 +150,7 @@ TDSetElement::TDSetElement(const TDSetElement& elem)
    fFriends = 0;
    fDataSet = elem.fDataSet;
    fAssocObjList = 0;
+   fMaxProcTime = elem.fMaxProcTime;
    ResetBit(kWriteV3);
    ResetBit(kHasBeenLookedUp);
    ResetBit(kEmpty);
@@ -987,8 +989,14 @@ void TDSet::SetObjName(const char *objname)
 {
    // Set/change object name.
 
-   if (objname)
+   if (objname) {
       fObjName = objname;
+      TIter next(GetListOfElements());
+      TDSetElement *e;
+      while ((e = (TDSetElement *) next())) {
+         e->SetTitle(objname);
+      }
+   }
 }
 
 //______________________________________________________________________________
