@@ -19,6 +19,7 @@
 //////////////////////////////////////////////////////////////////////////
 
 #include "TDataSetManagerAliEn.h"
+#include "TError.h"
 
 ClassImp(TAliEnFind);
 
@@ -121,9 +122,10 @@ TGridResult *TAliEnFind::GetGridResult(Bool_t forceNewQuery)
       TPMERegexp *reArchSubst = NULL;
       TString substWith;
       if (fArchSubst) {
-         TString temp = Form("/%s$", fFileName.Data());
+         TString temp;
+         temp.Form("/%s$", fFileName.Data());
          reArchSubst = new TPMERegexp(temp.Data());
-         substWith = Form("/root_archive.zip#%s", fFileName.Data());
+         substWith.Form("/root_archive.zip#%s", fFileName.Data());
       }
 
       TIter it(fGridResult);
@@ -312,8 +314,9 @@ void TDataSetManagerAliEn::Init(TString cacheDir, TString urlTpl,
   fUrlTpl = urlTpl;
   fUrlTpl.ReplaceAll("<path>", "$1");
 
-  fCache = new TDataSetManagerFile("_cache_", "_cache_",
-    Form("dir:%s perms:open", cacheDir.Data()));
+  TString dsDirFmt;
+  dsDirFmt.Form("dir:%s perms:open", cacheDir.Data());
+  fCache = new TDataSetManagerFile("_cache_", "_cache_", dsDirFmt);
 
   if (fCache->TestBit(TObject::kInvalidObject)) {
     Error("Init", "Cannot initialize cache on directory %s", cacheDir.Data());
@@ -379,7 +382,7 @@ TDataSetManagerAliEn::~TDataSetManagerAliEn()
 
 //______________________________________________________________________________
 TList *TDataSetManagerAliEn::GetFindCommandsFromUri(TString &uri,
-  EDataMode &dataMode)
+  EDataMode &dataMode, Bool_t &forceUpdate)
 {
   // Parse kind
   TPMERegexp reKind("^(Data;|Sim;|Find;)");
@@ -448,57 +451,100 @@ TList *TDataSetManagerAliEn::GetFindCommandsFromUri(TString &uri,
     findCommands = new TList();
     findCommands->SetOwner(kTRUE);
 
+    TString basePathRun;
+
+    if (!gGrid) {
+      TGrid::Connect("alien:");
+      if (!gGrid) {
+        delete findCommands;
+        delete runList;
+        return NULL;
+      }
+    }
+
+    if (sim) {
+      // Montecarlo init.
+      // Check whether this period is in /alice/sim/<period> or in
+      // /alice/sim/<year>/<period> and act properly, since naming convention
+      // is unclear!
+
+      // Check once for all
+      basePathRun.Form("/alice/sim/%s", lhcPeriod.Data());  // no year
+      if (!gGrid->Cd(basePathRun.Data())) {
+        basePathRun.Form("/alice/sim/%d/%s", year, lhcPeriod.Data());
+      }
+    }
+    else {
+      // Real data init.
+      // Parse the pass string: if it starts with a number, prepend "pass"
+      if ((pass[0] >= '0') && (pass[0] <= '9')) pass.Prepend("pass");
+      basePathRun.Form("/alice/data/%d/%s", year, lhcPeriod.Data());
+    }
+
+    // Form a list of valid runs (to avoid unnecessary queries when run ranges
+    // are specified)
+    std::vector<Int_t> validRuns;
+    {
+      TGridResult *validRunDirs = gGrid->Ls( basePathRun.Data() );
+      if (!validRunDirs) return NULL;
+
+      TIter nrd(validRunDirs);
+      TMap *dir;
+      TObjString *os;
+      validRuns.resize( (size_t)(validRunDirs->GetEntries()) );
+
+      while (( dir = dynamic_cast<TMap *>(nrd()) ) != NULL) {
+        os = dynamic_cast<TObjString *>( dir->GetValue("name") );
+        if (!os) continue;
+        Int_t run = (os->String()).Atoi();
+        if (run > 0) validRuns.push_back(run);
+      }
+    }
+
     for (UInt_t i=0; i<runList->size(); i++) {
 
+      // Check if current run is valid
+      Bool_t valid = kFALSE;
+      for (UInt_t j=0; j<validRuns.size(); j++) {
+        if (validRuns[j] == (*runList)[i]) {
+          valid = kTRUE;
+          break;
+        }
+      }
+      if (!valid) {
+        //if (gDebug >=1) {
+          Warning("TDataSetManagerAliEn::GetFindCommandsFromUri",
+            "Avoiding unnecessary find on run %d: not found", (*runList)[i]);
+        //}
+        continue;
+      }
+      else {
+        Info("TDataSetManagerAliEn::GetFindCommandsFromUri",
+          "Run found: %d", (*runList)[i]);
+      }
+
       // Here we need to assemble the find string
       TString basePath, fileName, temp;
 
       if (sim) {
-
-        //
         // Montecarlo
-        //
-
-        // Check whether this period is in /alice/sim/<period> or in
-        // /alice/sim/<year>/<period> and act properly, since naming convention
-        // is unclear!
-        if (!gGrid) {
-          TGrid::Connect("alien:");
-          if (!gGrid) {
-            delete findCommands;
-            return NULL;
-          }
-        }
-
-        basePath = Form("/alice/sim/%s", lhcPeriod.Data());  // no year
-        if (!gGrid->Cd(basePath.Data())) {
-          basePath = Form("/alice/sim/%d/%s", year, lhcPeriod.Data());
-        }
         temp.Form("/%06d", runList->at(i));
-        basePath.Append(temp);
+        basePath = basePathRun + temp;
 
         if (!esd) {
-          temp = Form("/AOD%03d", aodNum);
+          temp.Form("/AOD%03d", aodNum);
           basePath.Append(temp);
         }
       }
       else {
-
-        //
         // Real data
-        //
-
-        // Parse the pass string: if it starts with a number, prepend "pass"
-        if ((pass[0] >= '0') && (pass[0] <= '9')) pass.Prepend("pass");
-
-        // Data
-        basePath = Form("/alice/data/%d/%s/%09d/ESDs/%s", year,
-          lhcPeriod.Data(), runList->at(i), pass.Data());
+        temp.Form("/%09d/ESDs/%s", runList->at(i), pass.Data());
+        basePath = basePathRun + temp;
         if (esd) {
           basePath.Append("/*.*");
         }
         else {
-          temp = Form("/AOD%03d", aodNum);
+          temp.Form("/AOD%03d", aodNum);
           basePath.Append(temp);
         }
       }
@@ -524,7 +570,11 @@ TList *TDataSetManagerAliEn::GetFindCommandsFromUri(TString &uri,
 
   }
 
-  // If no valid data found, then findCommands is NULL
+  // Force update or use cache (when possible)
+  TPMERegexp reForceUpdate("(^|;)ForceUpdate(;|$)");
+  forceUpdate = (reForceUpdate.Match(uri) == 3);
+
+  // If no valid data was found, then findCommands is NULL
   return findCommands;
 }
 
@@ -534,43 +584,73 @@ Bool_t TDataSetManagerAliEn::ParseCustomFindUri(TString &uri,
    TString &regexp)
 {
 
+  // Copy URI to a dummy URI parsed to look for unrecognized stuff; initial
+  // part is known ("Find;") and stripped
+  TString checkUri = uri(5, uri.Length());
+
+  // Mode and ForceUpdate (strip them from the check string)
+  TPMERegexp reMode("(^|;)(Mode=[A-Za-z]+)(;|$)");
+  if (reMode.Match(uri) == 4)
+    checkUri.ReplaceAll(reMode[2], "");
+  TPMERegexp reForceUpdate("(^|;)(ForceUpdate)(;|$)");
+  if (reForceUpdate.Match(uri) == 4)
+    checkUri.ReplaceAll(reForceUpdate[2], "");
+
   // Base path
-  TPMERegexp reBasePath("(^|;)BasePath=([^; ]+)(;|$)");
-  if (reBasePath.Match(uri) != 4) {
-    Error("ParseCustomFindUri", "Base path not specified");
+  TPMERegexp reBasePath("(^|;)(BasePath=([^; ]+))(;|$)");
+  if (reBasePath.Match(uri) != 5) {
+    ::Error("TDataSetManagerAliEn::ParseCustomFindUri",
+      "Base path not specified");
     return kFALSE;
   }
-  basePath = reBasePath[2];
+  checkUri.ReplaceAll(reBasePath[2], "");
+  basePath = reBasePath[3];
 
   // File name
-  TPMERegexp reFileName("(^|;)FileName=([^; ]+)(;|$)");
-  if (reFileName.Match(uri) != 4) {
-    Error("ParseCustomFindUri", "File name not specified");
+  TPMERegexp reFileName("(^|;)(FileName=([^; ]+))(;|$)");
+  if (reFileName.Match(uri) != 5) {
+    ::Error("TDataSetManagerAliEn::ParseCustomFindUri",
+      "File name not specified");
     return kFALSE;
   }
-  fileName = reFileName[2];
+  checkUri.ReplaceAll(reFileName[2], "");
+  fileName = reFileName[3];
 
   // Anchor (optional)
-  TPMERegexp reAnchor("(^|;)Anchor=([^; ]+)(;|$)");
-  if (reAnchor.Match(uri) != 4)
+  TPMERegexp reAnchor("(^|;)(Anchor=([^; ]+))(;|$)");
+  if (reAnchor.Match(uri) != 5)
     anchor = "";
-  else
-    anchor = reAnchor[2];
+  else {
+    checkUri.ReplaceAll(reAnchor[2], "");
+    anchor = reAnchor[3];
+  }
 
   // Tree name (optional)
-  TPMERegexp reTreeName("(^|;)Tree=(/[^; ]+)(;|$)");
-  if (reTreeName.Match(uri) != 4)
+  TPMERegexp reTreeName("(^|;)(Tree=(/[^; ]+))(;|$)");
+  if (reTreeName.Match(uri) != 5)
     treeName = "";
-  else
-    treeName = reTreeName[2];
+  else {
+    checkUri.ReplaceAll(reTreeName[2], "");
+    treeName = reTreeName[3];
+  }
 
   // Regexp (optional)
-  TPMERegexp reRegexp("(^|;)Regexp=([^; ]+)(;|$)");
-  if (reRegexp.Match(uri) != 4)
+  TPMERegexp reRegexp("(^|;)(Regexp=([^; ]+))(;|$)");
+  if (reRegexp.Match(uri) != 5)
     regexp = "";
-  else
-    regexp = reRegexp[2];
+  else {
+    checkUri.ReplaceAll(reRegexp[2], "");
+    regexp = reRegexp[3];
+  }
 
+  // Check for unparsed stuff; parsed stuff has been stripped from checkUri
+  checkUri.ReplaceAll(";", "");
+  checkUri.ReplaceAll(" ", "");
+  if (!checkUri.IsNull()) {
+    ::Error("TDataSetManagerAliEn::ParseCustomFindUri",
+      "There are unrecognized parameters in the dataset find string");
+    return kFALSE;
+  }
    return kTRUE;
 }
 
@@ -580,62 +660,92 @@ Bool_t TDataSetManagerAliEn::ParseOfficialDataUri(TString &uri, Bool_t sim,
   Int_t &aodNum, TString &pass)
 {
 
+  // Copy URI to a dummy URI parsed to look for unrecognized stuff
+  TString checkUri;
+
+  // Strip the initial part (either "Data;" or "Sim;")
+  {
+    Ssiz_t idx = uri.Index(";");
+    checkUri = uri(idx, uri.Length());
+  }
+
+  // Mode and ForceUpdate (strip them from the check string)
+  TPMERegexp reMode("(^|;)(Mode=[A-Za-z]+)(;|$)");
+  if (reMode.Match(uri) == 4)
+    checkUri.ReplaceAll(reMode[2], "");
+  TPMERegexp reForceUpdate("(^|;)(ForceUpdate)(;|$)");
+  if (reForceUpdate.Match(uri) == 4)
+    checkUri.ReplaceAll(reForceUpdate[2], "");
+
   //
   // Parse LHC period
   //
 
-  TPMERegexp rePeriod("(^|;)Period=(LHC([0-9]{2})[^;]*)(;|$)");
-  if (rePeriod.Match(uri) != 5) {
-    Error("ParseOfficialDataUri",
+  TPMERegexp rePeriod("(^|;)(Period=(LHC([0-9]{2})[^;]*))(;|$)");
+  if (rePeriod.Match(uri) != 6) {
+    ::Error("TDataSetManagerAliEn::ParseOfficialDataUri",
       "LHC period not specified (e.g. Period=LHC10h)");
     return kFALSE;
   }
 
-  period = rePeriod[2];
-  year = rePeriod[3].Atoi() + 2000;
+  checkUri.ReplaceAll(rePeriod[2], "");
+  period = rePeriod[3];
+  year = rePeriod[4].Atoi() + 2000;
 
   //
   // Parse data format (ESDs or AODXXX)
   //
 
-  TPMERegexp reFormat("(^|;)Variant=(ESDs?|AOD([0-9]{3}))(;|$)");
-  if (reFormat.Match(uri) != 5) {
-    Error("ParseOfficialDataUri",
+  TPMERegexp reFormat("(^|;)(Variant=(ESDs?|AOD([0-9]{3})))(;|$)");
+  if (reFormat.Match(uri) != 6) {
+    ::Error("TDataSetManagerAliEn::ParseOfficialDataUri",
       "Data variant (e.g., Variant=ESD or AOD079) not specified");
     return kFALSE;
   }
 
-  if (reFormat[2].BeginsWith("ESD")) esd = kTRUE;
+  checkUri.ReplaceAll(reFormat[2], "");
+  if (reFormat[3].BeginsWith("ESD")) esd = kTRUE;
   else {
     esd = kFALSE;
-    aodNum = reFormat[3].Atoi();
+    aodNum = reFormat[4].Atoi();
   }
 
   //
   // Parse pass: mandatory on Data, useless on Sim
   //
 
-  TPMERegexp rePass("(^|;)Pass=([a-zA-Z_0-9-]+)(;|$)");
-  if ((rePass.Match(uri) != 4) && (!sim)) {
-    Error("ParseOfficialDataUri",
+  TPMERegexp rePass("(^|;)(Pass=([a-zA-Z_0-9-]+))(;|$)");
+  if ((!sim) && (rePass.Match(uri) != 5)) {
+    ::Error("TDataSetManagerAliEn::ParseOfficialDataUri",
       "Pass (e.g., Pass=cpass1_muon) is mandatory on real data");
     return kFALSE;
   }
-  pass = rePass[2];
+  checkUri.ReplaceAll(rePass[2], "");
+  pass = rePass[3];
 
   //
   // Parse run list
   //
 
-  TPMERegexp reRun("(^|;)Run=([0-9,-]+)(;|$)");
-  if (reRun.Match(uri) != 4) {
-    Error("ParseOfficialDataUri",
+  TPMERegexp reRun("(^|;)(Run=([0-9,-]+))(;|$)");
+  if (reRun.Match(uri) != 5) {
+    ::Error("TDataSetManagerAliEn::ParseOfficialDataUri",
       "Run or run range not specified (e.g., Run=139104-139107,139306)");
     return kFALSE;
   }
-  TString runListStr = reRun[2];
+  checkUri.ReplaceAll(reRun[2], "");
+  TString runListStr = reRun[3];
   runList = ExpandRunSpec(runListStr);  // must be freed by caller
 
+  // Check for unparsed stuff; parsed stuff has been stripped from checkUri
+  checkUri.ReplaceAll(";", "");
+  checkUri.ReplaceAll(" ", "");
+  if (!checkUri.IsNull()) {
+    ::Error("TDataSetManagerAliEn::ParseOfficialDataUri",
+      "There are unrecognized parameters in dataset string");
+    return kFALSE;
+  }
+
   return kTRUE;
 }
 
@@ -712,9 +822,10 @@ TFileCollection *TDataSetManagerAliEn::GetDataSet(const char *uri, const char *)
 {
   TFileCollection *fc = NULL;  // global collection
 
-  EDataMode dataMode;
   TString sUri(uri);
-  TList *findCmds = GetFindCommandsFromUri(sUri, dataMode);
+  EDataMode dataMode;
+  Bool_t forceUpdate;
+  TList *findCmds = GetFindCommandsFromUri(sUri, dataMode, forceUpdate);
   if (!findCmds) return NULL;
 
   fc = new TFileCollection();  // this fc will contain all data
@@ -736,9 +847,13 @@ TFileCollection *TDataSetManagerAliEn::GetDataSet(const char *uri, const char *)
     Long_t now = gSystem->Now();
     now = now/1000 + 788914800;  // magic is secs between Jan 1st 1970 and 1995
 
-    if ((mtime > 0) && (now-mtime > fCacheExpire_s)) {
+    if (forceUpdate) {
       if (gDebug >= 1)
-        Info("GetDataSet", "Dataset cache expired");
+        Info("GetDataSet", "Ignoring cached query result: forcing update");
+    }
+    else if ((mtime > 0) && (now-mtime > fCacheExpire_s)) {
+      if (gDebug >= 1)
+        Info("GetDataSet", "Dataset cache has expired");
     }
     else {
       if (gDebug >= 1)
