@@ -279,6 +279,9 @@ Int_t TProofLite::Init(const char *, const char *conffile,
    fCurrentMonitor   = 0;
    fServSock         = 0;
 
+   fTerminatedSlaveInfos = new TList;
+   fTerminatedSlaveInfos->SetOwner(kTRUE);
+
    // Control how to start the workers; copy-on-write (fork) is *very*
    // experimental and available on Unix only.
    fForkStartup      = kFALSE;
@@ -979,6 +982,7 @@ void TProofLite::SetQueryRunning(TProofQueryResult *pq)
    pq->SetRunning(startlog, parlist, GetParallel());
 
    // Bytes and CPU at start (we will calculate the differential at end)
+   AskStatistics();
    pq->SetProcessInfo(pq->GetEntries(), GetCpuTime(), GetBytesRead());
 }
 
