@@ -1,4 +1,4 @@
-// @(#)root/proof:$Id: TProofMgr.cxx 42859 2012-02-03 12:22:48Z ganis $
+// @(#)root/proof:$Id$
 // Author: G. Ganis, Nov 2005
 
 /*************************************************************************
@@ -90,16 +90,6 @@ TProofMgr::TProofMgr(const char *url, Int_t, const char *alias)
       fUrl.SetPort(port);
    }
 
-   // Make sure that the user is defined
-   if (strlen(fUrl.GetUser()) <= 0) {
-      // Fill in the default user
-      UserGroup_t *pw = gSystem->GetUserInfo();
-      if (pw) {
-         fUrl.SetUser(pw->fUser);
-         delete pw;
-      }
-   }
-
    // Check and save the host FQDN ...
    if (strcmp(fUrl.GetHost(), "__lite__")) {
       if (strcmp(fUrl.GetHost(), fUrl.GetHostFQDN()))
@@ -1021,6 +1011,33 @@ TFileCollection *TProofMgr::UploadFiles(const char *srcfiles,
    return ds;
 }
 
+//______________________________________________________________________________
+Int_t TProofMgr::Rm(const char *what, const char *, const char *)
+{
+   // Run 'rm' on 'what'. Locally it is just a call to TSystem::Unlink .
+
+   Int_t rc = -1;
+   // Nothing to do if not in contact with proofserv
+   if (!IsValid()) {
+      Error("Rm", "invalid TProofMgr - do nothing");
+      return rc;
+   }
+   // Nothing to do if not in contact with proofserv
+   if (!what || (what && strlen(what) <= 0)) {
+      Error("Rm", "path undefined!");
+      return rc;
+   }
+   
+   TUrl u(what);
+   if (!strcmp(u.GetProtocol(), "file")) {
+      rc = gSystem->Unlink(u.GetFile());
+   } else {
+      rc = gSystem->Unlink(what);
+   }
+   // Done
+   return (rc == 0) ? 0 : -1;
+}
+
 //
 //  TProofDesc
 //
@@ -1031,7 +1048,7 @@ ClassImp(TProofDesc)
 void TProofDesc::Print(Option_t *) const
 {
    // Dump the content to the screen.
-   const char *st[] = { "unknown", "idle", "processsing", "shutting down"};
+   const char *st[] = { "unknown", "idle", "processing", "shutting down"};
 
    Printf("// # %d", fLocalId);
    Printf("// alias: %s, url: \"%s\"", GetTitle(), GetUrl());
