@@ -45,6 +45,7 @@
 #include "TMath.h"
 #include "TProfile.h"
 #include "TStyle.h"
+#include "TLegend.h"
 
 ClassImp(TProofBench)
 
@@ -54,6 +55,14 @@ TF1 *TProofBench::fgFp1 = 0;
 TF1 *TProofBench::fgFp1n = 0;
 TF1 *TProofBench::fgFp2 = 0;
 TF1 *TProofBench::fgFp2n = 0;
+TF1 *TProofBench::fgFp3 = 0;
+TF1 *TProofBench::fgFp3n = 0;
+TF1 *TProofBench::fgFio = 0;
+TF1 *TProofBench::fgFioV = 0;
+static Int_t gFioVn0 = -1;             // Number of real cores for fgFioV
+static Int_t gFioVn1 = -1;             // Number of real+hyper cores for fgFioV
+
+TList *TProofBench::fgGraphs = new TList;
 
 //_____________________________________________________________________
 Double_t funp1(Double_t *xx, Double_t *par)
@@ -91,11 +100,79 @@ Double_t funp2n(Double_t *xx, Double_t *par)
    return res;
 }
 
+//_____________________________________________________________________
+Double_t funio(Double_t *xx, Double_t *par)
+{
+   // I/O saturated rate function
+   
+   Double_t sat = par[0] / par[1] * (xx[0] * par[1] / par[2] - 1.);
+   if (xx[0] < par[2] / par[1]) sat = 0.;
+   Double_t res = par[0] * xx[0] / (1. + sat);
+   return res;
+}
+
+//_____________________________________________________________________
+Double_t funiov(Double_t *xx, Double_t *par)
+{
+   // I/O saturated rate function with varying Rcpu
+   
+   // par[0] = rio
+   // par[1] = b1
+   // par[2] = b2
+   // par[3] = nc
+   // par[4] = ri
+
+   Double_t rio = par[0] / par[3] * xx[0];
+   if (xx[0] > par[3]) rio = par[0];
+
+   Double_t rcpu = par[1] * xx[0];
+   if (xx[0] > gFioVn0) rcpu = par[1]*gFioVn0 + par[2]*(xx[0] - gFioVn0);
+   if (xx[0] > gFioVn1) rcpu = par[1]*gFioVn0 + par[2]*(gFioVn1 - gFioVn0);
+
+   Double_t res = 1. / (1./par[4] + 1./rio + 1./rcpu);
+
+   return res;
+}
+
+//_____________________________________________________________________
+Double_t funcpuv(Double_t *xx, Double_t *par)
+{
+   // Function with varying Rcpu
+   
+   // par[0] = offset
+   // par[1] = rate contribution from real cores 
+   // par[2] = rate contribution from hyper cores 
+
+   Double_t n = (xx[0] - par[0]);
+   Double_t rcpu = par[1] * n;
+   if (xx[0] > gFioVn0) rcpu = par[1]*gFioVn0 + par[2]*(n - gFioVn0);
+   if (xx[0] > gFioVn1) rcpu = par[1]*gFioVn0 + par[2]*(gFioVn1 - gFioVn0);
+
+   return rcpu;
+}
+
+//_____________________________________________________________________
+Double_t funcpuvn(Double_t *xx, Double_t *par)
+{
+   // Function with varying Rcpu normalized
+   
+   // par[0] = offset
+   // par[1] = rate contribution from real cores 
+   // par[2] = rate contribution from hyper cores 
+
+   Double_t n = (xx[0] - par[0]);
+   Double_t rcpu = par[1] * n;
+   if (xx[0] > gFioVn0) rcpu = par[1]*gFioVn0 + par[2]*(n - gFioVn0);
+   if (xx[0] > gFioVn1) rcpu = par[1]*gFioVn0 + par[2]*(gFioVn1 - gFioVn0);
+
+   return rcpu / xx[0];
+}
+
 //______________________________________________________________________________
 TProofBench::TProofBench(const char *url, const char *outfile, const char *proofopt)
             : fUnlinkOutfile(kFALSE), fProofDS(0), fOutFile(0),
               fNtries(4), fHistType(0), fNHist(16), fReadType(0),
-              fDataSet("BenchDataSet"), fNFilesWrk(4),
+              fDataSet("BenchDataSet"), fNFilesWrk(2), fReleaseCache(kTRUE),
               fDataGenSel(kPROOF_BenchSelDataGenDef),
               fRunCPU(0), fRunDS(0), fDS(0), fDebug(kFALSE), fDescription(0)
 {
@@ -299,17 +376,25 @@ Int_t TProofBench::RunCPUx(Long64_t nevents, Int_t start, Int_t stop)
 }
 
 //______________________________________________________________________________
-void TProofBench::DrawCPU(const char *outfile, const char *opt, Bool_t verbose, Int_t dofit)
+void TProofBench::DrawCPU(const char *outfile, const char *opt, Bool_t verbose,
+                          Int_t dofit, Int_t n0, Int_t n1)
 {
    // Draw the CPU speedup plot.
-   //  opt =    'std:'      draw standard evt/s plot
+   //  opt = 'typewhat', e.g. 'std:max:'
+   //    type = 'std:'      draw standard evt/s plot
    //           'stdx:'     draw standard evt/s plot, 1 worker per node
    //           'norm:'     draw normalized plot
    //           'normx:'    draw normalized plot, 1 worker per node
+   //    what = 'max:'      draw max rate
+   //           'avg:'      draw average rate
+   //           'all:'      draw max and average rate on same plot (default)
    //  dofit =  0           no fit
    //           1           fit with the relevant '1st degree related' function
    //           2           fit with the relevant '2nd degree related' function
-   //
+   //           3           fit with varying rcpu function
+   //     n0 = for dofit == 3, number of real cores
+   //     n1 = for dofit == 3, number of total cores (real + hyperthreaded)
+    //
 
    // Get the TProfile an create the graphs
    TFile *fout = TFile::Open(outfile, "READ");
@@ -323,103 +408,127 @@ void TProofBench::DrawCPU(const char *outfile, const char *opt, Bool_t verbose,
    TNamed *nmdesc = (TNamed *) fout->Get("PB_description");
    if (nmdesc) description = nmdesc->GetTitle();
 
+   // Parse option
    TString oo(opt);
-   const char *dirn = (oo.Contains("x:")) ? "RunCPUx" : "RunCPU";
+   Bool_t isNorm = (oo.Contains("norm")) ? kTRUE : kFALSE;
+   Bool_t isX = (oo.Contains("stdx:") || oo.Contains("normx:")) ? kTRUE : kFALSE;
+   Bool_t doAvg = kTRUE, doMax = kTRUE;
+   if (oo.Contains("avg:")) doMax = kFALSE;
+   if (oo.Contains("max:")) doAvg = kFALSE;
+
+   const char *dirn = (isX) ? "RunCPUx" : "RunCPU";
    TDirectory *d = (TDirectory *) fout->Get(dirn);
    if (!d) {
-      ::Error("DrawCPU", "could not find directory 'RunCPU' ...");
+      ::Error("DrawCPU", "could not find directory '%s' ...", dirn);
       fout->Close();
       delete fout;
       return;
    }
    d->cd();
-   TString hprofn;
-   Bool_t isnorm = kFALSE;
-   if (!strcmp(opt, "std:")) {
-      hprofn = "Prof_CPU_QR_Evts";
-   } else if (!strcmp(opt, "stdx:")) {
-      hprofn = "Prof_x_CPU_QR_Evts";
-   } else if (!strcmp(opt, "norm:")) {
-      hprofn = "Norm_CPU_QR_Evts";
-      isnorm = kTRUE;
-    } else if (!strcmp(opt, "normx:")) {
-      hprofn = "Norm_x_CPU_QR_Evts";
-      isnorm = kTRUE;
-   } else {
-      ::Error("DrawCPU", "unknown option '%s'", opt);
-      fout->Close();
-      delete fout;
-      return;
-   }
-   TProfile *pf = 0;
-   TList *keylist = d->GetListOfKeys();
-   TKey *key = 0;
-   TIter nxk(keylist);
-   while ((key = (TKey *) nxk())) {
-      if (TString(key->GetName()).BeginsWith(hprofn)) {
-         pf = (TProfile *) d->Get(key->GetName());
-         break;
+
+   TString hprofn, hmaxn;
+   const char *lx = (isX) ? "_x" : "";
+   const char *ln = (isNorm) ? "Norm" : "Prof";
+   hprofn.Form("%s%s_CPU_QR_Evts", ln, lx);
+   hmaxn.Form("%s%s_CPU_PS_MaxEvts", ln, lx);
+
+   Double_t xmin = -1., xmax = -1.;
+   Double_t ami = -1., amx = -1., mmi = -1., mmx = -1.;
+   Int_t kamx = -1, kmmx = -1, nbins = -1;
+   Double_t ymx = -1., ymi = -1.;
+
+   TProfile *pfav = 0;
+   TGraphErrors *grav = 0;
+   if (doAvg) {
+      if (!(grav = GetGraph(d, hprofn, nbins, xmin, xmax, ami, amx, kamx, pfav))) {
+         ::Error("DrawCPU", "could not find '%s' ...", hprofn.Data());
+         fout->Close();
+         delete fout;
+         return;
       }
+      ymx = amx;
+      ymi = ami;
    }
-   if (!pf) {
-      ::Error("DrawCPU", "could not find '%s' ...", hprofn.Data());
-      fout->Close();
-      delete fout;
-      return;
+   TProfile *pfmx = 0;
+   TGraphErrors *grmx = 0;
+   if (doMax) {
+      if (!(grmx = GetGraph(d, hmaxn, nbins, xmin, xmax, mmi, mmx, kmmx, pfmx))) {
+         ::Warning("DrawCPU", "could not find '%s': feature added in 5.34/11", hmaxn.Data());
+         if (!grav) {
+            // Nothing to do if not asked for the average
+            fout->Close();
+            delete fout;
+            return;
+         }
+         doMax = kFALSE;
+      }
+      if (mmx > ymx) ymx = mmx;
+      if ((ymi > 0 && mmi < ymi) || (ymi < 0.)) ymi = mmi;
    }
 
-   Int_t nbins = pf->GetNbinsX();
-   TGraphErrors *gr = new TGraphErrors(nbins);
-   Double_t xx, ex, yy, ey, ymi = pf->GetBinContent(1), ymx = ymi;
-   Double_t xlow = pf->GetBinCenter(1) - pf->GetBinWidth(1)/2. ;
-   Double_t xhigh = pf->GetBinCenter(nbins) + pf->GetBinWidth(nbins)/2. ;
-   Int_t k =1, kmx = -1;
-   for (;k <= nbins; k++) {
-      xx = pf->GetBinCenter(k);
-      ex = pf->GetBinWidth(k) * .001;
-      yy = pf->GetBinContent(k);
-      ey = pf->GetBinError(k);
-      if (k == 1) {
-         ymi = yy;
-         ymx = yy;
-         kmx = k;
-      } else {
-         if (yy < ymi) ymi = yy; 
-         if (yy > ymx) { ymx = yy; kmx = k; }
-      }
-      gr->SetPoint(k-1, xx, yy);
-      gr->SetPointError(k-1, ex, ey);
-   }
+   TProfile *pf = (doMax) ? pfmx : pfav;   
+   Int_t kmx = (doMax) ? kmmx : kamx; 
 
    // Create the canvas
    TCanvas *cpu = new TCanvas("cpu", "Rate vs wrks",204,69,1050,502);
    cpu->Range(-3.106332,0.7490716,28.1362,1.249867);
 
-   gStyle->SetOptTitle(0);
-   gr->SetFillColor(1);
-   gr->SetLineColor(13);
-   gr->SetMarkerStyle(21);
-   gr->SetMarkerSize(1.2);
-
-   TH1F *hgr = new TH1F("Graph-CPU"," CPU speed-up", nbins*4, xlow, xhigh);
+   TH1F *hgr = new TH1F("Graph-CPU"," CPU speed-up", nbins*4, xmin, xmax);
    hgr->SetMaximum(ymx + (ymx-ymi)*0.2);
    hgr->SetMinimum(0);
+   if (isNorm) hgr->SetMaximum(ymx*1.2);
    hgr->SetDirectory(0);
    hgr->SetStats(0);
-//   hgr->CenterTitle(true);
    hgr->GetXaxis()->SetTitle(pf->GetXaxis()->GetTitle());
    hgr->GetXaxis()->CenterTitle(true);
    hgr->GetXaxis()->SetLabelSize(0.05);
    hgr->GetXaxis()->SetTitleSize(0.06);
    hgr->GetXaxis()->SetTitleOffset(0.62);
-   hgr->GetYaxis()->SetLabelSize(0.06);
-   gr->SetHistogram(hgr);
+   hgr->GetYaxis()->SetTitleSize(0.08);
+   hgr->GetYaxis()->SetTitleOffset(0.52);
+   hgr->GetYaxis()->SetTitle("Rate (events/s)");      
 
-   if (verbose) gr->Print();
-   
-   gr->Draw("alp");
+   TLegend *leg = 0;
+   if (isNorm) {
+      leg = new TLegend(0.7, 0.8, 0.9, 0.9);
+   } else {
+      leg = new TLegend(0.1, 0.8, 0.3, 0.9);
+   }
+
+   gStyle->SetOptTitle(0);
+   if (doAvg) {
+      grav->SetFillColor(1);
+      grav->SetLineColor(13);
+      grav->SetMarkerColor(4);
+      grav->SetMarkerStyle(21);
+      grav->SetMarkerSize(1.2);
+      grav->SetHistogram(hgr);
+
+      if (verbose) grav->Print();
+      grav->Draw("alp");
+      leg->AddEntry(grav, "Average", "P");
+   }
+   if (doMax) {
+      grmx->SetFillColor(1);
+      grmx->SetLineColor(13);
+      grmx->SetMarkerColor(2);
+      grmx->SetMarkerStyle(29);
+      grmx->SetMarkerSize(1.8);
+      grmx->SetHistogram(hgr);
+
+      if (verbose) grmx->Print();
+      if (doAvg) {
+         grmx->Draw("lpSAME");
+      } else {
+         grmx->Draw("alp");
+      }
+      leg->AddEntry(grmx, "Maximum", "P");
+   }
+   leg->Draw();
+   gPad->Update();
 
    if (dofit > 0) {
+      TGraphErrors *gr = (doMax) ? grmx : grav;   
       // Make sure the fitting functions are defined
       Double_t xmi = 0.9;
       if (nbins > 5) xmi = 1.5;
@@ -428,7 +537,7 @@ void TProofBench::DrawCPU(const char *outfile, const char *opt, Bool_t verbose,
       // Starting point for the parameters and fit
       Double_t normrate = -1.;
       if (dofit == 1) {
-         if (isnorm) {
+         if (isNorm) {
             fgFp1n->SetParameter(0, pf->GetBinContent(1));
             fgFp1n->SetParameter(1, pf->GetBinContent(nbins-1));
             gr->Fit(fgFp1n);
@@ -439,10 +548,10 @@ void TProofBench::DrawCPU(const char *outfile, const char *opt, Bool_t verbose,
             fgFp1->SetParameter(1, pf->GetBinContent(1));
             gr->Fit(fgFp1);
             if (verbose) fgFp1->Print();
-            normrate = fgFp1->GetParameter(1);
+            normrate = fgFp1->Derivative(1.);
          }
-      } else {
-         if (isnorm) {
+      } else if (dofit == 2) {
+         if (isNorm) {
             fgFp2n->SetParameter(0, pf->GetBinContent(1));
             fgFp2n->SetParameter(1, pf->GetBinContent(nbins-1));
             fgFp2n->SetParameter(2, 0.);
@@ -455,12 +564,31 @@ void TProofBench::DrawCPU(const char *outfile, const char *opt, Bool_t verbose,
             fgFp2->SetParameter(2, 0.);
             gr->Fit(fgFp2);
             if (verbose) fgFp2->Print();
-            normrate = fgFp2->GetParameter(1);
+            normrate = fgFp2->Derivative(1.);
+         }
+      } else {
+         // Starting point for the parameters and fit
+         gFioVn0 = (n0 > 0) ? n0 : (Int_t) (nbins + .1)/2.;
+         gFioVn1 = (n1 > 0) ? n1 : (Int_t) (nbins + .1);
+         if (isNorm) {
+            fgFp3n->SetParameter(0, 0.);
+            fgFp3n->SetParameter(1, pf->GetBinContent(1));
+            fgFp3n->SetParameter(2, pf->GetBinContent(nbins-1));
+            gr->Fit(fgFp3n);
+            if (verbose) fgFp3n->Print();
+            normrate = pf->GetBinContent(1);
+         } else {
+            fgFp3->SetParameter(0, 0.);
+            fgFp3->SetParameter(1, 0.);
+            fgFp3->SetParameter(2, pf->GetBinContent(1));
+            gr->Fit(fgFp3);
+            if (verbose) fgFp3->Print();
+            normrate = fgFp3->Derivative(1.);
          }
       }
 
       // Notify the cluster performance parameters
-      if (!isnorm) {
+      if (!isNorm) {
          printf("* ************************************************************ *\n");
          printf("*                                                              *\r");
          printf("* Cluster: %s\n", description.Data());
@@ -481,6 +609,67 @@ void TProofBench::DrawCPU(const char *outfile, const char *opt, Bool_t verbose,
    }
    // Close the file
    fout->Close();
+   if (grav) fgGraphs->Add(grav);
+   if (grmx) fgGraphs->Add(grmx);
+}
+
+//______________________________________________________________________________
+TGraphErrors *TProofBench::GetGraph(TDirectory *d, const char *pfn, Int_t &nb,
+                                    Double_t &xmi, Double_t &xmx,
+                                    Double_t &ymi, Double_t &ymx, Int_t &kmx, TProfile *&pf)
+{
+   // Get from TDirectory 'd' the TProfile named 'pfn' and create the graph.
+   // Return also the max y in mx.
+
+   // Sanity checks
+   if (!d || !pfn || (pfn && strlen(pfn) <= 0)) {
+      ::Error("TProofBench::GetGraph", "directory or name not defined!");
+      return (TGraphErrors *)0;
+   }
+
+   TList *keylist = d->GetListOfKeys();
+   TKey *key = 0;
+   TIter nxk(keylist);
+   while ((key = (TKey *) nxk())) {
+      if (TString(key->GetName()).BeginsWith(pfn)) {
+         pf = (TProfile *) d->Get(key->GetName());
+         break;
+      }
+   }
+   // Sanity checks
+   if (!pf) {
+      ::Error("TProofBench::GetGraph", "TProfile for '%s' not found in directory '%s'", pfn, d->GetName());
+      return (TGraphErrors *)0;
+   }
+
+   nb = pf->GetNbinsX();
+   TGraphErrors *gr = new TGraphErrors(nb);
+   gr->SetName(TString::Format("Graph_%s", pfn));
+   Double_t xx, ex, yy, ey;
+   ymi = pf->GetBinContent(1);
+   ymx = ymi;
+   xmi = pf->GetBinCenter(1) - pf->GetBinWidth(1)/2. ;
+   xmx = pf->GetBinCenter(nb) + pf->GetBinWidth(nb)/2. ;
+   kmx = -1;
+   for (Int_t k = 1;k <= nb; k++) {
+      xx = pf->GetBinCenter(k);
+      ex = pf->GetBinWidth(k) * .001;
+      yy = pf->GetBinContent(k);
+      ey = pf->GetBinError(k);
+      if (k == 1) {
+         ymi = yy;
+         ymx = yy;
+         kmx = k;
+      } else {
+         if (yy < ymi) ymi = yy; 
+         if (yy > ymx) { ymx = yy; kmx = k; }
+      }
+      gr->SetPoint(k-1, xx, yy);
+      gr->SetPointError(k-1, ex, ey);
+   }
+
+   // Done  
+   return gr;
 }
 
 //______________________________________________________________________________
@@ -508,6 +697,25 @@ void TProofBench::AssertFittingFun(Double_t mi, Double_t mx)
       fgFp2n->SetParNames("decay", "norm rate", "deviation");
    }
 
+   if (!fgFp3) {
+      fgFp3 = new TF1("funcpuv", funcpuv, mi, mx, 3);
+      fgFp3->SetParNames("offset", "slope real", "slope hyper");
+   }
+
+   if (!fgFp3n) {
+      fgFp3n = new TF1("funcpuvn", funcpuvn, mi, mx, 3);
+      fgFp3n->SetParNames("offset", "slope real", "slope hyper");
+   }
+
+   if (!fgFio) {
+      fgFio = new TF1("funio", funio, mi, mx, 3);
+      fgFio->SetParNames("R1", "RIO", "TotIO");
+   }
+   if (!fgFioV) {
+      fgFioV = new TF1("funiov", funiov, mi, mx, 5);
+      fgFioV->SetParNames("rio", "b1", "b2", "nc", "ri");
+   }
+
 }
 
 //______________________________________________________________________________
@@ -676,13 +884,14 @@ Int_t TProofBench::RunDataSet(const char *dset,
    }
    fUnlinkOutfile = kFALSE;
 
-   ReleaseCache(dset);
+   if (fReleaseCache) ReleaseCache(dset);
    SafeDelete(fRunDS);
    TPBReadType *readType = fReadType;
    if (!readType) readType = new TPBReadType(TPBReadType::kReadOpt);
    fRunDS = new TProofBenchRunDataRead(fDS, readType, fOutFile); 
    if (!fDataSel.IsNull()) fRunDS->SetSelName(fDataSel);
    if (!fDataPar.IsNull()) fRunDS->SetParList(fDataPar);
+   fRunDS->SetReleaseCache(fReleaseCache);
    fRunDS->Run(dset, start, stop, step, fNtries, fDebug, -1);
    if (!fReadType) SafeDelete(readType);
    
@@ -728,15 +937,25 @@ Int_t TProofBench::RunDataSetx(const char *dset, Int_t start, Int_t stop)
 
 //______________________________________________________________________________
 void TProofBench::DrawDataSet(const char *outfile,
-                              const char *opt, const char *type, Bool_t verbose)
+                              const char *opt, const char *type, Bool_t verbose,
+                              Int_t dofit, Int_t n0, Int_t n1)
 {
    // Draw the CPU speedup plot.
-   //  opt =    'std:'          Standard scaling plot
-   //           'norm:'         Normalized scaling plot
-   //           'stdx:'         Standard scaling plot, 1 worker per node
-   //           'normx:'        Normalized scaling plot, 1 worker per node
+   //  opt = 'typewhat', e.g. 'std:max:'
+   //    type = 'std:'      draw standard plot
+   //           'stdx:'     draw standard plot, 1 worker per node
+   //           'norm:'     draw normalized plot
+   //           'normx:'    draw normalized plot, 1 worker per node
+   //    what = 'max:'      draw max rate
+   //           'avg:'      draw average rate
+   //           'all:'      draw max and average rate on same plot (default)
    // type =    'mbs'           MB/s scaling plots (default)
    //           'evts'          Event/s scaling plots
+   //  dofit =  0           no fit
+   //           1           fit with default 3 parameter saturated I/O formula
+   //           2           fit with 4 parameter saturated I/O formula (varying Rcpu)
+   //     n0 = for dofit == 2, number of real cores
+   //     n1 = for dofit == 2, number of total cores (real + hyperthreaded)
    //
 
    // Get the TProfile an create the graphs
@@ -745,102 +964,309 @@ void TProofBench::DrawDataSet(const char *outfile,
       ::Error("DrawDataSet", "could not open file '%s' ...", outfile);
       return;
    }
+   
+   // Get description
+   TString description("<not available>");
+   TNamed *nmdesc = (TNamed *) fout->Get("PB_description");
+   if (nmdesc) description = nmdesc->GetTitle();
+
+   // Parse option
    TString oo(opt);
-   const char *dirn = (oo.Contains("x:")) ? "RunDataReadx" : "RunDataRead";
+   Bool_t isNorm = (oo.Contains("norm")) ? kTRUE : kFALSE;
+   Bool_t isX = (oo.Contains("stdx:") || oo.Contains("normx:")) ? kTRUE : kFALSE;
+   Bool_t doAvg = kTRUE, doMax = kTRUE;
+   if (oo.Contains("avg:")) doMax = kFALSE;
+   if (oo.Contains("max:")) doAvg = kFALSE;
+
+   const char *dirn = (isX) ? "RunDataReadx" : "RunDataRead";
    TDirectory *d = (TDirectory *) fout->Get(dirn);
    if (!d) {
-      ::Error("DrawDataSet", "could not find directory 'RunDataRead' ...");
+      ::Error("DrawCPU", "could not find directory '%s' ...", dirn);
       fout->Close();
       delete fout;
       return;
    }
    d->cd();
 
-   TString hprofn, typ("QR_IO");
-   if (type && !strcmp(type, "evts")) typ = "QR_Evts";
-
-   if (!strcmp(opt, "std:")) {
-      hprofn.Form("Prof_DataRead_%s", typ.Data());
-   } else if (!strcmp(opt, "stdx:")) {
-      hprofn.Form("Prof_x_DataRead_%s", typ.Data());
-   } else if (!strcmp(opt, "norm:")) {
-      hprofn.Form("Norm_DataRead_%s", typ.Data());
-   } else if (!strcmp(opt, "normx:")) {
-      hprofn.Form("Norm_x_DataRead_%s", typ.Data());
+   TString hprofn, hmaxn;
+   const char *lx = (isX) ? "_x" : "";
+   const char *ln = (isNorm) ? "Norm" : "Prof";
+   Bool_t isIO = kTRUE;
+   if (type && !strcmp(type, "evts")) {
+      hprofn.Form("%s%s_DataRead_QR_Evts", ln, lx);
+      hmaxn.Form("%s%s_DataRead_PS_MaxEvts", ln, lx);
+      isIO = kFALSE;
    } else {
-      ::Error("DrawDataSet", "unknown option '%s'", opt);
-      fout->Close();
-      delete fout;
-      return;
+      hprofn.Form("%s%s_DataRead_QR_IO", ln, lx);
+      hmaxn.Form("%s%s_DataRead_PS_MaxIO", ln, lx);      
    }
-   TProfile *pf = 0;
-   TList *keylist = d->GetListOfKeys();
-   TKey *key = 0;
-   TIter nxk(keylist);
-   while ((key = (TKey *) nxk())) {
-      if (TString(key->GetName()).BeginsWith(hprofn)) {
-         pf = (TProfile *) d->Get(key->GetName());
-         break;
+
+   Double_t xmin = -1., xmax = -1.;
+   Double_t ami = -1., amx = -1., mmi = -1., mmx = -1.;
+   Int_t kamx = -1, kmmx = -1, nbins = -1;
+   Double_t ymx = -1., ymi = -1.;
+ 
+   TProfile *pfav = 0;
+   TGraphErrors *grav = 0;
+   if (doAvg) {
+      if (!(grav = GetGraph(d, hprofn, nbins, xmin, xmax, ami, amx, kamx, pfav))) {
+         ::Error("DrawCPU", "could not find '%s' ...", hprofn.Data());
+         fout->Close();
+         delete fout;
+         return;
       }
+      ymx = amx;
+      ymi = ami;
    }
-   if (!pf) {
-      ::Error("DrawDataSet", "could not find '%s' ...", hprofn.Data());
-      fout->Close();
-      delete fout;
-      return;
-   }
-   Int_t nbins = pf->GetNbinsX();
-   TGraphErrors *gr = new TGraphErrors(nbins);
-   Double_t xx, ex, yy, ey, ymi = pf->GetBinContent(1), ymx = ymi;
-   Double_t xlow = pf->GetBinCenter(1) - pf->GetBinWidth(1)/2. ;
-   Double_t xhigh = pf->GetBinCenter(nbins) + pf->GetBinWidth(nbins)/2. ;
-   Int_t k =1;
-   for (;k <= nbins; k++) {
-      xx = pf->GetBinCenter(k);
-      ex = pf->GetBinWidth(k) * .001;
-      yy = pf->GetBinContent(k);
-      ey = pf->GetBinError(k);
-      if (k == 1) {
-         ymi = yy;
-         ymx = yy;
-      } else {
-         if (yy < ymi) ymi = yy; 
-         if (yy > ymx) ymx = yy;
+   TProfile *pfmx = 0;
+   TGraphErrors *grmx = 0;
+   if (doMax) {
+      if (!(grmx = GetGraph(d, hmaxn, nbins, xmin, xmax, mmi, mmx, kmmx, pfmx))) {
+         ::Warning("DrawCPU", "could not find '%s': feature added in 5.34/11", hmaxn.Data());
+         if (!grav) {
+            // Nothing to do if not asked for the average
+            fout->Close();
+            delete fout;
+            return;
+         }
+         doMax = kFALSE;
       }
-      gr->SetPoint(k-1, xx, yy);
-      gr->SetPointError(k-1, ex, ey);
-      Printf("%d %f %f", (Int_t)xx, yy, ey);
+      if (mmx > ymx) ymx = mmx;
+      if ((ymi > 0 && mmi < ymi) || (ymi < 0.)) ymi = mmi;
    }
 
+   TProfile *pf = (doMax) ? pfmx : pfav;   
+   Int_t kmx = (doMax) ? kmmx : kamx; 
+
    // Create the canvas
    TCanvas *cpu = new TCanvas("dataset", "Rate vs wrks",204,69,1050,502);
    cpu->Range(-3.106332,0.7490716,28.1362,1.249867);
 
-   gStyle->SetOptTitle(0);
-   gr->SetFillColor(1);
-   gr->SetLineColor(13);
-   gr->SetMarkerStyle(21);
-   gr->SetMarkerSize(1.2);
-
-   TH1F *hgr = new TH1F("Graph-DataSet"," Data Read speed-up", nbins*4, xlow, xhigh);
+   TH1F *hgr = new TH1F("Graph-DataSet"," Data Read speed-up", nbins*4, xmin, xmax);
    hgr->SetMaximum(ymx + (ymx-ymi)*0.2);
    hgr->SetMinimum(0);
+   if (isNorm) hgr->SetMaximum(ymx*1.2);
    hgr->SetDirectory(0);
    hgr->SetStats(0);
-//   hgr->CenterTitle(true);
    hgr->GetXaxis()->SetTitle(pf->GetXaxis()->GetTitle());
    hgr->GetXaxis()->CenterTitle(true);
    hgr->GetXaxis()->SetLabelSize(0.05);
    hgr->GetXaxis()->SetTitleSize(0.06);
    hgr->GetXaxis()->SetTitleOffset(0.62);
    hgr->GetYaxis()->SetLabelSize(0.06);
+   hgr->GetYaxis()->SetTitleSize(0.08);
+   hgr->GetYaxis()->SetTitleOffset(0.52);
+   if (isIO) {
+      hgr->GetYaxis()->SetTitle("Rate (MB/s)");
+   } else {
+      hgr->GetYaxis()->SetTitle("Rate (events/s)");      
+   }
+
+   TLegend *leg = 0;
+   if (isNorm) {
+      leg = new TLegend(0.7, 0.8, 0.9, 0.9);
+   } else {
+      leg = new TLegend(0.1, 0.8, 0.3, 0.9);
+   }
+
+   if (doAvg) {
+      grav->SetFillColor(1);
+      grav->SetLineColor(13);
+      grav->SetMarkerColor(4);
+      grav->SetMarkerStyle(21);
+      grav->SetMarkerSize(1.2);
+      grav->SetHistogram(hgr);
+
+      if (verbose) grav->Print();
+      grav->Draw("alp");
+      leg->AddEntry(grav, "Average", "P");
+   }
+   if (doMax) {
+      grmx->SetFillColor(1);
+      grmx->SetLineColor(13);
+      grmx->SetMarkerColor(2);
+      grmx->SetMarkerStyle(29);
+      grmx->SetMarkerSize(1.8);
+      grmx->SetHistogram(hgr);
+
+      if (verbose) grmx->Print();
+      if (doAvg) {
+         grmx->Draw("lpSAME");
+      } else {
+         grmx->Draw("alp");
+      }
+      leg->AddEntry(grmx, "Maximum", "P");
+   }
+   leg->Draw();
+   gPad->Update();
+
+   Double_t normrate = -1.;
+   if (dofit > 0) {
+      TGraphErrors *gr = (doMax) ? grmx : grav;   
+      // Make sure the fitting functions are defined
+      Double_t xmi = 0.9;
+      if (nbins > 5) xmi = 1.5;
+      AssertFittingFun(xmi, nbins + .1);
+
+      if (dofit == 1) {
+         // Starting point for the parameters and fit
+         fgFio->SetParameter(0, pf->GetBinContent(1));
+         fgFio->SetParameter(1, pf->GetBinContent(nbins-1));
+         fgFio->SetParameter(2, pf->GetBinContent(nbins-1));
+         gr->Fit(fgFio);
+         if (verbose) fgFio->Print();
+         normrate = fgFio->Derivative(1.);
+      } else if (dofit > 1) {
+         // Starting point for the parameters and fit
+         gFioVn0 = (n0 > 0) ? n0 : (Int_t) (nbins + .1)/2.;
+         gFioVn1 = (n1 > 0) ? n1 : (Int_t) (nbins + .1);
+         fgFioV->SetParameter(0, 20.);
+         fgFioV->SetParameter(1, pf->GetBinContent(1));
+         fgFioV->SetParameter(2, pf->GetBinContent(1));
+         fgFioV->SetParameter(3, 4.);
+         fgFioV->SetParameter(4, 1000.);
+
+         gr->Fit(fgFioV);
+         if (verbose) fgFio->Print();
+         normrate = fgFioV->Derivative(1.);
+      }
+   }
+
+   // Notify the cluster performance parameters
+   if (!isNorm) {
+      printf("* ************************************************************ *\n");
+      printf("*                                                              *\r");
+      printf("* Cluster: %s\n", description.Data());
+      printf("* Performance measurement from scalability plot:               *\n");
+      printf("*                                                              *\r");
+      if (isIO) {
+         printf("*    rate max:         %.3f\tMB/s (@ %d workers)\n", ymx, kmx);
+         printf("*                                                              *\r");
+         printf("*    per-worker rate:  %.3f\tMB/s \n", normrate);
+      } else {
+         printf("*    rate max:         %.3f\tevts/s (@ %d workers)\n", ymx, kmx);
+      }
+      printf("* ************************************************************ *\n");
+   }
+   // Close the file
+   fout->Close();
+   if (grav) fgGraphs->Add(grav);
+   if (grmx) fgGraphs->Add(grmx);
+}
+
+//______________________________________________________________________________
+void TProofBench::DrawEfficiency(const char *outfile,
+                                 const char *opt, Bool_t verbose)
+{
+   // Draw the efficiency plot.
+   //  opt = 'cpu' or 'data' (default the first found)
+   //
+
+   // Get the TProfile an create the graphs
+   TFile *fout = TFile::Open(outfile, "READ");
+   if (!fout || (fout && fout->IsZombie())) {
+      ::Error("DrawEfficiency", "could not open file '%s' ...", outfile);
+      return;
+   }
+   
+   // Get description
+   TString description("<not available>");
+   TNamed *nmdesc = (TNamed *) fout->Get("PB_description");
+   if (nmdesc) description = nmdesc->GetTitle();
+
+   // Parse option
+   TString oo(opt), ln("CPU");
+   const char *dirs[4] = { "RunCPU", "RunCPUx", "RunDataRead", "RunDataReadx"};
+   const char *labs[4] = { "CPU", "CPU", "DataRead", "DataRead"};
+   Int_t fst = 0, lst = 3;
+   if (oo == "cpu") {
+      lst = 0;
+   } else if (oo == "cpux") {
+      fst = 1;
+      lst = 1;
+   } else if (oo.BeginsWith("data")) {
+      if (oo.EndsWith("x")) {
+         fst = 3;
+         lst = 3;
+      } else {
+         fst = 2;
+         lst = 2;
+      }
+   }
+   const char *dirn = 0;
+   TDirectory *d = 0;
+   for (Int_t i = fst; i <= lst; i++) {
+      if ((d = (TDirectory *) fout->Get(dirs[i]))) {
+         dirn = dirs[i];
+         ln = labs[i]; 
+         break;
+      }
+   }
+   if (!d && !dirn) {
+      ::Error("DrawEfficiency", "could not find directory ...");
+      fout->Close();
+      delete fout;
+      return;
+   }
+   d->cd();
+
+   TString hprof;
+   hprof.Form("Prof_%s_CPU_eff", ln.Data());
+
+   Double_t xmin = -1., xmax = -1.;
+   Int_t kmx = -1, nbins = -1;
+   Double_t ymx = -1., ymi = -1.;
+ 
+   TProfile *pf = 0;
+   TGraphErrors *gr = 0;
+   if (!(gr = GetGraph(d, hprof, nbins, xmin, xmax, ymi, ymx, kmx, pf))) {
+      ::Error("DrawEfficiency", "could not find '%s' ...", hprof.Data());
+      fout->Close();
+      delete fout;
+      return;
+   }
+
+   // Create the canvas
+   TCanvas *cpu = new TCanvas("efficiency", "efficiency vs wrks",204,69,1050,502);
+   cpu->Range(-3.106332,0.7490716,28.1362,1.249867);
+
+   TH1F *hgr = new TH1F("Graph-Efficiency","CPU effectiveness", nbins*4, xmin, xmax);
+   hgr->SetMaximum(1.2);
+   hgr->SetMinimum(0);
+   hgr->SetDirectory(0);
+   hgr->SetStats(0);
+   hgr->GetXaxis()->SetTitle(pf->GetXaxis()->GetTitle());
+   hgr->GetXaxis()->CenterTitle(true);
+   hgr->GetXaxis()->SetLabelSize(0.05);
+   hgr->GetXaxis()->SetTitleSize(0.06);
+   hgr->GetXaxis()->SetTitleOffset(0.62);
+   hgr->GetYaxis()->SetLabelSize(0.06);
+   hgr->GetYaxis()->SetTitleSize(0.08);
+   hgr->GetYaxis()->SetTitleOffset(0.52);
+   hgr->GetYaxis()->SetTitle("CPU effectiveness");
+
+   gr->SetFillColor(1);
+   gr->SetLineColor(13);
+   gr->SetMarkerColor(4);
+   gr->SetMarkerStyle(21);
+   gr->SetMarkerSize(1.2);
    gr->SetHistogram(hgr);
 
    if (verbose) gr->Print();
-   
    gr->Draw("alp");
-  
+
+   // Notify the cluster performance parameters
+   printf("* ************************************************************ *\n");
+   printf("*                                                              *\r");
+   printf("* Cluster: %s\n", description.Data());
+   printf("* CPU effectiveness measurement:                               *\n");
+   printf("*                                                              *\r");
+   printf("*    effectiveness max:     %.3f (@ %d workers)\n", ymx, kmx);
+   printf("*                                                              *\r");
+   printf("* ************************************************************ *\n");
+   // Close the file
    fout->Close();
+   if (gr) fgGraphs->Add(gr);
 }
 
 //______________________________________________________________________________
