@@ -1,4 +1,4 @@
-// @(#)root/proofd:$Id: XrdProofConn.cxx 44523 2012-06-04 15:17:29Z ganis $
+// @(#)root/proofd:$Id$
 // Author: Gerardo Ganis  12/12/2005
 
 /*************************************************************************
@@ -32,7 +32,6 @@
 
 #include "XrdClient/XrdClientConnMgr.hh"
 #include "XrdClient/XrdClientConst.hh"
-#include "XrdClient/XrdClientDebug.hh"
 #include "XrdClient/XrdClientEnv.hh"
 #include "XrdClient/XrdClientLogConnection.hh"
 #include "XrdClient/XrdClientPhyConnection.hh"
@@ -41,6 +40,7 @@
 #include "XrdOuc/XrdOucErrInfo.hh"
 #include "XrdOuc/XrdOucString.hh"
 #include "XrdSec/XrdSecInterface.hh"
+#include "XrdSys/XrdSysLogger.hh"
 #include "XrdSys/XrdSysPlatform.hh"
 
 // Dynamic libs
@@ -1259,7 +1259,7 @@ XrdSecProtocol *XrdProofConn::Authenticate(char *plist, int plsiz)
       // Initialize the security library plugin, if needed
       XrdOucString libsec;
       if (!fgSecPlugin) { 
-#if ROOTXRDVERS >= ROOT_XrdUtils
+#if !defined(ROOT_XrdNoUtils)
          libsec = "libXrdSec";
          libsec += LT_MODULE_EXT;
 #else
