@@ -1,4 +1,4 @@
-// @(#)root/proofd:$Id: XrdProofdProtocol.cxx 44498 2012-06-04 09:06:32Z ganis $
+// @(#)root/proofd:$Id$
 // Author: Gerardo Ganis  12/12/2005
 
 /*************************************************************************
@@ -29,6 +29,7 @@
 
 #include "XrdVersion.hh"
 #include "Xrd/XrdBuffer.hh"
+#include "Xrd/XrdScheduler.hh"
 
 #include "XrdProofdClient.h"
 #include "XrdProofdClientMgr.h"
@@ -54,8 +55,7 @@ static XrdSysLogger   gMainLogger;
 //
 // Static area: general protocol managing section
 int                   XrdProofdProtocol::fgCount    = 0;
-XrdObjectQ<XrdProofdProtocol>
-                      XrdProofdProtocol::fgProtStack("ProtStack",
+XpdObjectQ            XrdProofdProtocol::fgProtStack("ProtStack",
                                                      "xproofd protocol anchor");
 XrdSysRecMutex        XrdProofdProtocol::fgBMutex;    // Buffer management mutex
 XrdBuffManager       *XrdProofdProtocol::fgBPool    = 0;
@@ -508,10 +508,9 @@ void XrdProofdProtocol::Reset()
    // Cleanup existing XrdProofdResponse objects
    std::vector<XrdProofdResponse *>::iterator ii = fResponses.begin(); // One per each logical connection
    while (ii != fResponses.end()) {
-      delete *ii;
+      (*ii)->Reset();
       ii++;
    }
-   fResponses.clear();
 }
 
 //______________________________________________________________________________
@@ -543,8 +542,12 @@ int XrdProofdProtocol::Configure(char *, XrdProtocol_Config *pi)
    // Schedule protocol object cleanup; the maximum number of objects
    // and the max age are taken from XrdXrootdProtocol: this may need
    // some optimization in the future.
+#if 1
    fgProtStack.Set(pi->Sched, XrdProofdTrace, TRACE_MEM);
    fgProtStack.Set((pi->ConnMax/3 ? pi->ConnMax/3 : 30), 60*60);
+#else
+   fgProtStack.Set(pi->Sched, 3600);
+#endif
 
    // Default tracing options: always trace logins and errors for all
    // domains; if the '-d' option was specified on the command line then
@@ -735,16 +738,36 @@ void XrdProofdProtocol::Recycle(XrdLink *, int, const char *)
    XrdProofdClient *pmgr = fPClient;
 
    if (pmgr) {
-
-
       if (!Internal()) {
 
-         // Signal the client manager that a client has just gone
-         if (fgMgr && fgMgr->ClientMgr()) {
-            TRACE(HDBG, "fAdminPath: "<<fAdminPath);
-            XPDFORM(buf, "%s %p %d %d", fAdminPath.c_str(), pmgr, fCID, fPid);
-            TRACE(DBG, "sending to ClientMgr: "<<buf);
-            fgMgr->ClientMgr()->Pipe()->Post(XrdProofdClientMgr::kClientDisconnect, buf.c_str());
+         TRACE(REQ,"External disconnection of protocol associated with pid "<<fPid);
+
+         // Write disconnection file
+         XrdOucString discpath(fAdminPath);
+         discpath.replace("/cid", "/disconnected");
+         FILE *fd = fopen(discpath.c_str(), "w");
+         if (!fd && errno != ENOENT) {
+            TRACE(XERR, "unable to create path: " <<discpath<<" (errno: "<<errno<<")");
+         } else if (fd) {
+            fclose(fd);  
+         } 
+
+         // Remove protocol and response from attached client/proofserv instances
+         // Set reconnect flag if proofserv instances attached to this client are still running
+         pmgr->ResetClientSlot(fCID);
+         if(fgMgr && fgMgr->SessionMgr()) {
+            XrdSysMutexHelper mhp(fgMgr->SessionMgr()->Mutex());
+
+            fgMgr->SessionMgr()->DisconnectFromProofServ(fPid);
+            if((fConnType == 0) && fgMgr->SessionMgr()->Alive(this)) {
+               TRACE(REQ, "Non-destroyed proofserv processes attached to this protocol ("<<this<<
+                          "), setting reconnect time");             
+               fgMgr->SessionMgr()->SetReconnectTime(true);
+            }
+            fgMgr->SessionMgr()->CheckActiveSessions(0);
+         } else {
+            TRACE(XERR, "No XrdProofdMgr ("<<fgMgr<<") or SessionMgr ("
+                        <<(fgMgr ? fgMgr->SessionMgr() : (void *) -1)<<")")
          }
 
       } else {
@@ -753,19 +776,30 @@ void XrdProofdProtocol::Recycle(XrdLink *, int, const char *)
          // of proxy servers and to notify the attached clients.
          // Tell the session manager that this session has gone
          if (fgMgr && fgMgr->SessionMgr()) {
+            XrdSysMutexHelper mhp(fgMgr->SessionMgr()->Mutex());
             TRACE(HDBG, "fAdminPath: "<<fAdminPath);
             buf.assign(fAdminPath, fAdminPath.rfind('/') + 1, -1);
-            TRACE(DBG, "sending to ProofServMgr: "<<buf);
-            fgMgr->SessionMgr()->Pipe()->Post(XrdProofdProofServMgr::kSessionRemoval, buf.c_str());
+            fgMgr->SessionMgr()->DeleteFromSessions(buf.c_str());
+            // Move the entry to the terminated sessions area
+            fgMgr->SessionMgr()->MvSession(buf.c_str());
+         }
+         else {
+            TRACE(XERR,"No XrdProofdMgr ("<<fgMgr<<") or SessionMgr ("<<fgMgr->SessionMgr()<<")")
          }
       }
    }
-
    // Set fields to starting point (debugging mostly)
    Reset();
 
    // Push ourselves on the stack
    fgProtStack.Push(&fProtLink);
+#if 0
+   if(fgProtStack.Push(&fProtLink) != 0) {
+      XrdProofdProtocol *xp = fProtLink.objectItem();
+      fProtLink.setItem(0);
+      delete xp;
+   }
+#endif
 }
 
 //______________________________________________________________________________
@@ -1410,7 +1444,7 @@ void XrdProofdProtocol::TouchAdminPath()
             apath.replace(".status", "");
             rc = XrdProofdAux::Touch(apath.c_str());
          }
-         if (rc != 0) {
+         if (rc != 0 && rc != -ENOENT) {
             const char *type = Internal() ? "internal" : "external";
             TRACEP(this, XERR, type<<": problems touching "<<apath<<"; errno: "<<-rc);
          }
