@@ -1,4 +1,4 @@
-// @(#)root/proofd:$Id: XrdProofdResponse.cxx 30920 2009-10-29 18:17:44Z ganis $
+// @(#)root/proofd:$Id$
 // Author: Gerardo Ganis  12/12/2005
 
 /*************************************************************************
@@ -48,6 +48,16 @@
 #define XPRTRACING(a) ((a != 0) || (TRACING(RSP)))
 // Check link macro
 #define CHECKLINK \
+   {  XrdSysMutexHelper mh(fMutex); \
+      if (!fLink) { \
+         TRACE(XERR, "link is undefined! "); \
+         return 0; \
+      } else if (fLink->FDnum() < 0) { \
+         TRACE(XERR, "link descriptor invalid for link "<<fLink<<"! ("<< fLink->FDnum()<<")"); \
+         return 0; \
+      } \
+   }
+#define CHECKLINKNOMTX \
    if (!fLink) { \
       TRACE(XERR, "link is undefined! "); \
       return 0; \
@@ -551,17 +561,29 @@ int XrdProofdResponse::LinkSend(const char *buff, int len, XrdOucString &emsg)
    // The link is closed in case of error, because we cannot use it anymore
    // and the counter part needs to reconnect.
    // Return 0 on success, -1 on failure.
+   XPDLOC(RSP, "Response::LinkSend:1")
+
+   XrdSysMutexHelper mxh(fMutex);
+   CHECKLINKNOMTX;
 
    int rc = 0;
 
    // If we fail we close the link, and ask the client to reconnect
    if ((rc = fLink->Send(buff, len)) < 0) {
       XPDFORM(emsg, "problems sending %d bytes", len);
+#if 0
       fLink->Close();
    }
 
    // Done
    return ((rc < 0) ? fLink->setEtext("send failure") : 0);
+#else
+      fLink = 0;
+      return -1;
+   }
+   // Done
+   return 0;
+#endif
 }
 
 //______________________________________________________________________________
@@ -572,19 +594,30 @@ int XrdProofdResponse::LinkSend(const struct iovec *iov,
    // Functionality a la 'writev' is simulated by segmenting the sending.
    // This allows to avoid a recovery problem with 'writev'.
    // Return 0 on success, -1 on failure.
+   XPDLOC(RSP, "Response::LinkSend:2")
 
    int rc = 0;
+   XrdSysMutexHelper mxh(fMutex);
+   CHECKLINKNOMTX;
 
    // If we fail we close the link, and ask the client to reconnect
    if ((rc = fLink->Send(iov, iocnt, 0)) < 0) {
       int bytes = 0;
       for (int i = 0; i < iocnt; i++) bytes += iov[i].iov_len;
       XPDFORM(emsg, "problems sending %d bytes (writev)", bytes);
+#if 0
       fLink->Close();
    }
 
    // Done
    return ((rc < 0) ? fLink->setEtext("send (writev) failure") : 0);
+#else
+      fLink = 0;
+      return -1;
+   }
+   // Done
+   return 0;
+#endif
 }
 
 //______________________________________________________________________________
@@ -622,9 +655,8 @@ void XrdProofdResponse::GetSID(unsigned short &sid)
 {
    // Get stream ID (to be able to restore it later
 
-   {  XrdSysMutexHelper mh(fMutex);
-      memcpy((void *)&sid, (void *)&fResp.streamid[0], sizeof(sid));
-   }
+   XrdSysMutexHelper mh(fMutex);
+   memcpy((void *)&sid, (void *)&fResp.streamid[0], sizeof(sid));
 }
 
 //______________________________________________________________________________
@@ -643,20 +675,10 @@ void XrdProofdResponse::Set(ServerResponseHeader *resp)
 void XrdProofdResponse::Set(XrdLink *l)
 {
    // Set the link to be used by this response
-   XPDLOC(RSP, "Response::Set")
 
    {  XrdSysMutexHelper mh(fMutex);
       fLink = l;
-   }
-   GetSID(fSID);
-   if (fLink) {
-      if (fLink->FDnum() < 0) {
-         TRACE(XERR, "link descriptor invalid for link "<<fLink<<"! ("<< fLink->FDnum()<<")");
-      } else {
-         TRACE(DBG,"using link "<<fLink<<", descriptor:"<<fLink->FDnum());
-      }
-   } else {
-      TRACE(XERR,"link is undefined!");
+      memcpy((void *)&fSID, (void *)&fResp.streamid[0], sizeof(fSID));
    }
 }
 
