@@ -70,6 +70,7 @@ class TTimer;
 class THashList;
 class TH1;
 class TFile;
+class TStopwatch;
 
 //------------------------------------------------------------------------
 
@@ -80,7 +81,7 @@ private:
 
 protected:
    TList        *fInput;           //-> list with input objects
-   TList        *fOutput;          //   list with output objects
+   THashList    *fOutput;          //   list with output objects
    TSelector    *fSelector;        //!  the latest selector
    Bool_t        fCreateSelObj;    //!  kTRUE when fSelector has been created locally
    TClass       *fSelectorClass;   //!  class of the latest selector
@@ -107,6 +108,9 @@ protected:
 
    TTimer       *fDispatchTimer;    //Dispatch pending events while processing
 
+   TTimer       *fProcTimeTimer;    //Notifies reaching of allowed max proc time 
+   TStopwatch   *fProcTime;         //Packet proc time
+
    TString       fOutputFilePath;   //Path to file with (partial) results of the query
    TFile        *fOutputFile;       //TFile object attached to fOutputFilePath
    Long_t        fSaveMemThreshold; //Threshold for saving output to file
@@ -141,7 +145,8 @@ protected:
    void MapOutputListToDataMembers() const;
 
 public:
-   enum EStatusBits { kDispatchOneEvent = BIT(15), kIsProcessing = BIT(16) };
+   enum EStatusBits { kDispatchOneEvent = BIT(15), kIsProcessing = BIT(16),
+                      kMaxProcTimeReached = BIT(17), kMaxProcTimeExtended = BIT(18) };
 
    TProofPlayer(TProof *proof = 0);
    virtual ~TProofPlayer();
@@ -152,6 +157,7 @@ public:
    Long64_t  Process(TDSet *set,
                      TSelector *selector, Option_t *option = "",
                      Long64_t nentries = -1, Long64_t firstentry = 0);
+   virtual Bool_t JoinProcess(TList *workers);
    TVirtualPacketizer *GetPacketizer() const { return 0; }
    Long64_t  Finalize(Bool_t force = kFALSE, Bool_t sync = kFALSE);
    Long64_t  Finalize(TQueryResult *qr);
@@ -297,6 +303,8 @@ protected:
    ErrorHandlerFunc_t  fErrorHandler;  // Store previous handler when redirecting output
    Bool_t              fMergeTH1OneByOne;  // If kTRUE forces TH1 merge one-by-one [kTRUE]
    TH1                *fProcPackets;    //!Histogram with packets being processed (owned by TPerfStats)
+   TMessage           *fProcessMessage;  // Process message to replay when adding new workers dynamically
+   TString             fSelectorFileName;  // Current Selector's name, set by Process()
 
    virtual Bool_t  HandleTimer(TTimer *timer);
    Int_t           InitPacketizer(TDSet *dset, Long64_t nentries,
@@ -316,7 +324,8 @@ public:
    TProofPlayerRemote(TProof *proof = 0) : fProof(proof), fOutputLists(0), fFeedback(0),
                                            fFeedbackLists(0), fPacketizer(0),
                                            fMergeFiles(kFALSE), fDSet(0), fErrorHandler(0),
-                                           fMergeTH1OneByOne(kTRUE), fProcPackets(0)
+                                           fMergeTH1OneByOne(kTRUE), fProcPackets(0),
+                                           fProcessMessage(0)
                                            { fProgressStatus = new TProofProgressStatus(); }
    virtual ~TProofPlayerRemote();   // Owns the fOutput list
    virtual Long64_t Process(TDSet *set, const char *selector,
@@ -325,6 +334,7 @@ public:
    virtual Long64_t Process(TDSet *set, TSelector *selector,
                             Option_t *option = "", Long64_t nentries = -1,
                             Long64_t firstentry = 0);
+   virtual Bool_t JoinProcess(TList *workers);
    virtual Long64_t Finalize(Bool_t force = kFALSE, Bool_t sync = kFALSE);
    virtual Long64_t Finalize(TQueryResult *qr);
    Long64_t       DrawSelect(TDSet *set, const char *varexp,
