@@ -1,4 +1,4 @@
-// @(#)root/proofplayer:$Id: TEventIter.cxx 44010 2012-04-29 23:07:48Z ganis $
+// @(#)root/proofplayer:$Id$
 // Author: Maarten Ballintijn   07/01/02
 // Modified: Long Tran-Thanh    04/09/07  (Addition of TEventIterUnit)
 
@@ -72,6 +72,15 @@ TEventIter::TEventIter()
    fElemNum = 0;
    fElemCur = -1;
    ResetBit(TEventIter::kData);
+   
+   if ((fPackets = new TList)) {
+      TString n("ProcessedPackets_");
+      if (gProofServ) n += gProofServ->GetOrdinal();
+      fPackets->SetName(n);
+      Info("TEventIter", "fPackets list '%s' created", n.Data());
+   } else {
+      Warning("TEventIter", "fPackets list could not be created");
+   }
 }
 
 //______________________________________________________________________________
@@ -96,6 +105,15 @@ TEventIter::TEventIter(TDSet *dset, TSelector *sel, Long64_t first, Long64_t num
    fElemNum = 0;
    fElemCur = -1;
    ResetBit(TEventIter::kData);
+  
+   if ((fPackets = new TList)) {
+      TString n("ProcessedPackets_");
+      if (gProofServ) n += gProofServ->GetOrdinal();
+      fPackets->SetName(n);
+      Info("TEventIter", "fPackets list '%s' created", n.Data());
+   } else {
+      Warning("TEventIter", "fPackets list could not be created");
+   }
 }
 
 //______________________________________________________________________________
@@ -103,6 +121,10 @@ TEventIter::~TEventIter()
 {
    // Destructor
 
+   if (fPackets) {
+      fPackets->SetOwner(kTRUE);
+      SafeDelete(fPackets);
+   }
    delete fFile;
 }
 
@@ -253,14 +275,28 @@ Int_t TEventIterUnit::GetNextPacket(Long64_t &fst, Long64_t &num,
 
    if (fDSet->TestBit(TDSet::kIsLocal)) {
       if (fElem) {
-         SafeDelete(fElem);
+         if (fPackets) {
+            fPackets->Add(fElem);
+            PDB(kLoop, 2)
+               Info("GetNextEvent", "packet added to list (sz: %d)", fPackets->GetSize());
+            fElem = 0;
+         } else {
+            SafeDelete(fElem);
+         }
          return -1;
       } else {
          fElem = new TDSetElement("", "", "", 0, fNum);
          fElem->SetBit(TDSetElement::kEmpty);
       }
    } else {
-      SafeDelete(fElem);
+      if (fPackets && fElem) {
+         fPackets->Add(fElem);
+         PDB(kLoop, 2)
+            Info("GetNextEvent", "packet added to list (sz: %d)", fPackets->GetSize());
+         fElem = 0;
+      } else {
+         SafeDelete(fElem);
+      }
       if (!(fElem = fDSet->Next()))
          return -1;
    }
@@ -302,14 +338,28 @@ Long64_t TEventIterUnit::GetNextEvent()
 
       if (fDSet->TestBit(TDSet::kIsLocal)) {
          if (fElem) {
-            SafeDelete(fElem);
+            if (fPackets) {
+               fPackets->Add(fElem);
+               PDB(kLoop, 2)
+                  Info("GetNextEvent", "packet added to list (sz: %d)", fPackets->GetSize());
+               fElem = 0;
+            } else {
+               SafeDelete(fElem);
+            }
             return -1;
          } else {
             fElem = new TDSetElement("", "", "", 0, fNum);
             fElem->SetBit(TDSetElement::kEmpty);
          }
       } else {
-         SafeDelete(fElem);
+         if (fPackets && fElem) {
+            fPackets->Add(fElem);
+            PDB(kLoop, 2)
+               Info("GetNextEvent", "packet added to list (sz: %d)", fPackets->GetSize());
+            fElem = 0;
+         } else {
+            SafeDelete(fElem);
+         }
          if (!(fElem = fDSet->Next()))
             return -1;
       }
@@ -388,7 +438,15 @@ Int_t TEventIterObj::GetNextPacket(Long64_t &first, Long64_t &num,
          fOldBytesRead = bytesRead;
       }
 
-      SafeDelete(fElem);
+      if (fElem) {
+         // Save it to the list of processed packets
+         if (fPackets) {
+            fPackets->Add(fElem);
+            fElem = 0;
+         } else {
+            SafeDelete(fElem);
+         }
+      }
       fElem = fDSet->Next(fKeys->GetSize());
       if (fElem && fElem->GetEntryList()) {
          Error("GetNextPacket", "entry- or event-list not available");
@@ -495,7 +553,15 @@ Long64_t TEventIterObj::GetNextEvent()
          fOldBytesRead = bytesRead;
       }
 
-      SafeDelete(fElem);
+      if (fElem) {
+         // Save it to the list of processed packets
+         if (fPackets) {
+            fPackets->Add(fElem);
+            fElem = 0;
+         } else {
+            SafeDelete(fElem);
+         }
+      }
       fElem = fDSet->Next(fKeys->GetSize());
       if (fElem && fElem->GetEntryList()) {
          Error("GetNextEvent", "Entry- or event-list not available");
@@ -945,7 +1011,15 @@ Int_t TEventIterTree::GetNextPacket(Long64_t &first, Long64_t &num,
          fOldBytesRead = totBytesRead;
       }
       
-      SafeDelete(fElem);
+      if (fElem) {
+         // Save it to the list of processed packets
+         if (fPackets) {
+            fPackets->Add(fElem);
+            fElem = 0;
+         } else {
+            SafeDelete(fElem);
+         }
+      }
       while (!fElem) {
          // For a corrupted/invalid file the request for a new packet is with totalEntries = -1
          // (the default) so that the packetizer invalidates the element
@@ -1115,9 +1189,15 @@ Long64_t TEventIterTree::GetNextEvent()
       if (fElem) {
          rest = fElem->GetNum();
          if (fElemCur >= 0) rest -= (fElemCur + 1 - fElemFirst);
+         // Save it to the list of processed packets
+         if (fPackets) {
+            fPackets->Add(fElem);
+            fElem = 0;
+         } else {
+            SafeDelete(fElem);
+         }
       }
       
-      SafeDelete(fElem);
       while (!fElem) {
          // For a corrupted/invalid file the request for a new packet is with totalEntries = -1
          // (the default) so that the packetizer invalidates the element
