@@ -26,6 +26,10 @@ namespace HistFactory{
   public:
 
     FlexibleInterpVar() ;
+    FlexibleInterpVar(const char *name, const char *title,
+		      const RooArgList& _paramList, 
+		      Double_t nominal, const RooArgList& low, const RooArgList& high);
+
     FlexibleInterpVar(const char *name, const char *title,
 		      const RooArgList& _paramList, 
 		      double nominal, std::vector<double> low, std::vector<double> high);
@@ -40,12 +44,17 @@ namespace HistFactory{
     void setInterpCode(RooAbsReal& param, int code);
     void setAllInterpCodes(int code);
     void setGlobalBoundary(double boundary) {_interpBoundary = boundary;}
+    void setNominal(Double_t newNominal);
+    void setLow(RooAbsReal& param, Double_t newLow);
+    void setHigh(RooAbsReal& param, Double_t newHigh);
 
     void printAllInterpCodes();
 
     virtual TObject* clone(const char* newname) const { return new FlexibleInterpVar(*this, newname); }
     virtual ~FlexibleInterpVar() ;
 
+    virtual void printMultiline(ostream& os, Int_t contents, Bool_t verbose = kFALSE, TString indent = "") const;
+    virtual void printFlexibleInterpVars(ostream& os) const;
 
   protected:
 
