@@ -1,3 +1,29 @@
+// @(#)root/roostats:$Id$
+// Author: Kyle Cranmer, George Lewis 
+/*************************************************************************
+ * Copyright (C) 1995-2008, Rene Brun and Fons Rademakers.               *
+ * All rights reserved.                                                  *
+ *                                                                       *
+ * For the licensing terms see $ROOTSYS/LICENSE.                         *
+ * For the list of contributors see $ROOTSYS/README/CREDITS.             *
+ *************************************************************************/
+
+//_________________________________________________
+/*
+BEGIN_HTML
+<p>
+This class encapsulates all information for the statistical interpretation of one experiment.
+It can be combined with other channels (e.g. for the combination of multiple experiments, or
+to constrain nuisance parameters with information obtained in a control region).
+A channel contains one or more samples which describe the contribution from different processes
+to this measurement.
+</p>
+END_HTML
+*/
+//
+
+
+
 #include "RooStats/HistFactory/Channel.h"
 #include <stdlib.h>
 
@@ -9,10 +35,16 @@
 using namespace std;
 
 RooStats::HistFactory::Channel::Channel() :
-  fName( "" ) { ; }
+  fName( "" )
+{
+  // standard constructor
+}
 
 RooStats::HistFactory::Channel::Channel(std::string ChanName, std::string ChanInputFile) :
-  fName( ChanName ), fInputFile( ChanInputFile ) { ; }
+  fName( ChanName ), fInputFile( ChanInputFile )
+{
+  // create channel with given name and input file
+}
 
 namespace RooStats{
   namespace HistFactory{
@@ -23,13 +55,16 @@ namespace RooStats{
 }
 
 
-void RooStats::HistFactory::Channel::AddSample( RooStats::HistFactory::Sample sample ) { 
+void RooStats::HistFactory::Channel::AddSample( RooStats::HistFactory::Sample sample )
+{
+  // add fully configured sample to channel
+  
   sample.SetChannelName( GetName() );
   fSamples.push_back( sample ); 
 }
 
 void RooStats::HistFactory::Channel::Print( std::ostream& stream ) {
-
+  // print information of channel to given stream
 
   stream << "\t Channel Name: " << fName
 	 << "\t InputFile: " << fInputFile
@@ -61,7 +96,6 @@ void RooStats::HistFactory::Channel::Print( std::ostream& stream ) {
 void RooStats::HistFactory::Channel::PrintXML( std::string Directory, std::string Prefix ) {
 
   // Create an XML file for this channel
-
   std::cout << "Printing XML Files for channel: " << GetName() << std::endl;
   
   std::string XMLName = Prefix + fName + ".xml";
@@ -69,19 +103,10 @@ void RooStats::HistFactory::Channel::PrintXML( std::string Directory, std::strin
   
   ofstream xml( XMLName.c_str() );
 
-
   // Add the time
   xml << "<!--" << std::endl;
   xml << "This xml file created automatically on: " << std::endl;
-/*
-  time_t t = time(0);   // get time now
-  struct tm * now = localtime( &t );
-  xml << (now->tm_year + 1900) << '-'
-      << (now->tm_mon + 1) << '-'
-      << now->tm_mday
-      << std::endl;
-*/
-// LM: use TTimeStamp since time_t does not work on Windows
+  // LM: use TTimeStamp since time_t does not work on Windows
   TTimeStamp t; 
   UInt_t year = 0; 
   UInt_t month = 0; 
@@ -91,9 +116,7 @@ void RooStats::HistFactory::Channel::PrintXML( std::string Directory, std::strin
       << month << '-'
       << day
       << std::endl;
-
   xml << "-->" << std::endl;
-  
 
   // Add the DOCTYPE
   xml << "<!DOCTYPE Channel  SYSTEM 'HistFactorySchema.dtd'>  " << std::endl << std::endl;
@@ -101,16 +124,20 @@ void RooStats::HistFactory::Channel::PrintXML( std::string Directory, std::strin
   // Add the Channel
   xml << "  <Channel Name=\"" << fName << "\" InputFile=\"" << fInputFile << "\" >" << std::endl << std::endl;
 
+  fData.PrintXML( xml );
+  /*
   xml << "    <Data HistoName=\"" << fData.GetHistoName() << "\" "
       << "InputFile=\"" << fData.GetInputFile() << "\" "
       << "HistoPath=\"" << fData.GetHistoPath() << "\" "
       << " /> " << std::endl << std::endl;  
+  */
 
-
+  fStatErrorConfig.PrintXML( xml );
+  /*
   xml << "    <StatErrorConfig RelErrorThreshold=\"" << fStatErrorConfig.GetRelErrorThreshold() << "\" "
       << "ConstraintType=\"" << Constraint::Name( fStatErrorConfig.GetConstraintType() ) << "\" "
       << "/> " << std::endl << std::endl;            
-
+  */
 
   for( unsigned int i = 0; i < fSamples.size(); ++i ) {
     fSamples.at(i).PrintXML( xml );
@@ -118,20 +145,18 @@ void RooStats::HistFactory::Channel::PrintXML( std::string Directory, std::strin
   }
 
   xml << std::endl;
-
   xml << "  </Channel>  " << std::endl;
-
   xml.close();
 
   std::cout << "Finished printing XML files" << std::endl;
 
-
-
 }
 
 
 
 void RooStats::HistFactory::Channel::SetData( std::string DataHistoName, std::string DataInputFile, std::string DataHistoPath ) {
+  // set data for this channel by specifying the name of the histogram,
+  // the external ROOT file and the path to the histogram inside the ROOT file
 
   fData.SetHistoName( DataHistoName );
   fData.SetInputFile( DataInputFile );
@@ -141,7 +166,8 @@ void RooStats::HistFactory::Channel::SetData( std::string DataHistoName, std::st
 
 
 
-void RooStats::HistFactory::Channel::SetData( TH1* hData ) { 
+void RooStats::HistFactory::Channel::SetData( TH1* hData ) {
+  // set data directly to some histogram
   fData.SetHisto( hData ); 
 }
 
@@ -218,9 +244,7 @@ void RooStats::HistFactory::Channel::CollectHistograms() {
 
 
     // Get the StatError Histogram (if necessary)
-
     if( sample.GetStatError().GetUseHisto() ) {
-
       sample.GetStatError().SetErrorHist( GetHistogram(sample.GetStatError().GetInputFile(),
 						       sample.GetStatError().GetHistoPath(),
 						       sample.GetStatError().GetHistoName()) );
@@ -267,6 +291,20 @@ void RooStats::HistFactory::Channel::CollectHistograms() {
 					  shapeSys.GetHistoName()) );
     } // End Loop over ShapeSys
 
+    
+    // Get any initial shape for a ShapeFactor
+    for( unsigned int shapeFactorItr = 0; shapeFactorItr < sample.GetShapeFactorList().size(); ++shapeFactorItr ) {
+
+      RooStats::HistFactory::ShapeFactor& shapeFactor = sample.GetShapeFactorList().at( shapeFactorItr );
+
+      // Check if we need an InitialShape
+      if( shapeFactor.HasInitialShape() ) {
+	TH1* hist = GetHistogram( shapeFactor.GetInputFile(), shapeFactor.GetHistoPath(), 
+				  shapeFactor.GetHistoName() );
+	shapeFactor.SetInitialShape( hist );
+      }
+
+    } // End Loop over ShapeFactor
 
   } // End Loop over Samples
 
