@@ -53,7 +53,7 @@ FlexibleInterpVar::FlexibleInterpVar()
 //_____________________________________________________________________________
 FlexibleInterpVar::FlexibleInterpVar(const char* name, const char* title, 
 		       const RooArgList& paramList, 
-		       double nominal, vector<double> low, vector<double> high) :
+		       Double_t nominal, vector<double> low, vector<double> high) :
   RooAbsReal(name, title),
   _paramList("paramList","List of paramficients",this),
   _nominal(nominal), _low(low), _high(high), _interpBoundary(1.)
@@ -78,6 +78,49 @@ FlexibleInterpVar::FlexibleInterpVar(const char* name, const char* title,
 
 }
 
+//_____________________________________________________________________________
+FlexibleInterpVar::FlexibleInterpVar(const char* name, const char* title, 
+		       const RooArgList& paramList, 
+		       double nominal, const RooArgList& low, const RooArgList& high) :
+  RooAbsReal(name, title),
+  _paramList("paramList","List of paramficients",this),
+  _nominal(nominal), _interpBoundary(1.)
+{
+
+  RooFIter lowIter = low.fwdIterator() ;
+  RooAbsReal* val ; 
+  while ((val = (RooAbsReal*) lowIter.next())) {
+    _low.push_back(val->getVal()) ;
+  }
+
+  RooFIter highIter = high.fwdIterator() ;
+  while ((val = (RooAbsReal*) highIter.next())) {
+    _high.push_back(val->getVal()) ;
+  }
+  
+  
+  _logInit = kFALSE ;
+  _paramIter = _paramList.createIterator() ;
+
+
+  TIterator* paramIter = paramList.createIterator() ;
+  RooAbsArg* param ;
+  while((param = (RooAbsArg*)paramIter->Next())) {
+    if (!dynamic_cast<RooAbsReal*>(param)) {
+      coutE(InputArguments) << "FlexibleInterpVar::ctor(" << GetName() << ") ERROR: paramficient " << param->GetName() 
+			    << " is not of type RooAbsReal" << endl ;
+      assert(0) ;
+    }
+    _paramList.add(*param) ;
+    _interpCode.push_back(0); // default code
+  }
+  delete paramIter ;
+
+}
+
+
+
+
 //_____________________________________________________________________________
 FlexibleInterpVar::FlexibleInterpVar(const char* name, const char* title, 
 				     const RooArgList& paramList, 
@@ -165,6 +208,47 @@ void FlexibleInterpVar::setAllInterpCodes(int code){
 
 }
 
+//_____________________________________________________________________________
+void FlexibleInterpVar::setNominal(Double_t newNominal){
+
+  coutW(InputArguments) << "FlexibleInterpVar::setNominal : nominal is now " << newNominal << endl ;
+  _nominal = newNominal;
+
+  setValueDirty();
+}
+
+//_____________________________________________________________________________
+void FlexibleInterpVar::setLow(RooAbsReal& param, Double_t newLow){
+
+  int index = _paramList.index(&param);
+  if(index<0){
+      coutE(InputArguments) << "FlexibleInterpVar::setLow ERROR:  " << param.GetName() 
+			    << " is not in list" << endl ;
+  } else {
+      coutW(InputArguments) << "FlexibleInterpVar::setLow :  " << param.GetName() 
+			    << " is now " << newLow << endl ;
+    _low.at(index) = newLow;
+  }
+
+  setValueDirty();
+}
+
+//_____________________________________________________________________________
+void FlexibleInterpVar::setHigh(RooAbsReal& param, Double_t newHigh){
+
+  int index = _paramList.index(&param);
+  if(index<0){
+      coutE(InputArguments) << "FlexibleInterpVar::setHigh ERROR:  " << param.GetName() 
+			    << " is not in list" << endl ;
+  } else {
+      coutW(InputArguments) << "FlexibleInterpVar::setHigh :  " << param.GetName() 
+			    << " is now " << newHigh << endl ;
+    _high.at(index) = newHigh;
+  }
+
+  setValueDirty();
+}
+
 //_____________________________________________________________________________
 void FlexibleInterpVar::printAllInterpCodes(){
 
@@ -192,49 +276,60 @@ Double_t FlexibleInterpVar::evaluate() const
   while((param=(RooAbsReal*)_paramIter->Next())) {
     //    param->Print("v");
 
-    if(_interpCode.at(i)==0){
+
+    Int_t icode = _interpCode[i] ;
+    switch(icode) {
+
+    case 0: {
       // piece-wise linear
       if(param->getVal()>0)
-	total +=  param->getVal()*(_high.at(i) - _nominal );
+	total +=  param->getVal()*(_high[i] - _nominal );
       else
-	total += param->getVal()*(_nominal - _low.at(i));
-    } else if(_interpCode.at(i)==1){
+	total += param->getVal()*(_nominal - _low[i]);
+      break ;
+    }
+    case 1: {
       // pice-wise log
       if(param->getVal()>=0)
-	total *= pow(_high.at(i)/_nominal, +param->getVal());
+	total *= pow(_high[i]/_nominal, +param->getVal());
       else
-	total *= pow(_low.at(i)/_nominal,  -param->getVal());
-    } else if(_interpCode.at(i)==2){
+	total *= pow(_low[i]/_nominal,  -param->getVal());
+      break ;
+    }
+    case 2: {
       // parabolic with linear
-      double a = 0.5*(_high.at(i)+_low.at(i))-_nominal;
-      double b = 0.5*(_high.at(i)-_low.at(i));
+      double a = 0.5*(_high[i]+_low[i])-_nominal;
+      double b = 0.5*(_high[i]-_low[i]);
       double c = 0;
       if(param->getVal()>1 ){
-	total += (2*a+b)*(param->getVal()-1)+_high.at(i)-_nominal;
+	total += (2*a+b)*(param->getVal()-1)+_high[i]-_nominal;
       } else if(param->getVal()<-1 ) {
-	total += -1*(2*a-b)*(param->getVal()+1)+_low.at(i)-_nominal;
+	total += -1*(2*a-b)*(param->getVal()+1)+_low[i]-_nominal;
       } else {
 	total +=  a*pow(param->getVal(),2) + b*param->getVal()+c;
       }
-    } else if(_interpCode.at(i)==3){
+      break ;
+    }
+    case 3: {
       //parabolic version of log-normal
-      double a = 0.5*(_high.at(i)+_low.at(i))-_nominal;
-      double b = 0.5*(_high.at(i)-_low.at(i));
+      double a = 0.5*(_high[i]+_low[i])-_nominal;
+      double b = 0.5*(_high[i]-_low[i]);
       double c = 0;
       if(param->getVal()>1 ){
-	total += (2*a+b)*(param->getVal()-1)+_high.at(i)-_nominal;
+	total += (2*a+b)*(param->getVal()-1)+_high[i]-_nominal;
       } else if(param->getVal()<-1 ) {
-	total += -1*(2*a-b)*(param->getVal()+1)+_low.at(i)-_nominal;
+	total += -1*(2*a-b)*(param->getVal()+1)+_low[i]-_nominal;
       } else {
 	total +=  a*pow(param->getVal(),2) + b*param->getVal()+c;
       }
-	
-    } else if(_interpCode.at(i)==4){ // Aaron Armbruster - exponential extrapolation, polynomial interpolation
+      break ;
+    }
+    case 4: {
       double boundary = _interpBoundary;
       // piece-wise log + parabolic
       if(param->getVal()>=boundary)
 	{
-	total *= pow(_high.at(i)/_nominal, +param->getVal());
+	total *= pow(_high[i]/_nominal, +param->getVal());
       }
       else if (param->getVal() < boundary && param->getVal() > -boundary && boundary != 0)
       {
@@ -264,42 +359,25 @@ Double_t FlexibleInterpVar::evaluate() const
 	  }
 	  
 	}
-
-// 	double pow_up       = pow(_high.at(i)/_nominal, x0);
-// 	double pow_down     = pow(_low.at(i)/_nominal,  x0);
-// 	double pow_up_log   = pow_up*TMath::Log(_high.at(i));
-// 	double pow_down_log =-pow_down*TMath::Log(_low.at(i));
-// 	double pow_up_log2  = pow_up_log*TMath::Log(_high.at(i));
-// 	double pow_down_log2=-pow_down*TMath::Log(_low.at(i));
-
-
-//fcns+der are eq at bd
-// 	  double a =  1./(4*pow(x0, 1))*(3*A0 - x0*S1);
-// 	double b =  1./(4*pow(x0, 2))*(4*S0 - x0*A1 - 8);
-// 	double c = -1./(4*pow(x0, 3))*(  A0 - x0*S1);
-// 	double d = -1./(4*pow(x0, 4))*(2*S0 - x0*A1 - 4);
-// 	total *= 1 + a*x + b*pow(x, 2) + c*pow(x, 3) + d*pow(x, 4);
-
-//fcns+der+2nd_der are eq at bd
+	
+	// GHL: Swagato's suggestions
+	// if( _low[i] == 0 ) _low[i] = 0.0001;
+	// if( _high[i] == 0 ) _high[i] = 0.0001;
 
 	// GHL: Swagato's suggestions
-	// if( _low.at(i) == 0 ) _low.at(i) = 0.0001;
-	// if( _high.at(i) == 0 ) _high.at(i) = 0.0001;
-
-	// GHL: Swagato's suggestions
-	double pow_up       = _powHi.at(i) ;
-	double pow_down     = _powLo.at(i) ;
-	double pow_up_log   = _high.at(i) <= 0.0 ? 0.0 : pow_up*_logHi.at(i) ;
-	double pow_down_log = _low.at(i) <= 0.0 ? 0.0 : -pow_down*_logLo.at(i) ;
-	double pow_up_log2  = _high.at(i) <= 0.0 ? 0.0 : pow_up_log*_logHi.at(i) ;
-	double pow_down_log2= _low.at(i) <= 0.0 ? 0.0 : pow_down_log*_logLo.at(i) ;
+	double pow_up       = _powHi[i] ;
+	double pow_down     = _powLo[i] ;
+	double pow_up_log   = _high[i] <= 0.0 ? 0.0 : pow_up*_logHi[i] ;
+	double pow_down_log = _low[i] <= 0.0 ? 0.0 : -pow_down*_logLo[i] ;
+	double pow_up_log2  = _high[i] <= 0.0 ? 0.0 : pow_up_log*_logHi[i] ;
+	double pow_down_log2= _low[i] <= 0.0 ? 0.0 : -pow_down_log*_logLo[i] ;
 	/*
-	double pow_up       = pow(_high.at(i)/_nominal, x0);
-	double pow_down     = pow(_low.at(i)/_nominal,  x0);
-	double pow_up_log   = pow_up*TMath::Log(_high.at(i));
-	double pow_down_log = -pow_down*TMath::Log(_low.at(i));
-	double pow_up_log2  = pow_up_log*TMath::Log(_high.at(i));
-	double pow_down_log2= pow_down_log*TMath::Log(_low.at(i));
+	double pow_up       = pow(_high[i]/_nominal, x0);
+	double pow_down     = pow(_low[i]/_nominal,  x0);
+	double pow_up_log   = pow_up*TMath::Log(_high[i]);
+	double pow_down_log = -pow_down*TMath::Log(_low[i]);
+	double pow_up_log2  = pow_up_log*TMath::Log(_high[i]);
+	double pow_down_log2= pow_down_log*TMath::Log(_low[i]);
 	*/
 	double S0 = (pow_up+pow_down)/2;
 	double A0 = (pow_up-pow_down)/2;
@@ -321,13 +399,16 @@ Double_t FlexibleInterpVar::evaluate() const
 	total *= 1 + a*x + b*xx + c*xxx + d*xx*xx + e*xxx*xx + f*xxx*xxx;
       }
       else if (param->getVal()<=-boundary)
-      {
-	total *= pow(_low.at(i)/_nominal,  -param->getVal());
+	{
+	total *= pow(_low[i]/_nominal,  -param->getVal());
       }
-    } else {
+      break ;
+    }
+    default: {
       coutE(InputArguments) << "FlexibleInterpVar::evaluate ERROR:  " << param->GetName() 
 			    << " with unknown interpolation code" << endl ;
     }
+    }
     ++i;
   }
 
@@ -338,5 +419,22 @@ Double_t FlexibleInterpVar::evaluate() const
   return total;
 }
 
+void FlexibleInterpVar::printMultiline(ostream& os, Int_t contents, 
+				       Bool_t verbose, TString indent) const
+{
+  RooAbsReal::printMultiline(os,contents,verbose,indent);
+  os << indent << "--- FlexibleInterpVar ---" << endl;
+  printFlexibleInterpVars(os);
+}
+
+void FlexibleInterpVar::printFlexibleInterpVars(ostream& os) const
+{
+  _paramIter->Reset();
+  for (int i=0;i<(int)_low.size();i++) {
+    RooAbsReal* param=(RooAbsReal*)_paramIter->Next();
+    os << setw(36) << param->GetName()<<": "<<setw(7) << _low[i]<<"  "<<setw(7) << _high[i]
+       <<endl;
+  }
+}
 
 
