@@ -86,175 +86,90 @@
 
 // from this package
 #include "Helper.h"
-#include "RooStats/HistFactory/ConfigParser.h"
 #include "RooStats/HistFactory/EstimateSummary.h"
 #include "RooStats/HistFactory/Measurement.h"
 #include "RooStats/HistFactory/HistoToWorkspaceFactoryFast.h"
-//#include "RooStats/HistFactory/HistoToWorkspaceFactoryNew.h"
 #include "RooStats/HistFactory/HistFactoryException.h"
 
 #include "RooStats/HistFactory/MakeModelAndMeasurementsFast.h"
 
 using namespace RooFit;
-using namespace RooStats;
-using namespace HistFactory;
+//using namespace RooStats;
+//using namespace HistFactory;
 
-using namespace std;
-
-void fastDriver(string input){
-  // TO DO:
-  // would like to fully factorize the XML parsing.  
-  // No clear need to have some here and some in ConfigParser
-
-
-  // Make the list of measurements and channels
-  std::vector< HistFactory::Measurement > measurement_list;
-  std::vector< HistFactory::Channel >     channel_list;
-
-  HistFactory::ConfigParser xmlParser;
-
-  measurement_list = xmlParser.GetMeasurementsFromXML( input );
-
-  // Fill them using the XML parser
-  // xmlParser.FillMeasurementsAndChannelsFromXML( input, measurement_list, channel_list );
-
-  // At this point, we have all the information we need
-  // from the xml files.
-  
-
-  // We will make the measurements 1-by-1
-  // This part will be migrated to the
-  // MakeModelAndMeasurements function,
-  // but is here for now.
-
-  
-  /* Now setup the measurement */
-  // At this point, all we need
-  // is the list of measurements
-    
-  for(unsigned int i = 0; i < measurement_list.size(); ++i) {
-
-    HistFactory::Measurement measurement = measurement_list.at(i);
-
-    measurement.CollectHistograms();
-
-    MakeModelAndMeasurementFast( measurement );
-
-  }
-
-  return;
-
-}
-
-/*
-  Moved to HistoToWorkspaceFactoryFast
-std::vector<EstimateSummary> RooStats::HistFactory::GetChannelEstimateSummaries(RooStats::HistFactory::Measurement& measurement, RooStats::HistFactory::Channel& channel) {
-
-*/
-
-/*
-void RooStats::HistFactory::ConfigureWorkspaceForMeasurement( const std::string& ModelName, RooWorkspace* ws_single, RooStats::HistFactory::Measurement& measurement ) {
-
-*/
+//using namespace std;
 
 
 
 RooWorkspace* RooStats::HistFactory::MakeModelAndMeasurementFast( RooStats::HistFactory::Measurement& measurement ) {
-  
-  /*
-  // Add the channels to this measurement
-  for( unsigned int chanItr = 0; chanItr < channel_list.size(); ++chanItr ) {
-  measurement.channels.push_back( channel_list.at( chanItr ) );
-  }
-  */
 
   // This will be returned
   RooWorkspace* ws = NULL;
+  TFile* outFile = NULL;
+  FILE*  tableFile=NULL;
 
   try {
 
-
     std::cout << "Making Model and Measurements (Fast) for measurement: " << measurement.GetName() << std::endl;
 
     double lumiError = measurement.GetLumi()*measurement.GetLumiRelErr();
 
     std::cout << "using lumi = " << measurement.GetLumi() << " and lumiError = " << lumiError
-	 << " including bins between " << measurement.GetBinLow() << " and " << measurement.GetBinHigh() << std::endl;
+	      << " including bins between " << measurement.GetBinLow() << " and " << measurement.GetBinHigh() << std::endl;
     std::cout << "fixing the following parameters:"  << std::endl;
 
-    for(vector<string>::iterator itr=measurement.GetConstantParams().begin(); itr!=measurement.GetConstantParams().end(); ++itr){
-      cout << "   " << *itr << endl;
+    for(std::vector<std::string>::iterator itr=measurement.GetConstantParams().begin(); itr!=measurement.GetConstantParams().end(); ++itr){
+      std::cout << "   " << *itr << std::endl;
     }
 
     std::string rowTitle = measurement.GetName();
     
-    vector<RooWorkspace*> channel_workspaces;
-    vector<string>        channel_names;
-
+    std::vector<RooWorkspace*> channel_workspaces;
+    std::vector<std::string>        channel_names;
 
+    // Create the outFile
     // This holds the TGraphs that are created during the fit
     std::string outputFileName = measurement.GetOutputFilePrefix() + "_" + measurement.GetName() + ".root";
     std::cout << "Creating the output file: " << outputFileName << std::endl;
-    TFile* outFile = new TFile(outputFileName.c_str(), "recreate");
+    outFile = new TFile(outputFileName.c_str(), "recreate");
 
+    // Create the table file
     // This holds the table of fitted values and errors
     std::string tableFileName = measurement.GetOutputFilePrefix() + "_results.table";
     std::cout << "Creating the table file: " << tableFileName << std::endl;
-    FILE*  tableFile =  fopen( tableFileName.c_str(), "a"); 
+    tableFile =  fopen( tableFileName.c_str(), "a"); 
 
     std::cout << "Creating the HistoToWorkspaceFactoryFast factory" << std::endl;
-
     HistoToWorkspaceFactoryFast factory( measurement );
-
-    // USING OLD VERSION...
-    /*
-    TFile* dummyFile = NULL; // TEMPORARY !!!!!
-    HistoToWorkspaceFactoryFast factory(measurement.GetOutputFilePrefix(), rowTitle, measurement.GetConstantParams(), 
-					measurement.GetLumi(), lumiError, 
-					measurement.GetBinLow(), measurement.GetBinHigh(), dummyFile );
-    */
-
-    std::cout << "Setting preprocess functions" << std::endl;
-
+    
     // Make the factory, and do some preprocessing
     // HistoToWorkspaceFactoryFast factory(measurement, rowTitle, outFile);
+    std::cout << "Setting preprocess functions" << std::endl;
     factory.SetFunctionsToPreprocess( measurement.GetPreprocessFunctions() );
-
   
     // for results tables
     fprintf(tableFile, " %s &", rowTitle.c_str() );
   
-    /***
-	First: Loop to make the individual channels
-    ***/
-
-
+    // First: Loop to make the individual channels
     for( unsigned int chanItr = 0; chanItr < measurement.GetChannels().size(); ++chanItr ) {
     
       HistFactory::Channel& channel = measurement.GetChannels().at( chanItr );
-
       if( ! channel.CheckHistograms() ) {
 	std::cout << "MakeModelAndMeasurementsFast: Channel: " << channel.GetName()
 		  << " has uninitialized histogram pointers" << std::endl;
 	throw hf_exc();
-	return NULL;
       }
 
-      string ch_name = channel.GetName();
-      channel_names.push_back(ch_name);
-
+      // Make the workspace for this individual channel
+      std::string ch_name = channel.GetName();
       std::cout << "Starting to process channel: " << ch_name << std::endl;
-
+      channel_names.push_back(ch_name);
       RooWorkspace* ws_single = factory.MakeSingleChannelModel( measurement, channel );
-
       channel_workspaces.push_back(ws_single);
 
-      // Get the Paramater of Interest as a RooRealVar
-      RooRealVar* poi = (RooRealVar*) ws_single->var( (measurement.GetPOI()).c_str() );
-
-      
       // Make the output
-      std::string ChannelFileName = measurement.GetOutputFilePrefix() + "_" + ch_name + "_" + rowTitle + "_model.root";
+      std::string ChannelFileName = measurement.GetOutputFilePrefix() + "_" 
+	+ ch_name + "_" + rowTitle + "_model.root";
       ws_single->writeToFile( ChannelFileName.c_str() );
     
       // Now, write the measurement to the file
@@ -269,19 +184,25 @@ RooWorkspace* RooStats::HistFactory::MakeModelAndMeasurementFast( RooStats::Hist
       std::cout << "Successfully wrote channel to file" << std::endl;
       chanFile->Close();
 
+      // Get the Paramater of Interest as a RooRealVar
+      RooRealVar* poi = dynamic_cast<RooRealVar*>( ws_single->var( (measurement.GetPOI()).c_str() ) );
+
       // do fit unless exportOnly requested
       if(! measurement.GetExportOnly()){
-	if(!poi){
-	  cout <<"can't do fit for this channel, no parameter of interest"<<endl;
-	} else{
-	  if(ws_single->data("obsData")){
-	    FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws_single, ch_name, "obsData",    outFile, tableFile);
+	if(!poi) {
+	  std::cout << "Can't do fit for: " << measurement.GetName() 
+		    << ", no parameter of interest" << std::endl;
+	} else {
+	  if(ws_single->data("obsData")) {
+	    FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws_single, 
+			    ch_name, "obsData",    outFile, tableFile);
 	  } else {
-	    FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws_single, ch_name, "asimovData", outFile, tableFile);
+	    FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws_single, 
+			    ch_name, "asimovData", outFile, tableFile);
 	  }
 	}
       }
-
+      
       fprintf(tableFile, " & " );
     } // End loop over channels
   
@@ -291,7 +212,6 @@ RooWorkspace* RooStats::HistFactory::MakeModelAndMeasurementFast( RooStats::Hist
 	"combine" : will do the individual cross-section measurements plus combination	
     ***/
   
-
     // Use HistFactory to combine the individual channel workspaces
     ws = factory.MakeCombinedModel(channel_names, channel_workspaces);
 
@@ -299,13 +219,13 @@ RooWorkspace* RooStats::HistFactory::MakeModelAndMeasurementFast( RooStats::Hist
     HistoToWorkspaceFactoryFast::ConfigureWorkspaceForMeasurement( "simPdf", ws, measurement );
 
     // Get the Parameter of interest as a RooRealVar
-    RooRealVar* poi = (RooRealVar*) ws->var( (measurement.GetPOI()).c_str() );
-
-    //	  ws->writeToFile(("results/model_combined_edited.root").c_str());
-    //ws->writeToFile((measurement.OutputFilePrefix+"_combined_"+rowTitle+"_model.root").c_str());
-    std::string CombinedFileName = measurement.GetOutputFilePrefix()+"_combined_"+rowTitle+"_model.root";
+    RooRealVar* poi = dynamic_cast<RooRealVar*>( ws->var( (measurement.GetPOI()).c_str() ) );
+    
+    std::string CombinedFileName = measurement.GetOutputFilePrefix() + "_combined_"
+      + rowTitle + "_model.root";
+    std::cout << "Writing combined workspace to file: " << CombinedFileName << std::endl;
     ws->writeToFile( CombinedFileName.c_str() );
-    std::cout << "About to write combined measurement to file" << std::endl;
+    std::cout << "Writing combined measurement to file: " << CombinedFileName << std::endl;
     TFile* combFile = TFile::Open( CombinedFileName.c_str(), "UPDATE" );
     if( combFile == NULL ) {
       std::cout << "Error: Failed to open file " << CombinedFileName << std::endl;
@@ -313,17 +233,21 @@ RooWorkspace* RooStats::HistFactory::MakeModelAndMeasurementFast( RooStats::Hist
     }
     measurement.writeToFile( combFile );
     combFile->Close();
-
-    // TO DO:
-    // Totally factorize the statistical test in "fit Model" to a different area
+    
+    // Fit the combined model
     if(! measurement.GetExportOnly()){
-      if(!poi){
-	cout <<"can't do fit for this channel, no parameter of interest"<<endl;
-      } else{
+      if(!poi) {
+	std::cout << "Can't do fit for: " << measurement.GetName() 
+		  << ", no parameter of interest" << std::endl;
+      } 
+      else {
 	if(ws->data("obsData")){
-	  FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws, "combined", "obsData",    outFile, tableFile);
-	} else {
-	  FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws, "combined", "asimovData", outFile, tableFile);
+	  FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws,"combined", 
+			  "obsData",    outFile, tableFile);
+	} 
+	else {
+	  FitModelAndPlot(measurement.GetName(), measurement.GetOutputFilePrefix(), ws,"combined", 
+			  "asimovData", outFile, tableFile);
 	}
       }
     }
@@ -336,193 +260,213 @@ RooWorkspace* RooStats::HistFactory::MakeModelAndMeasurementFast( RooStats::Hist
     fclose( tableFile );
 
   }
-  catch(exception& e)
-    {
-      std::cout << e.what() << std::endl;
-      throw hf_exc();
-      return NULL;
-    }
-
+  catch(...) {
+    if( tableFile ) fclose(tableFile);
+    if(outFile) outFile->Close();
+    throw;
+  }
+  
   return ws;
 
-
 }
 
 
-  ///////////////////////////////////////////////
-void RooStats::HistFactory::FitModelAndPlot(const std::string& MeasurementName, const std::string& FileNamePrefix, RooWorkspace * combined, string channel, string data_name, TFile* outFile, FILE* tableFile  )
-  {
-
-    cout << "In Fit Model"<<endl;
-    ModelConfig * combined_config = (ModelConfig *) combined->obj("ModelConfig");
-    if(!combined_config){
-      cout << "no model config " << "ModelConfig" << " exiting" << endl;
-      return;
-    }
-    //    RooDataSet * simData = (RooDataSet *) combined->obj(data_name.c_str());
-    RooAbsData* simData = combined->data(data_name.c_str());
-    if(!simData){
-      cout << "no data " << data_name << " exiting" << endl;
-      return;
-    }
-    //    const RooArgSet * constrainedParams=combined_config->GetNuisanceParameters();
-    const RooArgSet * POIs=combined_config->GetParametersOfInterest();
-    if(!POIs){
-      cout << "no poi " << data_name << " exiting" << endl;
-      return;
-    }
-
-    //RooAbsPdf* model=combined->pdf(model_name.c_str()); 
-    RooAbsPdf* model=combined_config->GetPdf();
-    //    RooArgSet* allParams = model->getParameters(*simData);
-
-    ///////////////////////////////////////
-    //Do combined fit
-    //RooMsgService::instance().setGlobalKillBelow(RooMsgService::INFO) ;
-    cout << "\n\n---------------" << endl;
-    cout << "---------------- Doing "<< channel << " Fit" << endl;
-    cout << "---------------\n\n" << endl;
-    //    RooFitResult* result = model->fitTo(*simData, Minos(kTRUE), Save(kTRUE), PrintLevel(1));
-    model->fitTo(*simData, Minos(kTRUE), PrintLevel(1));
-    //    PrintCovarianceMatrix(result, allParams, "results/"+FilePrefixStr(channel)+"_corrMatrix.table" );
-
-    if( outFile != NULL ) {
-
-      //
-      // We only print info for the FIRST POI,
-      // but the rest are still saved in the ModelConfig
-      // 
-
-      RooRealVar* poi = 0; // (RooRealVar*) POIs->first();
-      // for results tables
-      TIterator* params_itr=POIs->createIterator();
-      TObject* params_obj=0;
-      while((params_obj=params_itr->Next())){
-	poi = (RooRealVar*) params_obj;
-	cout << "printing results for " << poi->GetName() << " at " << poi->getVal()<< " high " << poi->getErrorLo() << " low " << poi->getErrorHi()<<endl;
-      }
-      fprintf(tableFile, " %.4f / %.4f  ", poi->getErrorLo(), poi->getErrorHi());
-
-      RooAbsReal* nll = model->createNLL(*simData);
-      RooAbsReal* profile = nll->createProfile(*poi);
-      if( profile==NULL ) {
-	std::cout << "Error: Failed to make ProfileLikelihood for: " << poi->GetName() 
-		  << " using model: " << model->GetName()
-		  << " and data: " << simData->GetName()
-		  << std::endl;
-	throw hf_exc();
-      }
-      RooPlot* frame = poi->frame();
-      if( frame == NULL ) {
-	std::cout << "Error: Failed to create RooPlot frame for: " << poi->GetName() << std::endl;
-	throw hf_exc();
-      }
-      FormatFrameForLikelihood(frame);
-      TCanvas* c1 = new TCanvas( channel.c_str(), "",800,600);
-      nll->plotOn(frame, ShiftToZero(), LineColor(kRed), LineStyle(kDashed));
-      profile->plotOn(frame);
-      frame->SetMinimum(0);
-      frame->SetMaximum(2.);
-      frame->Draw();
-      //    c1->SaveAs( ("results/"+FilePrefixStr(channel)+"_profileLR.eps").c_str() );
-      c1->SaveAs( (FileNamePrefix+"_"+channel+"_"+MeasurementName+"_profileLR.eps").c_str() );
-      delete c1;
-
-      TDirectory* channel_dir = outFile->mkdir(channel.c_str());
-      if( channel_dir == NULL ) {
-	std::cout << "Error: Failed to make channel directory: " << channel << std::endl;
-	throw hf_exc();
-      }
-      TDirectory* summary_dir = channel_dir->mkdir("Summary");
-      if( summary_dir == NULL ) {
-	std::cout << "Error: Failed to make Summary directory for channel: " << channel << std::endl;
-	throw hf_exc();
-      }
-      summary_dir->cd();
-      //outFile->mkdir(channel.c_str())->mkdir("Summary")->cd();
+///////////////////////////////////////////////
+void RooStats::HistFactory::FitModelAndPlot(const std::string& MeasurementName, 
+					    const std::string& FileNamePrefix, 
+					    RooWorkspace * combined, std::string channel, 
+					    std::string data_name, 
+					    TFile* outFile, FILE* tableFile  ) {
     
-      RooCurve* curve=frame->getCurve();
-      Int_t curve_N=curve->GetN();
-      Double_t* curve_x=curve->GetX();
-      delete frame;
+  if( outFile == NULL ) {
+    std::cout << "Error: Output File in FitModelAndPlot is NULL" << std::endl;
+    throw hf_exc();
+  }
+
+  if( tableFile == NULL ) {
+    std::cout << "Error: tableFile in FitModelAndPlot is NULL" << std::endl;
+    throw hf_exc();
+  }
+
+  if( combined == NULL ) {
+    std::cout << "Error: Supplied workspace in FitModelAndPlot is NULL" << std::endl;
+    throw hf_exc();
+  }
+
+  ModelConfig* combined_config = (ModelConfig *) combined->obj("ModelConfig");
+  if(!combined_config){
+    std::cout << "Error: no ModelConfig found in Measurement: "
+	      << MeasurementName <<  std::endl;
+    throw hf_exc();
+  }
+
+  RooAbsData* simData = combined->data(data_name.c_str());
+  if(!simData){
+    std::cout << "Error: Failed to get dataset: " << data_name
+	      << " in measurement: " << MeasurementName << std::endl;
+    throw hf_exc();
+  }
     
-      //
-      // Verbose output from MINUIT
-      //
-      /*
-	RooMsgService::instance().setGlobalKillBelow(RooFit::DEBUG) ;
-	profile->getVal();
-	RooMinuit* minuit = ((RooProfileLL*) profile)->minuit();
-	minuit->setPrintLevel(5) ; // Print MINUIT messages
-	minuit->setVerbose(5) ; // Print RooMinuit messages with parameter 
-	// changes (corresponds to the Verbose() option of fitTo()
-	*/
-    
-      Double_t * x_arr = new Double_t[curve_N];
-      Double_t * y_arr_nll = new Double_t[curve_N];
-      //     Double_t y_arr_prof_nll[curve_N];
-      //     Double_t y_arr_prof[curve_N];
+  const RooArgSet* POIs = combined_config->GetParametersOfInterest();
+  if(!POIs) {
+    std::cout << "Not Fitting Model for measurement: " << MeasurementName
+	      << ", no poi found" << std::endl;
+    // Should I throw an exception here?
+    return;
+  }
+
+  RooAbsPdf* model = combined_config->GetPdf();
+  if( model==NULL ) {
+    std::cout << "Error: Failed to find pdf in ModelConfig: " << combined_config->GetName()
+	      << std::endl;
+    throw hf_exc();
+  }
+
+  // Save a Snapshot
+  RooArgSet PoiPlusNuisance( *combined_config->GetNuisanceParameters() );
+  PoiPlusNuisance.add( *combined_config->GetParametersOfInterest() );
+  combined->saveSnapshot("InitialValues", PoiPlusNuisance);
+
+  ///////////////////////////////////////
+  // Do the fit
+  std::cout << "\n\n---------------" << std::endl;
+  std::cout << "---------------- Doing "<< channel << " Fit" << std::endl;
+  std::cout << "---------------\n\n" << std::endl;
+  model->fitTo(*simData, Minos(kTRUE), PrintLevel(1));
+
+  // If there are no parameters of interest,
+  // we exit the function here
+  if( POIs->getSize()==0 ) {
+    std::cout << "WARNING: No POIs found in measurement: " << MeasurementName << std::endl;
+    return;
+  }
+
+  // Loop over all POIs and print their fitted values
+  RooRealVar* poi = NULL; // (RooRealVar*) POIs->first();
+  TIterator* params_itr = POIs->createIterator();
+  TObject* poi_obj=NULL;
+  while( (poi_obj=params_itr->Next()) ) {
+    //poi = (RooRealVar*) poi_obj;
+    poi = dynamic_cast<RooRealVar*>(poi_obj);
+    std::cout << "printing results for " << poi->GetName() 
+	      << " at " << poi->getVal()<< " high " 
+	      << poi->getErrorLo() << " low " 
+	      << poi->getErrorHi() << std::endl;
+  }
+
+  // But we only make detailed plots and tables
+  // for the 'first' POI
+  poi = dynamic_cast<RooRealVar*>(POIs->first());
+
+  // Print the MINOS errors to the TableFile
+  fprintf(tableFile, " %.4f / %.4f  ", poi->getErrorLo(), poi->getErrorHi());
+
+  // Make the Profile Likelihood Plot
+  RooAbsReal* nll = model->createNLL(*simData);
+  RooAbsReal* profile = nll->createProfile(*poi);
+  if( profile==NULL ) {
+    std::cout << "Error: Failed to make ProfileLikelihood for: " << poi->GetName() 
+	      << " using model: " << model->GetName()
+	      << " and data: " << simData->GetName()
+	      << std::endl;
+    throw hf_exc();
+  }
+
+  RooPlot* frame = poi->frame();
+  if( frame == NULL ) {
+    std::cout << "Error: Failed to create RooPlot frame for: " << poi->GetName() << std::endl;
+    throw hf_exc();
+  }
+
+  // Draw the likelihood curve
+  FormatFrameForLikelihood(frame);
+  TCanvas* ProfileLikelihoodCanvas = new TCanvas( channel.c_str(), "",800,600);
+  nll->plotOn(frame, ShiftToZero(), LineColor(kRed), LineStyle(kDashed));
+  profile->plotOn(frame);
+  frame->SetMinimum(0);
+  frame->SetMaximum(2.);
+  frame->Draw();
+  std::string ProfilePlotName = FileNamePrefix+"_"+channel+"_"+MeasurementName+"_profileLR.eps";
+  ProfileLikelihoodCanvas->SaveAs( ProfilePlotName.c_str() );
+  delete ProfileLikelihoodCanvas;
+
+  // Now, we save our results to the 'output' file
+  // (I'm not sure if users actually look into this file,
+  // but adding additional information and useful plots
+  // may make it more attractive)
+
+  // Save to the output file
+  TDirectory* channel_dir = outFile->mkdir(channel.c_str());
+  if( channel_dir == NULL ) {
+    std::cout << "Error: Failed to make channel directory: " << channel << std::endl;
+    throw hf_exc();
+  }
+  TDirectory* summary_dir = channel_dir->mkdir("Summary");
+  if( summary_dir == NULL ) {
+    std::cout << "Error: Failed to make Summary directory for channel: " 
+	      << channel << std::endl;
+    throw hf_exc();
+  }
+  summary_dir->cd();
+
+  // Save a graph of the profile likelihood curve
+  RooCurve* curve=frame->getCurve();
+  Int_t curve_N=curve->GetN();
+  Double_t* curve_x=curve->GetX();
+  delete frame;
+
+  Double_t * x_arr = new Double_t[curve_N];
+  Double_t * y_arr_nll = new Double_t[curve_N];
       
-      for(int i=0; i<curve_N; i++){
-	double f=curve_x[i];
-	poi->setVal(f);
-	x_arr[i]=f;
-	y_arr_nll[i]=nll->getVal();
-      }
-
-      TGraph * g = new TGraph(curve_N, x_arr, y_arr_nll);
-      //g->SetName( (FilePrefixStr(channel) +"_nll").c_str());
-      g->SetName( (FileNamePrefix +"_nll").c_str() );
-      g->Write(); 
-      delete g;
-      delete [] x_arr;
-      delete [] y_arr_nll;
-
-    }
-
-    /** find out what's inside the workspace **/
-    //combined->Print();
-
+  for(int i=0; i<curve_N; i++){
+    double f=curve_x[i];
+    poi->setVal(f);
+    x_arr[i]=f;
+    y_arr_nll[i]=nll->getVal();
   }
 
+  TGraph* g = new TGraph(curve_N, x_arr, y_arr_nll);
+  g->SetName( (FileNamePrefix +"_nll").c_str() );
+  g->Write(); 
+  delete g;
+  delete [] x_arr;
+  delete [] y_arr_nll;
+    
+  // Finally, restore the initial values
+  combined->loadSnapshot("InitialValues");
+    
+}
 
-void RooStats::HistFactory::FitModel(RooWorkspace * combined, string data_name )
-  {
 
-    cout << "In Fit Model"<<endl;
+void RooStats::HistFactory::FitModel(RooWorkspace * combined, std::string data_name ) {
+
+    std::cout << "In Fit Model" << std::endl;
     ModelConfig * combined_config = (ModelConfig *) combined->obj("ModelConfig");
     if(!combined_config){
-      cout << "no model config " << "ModelConfig" << " exiting" << endl;
+      std::cout << "no model config " << "ModelConfig" << " exiting" << std::endl;
       return;
     }
-    //    RooDataSet * simData = (RooDataSet *) combined->obj(data_name.c_str());
+    
     RooAbsData* simData = combined->data(data_name.c_str());
     if(!simData){
-      cout << "no data " << data_name << " exiting" << endl;
+      std::cout << "no data " << data_name << " exiting" << std::endl;
       return;
     }
-    //    const RooArgSet * constrainedParams=combined_config->GetNuisanceParameters();
+
     const RooArgSet * POIs=combined_config->GetParametersOfInterest();
     if(!POIs){
-      cout << "no poi " << data_name << " exiting" << endl;
+      std::cout << "no poi " << data_name << " exiting" << std::endl;
       return;
     }
 
-    //RooAbsPdf* model=combined->pdf(model_name.c_str()); 
     RooAbsPdf* model=combined_config->GetPdf();
-    //    RooArgSet* allParams = model->getParameters(*simData);
-
-    ///////////////////////////////////////
-    //Do combined fit
-    //RooMsgService::instance().setGlobalKillBelow(RooMsgService::INFO) ;
-    //    RooFitResult* result = model->fitTo(*simData, Minos(kTRUE), Save(kTRUE), PrintLevel(1));
     model->fitTo(*simData, Minos(kTRUE), PrintLevel(1));
-    //    PrintCovarianceMatrix(result, allParams, "results/"+FilePrefixStr(channel)+"_corrMatrix.table" );
-
+    
   }
 
 
-void RooStats::HistFactory::FormatFrameForLikelihood(RooPlot* frame, string /*XTitle*/, string YTitle){
+void RooStats::HistFactory::FormatFrameForLikelihood(RooPlot* frame, std::string /*XTitle*/, 
+						     std::string YTitle){
 
     gStyle->SetCanvasBorderMode(0);
     gStyle->SetPadBorderMode(0);
@@ -554,9 +498,3 @@ void RooStats::HistFactory::FormatFrameForLikelihood(RooPlot* frame, string /*XT
 }
 
 
-
-
-/*
-Removed.  Use instead HistoToWorkspaceFactoryFast.MakeCombinedModel()
-RooWorkspace* RooStats::HistFactory::MakeModelFast( RooStats::HistFactory::Measurement& measurement ) {
-*/
