@@ -20,18 +20,26 @@
 // END_HTML
 //
 
+#include <cmath>
+#include <iostream>
+
 #include "RooFit.h"
 
 #include "Riostream.h"
-#include "Riostream.h"
-#include <math.h>
 
 #include "RooChebychev.h"
 #include "RooAbsReal.h"
 #include "RooRealVar.h"
 #include "RooArgList.h"
 
-using namespace std;
+#if defined(__my_func__)
+#undef __my_func__
+#endif
+#if defined(WIN32)
+#define __my_func__ __FUNCTION__
+#else
+#define __my_func__ __func__
+#endif
 
 ClassImp(RooChebychev)
 ;
@@ -55,8 +63,9 @@ RooChebychev::RooChebychev(const char* name, const char* title,
   RooAbsArg* coef ;
   while((coef = (RooAbsArg*)coefIter->Next())) {
     if (!dynamic_cast<RooAbsReal*>(coef)) {
-      cout << "RooChebychev::ctor(" << GetName() << ") ERROR: coefficient " << coef->GetName() 
-	   << " is not of type RooAbsReal" << endl ;
+	std::cerr << "RooChebychev::ctor(" << GetName() <<
+	    ") ERROR: coefficient " << coef->GetName() <<
+	    " is not of type RooAbsReal" << std::endl ;
       assert(0) ;
     }
     _coefList.add(*coef) ;
@@ -74,11 +83,11 @@ RooChebychev::RooChebychev(const RooChebychev& other, const char* name) :
 {
 }
 
-inline static double p0(double ,double a) {  return a; }
-inline static double p1(double t,double a,double b) {  return a*t+b; }
-inline static double p2(double t,double a,double b,double c) {  return p1(t,p1(t,a,b),c); }
-inline static double p3(double t,double a,double b,double c,double d) {  return p2(t,p1(t,a,b),c,d); }
-inline static double p4(double t,double a,double b,double c,double d,double e) {  return p3(t,p1(t,a,b),c,d,e); }
+inline static double p0(double ,double a) { return a; }
+inline static double p1(double t,double a,double b) { return a*t+b; }
+inline static double p2(double t,double a,double b,double c) { return p1(t,p1(t,a,b),c); }
+inline static double p3(double t,double a,double b,double c,double d) { return p2(t,p1(t,a,b),c,d); }
+inline static double p4(double t,double a,double b,double c,double d,double e) { return p3(t,p1(t,a,b),c,d,e); }
 
 
 //_____________________________________________________________________________
@@ -97,20 +106,19 @@ Double_t RooChebychev::evaluate() const
   case  3: sum+=((RooAbsReal&)_coefList[2]).getVal()*x*p1(x2,4,-3);
   case  2: sum+=((RooAbsReal&)_coefList[1]).getVal()*p1(x2,2,-1);
   case  1: sum+=((RooAbsReal&)_coefList[0]).getVal()*x;
-  case  0: sum+=1;
+  case  0: sum+=1; break;
+  default: std::cerr << "In " << __my_func__ << " (" << __FILE__ << ", line " <<
+	       __LINE__ << "): Higher order Chebychev polynomials currently "
+	       "unimplemented." << std::endl;
+	   assert(false);
   }
   return sum;
 }
 
 
 //_____________________________________________________________________________
-Int_t RooChebychev::getAnalyticalIntegral(RooArgSet& allVars, RooArgSet& analVars, const char* rangeName) const 
+Int_t RooChebychev::getAnalyticalIntegral(RooArgSet& allVars, RooArgSet& analVars, const char* /* rangeName */) const 
 {
-  // No analytical calculation available (yet) of integrals over subranges
-  if (rangeName && strlen(rangeName)) {
-    return 0 ;
-  }
-
   if (matchArgs(allVars, analVars, _x)) return 1;
   return 0;
 }
@@ -119,19 +127,48 @@ Int_t RooChebychev::getAnalyticalIntegral(RooArgSet& allVars, RooArgSet& analVar
 //_____________________________________________________________________________
 Double_t RooChebychev::analyticalIntegral(Int_t code, const char* rangeName) const 
 {
-  assert(code==1) ;
-  // WVE check that this works all right for sub ranges
-  Double_t xmin = _x.min(rangeName); Double_t xmax = _x.max(rangeName);
-  Double_t norm(0) ;
-  switch(_coefList.getSize()) {
-  // coverity[MISSING_BREAK]
-  case  7: case  6: norm+=((RooAbsReal&)_coefList[5]).getVal()*(-1 + 18./3. - 48./5. + 32./7.);
-  // coverity[MISSING_BREAK]
-  case  5: case  4: norm+=((RooAbsReal&)_coefList[3]).getVal()*( 1 -  8./3. +  8./5.);
-  // coverity[MISSING_BREAK]
-  case  3: case  2: norm+=((RooAbsReal&)_coefList[1]).getVal()*(-1 +  2./3.);
-  case  1: case  0: norm+= 1;
+  assert(1 == code);
+
+  // the full range of the function is mapped to the normalised [-1, 1] range
+  const Double_t xminfull(_x.min()), xmaxfull(_x.max());
+  const Double_t fullRange = xmaxfull - xminfull;
+
+  // define limits of the integration range on a normalised scale
+  Double_t minScaled = -1., maxScaled = +1.;
+
+  // check to see if integral of a subrange is requested
+  if (rangeName && 0 != rangeName[0]) {
+    assert(xminfull <= _x.min(rangeName) && _x.min(rangeName) <= xmaxfull);
+    assert(xminfull <= _x.max(rangeName) && _x.max(rangeName) <= xmaxfull);
+    minScaled = -1. + 2. * (_x.min(rangeName) - xminfull) / fullRange;
+    maxScaled = +1. - 2. * (xmaxfull - _x.max(rangeName)) / fullRange;
   }
-  norm *= xmax-xmin;
-  return norm;
+
+  // return half of the range since the normalised range runs from -1 to 1
+  // which has a range of two
+  return 0.5 * fullRange * (evalAnaInt(maxScaled) - evalAnaInt(minScaled));
 }
+
+Double_t RooChebychev::evalAnaInt(const Double_t x) const
+{
+  const Double_t x2 = x * x;
+  Double_t sum = 0.;
+  switch (_coefList.getSize()) {
+    case  7: sum+=((RooAbsReal&)_coefList[6]).getVal()*x2*p3(x2,8.,-112./6.,14.,-7./2.);
+    case  6: sum+=((RooAbsReal&)_coefList[5]).getVal()*x*p3(x2,32./7.,-48./5.,6.,-1.);
+    case  5: sum+=((RooAbsReal&)_coefList[4]).getVal()*x2*p2(x2,16./6.,-5.,2.5);
+    case  4: sum+=((RooAbsReal&)_coefList[3]).getVal()*x*p2(x2,8./5.,-8./3.,1.);
+    case  3: sum+=((RooAbsReal&)_coefList[2]).getVal()*x2*p1(x2,1.,-3./2.);
+    case  2: sum+=((RooAbsReal&)_coefList[1]).getVal()*x*p1(x2,2./3.,-1.);
+    case  1: sum+=((RooAbsReal&)_coefList[0]).getVal()*x2*.5;
+    case  0: sum+=x; break;
+	     
+    default: std::cerr << "In " << __my_func__ << " (" << __FILE__ << ", line " <<
+	     __LINE__ << "): Higher order Chebychev polynomials currently "
+		 "unimplemented." << std::endl;
+	     assert(false);
+  }
+  return sum;
+}
+
+#undef __my_func__
