@@ -16,6 +16,8 @@
  *****************************************************************************/
 #include "RooFit.h"
 
+#include <limits>
+#include <algorithm>
 #include <math.h>
 #include "Riostream.h"
 #include "TMath.h"
@@ -64,7 +66,7 @@ RooKeysPdf::RooKeysPdf(const char *name, const char *title,
                        RooAbsReal& x, RooDataSet& data,
                        Mirror mirror, Double_t rho) :
   RooAbsPdf(name,title),
-  _x("x","Dependent",this,x),
+  _x("x","observable",this,x),
   _nEvents(0),
   _dataPts(0),
   _dataWgts(0),
@@ -77,7 +79,36 @@ RooKeysPdf::RooKeysPdf(const char *name, const char *title,
 {
   // cache stuff about x
   snprintf(_varName, 128,"%s", x.GetName());
-  RooRealVar real= (RooRealVar&)(_x.arg());
+  RooAbsRealLValue& real= (RooRealVar&)(_x.arg());
+  _lo = real.getMin();
+  _hi = real.getMax();
+  _binWidth = (_hi-_lo)/(_nPoints-1);
+
+  // form the lookup table
+  LoadDataSet(data);
+}
+
+
+
+//_____________________________________________________________________________
+RooKeysPdf::RooKeysPdf(const char *name, const char *title,
+                       RooAbsReal& xpdf, RooRealVar& xdata, RooDataSet& data,
+                       Mirror mirror, Double_t rho) :
+  RooAbsPdf(name,title),
+  _x("x","Observable",this,xpdf),
+  _nEvents(0),
+  _dataPts(0),
+  _dataWgts(0),
+  _weights(0),
+  _mirrorLeft(mirror==MirrorLeft || mirror==MirrorBoth || mirror==MirrorLeftAsymRight),
+  _mirrorRight(mirror==MirrorRight || mirror==MirrorBoth || mirror==MirrorAsymLeftRight),
+  _asymLeft(mirror==MirrorAsymLeft || mirror==MirrorAsymLeftRight || mirror==MirrorAsymBoth),
+  _asymRight(mirror==MirrorAsymRight || mirror==MirrorLeftAsymRight || mirror==MirrorAsymBoth),
+  _rho(rho)
+{
+  // cache stuff about x
+  snprintf(_varName, 128,"%s", xdata.GetName());
+  RooAbsRealLValue& real= (RooRealVar&)(xdata);
   _lo = real.getMin();
   _hi = real.getMax();
   _binWidth = (_hi-_lo)/(_nPoints-1);
@@ -150,7 +181,7 @@ RooKeysPdf::LoadDataSet( RooDataSet& data) {
   Int_t i, idata=0;
   for (i=0; i<data.numEntries(); i++) {
     const RooArgSet *values= data.get(i);
-    RooRealVar real= (RooRealVar&)(values->operator[](_varName));
+    RooRealVar& real= (RooRealVar&)(values->operator[](_varName));
 
     _dataPts[idata]= real.getVal();
     _dataWgts[idata] = data.weight() ;
@@ -197,24 +228,87 @@ RooKeysPdf::LoadDataSet( RooDataSet& data) {
 Double_t RooKeysPdf::evaluate() const {
   Int_t i = (Int_t)floor((Double_t(_x)-_lo)/_binWidth);
   if (i<0) {
-    cerr << "got point below lower bound:"
-	 << Double_t(_x) << " < " << _lo
-	 << " -- performing linear extrapolation..." << endl;
+//     cerr << "got point below lower bound:"
+// 	 << Double_t(_x) << " < " << _lo
+// 	 << " -- performing linear extrapolation..." << endl;
     i=0;
   }
   if (i>_nPoints-1) {
-    cerr << "got point above upper bound:"
-	 << Double_t(_x) << " > " << _hi
-	 << " -- performing linear extrapolation..." << endl;
+//     cerr << "got point above upper bound:"
+// 	 << Double_t(_x) << " > " << _hi
+// 	 << " -- performing linear extrapolation..." << endl;
     i=_nPoints-1;
   }
   Double_t dx = (Double_t(_x)-(_lo+i*_binWidth))/_binWidth;
   
   // for now do simple linear interpolation.
   // one day replace by splines...
-  return (_lookupTable[i]+dx*(_lookupTable[i+1]-_lookupTable[i]));
+  Double_t ret = (_lookupTable[i]+dx*(_lookupTable[i+1]-_lookupTable[i]));
+  if (ret<0) ret=0 ;
+  return ret ;
 }
 
+Int_t RooKeysPdf::getAnalyticalIntegral(
+	RooArgSet& allVars, RooArgSet& analVars, const char* /* rangeName */) const
+{
+  if (matchArgs(allVars, analVars, _x)) return 1;
+  return 0;
+}
+
+Double_t RooKeysPdf::analyticalIntegral(Int_t code, const char* rangeName) const
+{
+  assert(1 == code);
+  // this code is based on _lookupTable and uses linear interpolation, just as
+  // evaluate(); integration is done using the trapez rule
+  const Double_t xmin = std::max(_lo, _x.min(rangeName));
+  const Double_t xmax = std::min(_hi, _x.max(rangeName));
+  const Int_t imin = (Int_t)floor((xmin - _lo) / _binWidth);
+  const Int_t imax = std::min((Int_t)floor((xmax - _lo) / _binWidth),
+      _nPoints - 1);
+  Double_t sum = 0.;
+  // sum up complete bins in middle
+  if (imin + 1 < imax)
+    sum += _lookupTable[imin + 1] + _lookupTable[imax];
+  for (Int_t i = imin + 2; i < imax; ++i)
+    sum += 2. * _lookupTable[i];
+  sum *= _binWidth * 0.5;
+  // treat incomplete bins
+  const Double_t dxmin = (xmin - (_lo + imin * _binWidth)) / _binWidth;
+  const Double_t dxmax = (xmax - (_lo + imax * _binWidth)) / _binWidth;
+  if (imin < imax) {
+    // first bin
+    sum += _binWidth * (1. - dxmin) * 0.5 * (_lookupTable[imin + 1] +
+	_lookupTable[imin] + dxmin *
+	(_lookupTable[imin + 1] - _lookupTable[imin]));
+    // last bin
+    sum += _binWidth * dxmax * 0.5 * (_lookupTable[imax] +
+	_lookupTable[imax] + dxmax *
+	(_lookupTable[imax + 1] - _lookupTable[imax]));
+  } else if (imin == imax) {
+    // first bin == last bin
+    sum += _binWidth * (dxmax - dxmin) * 0.5 * (
+	_lookupTable[imin] + dxmin *
+	(_lookupTable[imin + 1] - _lookupTable[imin]) +
+	_lookupTable[imax] + dxmax *
+	(_lookupTable[imax + 1] - _lookupTable[imax]));
+  }
+  return sum;
+}
+
+Int_t RooKeysPdf::getMaxVal(const RooArgSet& vars) const
+{
+  if (vars.contains(*_x.absArg())) return 1;
+  return 0;
+}
+
+Double_t RooKeysPdf::maxVal(Int_t code) const
+{
+  assert(1 == code);
+  Double_t max = -std::numeric_limits<Double_t>::max();
+  for (Int_t i = 0; i <= _nPoints; ++i)
+    if (max < _lookupTable[i]) max = _lookupTable[i];
+  return max;
+}
 
 //_____________________________________________________________________________
 Double_t RooKeysPdf::evaluateFull( Double_t x ) const {
@@ -249,7 +343,6 @@ Double_t RooKeysPdf::evaluateFull( Double_t x ) const {
   return y/(sqrt2pi*_sumWgt);
 }
 
-
 //_____________________________________________________________________________
 Double_t RooKeysPdf::g(Double_t x,Double_t sigmav) const {
   
