@@ -28,6 +28,7 @@
 #include <map>
 #include <set>
 #include <deque>
+#include <stack>
 
 #include <iostream>
 
@@ -70,9 +71,9 @@ public:
   virtual ~RooAbsArg();
   RooAbsArg(const char *name, const char *title);
   RooAbsArg(const RooAbsArg& other, const char* name=0) ;
-  virtual TObject* clone(const char* newname) const = 0 ;
+  virtual TObject* clone(const char* newname=0) const = 0 ;
   virtual TObject* Clone(const char* newname=0) const { 
-    return clone(newname?newname:GetName()) ; 
+    return clone(newname) ; 
   }
   virtual RooAbsArg* cloneTree(const char* newname=0) const ;
 
@@ -395,7 +396,16 @@ public:
   inline OperMode operMode() const { return _operMode  ; }
   void setOperMode(OperMode mode, Bool_t recurseADirty=kTRUE) ; 
 
-  static UInt_t crc32(const char* data) ;
+  static UInt_t crc32(const char* data);
+  static UInt_t crc32(const char* data, ULong_t sz, UInt_t crc = 0);
+
+  static const UInt_t fnv1a32start = 2166136261u;
+  static UInt_t fnv1a32(const char* data);
+  static UInt_t fnv1a32(const char* data, ULong_t sz, UInt_t hash = fnv1a32start);
+
+  static const ULong64_t fnv1a64start = (ULong64_t(3421674724u) << 32) | ULong64_t(2216829733u);
+  static ULong64_t fnv1a64(const char* data);
+  static ULong64_t fnv1a64(const char* data, ULong_t sz, ULong64_t hash = fnv1a64start);
   
   Bool_t addOwnedComponents(const RooArgSet& comps) ;
   const RooArgSet* ownedComponents() const { return _ownedComponents ; }
@@ -481,7 +491,7 @@ public:
   RooAbsArg *findNewServer(const RooAbsCollection &newSet, Bool_t nameChange) const;
 
   RooExpensiveObjectCache& expensiveObjectCache() const ;
-  void setExpensiveObjectCache(RooExpensiveObjectCache& cache) { _eocache = &cache ; }  
+  virtual void setExpensiveObjectCache(RooExpensiveObjectCache& cache) { _eocache = &cache ; }  
 
   virtual Bool_t importWorkspaceHook(RooWorkspace&) { return kFALSE ; } ;
 
@@ -561,10 +571,14 @@ public:
   mutable TNamed* _namePtr ; //! Do not persist. Pointer to global instance of string that matches object named
   Bool_t _isConstant ; //! Cached isConstant status 
 
+/*   RooArgSet _leafNodeCache ; //! Cached leaf nodes */
+/*   RooArgSet _branchNodeCache //! Cached branch nodes     */
+
  public:  
   virtual void ioStreamerPass2() ;
   static void ioStreamerPass2Finalize() ;
   static std::map<RooAbsArg*,TRefArray*> _ioEvoList ; // temporary holding list for proxies needed in schema evolution  
+  static std::stack<RooAbsArg*> _ioReadStack ; // reading stack 
   
   ClassDef(RooAbsArg,6) // Abstract variable
 };
