@@ -98,10 +98,10 @@ public:
   
   // Constant term  optimizer interface
   virtual const RooAbsArg* cacheOwner() { return _cacheOwner ; }
-  virtual void cacheArgs(const RooAbsArg* owner, RooArgSet& varSet, const RooArgSet* nset=0) ;
+  virtual void cacheArgs(const RooAbsArg* owner, RooArgSet& varSet, const RooArgSet* nset=0, Bool_t skipZeroWeights=kTRUE) ;
   virtual void attachCache(const RooAbsArg* newOwner, const RooArgSet& cachedVars) ;
   virtual void resetCache() ;
-  virtual void recalculateCache(const RooArgSet* /*proj*/, Int_t firstEvent, Int_t lastEvent, Int_t stepSize) ;
+  virtual void recalculateCache(const RooArgSet* /*proj*/, Int_t firstEvent, Int_t lastEvent, Int_t stepSize, Bool_t skipZeroWeights) ;
 
   virtual void setArgStatus(const RooArgSet& set, Bool_t active) ;
 
@@ -599,7 +599,8 @@ public:
     // First try a match by name
     std::vector<RealVector*>::iterator iter = _realStoreList.begin() ;
     for (; iter!=_realStoreList.end() ; ++iter) {
-      if (std::string((*iter)->bufArg()->GetName())==real->GetName()) {
+      //if (std::string((*iter)->bufArg()->GetName())==real->GetName()) {
+      if ((*iter)->bufArg()->namePtr()==real->namePtr()) {
 	rv = (*iter) ;
 	return rv ;
       }
@@ -608,7 +609,8 @@ public:
     // Then check if an entry already exists for a full real    
     std::vector<RealFullVector*>::iterator iter2 = _realfStoreList.begin() ;
     for (; iter2!=_realfStoreList.end() ; ++iter2) {
-      if (std::string((*iter2)->bufArg()->GetName())==real->GetName()) {
+      //if (std::string((*iter2)->bufArg()->GetName())==real->GetName()) {
+      if ((*iter2)->bufArg()->namePtr()==real->namePtr()) {
 	// Return full vector as RealVector base class here
 	return (*iter2) ;
       }
