@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Project: RooFit                                                           *
  * Package: RooFitCore                                                       *
- * @(#)root/roofitcore:$Id: RooAbsAnaConvPdf.cxx 43190 2012-03-01 12:09:43Z wouter $
+ * @(#)root/roofitcore:$Id$
  * Authors:                                                                  *
  *   WV, Wouter Verkerke, UC Santa Barbara, verkerke@slac.stanford.edu       *
  *   DK, David Kirkby,    UC Irvine,         dkirkby@uci.edu                 *
@@ -70,6 +70,8 @@
 #include "RooConvCoefVar.h"
 #include "RooNameReg.h"
 
+using namespace std;
+
 ClassImp(RooAbsAnaConvPdf) 
 ;
 
@@ -231,7 +233,7 @@ Bool_t RooAbsAnaConvPdf::changeModel(const RooResolutionModel& newModel)
   }
   delete cIter ;
 
-  // Check if all convolutions were succesfully built
+  // Check if all convolutions were successfully built
   if (!allOK) {
     // Delete new basis functions created sofar
     TIterator* iter = newConvSet.createIterator() ;
@@ -262,22 +264,18 @@ RooAbsGenContext* RooAbsAnaConvPdf::genContext(const RooArgSet &vars, const RooD
   // and the smearing separately, adding them a posteriori. If this is not possible return
   // a (slower) generic generation context that uses accept/reject sampling
 
+  // Check if the resolution model specifies a special context to be used.
+  RooResolutionModel* conv = dynamic_cast<RooResolutionModel*>(_model.absArg());
+  assert(conv);
 
   RooArgSet* modelDep = _model.absArg()->getObservables(&vars) ;
   modelDep->remove(*convVar(),kTRUE,kTRUE) ;
   Int_t numAddDep = modelDep->getSize() ;
   delete modelDep ;
 
-  if (dynamic_cast<RooTruthModel*>(_model.absArg())) {
-    // Truth resolution model: use generic context explicitly allowing generation of convolution variable
-    RooArgSet forceDirect(*convVar()) ;
-    return new RooGenContext(*this,vars,prototype,auxProto,verbose,&forceDirect) ;
-  } 
-
   // Check if physics PDF and resolution model can both directly generate the convolution variable
   RooArgSet dummy ;
   Bool_t pdfCanDir = (getGenerator(*convVar(),dummy) != 0) ;
-  RooResolutionModel* conv = (RooResolutionModel*) _convSet.at(0) ;
   Bool_t resCanDir = conv && (conv->getGenerator(*convVar(),dummy)!=0) && conv->isDirectGenSafe(*convVar()) ;
 
   if (numAddDep>0 || !pdfCanDir || !resCanDir) {
@@ -291,6 +289,9 @@ RooAbsGenContext* RooAbsAnaConvPdf::genContext(const RooArgSet &vars, const RooD
     coutI(Generation) << "RooAbsAnaConvPdf::genContext(" << GetName() << ") Using regular accept/reject generator for convolution p.d.f because: " << reason.c_str() << endl ;    
     return new RooGenContext(*this,vars,prototype,auxProto,verbose) ;
   } 
+
+  RooAbsGenContext* context = conv->modelGenContext(*this, vars, prototype, auxProto, verbose);
+  if (context) return context;
   
   // Any other resolution model: use specialized generator context
   return new RooConvGenContext(*this,vars,prototype,auxProto,verbose) ;
