@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Project: RooFit                                                           *
  * Package: RooFitCore                                                       *
- * @(#)root/roofitcore:$Id: RooAbsCategory.cxx 41862 2011-11-10 09:44:32Z wouter $
+ * @(#)root/roofitcore:$Id$
  * Authors:                                                                  *
  *   WV, Wouter Verkerke, UC Santa Barbara, verkerke@slac.stanford.edu       *
  *   DK, David Kirkby,    UC Irvine,         dkirkby@uci.edu                 *
@@ -44,6 +44,8 @@
 #include "RooMsgService.h"
 #include "RooVectorDataStore.h"
 
+using namespace std;
+
 ClassImp(RooAbsCategory) 
 ;
 
@@ -191,6 +193,19 @@ Bool_t RooAbsCategory::operator==(const RooAbsArg& other)
 }
 
 
+//_____________________________________________________________________________
+Bool_t RooAbsCategory::isIdentical(const RooAbsArg& other, Bool_t assumeSameType)  
+{
+  if (!assumeSameType) {
+    const RooAbsCategory* otherCat = dynamic_cast<const RooAbsCategory*>(&other) ;
+    return otherCat ? operator==(otherCat->getIndex()) : kFALSE ;
+  } else {
+    return getIndex()==((RooAbsCategory&)other).getIndex() ;
+  }
+}
+
+
+
 
 //_____________________________________________________________________________
 Bool_t RooAbsCategory::isValidIndex(Int_t index) const
