@@ -449,13 +449,16 @@ Double_t RooAbsOptTestStatistic::combinedValue(RooAbsReal** array, Int_t n) cons
   // values
   
   // Default implementation returns sum of components
-  Double_t sum(0) ;
-  Int_t i ;
-  for (i=0 ; i<n ; i++) {
-    Double_t tmp = array[i]->getValV() ;
-    // if (tmp==0) return 0 ; WVE no longer needed
-    sum += tmp ;
+  Double_t sum(0), carry(0);
+  for (Int_t i = 0; i < n; ++i) {
+    Double_t y = array[i]->getValV();
+    carry += reinterpret_cast<RooAbsOptTestStatistic*>(array[i])->getCarry();
+    y -= carry;
+    const Double_t t = sum + y;
+    carry = (t - sum) - y;
+    sum = t;
   }
+  _evalCarry = carry;
   return sum ;
 }
 
@@ -701,8 +704,8 @@ void RooAbsOptTestStatistic::optimizeConstantTerms(Bool_t activate, Bool_t apply
 //     _funcClone->Print("t") ;
 
 
-    // Cache constant nodes with dataset 
-    _dataClone->cacheArgs(this,_cachedNodes,_normSet) ;  
+    // Cache constant nodes with dataset - also cache entries corresponding to zero-weights in data when using BinnedLikelihood
+    _dataClone->cacheArgs(this,_cachedNodes,_normSet,!_funcClone->getAttribute("BinnedLikelihood")) ;  
 
 //     cout << "ROATS::oCT(" << GetName() << ") funcClone structure dump AFTER cacheArgs" << endl ;
 //     _funcClone->Print("t") ;
@@ -721,10 +724,23 @@ void RooAbsOptTestStatistic::optimizeConstantTerms(Bool_t activate, Bool_t apply
     RooArgSet actualTrackNodes(_cachedNodes) ;
     actualTrackNodes.remove(*constNodes) ;
     if (constNodes->getSize()>0) {
-      coutI(Minimization) << " The following expressions have been identified as constant and will be precalculated and cached: " << *constNodes << endl ;
+      if (constNodes->getSize()<20) {
+	coutI(Minimization) << " The following expressions have been identified as constant and will be precalculated and cached: " << *constNodes << endl ;
+      } else {
+	coutI(Minimization) << " A total of " << constNodes->getSize() << " expressions have been identified as constant and will be precalculated and cached." << endl ;
+      }
+//       RooFIter i = constNodes->fwdIterator() ;
+//       RooAbsArg* cnode ;
+//       while((cnode=i.next())) {
+// 	cout << cnode->IsA()->GetName() << "::" << cnode->GetName() << endl ;
+//       }      
     }
     if (actualTrackNodes.getSize()>0) {
-      coutI(Minimization) << " The following expressions will be evaluated in cache-and-track mode: " << actualTrackNodes << endl ;
+      if (actualTrackNodes.getSize()<20) {
+	coutI(Minimization) << " The following expressions will be evaluated in cache-and-track mode: " << actualTrackNodes << endl ;
+      } else {
+	coutI(Minimization) << " A total of " << constNodes->getSize() << " expressions will be evaluated in cache-and-track-mode." << endl ;
+      }
     }
     delete constNodes ;
     
@@ -765,19 +781,6 @@ Bool_t RooAbsOptTestStatistic::setDataSlave(RooAbsData& indata, Bool_t cloneData
   // a range specification on the data, the cloneData argument is ignore and
   // the data is always cloned.
 
-//   static Bool_t first = kTRUE ;
-//   if (first) {
-//     cout << "RAOTS::setDataSlave(" << this << ") activating tracing" << endl ; 
-//     RooTrace::active(kTRUE) ;
-//     RooTrace::mark() ;
-//     first = kFALSE ;
-//   } else {
-//     cout << "RAOTS::setDataSlave(" << this << ") dump and mark" << endl ; 
-//     RooTrace::dump(cout,kTRUE) ;
-//     RooTrace::mark() ;
-//   }
-
-
 
   if (operMode()==SimMaster) {
     //cout << "ROATS::setDataSlave() ERROR this is SimMaster _funcClone = " << _funcClone << endl ;    
