@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Project: RooFit                                                           *
  * Package: RooFitCore                                                       *
- * @(#)root/roofitcore:$Id: RooAbsRealLValue.cxx 42984 2012-02-13 15:30:31Z wouter $
+ * @(#)root/roofitcore:$Id$
  * Authors:                                                                  *
  *   WV, Wouter Verkerke, UC Santa Barbara, verkerke@slac.stanford.edu       *
  *   DK, David Kirkby,    UC Irvine,         dkirkby@uci.edu                 *
@@ -59,6 +59,8 @@
 
 
 
+using namespace std;
+
 ClassImp(RooAbsRealLValue)
 
 //_____________________________________________________________________________
@@ -502,8 +504,9 @@ Bool_t RooAbsRealLValue::fitRangeOKForPlotting() const
 Bool_t RooAbsRealLValue::inRange(const char* name) const 
 {
   // Check if current value is inside range with given name
-
-  return (getVal() >= getMin(name) && getVal() <= getMax(name)) ;
+  Double_t val = getVal() ;
+  Double_t epsilon = 1e-8 * fabs(val) ;
+  return (val >= getMin(name)-epsilon && val <= getMax(name)+epsilon) ;
 }
 
 
