@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Project: RooFit                                                           *
  * Package: RooFitCore                                                       *
- * @(#)root/roofitcore:$Id: RooFitResult.cxx 44381 2012-05-31 06:45:52Z moneta $
+ * @(#)root/roofitcore:$Id$
  * Authors:                                                                  *
  *   WV, Wouter Verkerke, UC Santa Barbara, verkerke@slac.stanford.edu       *
  *   DK, David Kirkby,    UC Irvine,         dkirkby@uci.edu                 *
@@ -56,6 +56,8 @@
 
 
 
+using namespace std;
+
 ClassImp(RooFitResult) 
 ;
 
@@ -606,7 +608,7 @@ void RooFitResult::fillCorrMatrix(const std::vector<double>& globalCC, const TMa
   for(int i=0 ; i<_CM->GetNcols() ; i++) {
     (*_GC)[i] = globalCC[i] ;
   }
-  fillLegacyCorrMatrix() ;
+  //fillLegacyCorrMatrix() ;
 }
 
 
@@ -806,7 +808,7 @@ Bool_t RooFitResult::isIdentical(const RooFitResult& other, Double_t tol, Double
     }
   }
 
-  // Only examine correlations for cases with >1 floating paramater
+  // Only examine correlations for cases with >1 floating parameter
   if (_finalPars->getSize()>1) {
     
     fillLegacyCorrMatrix() ;
@@ -1246,7 +1248,7 @@ RooAbsPdf* RooFitResult::createHessePdf(const RooArgSet& params) const
   // Calculate offset vectors mu1 and mu2
   RooArgList mu1 ;
   for (UInt_t i=0 ; i<map1.size() ; i++) {
-    RooRealVar* parclone = (RooRealVar*) _finalPars->at(map1[i])->Clone(Form("%s_centralvalue",_finalPars->at(i)->GetName())) ;
+    RooRealVar* parclone = (RooRealVar*) _finalPars->at(map1[i])->Clone(Form("%s_centralvalue",_finalPars->at(map1[i])->GetName())) ;
     parclone->setConstant(kTRUE) ;
     mu1.add(*parclone) ;      
   }
