@@ -196,7 +196,9 @@ Bool_t RooListProxy::changePointer(const RooAbsCollection& newServerList, Bool_t
       TIterator* iter = newServerList.createIterator() ;
       RooAbsArg* arg ;
       while((arg=(RooAbsArg*)iter->Next())) {
-	add(*arg,kTRUE) ;
+	if (arg!=_owner) {
+	  add(*arg,kTRUE) ;
+	}
       }
       delete iter ;
     } else {
@@ -209,7 +211,7 @@ Bool_t RooListProxy::changePointer(const RooAbsCollection& newServerList, Bool_t
   while ((arg=(RooAbsArg*)_iter->Next())) {
     
     RooAbsArg* newArg= arg->findNewServer(newServerList, nameChange);
-    if (newArg) error |= !RooArgList::replace(*arg,*newArg) ;
+    if (newArg && newArg!=_owner) error |= !RooArgList::replace(*arg,*newArg) ;
   }
   return !error ;
 }
