@@ -185,6 +185,28 @@ void RooMinimizer::setStrategy(Int_t istrat)
 
 
 
+//_____________________________________________________________________________
+void RooMinimizer::setMaxIterations(Int_t n) 
+{
+  // Change maximum number of MINUIT iterations 
+  // (RooMinimizer default 500 * #parameters)
+  _theFitter->Config().MinimizerOptions().SetMaxIterations(n);
+}
+
+
+
+
+//_____________________________________________________________________________
+void RooMinimizer::setMaxFunctionCalls(Int_t n) 
+{
+  // Change maximum number of likelihood function calss from MINUIT
+  // (RooMinimizer default 500 * #parameters)
+  _theFitter->Config().MinimizerOptions().SetMaxFunctionCalls(n);
+}
+
+
+
+
 //_____________________________________________________________________________
 void RooMinimizer::setErrorLevel(Double_t level)
 {
@@ -229,6 +251,23 @@ void RooMinimizer::setMinimizerType(const char* type)
 
 
 
+//_____________________________________________________________________________
+ROOT::Fit::Fitter* RooMinimizer::fitter()
+{
+  // Return underlying ROOT fitter object 
+  return _theFitter ;
+}
+
+
+//_____________________________________________________________________________
+const ROOT::Fit::Fitter* RooMinimizer::fitter() const 
+{
+  // Return underlying ROOT fitter object 
+  return _theFitter ;
+}
+
+
+
 //_____________________________________________________________________________
 RooFitResult* RooMinimizer::fit(const char* options)
 {
