@@ -26,8 +26,11 @@
 // END_HTML
 //
 
+#include <algorithm>
+
 #include "RooFit.h"
 #include "Riostream.h"
+#include "TMath.h"
 
 #include "RooNLLVar.h"
 #include "RooAbsData.h"
@@ -36,9 +39,9 @@
 #include "RooMsgService.h"
 #include "RooAbsDataStore.h"
 #include "RooRealMPFE.h"
-
+#include "RooRealSumPdf.h"
 #include "RooRealVar.h"
-
+#include "RooProdPdf.h"
 
 ClassImp(RooNLLVar)
 ;
@@ -84,8 +87,12 @@ RooNLLVar::RooNLLVar(const char *name, const char* title, RooAbsPdf& pdf, RooAbs
   _extended = pc.getInt("extended") ;
   _weightSq = kFALSE ;
   _first = kTRUE ;
-  _offset = 0 ;
+  _offset = 0.;
+  _offsetCarry = 0.;
+  _offsetSaveW2 = 0.;
+  _offsetCarrySaveW2 = 0.;
 
+  _binnedPdf = 0 ;
 }
 
 
@@ -93,15 +100,44 @@ RooNLLVar::RooNLLVar(const char *name, const char* title, RooAbsPdf& pdf, RooAbs
 //_____________________________________________________________________________
 RooNLLVar::RooNLLVar(const char *name, const char *title, RooAbsPdf& pdf, RooAbsData& indata,
 		     Bool_t extended, const char* rangeName, const char* addCoefRangeName,
-		     Int_t nCPU, RooFit::MPSplit interleave, Bool_t verbose, Bool_t splitRange, Bool_t cloneData) : 
+		     Int_t nCPU, RooFit::MPSplit interleave, Bool_t verbose, Bool_t splitRange, Bool_t cloneData, Bool_t binnedL) : 
   RooAbsOptTestStatistic(name,title,pdf,indata,RooArgSet(),rangeName,addCoefRangeName,nCPU,interleave,verbose,splitRange,cloneData),
   _extended(extended),
   _weightSq(kFALSE),
-  _first(kTRUE)
+  _first(kTRUE), _offsetSaveW2(0.), _offsetCarrySaveW2(0.)
 {
   // Construct likelihood from given p.d.f and (binned or unbinned dataset)
   // For internal use.
 
+  // If binned likelihood flag is set, pdf is a RooRealSumPdf representing a yield vector
+  // for a binned likelihood calculation
+  _binnedPdf = binnedL ? (RooRealSumPdf*)_funcClone : 0 ;
+
+  // Retrieve and cache bin widths needed to convert unnormalized binnedPdf values back to yields
+  if (_binnedPdf) {
+
+    // The Active label will disable pdf integral calculations
+    _binnedPdf->setAttribute("BinnedLikelihoodActive") ;
+    
+    RooArgSet* obs = _funcClone->getObservables(_dataClone) ;
+    if (obs->getSize()!=1) {
+      _binnedPdf = 0 ;
+    } else {
+      RooRealVar* var = (RooRealVar*) obs->first() ;
+      std::list<Double_t>* boundaries = _binnedPdf->binBoundaries(*var,var->getMin(),var->getMax()) ;
+      std::list<Double_t>::iterator biter = boundaries->begin() ;
+      _binw.resize(boundaries->size()-1) ;
+      Double_t lastBound = (*biter) ;
+      biter++ ;
+      int ibin=0 ;
+      while (biter!=boundaries->end()) {
+	_binw[ibin] = (*biter) - lastBound ;
+	lastBound = (*biter) ;
+	ibin++ ;
+	biter++ ;
+      }
+    }
+  }
 }
 
 
@@ -109,16 +145,41 @@ RooNLLVar::RooNLLVar(const char *name, const char *title, RooAbsPdf& pdf, RooAbs
 //_____________________________________________________________________________
 RooNLLVar::RooNLLVar(const char *name, const char *title, RooAbsPdf& pdf, RooAbsData& indata,
 		     const RooArgSet& projDeps, Bool_t extended, const char* rangeName,const char* addCoefRangeName, 
-		     Int_t nCPU,RooFit::MPSplit interleave,Bool_t verbose, Bool_t splitRange, Bool_t cloneData) : 
+		     Int_t nCPU,RooFit::MPSplit interleave,Bool_t verbose, Bool_t splitRange, Bool_t cloneData, Bool_t binnedL) : 
   RooAbsOptTestStatistic(name,title,pdf,indata,projDeps,rangeName,addCoefRangeName,nCPU,interleave,verbose,splitRange,cloneData),
   _extended(extended),
   _weightSq(kFALSE),
-  _first(kTRUE)
+  _first(kTRUE), _offsetSaveW2(0.), _offsetCarrySaveW2(0.)
 {
   // Construct likelihood from given p.d.f and (binned or unbinned dataset)
   // For internal use.  
 
+  // If binned likelihood flag is set, pdf is a RooRealSumPdf representing a yield vector
+  // for a binned likelihood calculation
+  _binnedPdf = binnedL ? (RooRealSumPdf*)_funcClone : 0 ;
 
+  // Retrieve and cache bin widths needed to convert unnormalized binnedPdf values back to yields
+  if (_binnedPdf) {
+    
+    RooArgSet* obs = _funcClone->getObservables(_dataClone) ;
+    if (obs->getSize()!=1) {
+      _binnedPdf = 0 ;
+    } else {
+      RooRealVar* var = (RooRealVar*) obs->first() ;
+      std::list<Double_t>* boundaries = _binnedPdf->binBoundaries(*var,var->getMin(),var->getMax()) ;
+      std::list<Double_t>::iterator biter = boundaries->begin() ;
+      _binw.resize(boundaries->size()-1) ;
+      Double_t lastBound = (*biter) ;
+      biter++ ;
+      int ibin=0 ;
+      while (biter!=boundaries->end()) {
+	_binw[ibin] = (*biter) - lastBound ;
+	lastBound = (*biter) ;
+	ibin++ ;
+	biter++ ;
+      }
+    }
+  }
 }
 
 
@@ -128,9 +189,12 @@ RooNLLVar::RooNLLVar(const RooNLLVar& other, const char* name) :
   RooAbsOptTestStatistic(other,name),
   _extended(other._extended),
   _weightSq(other._weightSq),
-  _first(kTRUE)
-{
+  _first(kTRUE), _offsetSaveW2(other._offsetSaveW2),
+  _offsetCarrySaveW2(other._offsetCarrySaveW2),
+  _binw(other._binw) {
   // Copy constructor
+
+  _binnedPdf = other._binnedPdf ? (RooRealSumPdf*)_funcClone : 0 ;
 }
 
 
@@ -149,21 +213,18 @@ RooNLLVar::~RooNLLVar()
 void RooNLLVar::applyWeightSquared(Bool_t flag) 
 { 
   if (_gofOpMode==Slave) {
-    _weightSq = flag ; 
-    setValueDirty() ; 
-
-  } else if ( _gofOpMode==MPMaster) {
-
-    for (Int_t i=0 ; i<_nCPU ; i++) {
-      _mpfeArray[i]->applyNLLWeightSquared(flag) ;
-    }    
-
-  } else if ( _gofOpMode==SimMaster) {
-
-    for (Int_t i=0 ; i<_nGof ; i++) {
-      ((RooNLLVar*)_gofArray[i])->applyWeightSquared(flag) ;
+    if (flag != _weightSq) {
+      _weightSq = flag;
+      std::swap(_offset, _offsetSaveW2);
+      std::swap(_offsetCarry, _offsetCarrySaveW2);
     }
-
+    setValueDirty();
+  } else if ( _gofOpMode==MPMaster) {
+    for (Int_t i=0 ; i<_nCPU ; i++)
+      _mpfeArray[i]->applyNLLWeightSquared(flag);
+  } else if ( _gofOpMode==SimMaster) {
+    for (Int_t i=0 ; i<_nGof ; i++)
+      ((RooNLLVar*)_gofArray[i])->applyWeightSquared(flag);
   }
 } 
 
@@ -187,64 +248,125 @@ Double_t RooNLLVar::evaluatePartition(Int_t firstEvent, Int_t lastEvent, Int_t s
   RooAbsPdf* pdfClone = (RooAbsPdf*) _funcClone ;
 
   // cout << "RooNLLVar::evaluatePartition(" << GetName() << ") projDeps = " << (_projDeps?*_projDeps:RooArgSet()) << endl ;
-
-  _dataClone->store()->recalculateCache( _projDeps, firstEvent, lastEvent, stepSize ) ;
+  
+  _dataClone->store()->recalculateCache( _projDeps, firstEvent, lastEvent, stepSize,(_binnedPdf?kFALSE:kTRUE) ) ;
 
   Double_t sumWeight(0), sumWeightCarry(0);
-  for (i=firstEvent ; i<lastEvent ; i+=stepSize) {
-    
-    // get the data values for this event
-    //Double_t wgt = _dataClone->weight(i) ;
-    //if (wgt==0) continue ;
 
-    _dataClone->get(i) ;
-    //cout << "NLL - now loading event #" << i << endl ;
-//     _funcObsSet->Print("v") ;
-    
+  // If pdf is marked as binned - do a binned likelihood calculation here (sum of log-Poisson for each bin)
+  if (_binnedPdf) {
 
-    if (!_dataClone->valid()) continue;
+    for (i=firstEvent ; i<lastEvent ; i+=stepSize) {
+      
+      _dataClone->get(i) ;
+      
+      if (!_dataClone->valid()) continue;
+      
+      Double_t eventWeight = _dataClone->weight();
 
-    Double_t eventWeight = _dataClone->weight();
-    if (0. == eventWeight * eventWeight) continue ;
-    if (_weightSq) eventWeight = _dataClone->weightSquared() ;
 
-    Double_t term = -eventWeight * pdfClone->getLogVal(_normSet);
+      // Calculate log(Poisson(N|mu) for this bin
+      Double_t N = eventWeight ;
+      Double_t mu = _binnedPdf->getVal()*_binw[i] ; 
+      //cout << "RooNLLVar::binnedL(" << GetName() << ") N=" << N << " mu = " << mu << endl ;
 
-    Double_t y = eventWeight - sumWeightCarry;
-    Double_t t = sumWeight + y;
-    sumWeightCarry = (t - sumWeight) - y;
-    sumWeight = t;
+      if (mu<=0 && N>0) {
 
-    y = term - carry;
-    t = result + y;
-    carry = (t - result) - y;
-    result = t;
-  }
-  
-  // include the extended maximum likelihood term, if requested
-  if(_extended && _setNum==_extSet) {
-    if (_weightSq) {
+	// Catch error condition: data present where zero events are predicted
+	logEvalError(Form("Observed %f events in bin %d with zero event yield",N,i)) ;
+	
+      } else if (fabs(mu)<1e-10 && fabs(N)<1e-10) {
 
-      // Calculate sum of weights-squared here for extended term
-      Double_t sumW2(0), sumW2carry(0);
-      for (i=0 ; i<_dataClone->numEntries() ; i++) {
-	_dataClone->get(i);
-	Double_t y = _dataClone->weightSquared() - sumW2carry;
-	Double_t t = sumW2 + y;
-	sumW2carry = (t - sumW2) - y;
-	sumW2 = t;
+	// Special handling of this case since log(Poisson(0,0)=0 but can't be calculated with usual log-formula
+	// since log(mu)=0. No update of result is required since term=0.
+
+      } else {
+
+	Double_t term = -1*(-mu + N*log(mu) - TMath::LnGamma(N+1)) ;
+
+	// Kahan summation of sumWeight
+	Double_t y = eventWeight - sumWeightCarry;
+	Double_t t = sumWeight + y;
+	sumWeightCarry = (t - sumWeight) - y;
+	sumWeight = t;
+	
+	// Kahan summation of result
+	y = term - carry;
+	t = result + y;
+	carry = (t - result) - y;
+	result = t;
       }
-      Double_t y = pdfClone->extendedTerm(sumW2 , _dataClone->get()) - carry;
-      Double_t t = result + y;
-      carry = (t - result) - y;
-      result = t;
-    } else {
-      Double_t y = pdfClone->extendedTerm(_dataClone->sumEntries(), _dataClone->get()) - carry;
-      Double_t t = result + y;
+    }
+
+
+  } else {
+
+    for (i=firstEvent ; i<lastEvent ; i+=stepSize) {
+            
+      _dataClone->get(i) ;
+      
+      if (!_dataClone->valid()) continue;
+      
+      Double_t eventWeight = _dataClone->weight();
+      if (0. == eventWeight * eventWeight) continue ;
+      if (_weightSq) eventWeight = _dataClone->weightSquared() ;
+      
+      Double_t term = -eventWeight * pdfClone->getLogVal(_normSet);
+      
+      
+      Double_t y = eventWeight - sumWeightCarry;
+      Double_t t = sumWeight + y;
+      sumWeightCarry = (t - sumWeight) - y;
+      sumWeight = t;
+      
+      y = term - carry;
+      t = result + y;
       carry = (t - result) - y;
       result = t;
     }
-  }    
+    
+    // include the extended maximum likelihood term, if requested
+    if(_extended && _setNum==_extSet) {
+      if (_weightSq) {
+	
+	// Calculate sum of weights-squared here for extended term
+	Double_t sumW2(0), sumW2carry(0);
+	for (i=0 ; i<_dataClone->numEntries() ; i++) {
+	  _dataClone->get(i);
+	  Double_t y = _dataClone->weightSquared() - sumW2carry;
+	  Double_t t = sumW2 + y;
+	  sumW2carry = (t - sumW2) - y;
+	  sumW2 = t;
+
+
+	}
+
+	Double_t expected= pdfClone->expectedEvents(_dataClone->get());
+		
+	// Adjust calculation of extended term with W^2 weighting: adjust poisson such that 
+	// estimate of Nexpected stays at the same value, but has a different variance, rescale
+        // both the observed and expected count of the Poisson with a factor sum[w] / sum[w^2]
+	// i.e. change Poisson(Nobs = sum[w]| Nexp ) --> Poisson( sum[w] * sum[w] / sum[w^2] | Nexp * sum[w] / sum[w^2] )
+
+	Double_t observedW2 = ( _dataClone->sumEntries() * _dataClone->sumEntries() ) / sumW2 ;
+	Double_t expectedW2 = expected * _dataClone->sumEntries() / sumW2 ;
+	Double_t extra= expectedW2 - observedW2*log(expectedW2);	
+
+	// Double_t y = pdfClone->extendedTerm(sumW2, _dataClone->get()) - carry;
+	    
+	Double_t y = extra - carry ;
+	Double_t t = result + y;
+	carry = (t - result) - y;
+	result = t;
+      } else {
+	Double_t y = pdfClone->extendedTerm(_dataClone->sumEntries(), _dataClone->get()) - carry;
+	Double_t t = result + y;
+	carry = (t - result) - y;
+	result = t;
+      }
+    }    
+  }
+
 
   // If part of simultaneous PDF normalize probability over 
   // number of simultaneous PDFs: -sum(log(p/n)) = -sum(log(p)) + N*log(n) 
@@ -270,7 +392,7 @@ Double_t RooNLLVar::evaluatePartition(Int_t firstEvent, Int_t lastEvent, Int_t s
     
     // If no offset is stored enable this feature now
     if (_offset==0 && result !=0 ) {
-      coutI(Minimization) << "RooNLLVar::evaluatePartition(" << GetName() << ") first = "<< firstEvent << " last = " << lastEvent << " Likelihood offset now set to " << result << endl ;
+      coutI(Minimization) << "RooNLLVar::evaluatePartition(" << GetName() << ") first = "<< firstEvent << " last = " << lastEvent << " Likelihood offset now set to " << result << std::endl ;
       _offset = result ;
       _offsetCarry = carry;
     }
@@ -281,7 +403,9 @@ Double_t RooNLLVar::evaluatePartition(Int_t firstEvent, Int_t lastEvent, Int_t s
     carry = (t - result) - y;
     result = t;
   }
+
     
+  _evalCarry = carry;
   return result ;
 }
 
