@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Project: RooFit                                                           *
  * Package: RooFitCore                                                       *
- * @(#)root/roofitcore:$Id: RooPlot.cxx 44381 2012-05-31 06:45:52Z moneta $
+ * @(#)root/roofitcore:$Id$
  * Authors:                                                                  *
  *   WV, Wouter Verkerke, UC Santa Barbara, verkerke@slac.stanford.edu       *
  *   DK, David Kirkby,    UC Irvine,         dkirkby@uci.edu                 *
@@ -69,9 +69,16 @@
 #include <string.h>
 #include <assert.h>
 
+using namespace std;
+
 ClassImp(RooPlot)
 ;
 
+Bool_t RooPlot::_addDirStatus = kTRUE ;
+
+Bool_t RooPlot::addDirectoryStatus() { return _addDirStatus ; }
+Bool_t RooPlot::setAddDirectoryStatus(Bool_t flag) { Bool_t ret = flag ; _addDirStatus = flag ; return ret ; }
+
 
 //_____________________________________________________________________________
 RooPlot::RooPlot() : _hist(0), _plotVarClone(0), _plotVarSet(0), _normVars(0), _normObj(0), _dir(0)
@@ -81,7 +88,7 @@ RooPlot::RooPlot() : _hist(0), _plotVarClone(0), _plotVarSet(0), _normVars(0), _
 
   _iterator= _items.MakeIterator() ;
 
-  if (gDirectory) {
+  if (gDirectory && addDirectoryStatus()) {
     _dir = gDirectory ;
     gDirectory->Append(this) ;
   }
@@ -95,10 +102,15 @@ RooPlot::RooPlot(Double_t xmin, Double_t xmax) :
 {
   // Constructor of RooPlot with range [xmin,xmax]
 
-  Bool_t addDirectoryStatus = TH1::AddDirectoryStatus();
+  Bool_t histAddDirStatus = TH1::AddDirectoryStatus();
   TH1::AddDirectory(kFALSE) ;
+
   _hist = new TH1D(histName(),"A RooPlot",100,xmin,xmax) ;
-  TH1::AddDirectory(addDirectoryStatus) ;
+  _hist->Sumw2(kFALSE) ;
+  _hist->GetSumw2()->Set(0) ;
+
+  
+  TH1::AddDirectory(histAddDirStatus) ;
 
 
   // Create an empty frame with the specified x-axis limits.
@@ -115,10 +127,14 @@ RooPlot::RooPlot(Double_t xmin, Double_t xmax, Double_t ymin, Double_t ymax) :
 {
   // Construct of a two-dimensioanl RooPlot with ranges [xmin,xmax] x [ymin,ymax]
 
-  Bool_t addDirectoryStatus = TH1::AddDirectoryStatus();
+  Bool_t histAddDirStatus = TH1::AddDirectoryStatus();
   TH1::AddDirectory(kFALSE) ;
+
   _hist = new TH1D(histName(),"A RooPlot",100,xmin,xmax) ;
-  TH1::AddDirectory(addDirectoryStatus) ;
+  _hist->Sumw2(kFALSE) ;
+  _hist->GetSumw2()->Set(0) ;
+
+  TH1::AddDirectory(histAddDirStatus) ;
 
   SetMinimum(ymin);
   SetMaximum(ymax);
@@ -134,10 +150,14 @@ RooPlot::RooPlot(const RooAbsRealLValue &var1, const RooAbsRealLValue &var2) :
   // Construct a two-dimensional RooPlot with ranges and properties taken
   // from variables var1 and var2
 
-  Bool_t addDirectoryStatus = TH1::AddDirectoryStatus();
+  Bool_t histAddDirStatus = TH1::AddDirectoryStatus();
   TH1::AddDirectory(kFALSE) ;
+
   _hist = new TH1D(histName(),"A RooPlot",100,var1.getMin(),var1.getMax()) ;
-  TH1::AddDirectory(addDirectoryStatus) ;
+  _hist->Sumw2(kFALSE) ;
+  _hist->GetSumw2()->Set(0) ;
+
+  TH1::AddDirectory(histAddDirStatus) ;
 
   if(!var1.hasMin() || !var1.hasMax()) {
     coutE(InputArguments) << "RooPlot::RooPlot: cannot create plot for variable without finite limits: "
@@ -167,10 +187,14 @@ RooPlot::RooPlot(const RooAbsRealLValue &var1, const RooAbsRealLValue &var2,
   // from variables var1 and var2 but with an overriding range definition
   // of [xmin,xmax] x [ymin,ymax]
 
-  Bool_t addDirectoryStatus = TH1::AddDirectoryStatus();
+  Bool_t histAddDirStatus = TH1::AddDirectoryStatus();
   TH1::AddDirectory(kFALSE) ;
+
   _hist = new TH1D(histName(),"A RooPlot",100,xmin,xmax) ;
-  TH1::AddDirectory(addDirectoryStatus) ;
+  _hist->Sumw2(kFALSE) ;
+  _hist->GetSumw2()->Set(0) ;
+
+  TH1::AddDirectory(histAddDirStatus) ;
 
   SetMinimum(ymin);
   SetMaximum(ymax);
@@ -188,10 +212,14 @@ RooPlot::RooPlot(const char* name, const char* title, const RooAbsRealLValue &va
   // Create an 1-dimensional with all properties taken from 'var', but
   // with an explicit range [xmin,xmax] and a default binning of 'nbins'
 
-  Bool_t addDirectoryStatus = TH1::AddDirectoryStatus();
+  Bool_t histAddDirStatus = TH1::AddDirectoryStatus();
   TH1::AddDirectory(kFALSE) ;
+
   _hist = new TH1D(name,title,nbins,xmin,xmax) ;
-  TH1::AddDirectory(addDirectoryStatus) ;
+  _hist->Sumw2(kFALSE) ;
+  _hist->GetSumw2()->Set(0) ;
+
+  TH1::AddDirectory(histAddDirStatus) ;
 
   // plotVar can be a composite in case of a RooDataSet::plot, need deepClone
   _plotVarSet = (RooArgSet*) RooArgSet(var).snapshot() ;
@@ -214,10 +242,14 @@ RooPlot::RooPlot(const RooAbsRealLValue &var, Double_t xmin, Double_t xmax, Int_
   // Create an 1-dimensional with all properties taken from 'var', but
   // with an explicit range [xmin,xmax] and a default binning of 'nbins'
 
-  Bool_t addDirectoryStatus = TH1::AddDirectoryStatus();
+  Bool_t histAddDirStatus = TH1::AddDirectoryStatus();
   TH1::AddDirectory(kFALSE) ;
+
   _hist = new TH1D(histName(),"RooPlot",nbins,xmin,xmax) ;
-  TH1::AddDirectory(addDirectoryStatus) ;
+  _hist->Sumw2(kFALSE) ;
+  _hist->GetSumw2()->Set(0) ;
+
+  TH1::AddDirectory(histAddDirStatus) ;
 
   // plotVar can be a composite in case of a RooDataSet::plot, need deepClone
   _plotVarSet = (RooArgSet*) RooArgSet(var).snapshot() ;
@@ -255,7 +287,7 @@ void RooPlot::initialize()
 
   SetName(histName()) ;
 
-  if (gDirectory) {
+  if (gDirectory && addDirectoryStatus()) {
     _dir = gDirectory ;
     gDirectory->Append(this) ;
   }
@@ -502,6 +534,8 @@ void RooPlot::updateYAxis(Double_t ymin, Double_t ymax, const char *label)
   if(GetMaximum() < ymax) {
     _defYmax = ymax ;
     SetMaximum(ymax);
+    // if we don't do this - Unzoom on y-axis will reset upper bound to 1 
+    _hist->SetBinContent(1,ymax) ; 
   }
   if(GetMinimum() > ymin) {
     _defYmin = ymin ;
@@ -514,13 +548,23 @@ void RooPlot::updateYAxis(Double_t ymin, Double_t ymax, const char *label)
 
 
 //_____________________________________________________________________________
-void RooPlot::Draw(Option_t *options)
+void RooPlot::Draw(Option_t *option)
 {
   // Draw this plot and all of the elements it contains. The specified options
   // only apply to the drawing of our frame. The options specified in our add...()
   // methods will be used to draw each object we contain.
 
-  _hist->Draw(options);
+  TString optArg = option ;
+  optArg.ToLower() ;
+
+  // This draw options prevents the histogram with one dummy entry 
+  // to be drawn 
+  if (optArg.Contains("same")) {
+    _hist->Draw("FUNCSAME");
+  } else {
+    _hist->Draw("FUNC");
+  }
+
   _iterator->Reset();
   TObject *obj = 0;
   while((obj= _iterator->Next())) {
