@@ -1,7 +1,7 @@
 /*****************************************************************************
  * Project: RooFit                                                           *
  * Package: RooFitCore                                                       *
- * @(#)root/roofitcore:$Id: RooProdPdf.cxx 42984 2012-02-13 15:30:31Z wouter $
+ * @(#)root/roofitcore:$Id$
  * Authors:                                                                  *
  *   WV, Wouter Verkerke, UC Santa Barbara, verkerke@slac.stanford.edu       *
  *   DK, David Kirkby,    UC Irvine,         dkirkby@uci.edu                 *
@@ -95,6 +95,8 @@ static char *strtok_r(char *s1, const char *s2, char **lasts)
 
 #include "TSystem.h"
 
+using namespace std;
+
 ClassImp(RooProdPdf)
 ;
 
@@ -1744,6 +1746,8 @@ std::vector<RooAbsReal*> RooProdPdf::processProductTerm(const RooArgSet* nset, c
 
     const char* name = makeRGPPName("GENPROJ_",*term,termISet,termNSet,isetRangeName) ;
     RooAbsReal* partInt = new RooGenProdProj(name,name,*term,termISet,termNSet,isetRangeName,normRange()) ;
+    partInt->setExpensiveObjectCache(expensiveObjectCache()) ;
+    
     partInt->setStringAttribute("PROD_TERM_TYPE","IVa") ;
     //partInt->setOperMode(operMode()) ;
 
