@@ -42,7 +42,6 @@
 #include "RooRealConstant.h"
 #include "RooResolutionModel.h"
 #include "RooExpensiveObjectCache.h"
-#include "RooMath.h"
 
 Bool_t RooSentinel::_active = kFALSE ;
 
@@ -59,7 +58,6 @@ static void CleanUpRooFitAtExit()
   RooArgSet::cleanup() ;
   RooRealConstant::cleanup() ;
   RooResolutionModel::cleanup() ;
-  RooMath::cleanup() ;
   RooExpensiveObjectCache::cleanup() ;
 }
 
