@@ -1076,7 +1076,7 @@ struct less_dep : public binary_function<RooAbsArg*, RooAbsArg*, bool> {
 };
 
 //_____________________________________________________________________________
-void RooVectorDataStore::cacheArgs(const RooAbsArg* owner, RooArgSet& newVarSet, const RooArgSet* nset) 
+void RooVectorDataStore::cacheArgs(const RooAbsArg* owner, RooArgSet& newVarSet, const RooArgSet* nset, Bool_t skipZeroWeights) 
 {
   // Cache given RooAbsArgs with this tree: The tree is
   // given direct write access of the args internal cache
@@ -1203,7 +1203,7 @@ void RooVectorDataStore::cacheArgs(const RooAbsArg* owner, RooArgSet& newVarSet,
   newCache->reserve(numEntries());
   for (int i=0 ; i<numEntries() ; i++) {
     getNative(i) ;
-    if (weight()!=0) {    
+    if (weight()!=0 || !skipZeroWeights) {    
       cIter->Reset() ;
       vector<RooArgSet*>::iterator niter = nsetList.begin() ;
       while((cloneArg=(RooAbsArg*)cIter->Next())) {
@@ -1260,7 +1260,7 @@ void RooVectorDataStore::cacheArgs(const RooAbsArg* owner, RooArgSet& newVarSet,
 
 typedef RooVectorDataStore::RealVector* pRealVector ;
 //_____________________________________________________________________________
-void RooVectorDataStore::recalculateCache( const RooArgSet *projectedArgs, Int_t firstEvent, Int_t lastEvent, Int_t stepSize) 
+void RooVectorDataStore::recalculateCache( const RooArgSet *projectedArgs, Int_t firstEvent, Int_t lastEvent, Int_t stepSize, Bool_t skipZeroWeights) 
 {
   if (!_cache) return ;
 
@@ -1300,7 +1300,7 @@ void RooVectorDataStore::recalculateCache( const RooArgSet *projectedArgs, Int_t
   for (int i=firstEvent ; i<lastEvent ; i+=stepSize) {
     get(i) ;    
     Bool_t zeroWeight = (weight()==0) ;
-    if (!zeroWeight) {
+    if (!zeroWeight || !skipZeroWeights) {
       for (int j=0 ; j<ntv ; j++) {
 	tv[j]->_nativeReal->_valueDirty=kTRUE ;
 	tv[j]->_nativeReal->getValV(tv[j]->_nset ? tv[j]->_nset : usedNset) ;
