@@ -1,4 +1,4 @@
-// @(#)root/roostats:$Id: HybridCalculatorOriginal.cxx 35810 2010-09-27 20:05:22Z moneta $
+// @(#)root/roostats:$Id$
 
 /*************************************************************************
  * Project: RooStats                                                     *
@@ -73,6 +73,8 @@ see also the following interesting references:
 
 #include "RooStats/HybridCalculatorOriginal.h"
 
+using namespace std;
+
 ClassImp(RooStats::HybridCalculatorOriginal)
 
 using namespace RooStats;
@@ -122,7 +124,7 @@ HybridCalculatorOriginal::HybridCalculatorOriginal( RooAbsPdf& sbModel,
 
    // observables are managed by the class (they are copied in) 
   fObservables = new RooArgList(observables);
-  //Try to recover the informations from the pdf's
+  //Try to recover the information from the pdf's
   //fObservables=new RooArgList("fObservables");
   //fNuisanceParameters=new RooArgSet("fNuisanceParameters");
   // if (priorPdf){
