@@ -106,11 +106,7 @@ RooDataSet* ToyMCImportanceSampler::GetSamplingDistributionsSingleWorker(RooArgS
 //       cout << endl << endl << "Reweighted data columns: " << endl;
 //       columns.Print("v");
 //       cout << endl;
-         // Store dataset as a tree - problem with VectorStore and StoreError (bug #94908)
-         RooAbsData::StorageType defStore = RooAbsData::getDefaultStorageType();
-         RooAbsData::setDefaultStorageType(RooAbsData::Tree);
          fullResult = new RooDataSet( result->GetName(), result->GetTitle(), columns, "weight" );
-         RooAbsData::setDefaultStorageType(defStore);
       }
 
       for( int j=0; j < result->numEntries(); j++ ) {
@@ -248,7 +244,7 @@ RooAbsData* ToyMCImportanceSampler::GenerateToyData(
    }
 
    if( fNullDensities.size() == 0 ) {
-      oocoutE((TObject*)NULL,InputArguments) << "ToyMCImportanceSampler: Need to specify the null density explicitely." << endl;
+      oocoutE((TObject*)NULL,InputArguments) << "ToyMCImportanceSampler: Need to specify the null density explicitly." << endl;
       return NULL;
    }
    
@@ -358,7 +354,8 @@ RooAbsData* ToyMCImportanceSampler::GenerateToyData(
       *allVars = *fNullSnapshots[i];
       if( !fNullNLLs[i] ) {
          RooArgSet* allParams = fNullDensities[i]->getParameters(*data);
-         fNullNLLs[i] = fNullDensities[i]->createNLL(*data, RooFit::CloneData(kFALSE), RooFit::Constrain(*allParams));
+         fNullNLLs[i] = fNullDensities[i]->createNLL(*data, RooFit::CloneData(kFALSE), RooFit::Constrain(*allParams),
+                                                     RooFit::ConditionalObservables(fConditionalObs));
          delete allParams;
       }else{
          fNullNLLs[i]->setData( *data, kFALSE );
@@ -381,7 +378,8 @@ RooAbsData* ToyMCImportanceSampler::GenerateToyData(
       if( fImportanceSnapshots[i] ) *allVars = *fImportanceSnapshots[i];
       if( !fImpNLLs[i] ) {
          RooArgSet* allParams = fImportanceDensities[i]->getParameters(*data);
-         fImpNLLs[i] = fImportanceDensities[i]->createNLL(*data, RooFit::CloneData(kFALSE), RooFit::Constrain(*allParams));
+         fImpNLLs[i] = fImportanceDensities[i]->createNLL(*data, RooFit::CloneData(kFALSE), RooFit::Constrain(*allParams), 
+                                                          RooFit::ConditionalObservables(fConditionalObs));
          delete allParams;
       }else{
          fImpNLLs[i]->setData( *data, kFALSE );
