@@ -35,6 +35,7 @@
 // *******************Deleting the data files****************************
 // **********************************************************************
 
+#include <stdlib.h>
 #include "TApplication.h"
 #include "TEntryList.h"
 #include "TEventList.h"
@@ -523,7 +524,7 @@ void MakeTrees(Int_t nentries, Int_t nfiles)
 
    char buffer[50];
    for (Int_t ifile=0; ifile<nfiles; ifile++){
-      sprintf(buffer, "stressEntryListTrees_%d.root", ifile);
+      snprintf(buffer,50, "stressEntryListTrees_%d.root", ifile);
       f1 = new TFile(buffer, "UPDATE");
       tree1 = new TTree("tree1", "tree1");
       tree1->Branch("x", &x, "x/D");
@@ -556,7 +557,7 @@ void CleanUp(Int_t nfiles)
 {
    char buffer[50];
    for (Int_t i=0; i<nfiles; i++){
-      sprintf(buffer, "stressEntryListTrees_%d.root", i);
+      snprintf(buffer,50, "stressEntryListTrees_%d.root", i);
       gSystem->Unlink(buffer);
    }
 }
