@@ -53,6 +53,7 @@
 //                                                                           //
 //*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*_*//
 
+#include <stdlib.h>
 #include "TVirtualFitter.h"
 #include "TSystem.h"
 #include "TROOT.h"
@@ -73,7 +74,7 @@ void StatusPrint(Int_t id,const TString &title,Bool_t status)
   // Print test program number and its title
   const Int_t kMAX = 65;
   Char_t number[4];
-  sprintf(number,"%2d",id);
+  snprintf(number,4,"%2d",id);
   TString header = TString("Test ")+number+" : "+title;
   const Int_t nch = header.Length();
   for (Int_t i = nch; i < kMAX; i++) header += '.';
@@ -645,11 +646,18 @@ Int_t stressFit(const char *theFitter, Int_t N)
   Bool_t UNIX = strcmp(gSystem->GetName(), "Unix") == 0;
   printf("******************************************************************\n");
   if (UNIX) {
-    FILE *fp = gSystem->OpenPipe("uname -a", "r");
-    Char_t line[60];
-    fgets(line,60,fp); line[59] = 0;
-    printf("*  SYS: %s\n",line);
-    gSystem->ClosePipe(fp);
+     TString sp = gSystem->GetFromPipe("uname -a");
+     sp.Resize(60);
+     printf("*  SYS: %s\n",sp.Data());
+     if (strstr(gSystem->GetBuildNode(),"Linux")) {
+        sp = gSystem->GetFromPipe("lsb_release -d -s");
+        printf("*  SYS: %s\n",sp.Data());
+     }
+     if (strstr(gSystem->GetBuildNode(),"Darwin")) {
+        sp  = gSystem->GetFromPipe("sw_vers -productVersion");
+        sp += " Mac OS X ";
+        printf("*  SYS: %s\n",sp.Data());
+     }
   } else {
     const Char_t *os = gSystem->Getenv("OS");
     if (!os) printf("*  SYS: Windows 95\n");
@@ -681,6 +689,10 @@ int main(int argc,const char *argv[])
   gBenchmark = new TBenchmark();
   const char *fitter = "Minuit";
   if (argc > 1)  fitter = argv[1];
+  if (strcmp(fitter,"Minuit") && strcmp(fitter,"Minuit2") && strcmp(fitter,"Fumili")) {
+     printf("stressFit illegal option %s, using Minuit instead\n",fitter);
+     fitter = "Minuit";
+  }
   Int_t N = 2000;
   if (argc > 2) N = atoi(argv[2]);
   stressFit(fitter,N);  //default is Minuit
