@@ -30,8 +30,8 @@
 //    > ./stressMathMore
 //
 // to run inside ROOT using ACliC
-//  for using CINT you need first to have the library libTrackMathCoreCint.so 
-//   (type:  make libTrackMathCoreCint.so to make it)
+//  for using CINT you need first to have the library libTrackMathCoreDict.so 
+//   (type:  make libTrackMathCoreDict.so to make it)
 //  
 //   root> gSystem->Load("libMathCore");
 //   root> gSystem->Load("libTree");
@@ -56,7 +56,6 @@
 #ifndef __CINT__
 
 
-
 #include "Math/DistFuncMathCore.h"
 #ifdef USE_MATHMORE
 #include "Math/DistMathMore.h"
@@ -187,6 +186,8 @@ struct Evaluator<Func, 3> {
    }
 };
 
+// global test variable 
+int NFuncTest = 100; 
 
 // statistical function class 
 // template on the number of parameters
@@ -210,6 +211,7 @@ public:
    void SetParameters(double p0) { *fParams = p0; }
    void SetParameters(double p0, double p1) { *fParams = p0; *(fParams+1) = p1; }
    void SetParameters(double p0, double p1, double p2) { *fParams = p0; *(fParams+1) = p1; *(fParams+2) = p2; }
+   static void SetNTest(int n) { NFuncTest = n; }
 
    double Cdf(double x) const { 
       return Evaluator<Func,NPAR>::F(fCdf,x, fParams); 
@@ -227,17 +229,12 @@ public:
    void ScaleTol1(double s) { fScale1 *= s; }  
    void ScaleTol2(double s) { fScale2 *= s; }
 
-   //for building a TF1
-   using ROOT::Math::IParamFunction::operator();
-
-   double operator()(const double* x, const double *)  { 
-      return DoEval(*x);
-   }
 
 private: 
 
 
-   double DoEval(double x) const { 
+   double DoEvalPar(double x, const double * ) const { 
+      // implement explicitly using cached parameter values
       return Evaluator<Func,NPAR>::F(fPdf,x, fParams); 
    }
 
@@ -255,7 +252,6 @@ template<class F1, class F2, int N1, int N2>
 int StatFunction<F1,F2,N1,N2>::Test(double xmin, double xmax, double xlow, double xup, bool c) {
 
    int iret = 0; 
-   int NFuncTest = 100; 
 
    // scan all values from xmin to xmax
    double dx = (xmax-xmin)/NFuncTest; 
@@ -360,6 +356,7 @@ typedef StatFunction<F2,F1,2>   Dist_gaussian;
 typedef StatFunction<F3,F2,3>   Dist_lognormal; 
 typedef StatFunction<F2,F1,2>   Dist_tdistribution; 
 typedef StatFunction<F2,F1,2>   Dist_exponential; 
+typedef StatFunction<F2,F1,2>   Dist_landau; 
 typedef StatFunction<F3,F2,3>   Dist_uniform; 
 
  
@@ -377,11 +374,11 @@ int TestDist(Distribution & d, double x1, double x2) {
    return ir; 
 }
 
-int testStatFunctions(int /* nfunc */) { 
+int testStatFunctions(int nfunc = 100 ) { 
    // test statistical functions 
    
    int iret = 0; 
-   //NFuncTest = nfunc; 
+   NFuncTest = nfunc; 
 
 
    { 
@@ -505,6 +502,21 @@ int testStatFunctions(int /* nfunc */) {
       distc.ScaleTol2(100);
       iret |= distc.Test(0.,5.,0.,1.,true);
    }
+   { 
+      PrintTest("Landau distribution"); 
+      CREATE_DIST(landau);
+      dist.SetParameters( 2);
+       // Landau is not very precise (put prec at 10-6)
+      // as indicated in Landau paper (
+      dist.ScaleTol1(10000);  
+      dist.ScaleTol2(1.E10);
+      iret |= dist.Test(-1,10,-10.,1.E10);
+      CREATE_DIST_C(landau);
+      distc.SetParameters( 2);
+      distc.ScaleTol1(10000);  
+      distc.ScaleTol2(1.0E10);
+      iret |= distc.Test(-1,10,-10.,1.E10,true);
+   }
 
    { 
       PrintTest("Uniform distribution"); 
@@ -1097,7 +1109,7 @@ int testVector(int ngen, bool testio=false) {
    double sref1, sref2 = 0; 
 
    a.testCreate(v1);             iret |= a.check(VecType<V1>::name()+" creation",v1.size(),ngen);
-   s1 = a.testAddition(v1);    iret |= a.check(VecType<V1>::name()+" addition",s1,a.Sum(),Dim*8);
+   s1 = a.testAddition(v1);    iret |= a.check(VecType<V1>::name()+" addition",s1,a.Sum(),Dim*20);
    sref1 = s1; 
    v1.clear();
    assert(v1.size() == 0);
@@ -1113,7 +1125,14 @@ int testVector(int ngen, bool testio=false) {
 
    s1 = a.testOperations(v1);  a.print(VecType<V1>::name()+" operations");
    scale = Dim*20; 
-   if (Dim==4) scale *= 10000000; // for problem with PtEtaPhiE
+   if (Dim==3 && VecType<V2>::name() == "RhoEtaPhiVector") scale *= 10; // for problem with RhoEtaPhi
+   if (Dim==4 && VecType<V2>::name() == "PtEtaPhiMVector") scale *= 10; 
+#if defined (R__LINUX) && !defined(R__B64) 
+   // problem of precision on linux 32  
+   if (Dim ==4) scale = 1000000000;
+#endif    
+   // for problem with PtEtaPhiE
+   if (Dim==4 && VecType<V2>::name() == "PtEtaPhiEVector") scale = 0.01/(std::numeric_limits<double>::epsilon()); 
    s2 = a.testOperations(v2);  iret |= a.check(VecType<V2>::name()+" operations",s2,s1,scale);
 
    s1 = a.testDelta(v1);      a.print(VecType<V1>::name()+" delta values");
@@ -1126,7 +1145,7 @@ int testVector(int ngen, bool testio=false) {
    int ir = 0;
    if (!testio) return iret; 
 
-   double estSize = ngen*8 * Dim + 10 * ngen;  //add extra bytes
+   double estSize = ngen*8 * Dim  + 10000;  //add extra bytes
    scale = 0.1 / std::numeric_limits<double>::epsilon();
    fsize = a.testWrite(v1);  iret |= a.check(VecType<V1>::name()+" write",fsize,estSize,scale);
    ir = a.testRead(v1);   iret |= a.check(VecType<V1>::name()+" read",ir,0);
@@ -1135,14 +1154,14 @@ int testVector(int ngen, bool testio=false) {
    // test io vector 2
    fsize = a.testWrite(v2);  iret |= a.check(VecType<V2>::name()+" write",fsize,estSize,scale);
    ir = a.testRead(v2);      iret |= a.check(VecType<V2>::name()+" read",ir,0);
-   scale = 4; // gcc4.1.2 gives here an error for PtEtaPhiMV 
+   scale = 100; // gcc 4.3.2 gives and error for RhoEtaPhiVector for 32 bits
    s2 = a.testAddition(v2);       iret |= a.check(VecType<V2>::name()+" after read",s2,sref2,scale);
 
 
    // test io of double 32 for vector 1
    if (Dim==2) return iret; 
 
-   estSize = ngen*4 * Dim + 10 * ngen;  //add extra bytes
+   estSize = ngen*4 * Dim + 10000;  //add extra bytes
    scale = 0.1 / std::numeric_limits<double>::epsilon();
    
    std::string typeName = VecType<V1>::name32();
@@ -1179,7 +1198,7 @@ int testVector34(int ngen, bool testio=false) {
 
    std::string name = "SVector<double," + Util::ToString(Dim) + ">"; 
    a.testCreate(v1);             iret |= a.check(name+" creation",v1.size(),ngen);
-   s1 = a.testAddition(v1);    iret |= a.check(name+" addition",s1,a.Sum(),Dim*8);
+   s1 = a.testAddition(v1);    iret |= a.check(name+" addition",s1,a.Sum(),Dim*20);
    sref1 = s1; 
 
    // test the io
@@ -1189,7 +1208,7 @@ int testVector34(int ngen, bool testio=false) {
 
    std::string typeName = "ROOT::Math::"+name;
 
-   double estSize = ngen*8 * Dim + 10 * ngen;
+   double estSize = ngen*8 * Dim + 47000; // add extra bytes (why so much ? ) this is for ngen=10000
    double scale = 0.1 / std::numeric_limits<double>::epsilon();
    fsize = a.testWrite(v1,typeName);  iret |= a.check(name+" write",fsize,estSize,scale);
    ir = a.testRead(v1);   iret |= a.check(name+" read",ir,0);
@@ -1198,7 +1217,7 @@ int testVector34(int ngen, bool testio=false) {
    //std::cout << "File size = " << fsize << " estimated " << 8 * Dim * ngen << std::endl;
 
    // test Double32
-   estSize = ngen*4 * Dim + 10 * ngen;  //add extra bytes
+   estSize = ngen*4 * Dim + 47000;  //add extra bytes
    scale = 0.1 / std::numeric_limits<double>::epsilon();
    
    typeName = VecType<SV>::name32();
@@ -1245,7 +1264,7 @@ int testSVector(int ngen, bool testio=false) {
 
 
    std::string typeName = "ROOT::Math::"+name;
-   double estSize = ngen*8 * Dim + 10. * ngen;
+   double estSize = ngen*8 * Dim + 10000;
    double scale = 0.1 / std::numeric_limits<double>::epsilon();
    fsize = a.testWrite(v1,typeName);  iret |= a.check(name+" write",fsize,estSize,scale);
    ir = a.testRead(v1);   iret |= a.check(name+" read",ir,0);
@@ -1320,7 +1339,7 @@ int testSMatrix(int ngen, bool testio=false) {
    // the full name is needed for sym matrices
    std::string typeName = "ROOT::Math::"+name0 + "," + Rep::name()  + ">";
 
-   double estSize = ngen*8 * Dim + 10 * ngen;
+   double estSize = ngen*8 * Dim + 10000;
    double scale = 0.1 / std::numeric_limits<double>::epsilon();
    fsize = a.testWrite(v1,typeName);  iret |= a.check(name+" write",fsize,estSize,scale);
    ir = a.testRead(v1);   iret |= a.check(name+" read",ir,0);
@@ -1341,7 +1360,7 @@ int testSMatrix(int ngen, bool testio=false) {
    typeName = "ROOT::Math::"+name0+ "," + Rep::name32()  + ">";
 
 
-   estSize = ngen* 4 * Dim + 10 * ngen;
+   estSize = ngen* 4 * Dim + 10000;
    scale = 0.1 / std::numeric_limits<double>::epsilon();
    fsize32 = a.testWrite(v1,typeName);     iret |= a.check(name+" write",fsize32,estSize,scale);
    ir = a.testRead(v1);   iret |= a.check(name+" read",ir,0);
@@ -1392,7 +1411,7 @@ int testTrack(int ngen) {
 
    int wsize = 8; 
    if (T::IsD32() ) wsize = 4;
-   double estSize = ngen*wsize * Dim + 10 * ngen;
+   double estSize = ngen*wsize * Dim + 10000;
    double scale = 0.2 / std::numeric_limits<double>::epsilon();
    fsize = a.testWrite(v1,typeName);  iret |= a.check(name+" write",fsize,estSize,scale);
    ir = a.testRead(v1);   iret |= a.check(name+" read",ir,0);
@@ -1472,12 +1491,12 @@ int testCompositeObj(int ngen) {
    std::cout << "Test Using CINT library\n\n"; 
 
    // put path relative to LD_LIBRARY_PATH
-   iret = gSystem->Load("../test/libTrackMathCoreCint");
+   iret = gSystem->Load("../test/libTrackMathCoreDict");
    if (iret !=0) { 
       // if not assume running from top ROOT dir (case of roottest)
-      iret = gSystem->Load("test/libTrackMathCoreCint");
+      iret = gSystem->Load("test/libTrackMathCoreDict");
       if (iret !=0) {
-         std::cerr <<"Error Loading libTrackMathCoreCint" << std::endl;
+         std::cerr <<"Error Loading libTrackMathCoreDict" << std::endl;
          return iret; 
       }
    }
@@ -1540,7 +1559,11 @@ int stressMathCore(double nscale = 1) {
    TBenchmark bm;
    bm.Start("stressMathCore");
 
-   iret |= testStatFunctions(100);
+   const int ntest = 10000; 
+   int n = int(nscale*ntest);
+   //std::cout << "StressMathCore: test number  n = " << n << std::endl;
+  
+   iret |= testStatFunctions(n/10);
 
    bool io = true; 
 
@@ -1551,16 +1574,16 @@ int stressMathCore(double nscale = 1) {
    }
 
 
-   iret |= testGenVectors(int(nscale*1000),io); 
+   iret |= testGenVectors(n,io); 
 
-   iret |= testSMatrix(int(nscale*1000),io); 
+   iret |= testSMatrix(n,io); 
 
-   if (io) iret |= testCompositeObj(int(nscale*1000)); 
+   if (io) iret |= testCompositeObj(n); 
 
    bm.Stop("stressMathCore");
    std::cout <<"******************************************************************************\n";
    bm.Print("stressMathCore");
-   const double reftime = 1.70; // ref time on  pcbrun4
+   const double reftime = 7.1; // needs to be updated // ref time on  pcbrun4
    double rootmarks = 860 * reftime / bm.GetCpuTime("stressMathCore");
    std::cout << " ROOTMARKS = " << rootmarks << " ROOT version: " << gROOT->GetVersion() << "\t" 
              << gROOT->GetSvnBranch() << "@" << gROOT->GetSvnRevision() << std::endl;
@@ -1576,8 +1599,8 @@ int stressMathCore(double nscale = 1) {
 int main(int argc,const char *argv[]) { 
    double nscale = 1;
    if (argc > 1) { 
-      int scale = atoi(argv[1]);
-      nscale = std::pow(10.0,double(scale));
+      nscale = atof(argv[1]);
+      //nscale = std::pow(10.0,double(scale));
    } 
    return stressMathCore(nscale);
 }
