@@ -102,16 +102,16 @@ namespace TMVA {
    template<class T>
    struct DeleteFunctor_t
    {
-      DeleteFunctor_t& operator()(T* p) {
+      DeleteFunctor_t& operator()(const T* p) {
          delete p;
          return *this;
       }
    };
 
    template<class T>
-   DeleteFunctor_t<T> DeleteFunctor()
+   DeleteFunctor_t<const T> DeleteFunctor()
    {
-      return DeleteFunctor_t<T>();
+      return DeleteFunctor_t<const T>();
    }
 
 
@@ -207,7 +207,7 @@ namespace TMVA {
 
    class DataSetFactory {
 
-      typedef std::vector< Event* >                             EventVector;
+      typedef std::vector<Event* >                             EventVector;
       typedef std::vector< EventVector >                        EventVectorOfClasses;
       typedef std::map<Types::ETreeType, EventVectorOfClasses > EventVectorOfClassesOfTreeType;
       typedef std::map<Types::ETreeType, EventVector >          EventVectorOfTreeType;
@@ -311,6 +311,8 @@ namespace TMVA {
       Bool_t                     fVerbose;           //! Verbosity
       TString                    fVerboseLevel;      //! VerboseLevel
 
+      Bool_t                     fScaleWithPreselEff; //! how to deal with requested #events in connection with preselection cuts 
+
       // the event
       mutable TTree*             fCurrentTree;       //! the tree, events are currently read from
       mutable UInt_t             fCurrentEvtIdx;     //! the current event (to avoid reading of the same event)
