@@ -57,7 +57,7 @@ namespace TMVA {
       virtual ~VariableNormalizeTransform( void );
 
       void   Initialize();
-      Bool_t PrepareTransformation( const std::vector<Event*>& );
+      Bool_t PrepareTransformation (const std::vector<Event*>&);
 
       virtual const Event* Transform(const Event* const, Int_t cls ) const;
       virtual const Event* InverseTransform( const Event* const, Int_t cls ) const;
@@ -69,7 +69,7 @@ namespace TMVA {
       virtual void AttachXMLTo(void* parent);
       virtual void ReadFromXML( void* trfnode );
 
-      virtual void PrintTransformation( ostream & o );
+      virtual void PrintTransformation( std::ostream & o );
 
       // writer of function code
       virtual void MakeFunction( std::ostream& fout, const TString& fncName, Int_t part, UInt_t trCounter, Int_t cls );
@@ -79,7 +79,7 @@ namespace TMVA {
 
    private:
 
-      void CalcNormalizationParams( const std::vector<Event*>& events);
+      void CalcNormalizationParams( const std::vector< Event*>& events);
 
       //      mutable Event*           fTransformedEvent;
 
