@@ -70,6 +70,10 @@ TMVA::DataSetInfo::DataSetInfo(const TString& name)
      fClasses( 0 ),
      fNormalization( "NONE" ),
      fSplitOptions(""),
+     fTrainingSumSignalWeights(-1),
+     fTrainingSumBackgrWeights(-1),
+     fTestingSumSignalWeights (-1),
+     fTestingSumBackgrWeights (-1),
      fOwnRootDir(0),
      fVerbose( kFALSE ),
      fSignalClass(0),
@@ -462,3 +466,21 @@ Int_t TMVA::DataSetInfo::GetClassNameMaxLength() const
    return maxL;
 }
 
+
+Double_t TMVA::DataSetInfo::GetTrainingSumSignalWeights(){
+   if (fTrainingSumSignalWeights<0) Log() << kFATAL << " asking for the sum of training signal event weights which is not initicalised yet" << Endl;
+   return fTrainingSumSignalWeights;
+}
+Double_t TMVA::DataSetInfo::GetTrainingSumBackgrWeights(){
+   if (fTrainingSumBackgrWeights<0) Log() << kFATAL << " asking for the sum of training backgr event weights which is not initicalised yet" << Endl;
+   return fTrainingSumBackgrWeights;
+}
+Double_t TMVA::DataSetInfo::GetTestingSumSignalWeights (){
+   if (fTestingSumSignalWeights<0) Log() << kFATAL << " asking for the sum of testing signal event weights which is not initicalised yet" << Endl;
+   return fTestingSumSignalWeights ;
+}
+Double_t TMVA::DataSetInfo::GetTestingSumBackgrWeights (){
+   if (fTestingSumBackgrWeights<0) Log() << kFATAL << " asking for the sum of testing backgr event weights which is not initicalised yet" << Endl;
+   return fTestingSumBackgrWeights ;
+}
+
