@@ -301,6 +301,7 @@ TMVA::DataSetInfo& TMVA::MethodCategory::CreateCategoryDSI(const TCut& theCut,
    dsi->SetNormalization(norm);
 
    DataSetInfo& dsiReference= (*dsi);
+
    return dsiReference;  
 }
 
@@ -406,6 +407,10 @@ void TMVA::MethodCategory::Train()
                << " not trained (training tree has less entries ["
                << mva->Data()->GetNTrainingEvents()
                << "] than required [" << MinNoTrainingEvents << "]" << Endl;
+
+         Log() << kERROR << " w/o training/test events for that category, I better stop here and let you fix " << Endl;
+         Log() << kFATAL << "that one first, otherwise things get too messy later ... " << Endl;
+
       }
    }
 
@@ -554,6 +559,9 @@ const TMVA::Ranking* TMVA::MethodCategory::CreateRanking()
 Bool_t TMVA::MethodCategory::PassesCut( const Event* ev, UInt_t methodIdx )
 {
 
+   // if it's not a simple 'spectator' variable (0 or 1) that the categories are defined by
+   // (but rather some 'formula' (i.e. eta>0), then this formulas are stored in fCatTree and that
+   // one will be evaluated.. (the formulae return 'true' or 'false' 
    if (fCatTree) {
       if (methodIdx>=fCatFormulas.size()) {
          Log() << kFATAL << "Large method index " << methodIdx << ", number of category formulas = "
@@ -562,6 +570,7 @@ Bool_t TMVA::MethodCategory::PassesCut( const Event* ev, UInt_t methodIdx )
       TTreeFormula* f = fCatFormulas[methodIdx];
       return f->EvalInstance(0) > 0.5;
    } 
+   // otherwise, it simply looks if "variable == true"  ("greater 0.5 to be "sure" )
    else {
 
       // checks whether an event lies within a cut
