@@ -65,7 +65,7 @@ TMVA::MethodCompositeBase::MethodCompositeBase( const TString& jobName,
                                                 const TString& theOption,
                                                 TDirectory* theTargetDir )
    : TMVA::MethodBase( jobName, methodType, methodTitle, theData, theOption, theTargetDir ),
-     fMethodIndex(0)
+   fCurrentMethodIdx(0), fCurrentMethod(0)
 {}
 
 //_______________________________________________________________________
@@ -74,15 +74,15 @@ TMVA::MethodCompositeBase::MethodCompositeBase( Types::EMVA methodType,
                                                 const TString& weightFile,
                                                 TDirectory* theTargetDir )
    : TMVA::MethodBase( methodType, dsi, weightFile, theTargetDir ),
-     fMethodIndex(0)
+   fCurrentMethodIdx(0), fCurrentMethod(0)     
 {}
 
 //_______________________________________________________________________
 TMVA::IMethod* TMVA::MethodCompositeBase::GetMethod( const TString &methodTitle ) const
 {
    // returns pointer to MVA that corresponds to given method title
-   vector<IMethod*>::const_iterator itrMethod    = fMethods.begin();
-   vector<IMethod*>::const_iterator itrMethodEnd = fMethods.end();
+   std::vector<IMethod*>::const_iterator itrMethod    = fMethods.begin();
+   std::vector<IMethod*>::const_iterator itrMethodEnd = fMethods.end();
 
    for (; itrMethod != itrMethodEnd; itrMethod++) {
       MethodBase* mva = dynamic_cast<MethodBase*>(*itrMethod);
@@ -95,7 +95,7 @@ TMVA::IMethod* TMVA::MethodCompositeBase::GetMethod( const TString &methodTitle
 TMVA::IMethod* TMVA::MethodCompositeBase::GetMethod( const Int_t index ) const
 {
    // returns pointer to MVA that corresponds to given method index
-   vector<IMethod*>::const_iterator itrMethod = fMethods.begin()+index;
+   std::vector<IMethod*>::const_iterator itrMethod = fMethods.begin()+index;
    if (itrMethod<fMethods.end()) return *itrMethod;
    else                          return 0;
 }
@@ -130,7 +130,7 @@ void TMVA::MethodCompositeBase::AddWeightsXMLTo( void* parent ) const
 TMVA::MethodCompositeBase::~MethodCompositeBase( void )
 {
    // delete methods
-   vector<IMethod*>::iterator itrMethod = fMethods.begin();
+   std::vector<IMethod*>::iterator itrMethod = fMethods.begin();
    for (; itrMethod != fMethods.end(); itrMethod++) {
       Log() << kVERBOSE << "Delete method: " << (*itrMethod)->GetName() << Endl;
       delete (*itrMethod);
@@ -206,7 +206,7 @@ void TMVA::MethodCompositeBase::ReadWeightsFromXML( void* wghtnode )
 }
 
 //_______________________________________________________________________
-void  TMVA::MethodCompositeBase::ReadWeightsFromStream( istream& istr )
+void  TMVA::MethodCompositeBase::ReadWeightsFromStream( std::istream& istr )
 {
    // text streamer
    TString var, dummy;
@@ -221,10 +221,10 @@ void  TMVA::MethodCompositeBase::ReadWeightsFromStream( istream& istr )
    fMethods.clear();
    fMethodWeight.clear();
    for (UInt_t i=0; i<methodNum; i++) {
-      istr >> dummy >> methodName >>  dummy >> fMethodIndex >> dummy >> methodWeight;
-      if ((UInt_t)fMethodIndex != i) {
+      istr >> dummy >> methodName >>  dummy >> fCurrentMethodIdx >> dummy >> methodWeight;
+      if ((UInt_t)fCurrentMethodIdx != i) {
          Log() << kFATAL << "Error while reading weight file; mismatch MethodIndex="
-               << fMethodIndex << " i=" << i
+               << fCurrentMethodIdx << " i=" << i
                << " MethodName " << methodName
                << " dummy " << dummy
                << " MethodWeight= " << methodWeight
@@ -237,7 +237,7 @@ void  TMVA::MethodCompositeBase::ReadWeightsFromStream( istream& istr )
          if (GetMethodType() == Types::kBoost)
             ((TMVA::MethodBoost*)this)->BookMethod( Types::Instance().GetMethodType( methodName), methodTitle,  optionString );
       }
-      else methodTitle=Form("%s (%04i)",GetMethodName().Data(),fMethodIndex);
+      else methodTitle=Form("%s (%04i)",GetMethodName().Data(),fCurrentMethodIdx);
       fMethods.push_back(ClassifierFactory::Instance().Create( std::string(methodName), jobName,
                                                                methodTitle,DataInfo(), optionString) );
       fMethodWeight.push_back( methodWeight );
