@@ -114,6 +114,8 @@ End_Html */
 #include "TMVA/VariableTransformBase.h"
 #include "TMVA/Results.h"
 
+using std::atof;
+
 REGISTER_METHOD(Cuts)
 
 ClassImp(TMVA::MethodCuts)
@@ -222,16 +224,16 @@ void TMVA::MethodCuts::Init( void )
 
    // vector with fit results
    fNpar      = 2*GetNvar();
-   fRangeSign = new vector<Int_t>   ( GetNvar() );
+   fRangeSign = new std::vector<Int_t>   ( GetNvar() );
    for (UInt_t ivar=0; ivar<GetNvar(); ivar++) (*fRangeSign)[ivar] = +1;
 
-   fMeanS     = new vector<Double_t>( GetNvar() ); 
-   fMeanB     = new vector<Double_t>( GetNvar() ); 
-   fRmsS      = new vector<Double_t>( GetNvar() );  
-   fRmsB      = new vector<Double_t>( GetNvar() );  
+   fMeanS     = new std::vector<Double_t>( GetNvar() ); 
+   fMeanB     = new std::vector<Double_t>( GetNvar() ); 
+   fRmsS      = new std::vector<Double_t>( GetNvar() );  
+   fRmsB      = new std::vector<Double_t>( GetNvar() );  
 
    // get the variable specific options, first initialize default
-   fFitParams = new vector<EFitParameters>( GetNvar() );
+   fFitParams = new std::vector<EFitParameters>( GetNvar() );
    for (UInt_t ivar=0; ivar<GetNvar(); ivar++) (*fFitParams)[ivar] = kNotEnforced;
 
    fFitMethod = kUseMonteCarlo;
@@ -505,12 +507,12 @@ void TMVA::MethodCuts::PrintCuts( Double_t effS ) const
    Log() << Endl;
    for (UInt_t ivar=0; ivar<cutsMin.size(); ivar++) {
       Log() << kINFO 
-              << "Cut[" << setw(2) << ivar << "]: " 
-              << setw(10) << cutsMin[ivar] 
+              << "Cut[" << std::setw(2) << ivar << "]: " 
+              << std::setw(10) << cutsMin[ivar] 
               << " < " 
-              << setw(maxL) << (*varVec)[ivar]
+              << std::setw(maxL) << (*varVec)[ivar]
               << " <= " 
-              << setw(10) << cutsMax[ivar] << Endl;
+              << std::setw(10) << cutsMax[ivar] << Endl;
    }
    for (UInt_t i=0; i<maxLine; i++) Log() << "-";
    Log() << Endl;
@@ -606,7 +608,7 @@ void  TMVA::MethodCuts::Train( void )
       else if (xmax < fCutRange[ivar]->GetMax()) fCutRange[ivar]->SetMax( xmax );
    }   
 
-   vector<TH1F*> signalDist, bkgDist;
+   std::vector<TH1F*> signalDist, bkgDist;
 
    // this is important: reset the branch addresses of the training tree to the current event
    delete fEffBvsSLocal;
@@ -624,7 +626,7 @@ void  TMVA::MethodCuts::Train( void )
        fFitMethod == kUseSimulatedAnnealing) {
 
       // ranges
-      vector<Interval*> ranges;
+      std::vector<Interval*> ranges;
 
       for (UInt_t ivar=0; ivar<GetNvar(); ivar++) {
 
@@ -1072,12 +1074,12 @@ void TMVA::MethodCuts::CreateVariablePDFs( void )
    // for PDF method: create efficiency reference histograms and PDFs
 
    // create list of histograms and PDFs
-   fVarHistS        = new vector<TH1*>( GetNvar() );
-   fVarHistB        = new vector<TH1*>( GetNvar() );
-   fVarHistS_smooth = new vector<TH1*>( GetNvar() );
-   fVarHistB_smooth = new vector<TH1*>( GetNvar() );
-   fVarPdfS         = new vector<PDF*>( GetNvar() );
-   fVarPdfB         = new vector<PDF*>( GetNvar() );
+   fVarHistS        = new std::vector<TH1*>( GetNvar() );
+   fVarHistB        = new std::vector<TH1*>( GetNvar() );
+   fVarHistS_smooth = new std::vector<TH1*>( GetNvar() );
+   fVarHistB_smooth = new std::vector<TH1*>( GetNvar() );
+   fVarPdfS         = new std::vector<PDF*>( GetNvar() );
+   fVarPdfB         = new std::vector<PDF*>( GetNvar() );
 
    Int_t nsmooth = 0;
 
@@ -1178,7 +1180,7 @@ void TMVA::MethodCuts::CreateVariablePDFs( void )
 }
 
 //_______________________________________________________________________
-void  TMVA::MethodCuts::ReadWeightsFromStream( istream& istr )
+void  TMVA::MethodCuts::ReadWeightsFromStream( std::istream& istr )
 {
    // read the cuts from stream
    TString dummy;
@@ -1668,8 +1670,8 @@ Double_t TMVA::MethodCuts::GetEfficiency( const TString& theString, Types::ETree
 void TMVA::MethodCuts::MakeClassSpecific( std::ostream& fout, const TString& className ) const
 {
    // write specific classifier response
-   fout << "   // not implemented for class: \"" << className << "\"" << endl;
-   fout << "};" << endl;
+   fout << "   // not implemented for class: \"" << className << "\"" << std::endl;
+   fout << "};" << std::endl;
 }
 
 //_______________________________________________________________________
