@@ -304,7 +304,7 @@ void TMVA::MethodFisher::GetMean( void )
       const Event * ev = GetEvent(ievt);
 
       // sum of weights
-      Double_t weight = GetTWeight(ev);
+      Double_t weight = ev->GetWeight();
       if (DataInfo().IsSignal(ev)) fSumOfWeightsS += weight;
       else                         fSumOfWeightsB += weight;
 
@@ -355,7 +355,7 @@ void TMVA::MethodFisher::GetCov_WithinClass( void )
       // read the Training Event into "event"
       const Event* ev = GetEvent(ievt);
 
-      Double_t weight = GetTWeight(ev); // may ignore events with negative weights
+      Double_t weight = ev->GetWeight(); // may ignore events with negative weights
 
       for (Int_t x=0; x<nvar; x++) xval[x] = ev->GetValue( x );
       Int_t k=0;
@@ -365,7 +365,7 @@ void TMVA::MethodFisher::GetCov_WithinClass( void )
                Double_t v = ( (xval[x] - (*fMeanMatx)(x, 0))*(xval[y] - (*fMeanMatx)(y, 0)) )*weight;
                sumSig[k] += v;
             }else{
-               Double_t v = ( (xval[x] - (*fMeanMatx)(x, 0))*(xval[y] - (*fMeanMatx)(y, 0)) )*weight;
+               Double_t v = ( (xval[x] - (*fMeanMatx)(x, 1))*(xval[y] - (*fMeanMatx)(y, 1)) )*weight;
                sumBgd[k] += v;
             }
             k++;
@@ -375,7 +375,16 @@ void TMVA::MethodFisher::GetCov_WithinClass( void )
    Int_t k=0;
    for (Int_t x=0; x<nvar; x++) {
       for (Int_t y=0; y<nvar; y++) {
-         (*fWith)(x, y) = (sumSig[k] + sumBgd[k])/(fSumOfWeightsS + fSumOfWeightsB);
+         //(*fWith)(x, y) = (sumSig[k] + sumBgd[k])/(fSumOfWeightsS + fSumOfWeightsB);
+         // HHV: I am still convinced that THIS is how it should be (below) However, while
+         // the old version corresponded so nicely with LD, the FIXED version does not, unless
+         // we agree to change LD. For LD, it is not "defined" to my knowledge how the weights
+         // are weighted, while it is clear how the "Within" matrix for Fisher should be calcuated
+         // (i.e. as seen below). In order to agree with the Fisher classifier, one would have to
+         // weigh signal and background such that they correspond to the same number of effective
+         // (weithed) events.
+         // THAT is NOT done currently, but just "event weights" are used. 
+         (*fWith)(x, y) = sumSig[k]/fSumOfWeightsS + sumBgd[k]/fSumOfWeightsB;
          k++;
       }
    }
@@ -448,6 +457,7 @@ void TMVA::MethodFisher::GetFisherCoeff( void )
    }
 
    TMatrixD invCov( *theMat );
+
    if ( TMath::Abs(invCov.Determinant()) < 10E-24 ) {
       Log() << kWARNING << "<GetFisherCoeff> matrix is almost singular with deterninant="
               << TMath::Abs(invCov.Determinant()) 
@@ -455,9 +465,11 @@ void TMVA::MethodFisher::GetFisherCoeff( void )
               << Endl;
    }
    if ( TMath::Abs(invCov.Determinant()) < 10E-120 ) {
+      theMat->Print();
       Log() << kFATAL << "<GetFisherCoeff> matrix is singular with determinant="
               << TMath::Abs(invCov.Determinant())  
-              << " did you use the variables that are linear combinations?" 
+              << " did you use the variables that are linear combinations? \n" 
+              << " do you any clue as to what went wrong in above printout of the covariance matrix? " 
               << Endl;
    }
 
@@ -475,12 +487,12 @@ void TMVA::MethodFisher::GetFisherCoeff( void )
       for (jvar=0; jvar<GetNvar(); jvar++) {
          Double_t d = (*fMeanMatx)(jvar, 0) - (*fMeanMatx)(jvar, 1);
          (*fFisherCoeff)[ivar] += invCov(ivar, jvar)*d;
-      }    
-    
+      }
       // rescale
       (*fFisherCoeff)[ivar] *= xfact;
    }
-
+   
+   
    // offset correction
    fF0 = 0.0;
    for (ivar=0; ivar<GetNvar(); ivar++){ 
@@ -546,6 +558,9 @@ void TMVA::MethodFisher::PrintCoefficients( void )
    coeffs.push_back( fF0 );
    TMVA::gTools().FormattedOutput( coeffs, vars, "Variable" , "Coefficient", Log() );   
 
+   // for (int i=0; i<coeffs.size(); i++)
+   //    std::cout << "fisher coeff["<<i<<"]="<<coeffs[i]<<std::endl;
+
    if (IsNormalised()) {
       Log() << kINFO << "NOTE: You have chosen to use the \"Normalise\" booking option. Hence, the" << Endl;
       Log() << kINFO << "      coefficients must be applied to NORMALISED (') variables as follows:" << Endl;
@@ -555,12 +570,12 @@ void TMVA::MethodFisher::PrintCoefficients( void )
       // Print normalisation expression (see Tools.cxx): "2*(x - xmin)/(xmax - xmin) - 1.0"
       for (UInt_t ivar=0; ivar<GetNvar(); ivar++) {
          Log() << kINFO 
-                 << setw(maxL+9) << TString("[") + GetInputLabel(ivar) + "]' = 2*(" 
-                 << setw(maxL+2) << TString("[") + GetInputLabel(ivar) + "]"
-                 << setw(3) << (GetXmin(ivar) > 0 ? " - " : " + ")
-                 << setw(6) << TMath::Abs(GetXmin(ivar)) << setw(3) << ")/"
-                 << setw(6) << (GetXmax(ivar) -  GetXmin(ivar) )
-                 << setw(3) << " - 1"
+                 << std::setw(maxL+9) << TString("[") + GetInputLabel(ivar) + "]' = 2*(" 
+                 << std::setw(maxL+2) << TString("[") + GetInputLabel(ivar) + "]"
+                 << std::setw(3) << (GetXmin(ivar) > 0 ? " - " : " + ")
+                 << std::setw(6) << TMath::Abs(GetXmin(ivar)) << std::setw(3) << ")/"
+                 << std::setw(6) << (GetXmax(ivar) -  GetXmin(ivar) )
+                 << std::setw(3) << " - 1"
                  << Endl;
       }
       Log() << kINFO << "The TMVA Reader will properly account for this normalisation, but if the" << Endl;
@@ -571,7 +586,7 @@ void TMVA::MethodFisher::PrintCoefficients( void )
 }
   
 //_______________________________________________________________________
-void TMVA::MethodFisher::ReadWeightsFromStream( istream& istr )
+void TMVA::MethodFisher::ReadWeightsFromStream( std::istream& istr )
 {
    // read Fisher coefficients from weight file
    istr >> fF0;
@@ -619,41 +634,41 @@ void TMVA::MethodFisher::MakeClassSpecific( std::ostream& fout, const TString& c
 {
    // write Fisher-specific classifier response
    Int_t dp = fout.precision();
-   fout << "   double              fFisher0;" << endl;
-   fout << "   std::vector<double> fFisherCoefficients;" << endl;
-   fout << "};" << endl;
-   fout << "" << endl;
-   fout << "inline void " << className << "::Initialize() " << endl;
-   fout << "{" << endl;
-   fout << "   fFisher0 = " << std::setprecision(12) << fF0 << ";" << endl;
+   fout << "   double              fFisher0;" << std::endl;
+   fout << "   std::vector<double> fFisherCoefficients;" << std::endl;
+   fout << "};" << std::endl;
+   fout << "" << std::endl;
+   fout << "inline void " << className << "::Initialize() " << std::endl;
+   fout << "{" << std::endl;
+   fout << "   fFisher0 = " << std::setprecision(12) << fF0 << ";" << std::endl;
    for (UInt_t ivar=0; ivar<GetNvar(); ivar++) {
-      fout << "   fFisherCoefficients.push_back( " << std::setprecision(12) << (*fFisherCoeff)[ivar] << " );" << endl;
+      fout << "   fFisherCoefficients.push_back( " << std::setprecision(12) << (*fFisherCoeff)[ivar] << " );" << std::endl;
    }
-   fout << endl;
-   fout << "   // sanity check" << endl;
-   fout << "   if (fFisherCoefficients.size() != fNvars) {" << endl;
-   fout << "      std::cout << \"Problem in class \\\"\" << fClassName << \"\\\"::Initialize: mismatch in number of input values\"" << endl;
-   fout << "                << fFisherCoefficients.size() << \" != \" << fNvars << std::endl;" << endl;
-   fout << "      fStatusIsClean = false;" << endl;
-   fout << "   }         " << endl;
-   fout << "}" << endl;
-   fout << endl;
-   fout << "inline double " << className << "::GetMvaValue__( const std::vector<double>& inputValues ) const" << endl;
-   fout << "{" << endl;
-   fout << "   double retval = fFisher0;" << endl;
-   fout << "   for (size_t ivar = 0; ivar < fNvars; ivar++) {" << endl;
-   fout << "      retval += fFisherCoefficients[ivar]*inputValues[ivar];" << endl;
-   fout << "   }" << endl;
-   fout << endl;
-   fout << "   return retval;" << endl;
-   fout << "}" << endl;
-   fout << endl;
-   fout << "// Clean up" << endl;
-   fout << "inline void " << className << "::Clear() " << endl;
-   fout << "{" << endl;
-   fout << "   // clear coefficients" << endl;
-   fout << "   fFisherCoefficients.clear(); " << endl;
-   fout << "}" << endl;
+   fout << std::endl;
+   fout << "   // sanity check" << std::endl;
+   fout << "   if (fFisherCoefficients.size() != fNvars) {" << std::endl;
+   fout << "      std::cout << \"Problem in class \\\"\" << fClassName << \"\\\"::Initialize: mismatch in number of input values\"" << std::endl;
+   fout << "                << fFisherCoefficients.size() << \" != \" << fNvars << std::endl;" << std::endl;
+   fout << "      fStatusIsClean = false;" << std::endl;
+   fout << "   }         " << std::endl;
+   fout << "}" << std::endl;
+   fout << std::endl;
+   fout << "inline double " << className << "::GetMvaValue__( const std::vector<double>& inputValues ) const" << std::endl;
+   fout << "{" << std::endl;
+   fout << "   double retval = fFisher0;" << std::endl;
+   fout << "   for (size_t ivar = 0; ivar < fNvars; ivar++) {" << std::endl;
+   fout << "      retval += fFisherCoefficients[ivar]*inputValues[ivar];" << std::endl;
+   fout << "   }" << std::endl;
+   fout << std::endl;
+   fout << "   return retval;" << std::endl;
+   fout << "}" << std::endl;
+   fout << std::endl;
+   fout << "// Clean up" << std::endl;
+   fout << "inline void " << className << "::Clear() " << std::endl;
+   fout << "{" << std::endl;
+   fout << "   // clear coefficients" << std::endl;
+   fout << "   fFisherCoefficients.clear(); " << std::endl;
+   fout << "}" << std::endl;
    fout << std::setprecision(dp);
 }
 
