@@ -230,6 +230,8 @@ void TMVA::MethodPDEFoam::DeclareOptions()
 
 //_______________________________________________________________________
 void TMVA::MethodPDEFoam::DeclareCompatibilityOptions() {
+   // options that are used ONLY for the READER to ensure backward compatibility
+
    MethodBase::DeclareCompatibilityOptions();
    DeclareOptionRef(fCutNmin = kTRUE, "CutNmin",  "Requirement for minimal number of events in cell");
    DeclareOptionRef(fPeekMax = kTRUE, "PeekMax",  "Peek cell with max. loss for the next split");
@@ -270,7 +272,7 @@ void TMVA::MethodPDEFoam::ProcessOptions()
    else if (fDTLogic == "SdivSqrtSplusB")
       fDTSeparation = kSdivSqrtSplusB;
    else {
-      Log() << kWARNING << "Unknown separation type: " << fDTLogic 
+      Log() << kWARNING << "Unknown separation type: " << fDTLogic
 	    << ", setting to None" << Endl;
       fDTLogic = "None";
       fDTSeparation = kFoam;
@@ -303,7 +305,7 @@ TMVA::MethodPDEFoam::~MethodPDEFoam( void )
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::CalcXminXmax() 
+void TMVA::MethodPDEFoam::CalcXminXmax()
 {
    // Determine foam range [fXmin, fXmax] for all dimensions, such
    // that a fraction of 'fFrac' events lie outside the foam.
@@ -328,17 +330,17 @@ void TMVA::MethodPDEFoam::CalcXminXmax()
    Log() << kDEBUG << "Number of training events: " << Data()->GetNTrainingEvents() << Endl;
    Int_t nevoutside = (Int_t)((Data()->GetNTrainingEvents())*(fFrac)); // number of events that are outside the range
    Int_t rangehistbins = 10000;                               // number of bins in histos
-  
+
    // loop over all testing singnal and BG events and clac minimal and
    // maximal value of every variable
    for (Long64_t i=0; i<(GetNEvents()); i++) { // events loop
-      const Event* ev = GetEvent(i);    
+      const Event* ev = GetEvent(i);
       for (UInt_t dim=0; dim<kDim; dim++) { // variables loop
          Float_t val;
          if (fMultiTargetRegression) {
             if (dim < vDim)
                val = ev->GetValue(dim);
-            else 
+            else
                val = ev->GetTarget(dim-vDim);
          }
          else
@@ -354,12 +356,12 @@ void TMVA::MethodPDEFoam::CalcXminXmax()
    // Create and fill histograms for each dimension (with same events
    // as before), to determine range based on number of events outside
    // the range
-   TH1F **range_h = new TH1F*[kDim]; 
+   TH1F **range_h = new TH1F*[kDim];
    for (UInt_t dim=0; dim<kDim; dim++) {
       range_h[dim]  = new TH1F(Form("range%i", dim), "range", rangehistbins, xmin[dim], xmax[dim]);
    }
 
-   // fill all testing events into histos 
+   // fill all testing events into histos
    for (Long64_t i=0; i<GetNEvents(); i++) {
       const Event* ev = GetEvent(i);
       for (UInt_t dim=0; dim<kDim; dim++) {
@@ -375,8 +377,8 @@ void TMVA::MethodPDEFoam::CalcXminXmax()
    }
 
    // calc Xmin, Xmax from Histos
-   for (UInt_t dim=0; dim<kDim; dim++) { 
-      for (Int_t i=1; i<(rangehistbins+1); i++) { // loop over bins 
+   for (UInt_t dim=0; dim<kDim; dim++) {
+      for (Int_t i=1; i<(rangehistbins+1); i++) { // loop over bins
          if (range_h[dim]->Integral(0, i) > nevoutside) { // calc left limit (integral over bins 0..i = nevoutside)
             xmin[dim]=range_h[dim]->GetBinLowEdge(i);
             break;
@@ -388,13 +390,13 @@ void TMVA::MethodPDEFoam::CalcXminXmax()
             break;
          }
       }
-   }  
+   }
    // now xmin[] and xmax[] contain upper/lower limits for every dimension
 
    // copy xmin[], xmax[] values to the class variable
    fXmin.clear();
    fXmax.clear();
-   for (UInt_t dim=0; dim<kDim; dim++) { 
+   for (UInt_t dim=0; dim<kDim; dim++) {
       fXmin.push_back(xmin[dim]);
       fXmax.push_back(xmax[dim]);
    }
@@ -433,9 +435,9 @@ void TMVA::MethodPDEFoam::Train( void )
       if (DoMulticlass())
 	 TrainMultiClassification();
       else {
-	 if (DataInfo().GetNormalization() != "EQUALNUMEVENTS" ) { 
-	    Log() << kINFO << "NormMode=" << DataInfo().GetNormalization() 
-		  << " chosen. Note that only NormMode=EqualNumEvents" 
+	 if (DataInfo().GetNormalization() != "EQUALNUMEVENTS" ) {
+	    Log() << kINFO << "NormMode=" << DataInfo().GetNormalization()
+		  << " chosen. Note that only NormMode=EqualNumEvents"
 		  << " ensures that Discriminant values correspond to"
 		  << " signal probabilities." << Endl;
 	 }
@@ -453,13 +455,13 @@ void TMVA::MethodPDEFoam::Train( void )
 
    // delete the binary search tree in order to save memory
    for(UInt_t i=0; i<fFoam.size(); i++) {
-      if(fFoam.at(i)) 
+      if(fFoam.at(i))
 	 fFoam.at(i)->DeleteBinarySearchTree();
    }
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::TrainSeparatedClassification() 
+void TMVA::MethodPDEFoam::TrainSeparatedClassification()
 {
    // Creation of 2 separated foams: one for signal events, one for
    // backgound events.  At the end the foam cells of fFoam[0] will
@@ -474,7 +476,7 @@ void TMVA::MethodPDEFoam::TrainSeparatedClassification()
       // create 2 PDEFoams
       fFoam.push_back( InitFoam(foamcaption[i], kSeparate) );
 
-      Log() << kVERBOSE << "Filling binary search tree of " << foamcaption[i] 
+      Log() << kVERBOSE << "Filling binary search tree of " << foamcaption[i]
             << " with events" << Endl;
       // insert event to BinarySearchTree
       for (Long64_t k=0; k<GetNEvents(); ++k) {
@@ -500,7 +502,7 @@ void TMVA::MethodPDEFoam::TrainSeparatedClassification()
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::TrainUnifiedClassification() 
+void TMVA::MethodPDEFoam::TrainUnifiedClassification()
 {
    // Create only one unified foam (fFoam[0]) whose cells contain the
    // average discriminator (N_sig)/(N_sig + N_bg)
@@ -510,7 +512,7 @@ void TMVA::MethodPDEFoam::TrainUnifiedClassification()
    Log() << kVERBOSE << "Filling binary search tree of discriminator foam with events" << Endl;
    // insert event to BinarySearchTree
    for (Long64_t k=0; k<GetNEvents(); ++k) {
-      const Event* ev = GetEvent(k); 
+      const Event* ev = GetEvent(k);
       if (!(IgnoreEventsWithNegWeightsInTraining() && ev->GetWeight()<=0))
 	 fFoam.back()->FillBinarySearchTree(ev);
    }
@@ -521,7 +523,7 @@ void TMVA::MethodPDEFoam::TrainUnifiedClassification()
    Log() << kVERBOSE << "Filling foam cells with events" << Endl;
    // loop over all training events -> fill foam cells with N_sig and N_Bg
    for (Long64_t k=0; k<GetNEvents(); ++k) {
-      const Event* ev = GetEvent(k); 
+      const Event* ev = GetEvent(k);
       Float_t weight = fFillFoamWithOrigWeights ? ev->GetOriginalWeight() : ev->GetWeight();
       if (!(IgnoreEventsWithNegWeightsInTraining() && ev->GetWeight()<=0))
 	 fFoam.back()->FillFoamCells(ev, weight);
@@ -533,7 +535,7 @@ void TMVA::MethodPDEFoam::TrainUnifiedClassification()
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::TrainMultiClassification() 
+void TMVA::MethodPDEFoam::TrainMultiClassification()
 {
    // Create one unified foam (see TrainUnifiedClassification()) for
    // each class, where the cells of foam i (fFoam[i]) contain the
@@ -549,7 +551,7 @@ void TMVA::MethodPDEFoam::TrainMultiClassification()
 	    << iClass << " with events" << Endl;
       // insert event to BinarySearchTree
       for (Long64_t k=0; k<GetNEvents(); ++k) {
-	 const Event* ev = GetEvent(k); 
+	 const Event* ev = GetEvent(k);
 	 if (!(IgnoreEventsWithNegWeightsInTraining() && ev->GetWeight()<=0))
 	    fFoam.back()->FillBinarySearchTree(ev);
       }
@@ -561,7 +563,7 @@ void TMVA::MethodPDEFoam::TrainMultiClassification()
       // loop over all training events and fill foam cells with signal
       // and background events
       for (Long64_t k=0; k<GetNEvents(); ++k) {
-	 const Event* ev = GetEvent(k); 
+	 const Event* ev = GetEvent(k);
 	 Float_t weight = fFillFoamWithOrigWeights ? ev->GetOriginalWeight() : ev->GetWeight();
 	 if (!(IgnoreEventsWithNegWeightsInTraining() && ev->GetWeight()<=0))
 	    fFoam.back()->FillFoamCells(ev, weight);
@@ -574,7 +576,7 @@ void TMVA::MethodPDEFoam::TrainMultiClassification()
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::TrainMonoTargetRegression() 
+void TMVA::MethodPDEFoam::TrainMonoTargetRegression()
 {
    // Training one (mono target regression) foam, whose cells contain
    // the average 0th target.  The dimension of the foam = number of
@@ -592,7 +594,7 @@ void TMVA::MethodPDEFoam::TrainMonoTargetRegression()
    Log() << kVERBOSE << "Filling binary search tree with events" << Endl;
    // insert event to BinarySearchTree
    for (Long64_t k=0; k<GetNEvents(); ++k) {
-      const Event* ev = GetEvent(k); 
+      const Event* ev = GetEvent(k);
       if (!(IgnoreEventsWithNegWeightsInTraining() && ev->GetWeight()<=0))
 	 fFoam.back()->FillBinarySearchTree(ev);
    }
@@ -603,7 +605,7 @@ void TMVA::MethodPDEFoam::TrainMonoTargetRegression()
    Log() << kVERBOSE << "Filling foam cells with events" << Endl;
    // loop over all events -> fill foam cells with target
    for (Long64_t k=0; k<GetNEvents(); ++k) {
-      const Event* ev = GetEvent(k); 
+      const Event* ev = GetEvent(k);
       Float_t weight = fFillFoamWithOrigWeights ? ev->GetOriginalWeight() : ev->GetWeight();
       if (!(IgnoreEventsWithNegWeightsInTraining() && ev->GetWeight()<=0))
 	 fFoam.back()->FillFoamCells(ev, weight);
@@ -625,12 +627,12 @@ void TMVA::MethodPDEFoam::TrainMultiTargetRegression()
    Log() << kDEBUG << "Number of Targets:   " << Data()->GetNTargets()   << Endl;
    Log() << kDEBUG << "Dimension of foam:   " << Data()->GetNVariables()+Data()->GetNTargets() << Endl;
    if (fKernel==kLinN)
-      Log() << kFATAL << "LinNeighbors kernel currently not supported" 
+      Log() << kFATAL << "LinNeighbors kernel currently not supported"
             << " for multi target regression" << Endl;
 
    fFoam.push_back( InitFoam("MultiTargetRegressionFoam", kMultiTarget) );
 
-   Log() << kVERBOSE << "Filling binary search tree of multi target regression foam with events" 
+   Log() << kVERBOSE << "Filling binary search tree of multi target regression foam with events"
          << Endl;
    // insert event to BinarySearchTree
    for (Long64_t k=0; k<GetNEvents(); ++k) {
@@ -658,11 +660,11 @@ void TMVA::MethodPDEFoam::TrainMultiTargetRegression()
       Event *ev = new Event(*GetEvent(k));
       // since in multi-target regression targets are handled like
       // variables --> remove targets and add them to the event variabels
-      std::vector<Float_t> targets = ev->GetTargets(); 	 
+      std::vector<Float_t> targets = ev->GetTargets();
       const UInt_t nVariables = ev->GetValues().size();
       Float_t weight = fFillFoamWithOrigWeights ? ev->GetOriginalWeight() : ev->GetWeight();
-      for (UInt_t i = 0; i < targets.size(); ++i) 	 
-	 ev->SetVal(i+nVariables, targets.at(i)); 	 
+      for (UInt_t i = 0; i < targets.size(); ++i)
+	 ev->SetVal(i+nVariables, targets.at(i));
       ev->GetTargets().clear();
       if (!(IgnoreEventsWithNegWeightsInTraining() && ev->GetWeight()<=0))
 	 fFoam.back()->FillFoamCells(ev, weight);
@@ -838,7 +840,7 @@ const TMVA::Ranking* TMVA::MethodPDEFoam::CreateRanking()
       // the overall variable importance is the average over all foams
       for (UInt_t ivar = 0; ivar < GetNvar(); ++ivar) {
 	 importance.at(ivar) += tmp_importance.at(ivar) / fFoam.size();
-      }      
+      }
    }
 
    // fill ranking vector
@@ -861,7 +863,7 @@ void TMVA::MethodPDEFoam::GetNCuts(PDEFoamCell *cell, std::vector<UInt_t> &nCuts
    //
    // - nCuts - the number of cuts are saved in this vector
 
-   if (cell->GetStat() == 1) // cell is active
+   if (cell == NULL || cell->GetStat() == 1) // cell is active
       return;
 
    nCuts.at(cell->GetBest())++;
@@ -906,7 +908,7 @@ TMVA::PDEFoam* TMVA::MethodPDEFoam::InitFoam(TString foamcaption, EFoamType ft,
    // - foamcaption - name of PDEFoam object
    //
    // - ft - type of PDEFoam
-   //   Candidates are: 
+   //   Candidates are:
    //     - kSeparate    - creates TMVA::PDEFoamEvent
    //     - kDiscr       - creates TMVA::PDEFoamDiscriminant
    //     - kMonoTarget  - creates TMVA::PDEFoamTarget
@@ -982,7 +984,7 @@ TMVA::PDEFoam* TMVA::MethodPDEFoam::InitFoam(TString foamcaption, EFoamType ft,
 	 sepType = new SdivSqrtSplusB();
 	 break;
       default:
-	 Log() << kFATAL << "Separation type " << fDTSeparation 
+	 Log() << kFATAL << "Separation type " << fDTSeparation
 	       << " currently not supported" << Endl;
 	 break;
       }
@@ -1008,7 +1010,7 @@ TMVA::PDEFoam* TMVA::MethodPDEFoam::InitFoam(TString foamcaption, EFoamType ft,
 
    // set fLogger attributes
    pdefoam->Log().SetMinType(this->Log().GetMinType());
-   
+
    // set PDEFoam parameters
    pdefoam->SetDim(         dim);
    pdefoam->SetnCells(      fnCells);    // optional
@@ -1022,7 +1024,7 @@ TMVA::PDEFoam* TMVA::MethodPDEFoam::InitFoam(TString foamcaption, EFoamType ft,
 
    // Init PDEFoam
    pdefoam->Initialize();
-   
+
    // Set Xmin, Xmax
    SetXminXmax(pdefoam);
 
@@ -1039,7 +1041,7 @@ const std::vector<Float_t>& TMVA::MethodPDEFoam::GetRegressionValues()
    fRegressionReturnVal->reserve(Data()->GetNTargets());
 
    const Event* ev = GetEvent();
-   std::vector<Float_t> vals = ev->GetValues(); // get array of event variables (non-targets)   
+   std::vector<Float_t> vals = ev->GetValues(); // get array of event variables (non-targets)
 
    if (vals.empty()) {
       Log() << kWARNING << "<GetRegressionValues> value vector is empty. " << Endl;
@@ -1061,7 +1063,7 @@ const std::vector<Float_t>& TMVA::MethodPDEFoam::GetRegressionValues()
          fRegressionReturnVal->push_back(targets.at(i));
    }
    else {
-      fRegressionReturnVal->push_back(fFoam.at(0)->GetCellValue(vals, kValue, fKernelEstimator));   
+      fRegressionReturnVal->push_back(fFoam.at(0)->GetCellValue(vals, kValue, fKernelEstimator));
    }
 
    // apply inverse transformation to regression values
@@ -1105,7 +1107,7 @@ void TMVA::MethodPDEFoam::DeleteFoams()
    // Deletes all trained foams
    for (UInt_t i=0; i<fFoam.size(); i++)
       if (fFoam.at(i)) delete fFoam.at(i);
-   fFoam.clear();   
+   fFoam.clear();
 }
 
 //_______________________________________________________________________
@@ -1123,11 +1125,11 @@ void TMVA::MethodPDEFoam::Reset()
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::PrintCoefficients( void ) 
+void TMVA::MethodPDEFoam::PrintCoefficients( void )
 {}
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::AddWeightsXMLTo( void* parent ) const 
+void TMVA::MethodPDEFoam::AddWeightsXMLTo( void* parent ) const
 {
    // create XML output of PDEFoam method variables
 
@@ -1150,7 +1152,7 @@ void TMVA::MethodPDEFoam::AddWeightsXMLTo( void* parent ) const
    gTools().AddAttr( wght, "TargetSelection", TargetSelectionToUInt(fTargetSelection) );
    gTools().AddAttr( wght, "FillFoamWithOrigWeights", fFillFoamWithOrigWeights );
    gTools().AddAttr( wght, "UseYesNoCell",    fUseYesNoCell );
-   
+
    // save foam borders Xmin[i], Xmax[i]
    void *xmin_wrap;
    for (UInt_t i=0; i<fXmin.size(); i++){
@@ -1170,17 +1172,17 @@ void TMVA::MethodPDEFoam::AddWeightsXMLTo( void* parent ) const
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::WriteFoamsToFile() const 
+void TMVA::MethodPDEFoam::WriteFoamsToFile() const
 {
    // Write PDEFoams to file
 
    // fill variable names into foam
-   FillVariableNamesToFoam();   
+   FillVariableNamesToFoam();
 
-   TString rfname( GetWeightFileName() ); 
+   TString rfname( GetWeightFileName() );
 
    // replace in case of txt weight file
-   rfname.ReplaceAll( TString(".") + gConfig().GetIONames().fWeightFileExtension + ".txt", ".xml" );   
+   rfname.ReplaceAll( TString(".") + gConfig().GetIONames().fWeightFileExtension + ".txt", ".xml" );
 
    // add foam indicator to distinguish from main weight file
    rfname.ReplaceAll( ".xml", "_foams.root" );
@@ -1197,7 +1199,7 @@ void TMVA::MethodPDEFoam::WriteFoamsToFile() const
    }
 
    rootFile->Close();
-   Log() << kINFO << "Foams written to file: " 
+   Log() << kINFO << "Foams written to file: "
          << gTools().Color("lightblue") << rfname << gTools().Color("reset") << Endl;
 }
 
@@ -1213,13 +1215,13 @@ void  TMVA::MethodPDEFoam::ReadWeightsFromStream( std::istream& istr )
    istr >> fnCells;                         // Number of Cells  (500)
    istr >> fnSampl;                         // Number of MC events per cell in build-up (1000)
    istr >> fnBin;                           // Number of bins in build-up (100)
-   istr >> fEvPerBin;                       // Maximum events (equiv.) per bin in buid-up (1000) 
+   istr >> fEvPerBin;                       // Maximum events (equiv.) per bin in buid-up (1000)
    istr >> fCompress;                       // compress output file
 
    Bool_t regr;
    istr >> regr;                            // regression foam
    SetAnalysisType( (regr ? Types::kRegression : Types::kClassification ) );
-   
+
    Bool_t CutNmin, CutRMSmin; // dummy for backwards compatib.
    Float_t RMSmin;            // dummy for backwards compatib.
    istr >> CutNmin;                         // cut on minimal number of events in cell
@@ -1248,9 +1250,9 @@ void  TMVA::MethodPDEFoam::ReadWeightsFromStream( std::istream& istr )
    fXmax.assign(kDim, 0);
 
    // read range
-   for (UInt_t i=0; i<kDim; i++) 
+   for (UInt_t i=0; i<kDim; i++)
       istr >> fXmin.at(i);
-   for (UInt_t i=0; i<kDim; i++) 
+   for (UInt_t i=0; i<kDim; i++)
       istr >> fXmax.at(i);
 
    // read pure foams from file
@@ -1258,7 +1260,7 @@ void  TMVA::MethodPDEFoam::ReadWeightsFromStream( std::istream& istr )
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::ReadWeightsFromXML( void* wghtnode ) 
+void TMVA::MethodPDEFoam::ReadWeightsFromXML( void* wghtnode )
 {
    // read PDEFoam variables from xml weight file
 
@@ -1290,7 +1292,7 @@ void TMVA::MethodPDEFoam::ReadWeightsFromXML( void* wghtnode )
       gTools().ReadAttr( wghtnode, "FillFoamWithOrigWeights", fFillFoamWithOrigWeights );
    if (gTools().HasAttr(wghtnode, "UseYesNoCell"))
       gTools().ReadAttr( wghtnode, "UseYesNoCell", fUseYesNoCell );
-   
+
    // clear old range [Xmin, Xmax] and prepare new range for reading
    fXmin.clear();
    fXmax.clear();
@@ -1323,7 +1325,7 @@ void TMVA::MethodPDEFoam::ReadWeightsFromXML( void* wghtnode )
 
    // if foams exist, delete them
    DeleteFoams();
-   
+
    // read pure foams from file
    ReadFoamsFromFile();
 
@@ -1379,7 +1381,7 @@ void TMVA::MethodPDEFoam::ReadFoamsFromFile()
 {
    // read foams from file
 
-   TString rfname( GetWeightFileName() ); 
+   TString rfname( GetWeightFileName() );
 
    // replace in case of txt weight file
    rfname.ReplaceAll( TString(".") + gConfig().GetIONames().fWeightFileExtension + ".txt", ".xml" );
@@ -1387,7 +1389,7 @@ void TMVA::MethodPDEFoam::ReadFoamsFromFile()
    // add foam indicator to distinguish from main weight file
    rfname.ReplaceAll( ".xml", "_foams.root" );
 
-   Log() << kINFO << "Read foams from file: " << gTools().Color("lightblue") 
+   Log() << kINFO << "Read foams from file: " << gTools().Color("lightblue")
          << rfname << gTools().Color("reset") << Endl;
    TFile *rootFile = new TFile( rfname, "READ" );
    if (rootFile->IsZombie()) Log() << kFATAL << "Cannot open file \"" << rfname << "\"" << Endl;
@@ -1457,7 +1459,7 @@ TMVA::ETargetSelection TMVA::MethodPDEFoam::UIntToTargetSelection(UInt_t its)
 }
 
 //_______________________________________________________________________
-void TMVA::MethodPDEFoam::FillVariableNamesToFoam() const 
+void TMVA::MethodPDEFoam::FillVariableNamesToFoam() const
 {
    // store the variable names in all foams
    for (UInt_t ifoam=0; ifoam<fFoam.size(); ifoam++) {
@@ -1467,7 +1469,7 @@ void TMVA::MethodPDEFoam::FillVariableNamesToFoam() const
          else
             fFoam.at(ifoam)->AddVariableName(DataInfo().GetVariableInfo(idim).GetExpression().Data());
       }
-   }   
+   }
 }
 
 //_______________________________________________________________________
