@@ -99,6 +99,7 @@
 #include "TKey.h"
 #include "TVector.h"
 #include "TXMLEngine.h"
+#include "TMath.h"
 
 #include <cstdlib>
 
@@ -324,7 +325,7 @@ TString TMVA::Reader::GetMethodTypeFromFile( const TString& filename )
 {
    // read the method type from the file
 
-   ifstream fin( filename );
+   std::ifstream fin( filename );
    if (!fin.good()) { // file not found --> Error
       Log() << kFATAL << "<BookMVA> fatal error: "
             << "unable to open input weight file: " << filename << Endl;
@@ -419,7 +420,7 @@ TMVA::IMethod* TMVA::Reader::BookMVA( TMVA::Types::EMVA methodType, const TStrin
 TMVA::IMethod* TMVA::Reader::BookMVA( TMVA::Types::EMVA methodType, const char* xmlstr )
 {
 
-#if (ROOT_VERSION_CODE >= 334336) // 5.26/00
+#if (ROOT_SVN_REVISION >= 32259) && (ROOT_VERSION_CODE >= 334336) // 5.26/00
 
    // books MVA method from weightfile
    IMethod* im = ClassifierFactory::Instance().Create(std::string(Types::Instance().GetMethodName( methodType )),
@@ -463,7 +464,7 @@ TMVA::IMethod* TMVA::Reader::BookMVA( TMVA::Types::EMVA methodType, const char*
 //_______________________________________________________________________
 Double_t TMVA::Reader::EvaluateMVA( const std::vector<Float_t>& inputVec, const TString& methodTag, Double_t aux )
 {
-   // Evaluate a vector<float> of input data for a given method
+   // Evaluate a std::vector<float> of input data for a given method
    // The parameter aux is obligatory for the cuts method where it represents the efficiency cutoff
 
    // create a temporary event from the vector.
@@ -473,6 +474,13 @@ Double_t TMVA::Reader::EvaluateMVA( const std::vector<Float_t>& inputVec, const
 
 //   Event* tmpEvent=new Event(inputVec, 2); // ToDo resolve magic 2 issue
    Event* tmpEvent=new Event(inputVec, DataInfo().GetNVariables()); // is this the solution?
+   for (UInt_t i=0; i<inputVec.size(); i++){
+     if (TMath::IsNaN(inputVec[i])) {
+       Log() << kERROR << i << "-th variable of the event is NaN --> return MVA value -999, \n that's all I can do, please fix or remove this event." << Endl;
+       delete tmpEvent;
+       return -999;
+     }
+   }
 
    if (meth->GetMethodType() == TMVA::Types::kCuts) {
       TMVA::MethodCuts* mc = dynamic_cast<TMVA::MethodCuts*>(meth);
@@ -487,7 +495,7 @@ Double_t TMVA::Reader::EvaluateMVA( const std::vector<Float_t>& inputVec, const
 //_______________________________________________________________________
 Double_t TMVA::Reader::EvaluateMVA( const std::vector<Double_t>& inputVec, const TString& methodTag, Double_t aux )
 {
-   // Evaluate a vector<double> of input data for a given method
+   // Evaluate a std::vector<double> of input data for a given method
    // The parameter aux is obligatory for the cuts method where it represents the efficiency cutoff
 
    // performs a copy to float values which are internally used by all methods
@@ -521,6 +529,15 @@ Double_t TMVA::Reader::EvaluateMVA( const TString& methodTag, Double_t aux )
    if(kl==0)
       Log() << kFATAL << methodTag << " is not a method" << Endl;
 
+   // check for NaN in event data:  (note: in the factory, this check was done already at the creation of the datasets, hence
+   // it is not again checked in each of these subsequet calls..
+   const Event* ev = kl->GetEvent();
+   for (UInt_t i=0; i<ev->GetNVariables(); i++){
+     if (TMath::IsNaN(ev->GetValue(i))) {
+       Log() << kERROR << i << "-th variable of the event is NaN --> return MVA value -999, \n that's all I can do, please fix or remove this event." << Endl;
+       return -999;
+     }
+   }
    return this->EvaluateMVA( kl, aux );
 }
 
@@ -560,6 +577,14 @@ const std::vector< Float_t >& TMVA::Reader::EvaluateRegression( const TString& m
 
    if(kl==0)
       Log() << kFATAL << methodTag << " is not a method" << Endl;
+   // check for NaN in event data:  (note: in the factory, this check was done already at the creation of the datasets, hence
+   // it is not again checked in each of these subsequet calls..
+   const Event* ev = kl->GetEvent();
+   for (UInt_t i=0; i<ev->GetNVariables(); i++){
+     if (TMath::IsNaN(ev->GetValue(i))) {
+       Log() << kERROR << i << "-th variable of the event is NaN, \n regression values might evaluate to .. what do I know. \n sorry this warning is all I can do, please fix or remove this event." << Endl;
+     }
+   }
 
    return this->EvaluateRegression( kl, aux );
 }
@@ -568,6 +593,14 @@ const std::vector< Float_t >& TMVA::Reader::EvaluateRegression( const TString& m
 const std::vector< Float_t >& TMVA::Reader::EvaluateRegression( MethodBase* method, Double_t /*aux*/ )
 {
    // evaluates the regression MVA
+   // check for NaN in event data:  (note: in the factory, this check was done already at the creation of the datasets, hence
+   // it is not again checked in each of these subsequet calls..
+   const Event* ev = method->GetEvent();
+   for (UInt_t i=0; i<ev->GetNVariables(); i++){
+     if (TMath::IsNaN(ev->GetValue(i))) {
+       Log() << kERROR << i << "-th variable of the event is NaN, \n regression values might evaluate to .. what do I know. \n sorry this warning is all I can do, please fix or remove this event." << Endl;
+     }
+   }
    return method->GetRegressionValues();
 }
 
@@ -606,6 +639,15 @@ const std::vector< Float_t >& TMVA::Reader::EvaluateMulticlass( const TString& m
 
    if(kl==0)
       Log() << kFATAL << methodTag << " is not a method" << Endl;
+   // check for NaN in event data:  (note: in the factory, this check was done already at the creation of the datasets, hence
+   // it is not again checked in each of these subsequet calls..
+
+   const Event* ev = kl->GetEvent();
+   for (UInt_t i=0; i<ev->GetNVariables(); i++){
+     if (TMath::IsNaN(ev->GetValue(i))) {
+       Log() << kERROR << i << "-th variable of the event is NaN, \n regression values might evaluate to .. what do I know. \n sorry this warning is all I can do, please fix or remove this event." << Endl;
+     }
+   }
 
    return this->EvaluateMulticlass( kl, aux );
 }
@@ -614,6 +656,14 @@ const std::vector< Float_t >& TMVA::Reader::EvaluateMulticlass( const TString& m
 const std::vector< Float_t >& TMVA::Reader::EvaluateMulticlass( MethodBase* method, Double_t /*aux*/ )
 {
    // evaluates the multiclass MVA
+   // check for NaN in event data:  (note: in the factory, this check was done already at the creation of the datasets, hence
+   // it is not again checked in each of these subsequet calls..
+   const Event* ev = method->GetEvent();
+   for (UInt_t i=0; i<ev->GetNVariables(); i++){
+     if (TMath::IsNaN(ev->GetValue(i))) {
+       Log() << kERROR << i << "-th variable of the event is NaN, \n regression values might evaluate to .. what do I know. \n sorry this warning is all I can do, please fix or remove this event." << Endl;
+     }
+   }
    return method->GetMulticlassValues();
 }
 
@@ -665,6 +715,15 @@ Double_t TMVA::Reader::GetProba( const TString& methodTag,  Double_t ap_sig, Dou
 
    MethodBase* kl = dynamic_cast<MethodBase*>(method);
    if(kl==0) return -1;
+   // check for NaN in event data:  (note: in the factory, this check was done already at the creation of the datasets, hence
+   // it is not again checked in each of these subsequet calls..
+   const Event* ev = kl->GetEvent();
+   for (UInt_t i=0; i<ev->GetNVariables(); i++){
+     if (TMath::IsNaN(ev->GetValue(i))) {
+       Log() << kERROR << i << "-th variable of the event is NaN --> return MVA value -999, \n that's all I can do, please fix or remove this event." << Endl;
+       return -999;
+     }
+   }
 
    if (mvaVal == -9999999) mvaVal = kl->GetMvaValue();
 
@@ -686,6 +745,15 @@ Double_t TMVA::Reader::GetRarity( const TString& methodTag, Double_t mvaVal )
 
    MethodBase* kl = dynamic_cast<MethodBase*>(method);
    if(kl==0) return -1;
+   // check for NaN in event data:  (note: in the factory, this check was done already at the creation of the datasets, hence
+   // it is not again checked in each of these subsequet calls..
+   const Event* ev = kl->GetEvent();
+   for (UInt_t i=0; i<ev->GetNVariables(); i++){
+     if (TMath::IsNaN(ev->GetValue(i))) {
+       Log() << kERROR << i << "-th variable of the event is NaN --> return MVA value -999, \n that's all I can do, please fix or remove this event." << Endl;
+       return -999;
+     }
+   }
 
    if (mvaVal == -9999999) mvaVal = kl->GetMvaValue();
 
