@@ -60,7 +60,7 @@ void TMVA::VariableRearrangeTransform::Initialize()
 }
 
 //_______________________________________________________________________
-Bool_t TMVA::VariableRearrangeTransform::PrepareTransformation( const std::vector<Event*>& /*events*/ )
+Bool_t TMVA::VariableRearrangeTransform::PrepareTransformation (const std::vector<Event*>& /*events*/)
 {
    // prepare transformation --> (nothing to do)
    if (!IsEnabled() || IsCreated()) return kTRUE;
@@ -149,7 +149,7 @@ void TMVA::VariableRearrangeTransform::ReadFromXML( void* trfnode )
 }
 
 //_______________________________________________________________________
-void TMVA::VariableRearrangeTransform::PrintTransformation( ostream& ) 
+void TMVA::VariableRearrangeTransform::PrintTransformation( std::ostream& ) 
 {
    // prints the transformation ranges
 }
