@@ -451,7 +451,7 @@ void TMVA::VariableTransformBase::CountVariableTypes( UInt_t& nvars, UInt_t& ntg
 
 
 //_______________________________________________________________________
-void TMVA::VariableTransformBase::CalcNorm( const std::vector<Event*>& events ) 
+void TMVA::VariableTransformBase::CalcNorm( const std::vector<const Event*>& events ) 
 {
    // TODO --> adapt to variable,target,spectator selection
    // method to calculate minimum, maximum, mean, and RMS for all
@@ -781,8 +781,10 @@ void TMVA::VariableTransformBase::MakeFunction( std::ostream& fout, const TStrin
    if( part == 0 ){ // definitions
       fout << std::endl;
       fout << "   // define the indices of the variables which are transformed by this transformation" << std::endl;
-      fout << "   std::vector<int> indicesGet;" << std::endl;
-      fout << "   std::vector<int> indicesPut;" << std::endl << std::endl;
+      fout << "   static std::vector<int> indicesGet;" << std::endl;
+      fout << "   static std::vector<int> indicesPut;" << std::endl << std::endl;
+      fout << "   if ( indicesGet.empty() ) { " << std::endl;
+      fout << "      indicesGet.reserve(fNvars);" << std::endl;
 
       for( ItVarTypeIdxConst itEntry = fGet.begin(), itEntryEnd = fGet.end(); itEntry != itEntryEnd; ++itEntry ) {
 	 Char_t type = (*itEntry).first;
@@ -790,7 +792,7 @@ void TMVA::VariableTransformBase::MakeFunction( std::ostream& fout, const TStrin
 	 
 	 switch( type ) {
 	 case 'v':
-	    fout << "   indicesGet.push_back( " << idx << ");" << std::endl;
+	    fout << "      indicesGet.push_back( " << idx << ");" << std::endl;
 	    break;
 	 case 't':
 	    Log() << kWARNING << "MakeClass doesn't work with transformation of targets. The results will be wrong!" << Endl;
@@ -802,6 +804,9 @@ void TMVA::VariableTransformBase::MakeFunction( std::ostream& fout, const TStrin
 	    Log() << kFATAL << "VariableTransformBase/GetInput : unknown type '" << type << "'." << Endl;
 	 }
       }
+      fout << "   } " <<  std::endl;
+      fout << "   if ( indicesPut.empty() ) { " << std::endl;
+      fout << "      indicesPut.reserve(fNvars);" << std::endl;
 
       for( ItVarTypeIdxConst itEntry = fPut.begin(), itEntryEnd = fPut.end(); itEntry != itEntryEnd; ++itEntry ) {
 	 Char_t type = (*itEntry).first;
@@ -809,7 +814,7 @@ void TMVA::VariableTransformBase::MakeFunction( std::ostream& fout, const TStrin
 
 	 switch( type ) {
 	 case 'v':
-	    fout << "   indicesPut.push_back( " << idx << ");" << std::endl;
+	    fout << "      indicesPut.push_back( " << idx << ");" << std::endl;
 	    break;
 	 case 't':
 	    Log() << kWARNING << "MakeClass doesn't work with transformation of targets. The results will be wrong!" << Endl;
@@ -822,6 +827,7 @@ void TMVA::VariableTransformBase::MakeFunction( std::ostream& fout, const TStrin
 	 }
       }
 
+      fout << "   } " <<  std::endl;
       fout << std::endl;
 
    }else if( part == 1){ 
