@@ -45,7 +45,7 @@ h1f.Fit( 'sqroot' )
 fitlabel = TPaveText( 0.6, 0.3, 0.9, 0.80, 'NDC' )
 fitlabel.SetTextAlign( 12 )
 fitlabel.SetFillColor( 42 )
-fitlabel.ReadFile( 'fit1_C.C' )
+fitlabel.ReadFile( 'fit1_py.py' )
 fitlabel.Draw()
 c1.Update()
 gBenchmark.Show( 'fit1' )
